@@ -2,14 +2,14 @@ var class_ogre_1_1_d3_d11_render_system =
 [
     [ "D3D11RenderSystem", "class_ogre_1_1_d3_d11_render_system.html#ac204c162cda5ee29ae4b236383069735", null ],
     [ "~D3D11RenderSystem", "class_ogre_1_1_d3_d11_render_system.html#aad4e30395ccb5bcb6588f09c44e9b22e", null ],
-    [ "_addMetrics", "class_ogre_1_1_d3_d11_render_system.html#ab4c80dcdf2f20df687035fb8c72797ea", null ],
+    [ "_addMetrics", "class_ogre_1_1_d3_d11_render_system.html#a54ebaf329b7173ef06cbfcd0dff64cb5", null ],
     [ "_beginFrame", "class_ogre_1_1_d3_d11_render_system.html#a54c46af02f13834611169c2c164245ed", null ],
     [ "_beginFrameOnce", "class_ogre_1_1_d3_d11_render_system.html#ada60763d5b8ef9cfba1c77ecfe3e4188", null ],
     [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d11_render_system.html#a93ef27c77c394d18f8c1ba6361dbef98", null ],
     [ "_clearStateAndFlushCommandBuffer", "class_ogre_1_1_d3_d11_render_system.html#a0ac925a45fca27d13d4272c5da750220", null ],
     [ "_convertOpenVrProjectionMatrix", "class_ogre_1_1_d3_d11_render_system.html#ad05022b35e523cdba22d993a51fc4b78", null ],
     [ "_convertProjectionMatrix", "class_ogre_1_1_d3_d11_render_system.html#a2228dcfce5ec360f8f421f9544872f01", null ],
-    [ "_createRenderWindow", "class_ogre_1_1_d3_d11_render_system.html#a5ec0565aa70a8bf7c23484189ab3384e", null ],
+    [ "_createRenderWindow", "class_ogre_1_1_d3_d11_render_system.html#a44249e33fa42911c8c3e29279a23a4a0", null ],
     [ "_createRenderWindows", "class_ogre_1_1_d3_d11_render_system.html#a2d1a6b690161dcd972d7cfc13b59dc10", null ],
     [ "_dereferenceSharedDepthBuffer", "class_ogre_1_1_d3_d11_render_system.html#a24604b2949b6dfe884b7d87b9ebaf0cc", null ],
     [ "_descriptorSetSamplerCreated", "class_ogre_1_1_d3_d11_render_system.html#a5b3f8e6370d6df438402da2053e0cb54", null ],
@@ -23,13 +23,12 @@ var class_ogre_1_1_d3_d11_render_system =
     [ "_dispatch", "class_ogre_1_1_d3_d11_render_system.html#a108ffebb978c11bab8cf6b00af6ddbfd", null ],
     [ "_endFrame", "class_ogre_1_1_d3_d11_render_system.html#a60a4f07569425d0f0eaaba15ba1354c5", null ],
     [ "_endFrameOnce", "class_ogre_1_1_d3_d11_render_system.html#a7918658f5c363617c53f6179d23e63fc", null ],
-    [ "_executeResourceTransition", "class_ogre_1_1_d3_d11_render_system.html#a0c157a039184ac45bf575fb0d00601de", null ],
-    [ "_getBoundComputeProgram", "class_ogre_1_1_d3_d11_render_system.html#a9d3ba8b196457507a188fdfc0345da5d", null ],
-    [ "_getCurrentRenderViewport", "class_ogre_1_1_d3_d11_render_system.html#a8bd773d225cea6b0aee804c3c5b2a945", null ],
-    [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_d3_d11_render_system.html#a3c2256419916cbf7777c9bf8b1f3d716", null ],
-    [ "_getDevice", "class_ogre_1_1_d3_d11_render_system.html#afd58a20fc530467210747dbd715de8fa", null ],
+    [ "_getBoundComputeProgram", "class_ogre_1_1_d3_d11_render_system.html#a429bda5fbb42b3426e8ec9ac5f08835b", null ],
+    [ "_getCurrentRenderViewport", "class_ogre_1_1_d3_d11_render_system.html#a51cbd7a790f8bad97ac8983e00fcbfb2", null ],
+    [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_d3_d11_render_system.html#a6a719f86bcb5458d55bd0cd887f3ed3e", null ],
+    [ "_getDevice", "class_ogre_1_1_d3_d11_render_system.html#a6aae48bb613d39294f7591252cb11927", null ],
     [ "_getFeatureLevel", "class_ogre_1_1_d3_d11_render_system.html#aa7e43dffc65f93ba22f51268a218d7f1", null ],
-    [ "_getFrameBufferDescMap", "class_ogre_1_1_d3_d11_render_system.html#ac32711b3e57c29fedcc414c9138dc84a", null ],
+    [ "_getFrameBufferDescMap", "class_ogre_1_1_d3_d11_render_system.html#adb76175cbff4999b9b25d01862e636a6", null ],
     [ "_hlmsBlendblockCreated", "class_ogre_1_1_d3_d11_render_system.html#abbf3f4044624a7828962886880ce0cfa", null ],
     [ "_hlmsBlendblockDestroyed", "class_ogre_1_1_d3_d11_render_system.html#a26a83f5a987b7f089e0425fc81e03541", null ],
     [ "_hlmsComputePipelineStateObjectCreated", "class_ogre_1_1_d3_d11_render_system.html#a3a391f94b7eacb10aaa16ada32183767", null ],
@@ -40,10 +39,10 @@ var class_ogre_1_1_d3_d11_render_system =
     [ "_hlmsPipelineStateObjectDestroyed", "class_ogre_1_1_d3_d11_render_system.html#a3e65cdf108e22b556d602cec600da0ea", null ],
     [ "_hlmsSamplerblockCreated", "class_ogre_1_1_d3_d11_render_system.html#a7e50f9245426bfd78b0422fb899dfb26", null ],
     [ "_hlmsSamplerblockDestroyed", "class_ogre_1_1_d3_d11_render_system.html#a8a5c0096505ceb84aea7e7c8945ab6fe", null ],
-    [ "_initialise", "class_ogre_1_1_d3_d11_render_system.html#a01cff1f0abd9c23d88e2eed872dcadbf", null ],
+    [ "_initialise", "class_ogre_1_1_d3_d11_render_system.html#a28b563169183c9fd222e91fe5d8cac70", null ],
     [ "_makeRsProjectionMatrix", "class_ogre_1_1_d3_d11_render_system.html#a37208fe7f2e29b71a2972defdf9d04b2", null ],
     [ "_notifyWindowDestroyed", "class_ogre_1_1_d3_d11_render_system.html#a3247a609430cf6bcbd63acedba80f402", null ],
-    [ "_pauseFrame", "class_ogre_1_1_d3_d11_render_system.html#a9893de6903d77fe231da1135f5ee00db", null ],
+    [ "_pauseFrame", "class_ogre_1_1_d3_d11_render_system.html#a20ef2d587957ef999a1ecb8459f3db36", null ],
     [ "_render", "class_ogre_1_1_d3_d11_render_system.html#a94ec96fa5fecb9aa5761c4e56abd01f4", null ],
     [ "_render", "class_ogre_1_1_d3_d11_render_system.html#a5bc6482cb17b2519658302a4aa0b2415", null ],
     [ "_render", "class_ogre_1_1_d3_d11_render_system.html#a31a06ff4de93e0321d7fde974ebcb0cb", null ],
@@ -56,8 +55,6 @@ var class_ogre_1_1_d3_d11_render_system =
     [ "_renderNoBaseInstance", "class_ogre_1_1_d3_d11_render_system.html#adf4faec7fb049bc5092605c526cf1d72", null ],
     [ "_renderNoBaseInstance", "class_ogre_1_1_d3_d11_render_system.html#a85520f23e22840e951573681d4baef4f", null ],
     [ "_resetMetrics", "class_ogre_1_1_d3_d11_render_system.html#ac277fde4bc118aab022798181aa9afeb", null ],
-    [ "_resourceTransitionCreated", "class_ogre_1_1_d3_d11_render_system.html#adceb84c1be629865821a15c74d4f0c4f", null ],
-    [ "_resourceTransitionDestroyed", "class_ogre_1_1_d3_d11_render_system.html#a3aef1fb3705642dca6e6c243c456cca1", null ],
     [ "_resumeFrame", "class_ogre_1_1_d3_d11_render_system.html#abe9b7d178eb5d0ea90c7b9a35f612f91", null ],
     [ "_setBindingType", "class_ogre_1_1_d3_d11_render_system.html#a49569630a204d19796c0fbdec50c74fe", null ],
     [ "_setComputePso", "class_ogre_1_1_d3_d11_render_system.html#a95316a99c72a803d059b4abe8628b4b8", null ],
@@ -78,7 +75,7 @@ var class_ogre_1_1_d3_d11_render_system =
     [ "_setSurfaceParams", "class_ogre_1_1_d3_d11_render_system.html#a79b7ca9a17491099296c2a15bf799579", null ],
     [ "_setTessellationDomainTexture", "class_ogre_1_1_d3_d11_render_system.html#a87909ce773374c07bfa292d07bb90313", null ],
     [ "_setTessellationHullTexture", "class_ogre_1_1_d3_d11_render_system.html#addc451361abf88961a07c053b3acfe86", null ],
-    [ "_setTexture", "class_ogre_1_1_d3_d11_render_system.html#ab745610636ef6f5c7cd75e42b3e8f37e", null ],
+    [ "_setTexture", "class_ogre_1_1_d3_d11_render_system.html#af1501220b945f8028d88430867305afc", null ],
     [ "_setTextureBlendMode", "class_ogre_1_1_d3_d11_render_system.html#a1ef5ea3c20b27af514a7946ce3324873", null ],
     [ "_setTextureCoordCalculation", "class_ogre_1_1_d3_d11_render_system.html#aabb14d9c91c780f4641c283053f10d37", null ],
     [ "_setTextureMatrix", "class_ogre_1_1_d3_d11_render_system.html#a09f0a693271b46182a4fde117b6a7d7b", null ],
@@ -100,6 +97,7 @@ var class_ogre_1_1_d3_d11_render_system =
     [ "addClipPlane", "class_ogre_1_1_d3_d11_render_system.html#abe0fbe6b4972baf14137235fe3f6c499", null ],
     [ "addClipPlane", "class_ogre_1_1_d3_d11_render_system.html#a2eb75175291761881bdc0d73ec379089", null ],
     [ "addListener", "class_ogre_1_1_d3_d11_render_system.html#ada5d01c8a4eb8e64140d92fce245800c", null ],
+    [ "addSharedListener", "class_ogre_1_1_d3_d11_render_system.html#a89fe3734e6d495bfb73624ef269305cf", null ],
     [ "addToSwitchingFullscreenCounter", "class_ogre_1_1_d3_d11_render_system.html#abdc4aec8f1b64830480c62384db5def4", null ],
     [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_d3_d11_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
     [ "beginGPUSampleProfile", "class_ogre_1_1_d3_d11_render_system.html#a5f01e9e844268a77ba854188dc9cb656", null ],
@@ -109,55 +107,67 @@ var class_ogre_1_1_d3_d11_render_system =
     [ "bindGpuProgramPassIterationParameters", "class_ogre_1_1_d3_d11_render_system.html#ad02c0c838045830a7fdea3557635bf34", null ],
     [ "checkExtension", "class_ogre_1_1_d3_d11_render_system.html#ae869e9f5ca12313ee49fa0743dbcf1f3", null ],
     [ "clearFrameBuffer", "class_ogre_1_1_d3_d11_render_system.html#a3b5dcd62885de5a20c1574a12c2c84be", null ],
+    [ "compositorWorkspaceBegin", "class_ogre_1_1_d3_d11_render_system.html#a90d567191f24a30cb806ab0a146bf8b2", null ],
+    [ "compositorWorkspaceEnd", "class_ogre_1_1_d3_d11_render_system.html#ab732bb02d12b702817772ccf4973a47f", null ],
+    [ "compositorWorkspaceUpdate", "class_ogre_1_1_d3_d11_render_system.html#a2d2d776006ee7a9fa8fae1ac14265177", null ],
     [ "convertColourValue", "class_ogre_1_1_d3_d11_render_system.html#a80d543b61b1152b0dd0049961be4798e", null ],
-    [ "createDepthBufferFor", "class_ogre_1_1_d3_d11_render_system.html#a7cf573d5dae00ad59702f197bb79121f", null ],
-    [ "createHardwareOcclusionQuery", "class_ogre_1_1_d3_d11_render_system.html#aa9007109ddfcf4b13d45318c5cc71cc9", null ],
-    [ "createRenderPassDescriptor", "class_ogre_1_1_d3_d11_render_system.html#aba89661f023e4a771693b8f5e6c59b31", null ],
+    [ "createDepthBufferFor", "class_ogre_1_1_d3_d11_render_system.html#ac25a4eb8d691840f0d186d5fa38f9545", null ],
+    [ "createHardwareOcclusionQuery", "class_ogre_1_1_d3_d11_render_system.html#ab3468b989361b95a0c94326a26e9c3bf", null ],
+    [ "createRenderPassDescriptor", "class_ogre_1_1_d3_d11_render_system.html#a5c37ecfb395ab640f043bd1469e25499", null ],
+    [ "debugAnnotationPop", "class_ogre_1_1_d3_d11_render_system.html#ae6c671a9cd854d9e63b7835adf5fb5f3", null ],
+    [ "debugAnnotationPush", "class_ogre_1_1_d3_d11_render_system.html#aee386488e95d3a4b75a9dcd1a91c7336", null ],
     [ "deinitGPUProfiling", "class_ogre_1_1_d3_d11_render_system.html#ab8c247cac7c3dfb658577d1c719a4f1c", null ],
     [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_d3_d11_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
     [ "destroyRenderPassDescriptor", "class_ogre_1_1_d3_d11_render_system.html#a60e5ffa2ec8f2709435c3d11e8a321f6", null ],
     [ "destroyRenderWindow", "class_ogre_1_1_d3_d11_render_system.html#a36a560a1e0e171b9a1a19a2748e6dd15", null ],
     [ "enableClipPlane", "class_ogre_1_1_d3_d11_render_system.html#a69a555814009c44e88bdc5ab9257dbde", null ],
+    [ "endCopyEncoder", "class_ogre_1_1_d3_d11_render_system.html#a30b893cdd07ccd24f95623ebef2668b7", null ],
+    [ "endGpuDebuggerFrameCapture", "class_ogre_1_1_d3_d11_render_system.html#a0a72b69bed67cdf99239d884748bcb08", null ],
     [ "endGPUSampleProfile", "class_ogre_1_1_d3_d11_render_system.html#a77145f52d931b96a3fbf147fef635fb1", null ],
     [ "endProfileEvent", "class_ogre_1_1_d3_d11_render_system.html#aab0676ba6ae8c9713630cb30b54d467b", null ],
     [ "endRenderPassDescriptor", "class_ogre_1_1_d3_d11_render_system.html#a3f5e49730a9ffa1a7bcc1b9dac875ac8", null ],
     [ "executeRenderPassDescriptorDelayedActions", "class_ogre_1_1_d3_d11_render_system.html#a3dc08052db357beff034cad183fdfadc", null ],
-    [ "fireDeviceEvent", "class_ogre_1_1_d3_d11_render_system.html#ae3bb26236aa304060a2de7dd2eb1c406", null ],
-    [ "fireDeviceEvent", "class_ogre_1_1_d3_d11_render_system.html#a0a58444437763ea3d1cf373327eae3d6", null ],
+    [ "executeResourceTransition", "class_ogre_1_1_d3_d11_render_system.html#ad6efb4ed490715cf068fca69b689403d", null ],
+    [ "fireDeviceEvent", "class_ogre_1_1_d3_d11_render_system.html#a352db40a4a6ed3e770718f4b1e6f71ee", null ],
+    [ "fireSharedEvent", "class_ogre_1_1_d3_d11_render_system.html#add0b3b86b8ec2f51d8973b6b3e06448e", null ],
     [ "flushCommands", "class_ogre_1_1_d3_d11_render_system.html#a6266fa40499c9b823b46625b328f549a", null ],
-    [ "flushUAVs", "class_ogre_1_1_d3_d11_render_system.html#a8f3a51af4d8740ccc177902c92588bb1", null ],
-    [ "getCapabilities", "class_ogre_1_1_d3_d11_render_system.html#ac4b66fe49129476323eba9bdca672a36", null ],
+    [ "getBarrierSolver", "class_ogre_1_1_d3_d11_render_system.html#a66b206faf53b0b3ff54b10153c76b66f", null ],
+    [ "getBoundUav", "class_ogre_1_1_d3_d11_render_system.html#afb6f61d5c70531c1eb718cdfbefb0330", null ],
+    [ "getCapabilities", "class_ogre_1_1_d3_d11_render_system.html#aa6c951fc82f49ccf22787fcd1e7ee451", null ],
     [ "getColourVertexElementType", "class_ogre_1_1_d3_d11_render_system.html#a727ba3d6c45aa06daed47d9b54376ed3", null ],
-    [ "getConfigOptions", "class_ogre_1_1_d3_d11_render_system.html#a45d72b2e6d378f6ded36e68a26156530", null ],
-    [ "getCurrentPassDescriptor", "class_ogre_1_1_d3_d11_render_system.html#a6ec66a0d8c51ded50185ac9f90670ae4", null ],
-    [ "getCurrentRenderViewports", "class_ogre_1_1_d3_d11_render_system.html#a4f52275d3e3248a49318e3c584bf5515", null ],
+    [ "getConfigOptions", "class_ogre_1_1_d3_d11_render_system.html#a148532e4a1628afb33e70aa230da7219", null ],
+    [ "getCurrentPassDescriptor", "class_ogre_1_1_d3_d11_render_system.html#a56f9ba2b074ce74b1e1aed293b5fc6a0", null ],
+    [ "getCurrentRenderViewports", "class_ogre_1_1_d3_d11_render_system.html#a5c3cbe94dd790fa8083aedbbc146edcb", null ],
     [ "getCustomAttribute", "class_ogre_1_1_d3_d11_render_system.html#a42552a0f44d6234e3b9b4a09a6fcb4e7", null ],
     [ "getDebugShaders", "class_ogre_1_1_d3_d11_render_system.html#a05dbfafd87ccda8119c289c266e41ec1", null ],
-    [ "getDepthBufferFor", "class_ogre_1_1_d3_d11_render_system.html#a338829c9e5e3ef7e155c232f64c6a20e", null ],
+    [ "getDepthBufferFor", "class_ogre_1_1_d3_d11_render_system.html#af088707ac4e0c0a0904a50fdc74b7325", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_d3_d11_render_system.html#a8d9a996201d2fdbd5db0b69c5f70c5a4", null ],
-    [ "getDriverVersion", "class_ogre_1_1_d3_d11_render_system.html#a6e6521ead351b0b7a8b2cc519b5f4dd6", null ],
+    [ "getDriverVersion", "class_ogre_1_1_d3_d11_render_system.html#ac7d381c6d59bc7b3d4483746f04e2a90", null ],
     [ "getErrorDescription", "class_ogre_1_1_d3_d11_render_system.html#aab1eb2dd87981c77b475a10a74eb90ba", null ],
-    [ "getFriendlyName", "class_ogre_1_1_d3_d11_render_system.html#a5557d9432d0bf160a7668c2af6205b2a", null ],
+    [ "getFriendlyName", "class_ogre_1_1_d3_d11_render_system.html#a9acd4281f7c6af5ed4c16a9f5bd00fa1", null ],
     [ "getGlobalInstanceVertexBuffer", "class_ogre_1_1_d3_d11_render_system.html#a2a859eea18cd0c3cf0c7876bbab862a4", null ],
-    [ "getGlobalInstanceVertexBufferVertexDeclaration", "class_ogre_1_1_d3_d11_render_system.html#a38924cc348317c9104797536eb29be13", null ],
+    [ "getGlobalInstanceVertexBufferVertexDeclaration", "class_ogre_1_1_d3_d11_render_system.html#ad1a30f09bb15daac26e8e10901525214", null ],
     [ "getGlobalNumberOfInstances", "class_ogre_1_1_d3_d11_render_system.html#af41e08cc1bc54e34d0314f4c9ffa58f6", null ],
     [ "getHorizontalTexelOffset", "class_ogre_1_1_d3_d11_render_system.html#aca19ecf0824bf34b0dae9211b0b2b104", null ],
+    [ "getInvertedClipSpaceY", "class_ogre_1_1_d3_d11_render_system.html#a9742abc3eb4609b4fc9cbd7df1051661", null ],
     [ "getInvertVertexWinding", "class_ogre_1_1_d3_d11_render_system.html#a133c89c9430091210e01ac44d638a0a3", null ],
     [ "getMaxBoundViewports", "class_ogre_1_1_d3_d11_render_system.html#a3a83f5a8128df163c7bed5a87a7ee923", null ],
     [ "getMaximumDepthInputValue", "class_ogre_1_1_d3_d11_render_system.html#af9f85102202b26e1b02c9391560cdec3", null ],
-    [ "getMetrics", "class_ogre_1_1_d3_d11_render_system.html#a2e51b45ee14fa30894f79bd9cff33c4a", null ],
+    [ "getMetrics", "class_ogre_1_1_d3_d11_render_system.html#a2c8b21df3f79f69fbcf304fa131cb1f9", null ],
     [ "getMinimumDepthInputValue", "class_ogre_1_1_d3_d11_render_system.html#acace301a6ac5c0ec16b55186abaf1e3a", null ],
-    [ "getMutableCapabilities", "class_ogre_1_1_d3_d11_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
-    [ "getName", "class_ogre_1_1_d3_d11_render_system.html#a208fb0a3bacba965472cf7601f2383fa", null ],
+    [ "getMutableCapabilities", "class_ogre_1_1_d3_d11_render_system.html#a7125b8a614f54a9750b85c5eba62b474", null ],
+    [ "getName", "class_ogre_1_1_d3_d11_render_system.html#a5227b91b73915987049e671a47f13b3c", null ],
     [ "getNativeShadingLanguageVersion", "class_ogre_1_1_d3_d11_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
-    [ "getPixelFormatToShaderType", "class_ogre_1_1_d3_d11_render_system.html#a7379a67f31058d1b2495e70e90ce704d", null ],
-    [ "getRenderSystemEvents", "class_ogre_1_1_d3_d11_render_system.html#a9a240df431ddcd945a4a3c1c1b59abbf", null ],
+    [ "getNumPriorityConfigOptions", "class_ogre_1_1_d3_d11_render_system.html#ad76e146b7e58edd27189e8fc25af2be9", null ],
+    [ "getPixelFormatToShaderType", "class_ogre_1_1_d3_d11_render_system.html#ad25d4a1451b198a772dff88b574f4d40", null ],
+    [ "getPriorityConfigOption", "class_ogre_1_1_d3_d11_render_system.html#a90de8a1ac6801617fb49acc2142efc27", null ],
+    [ "getRenderDocApi", "class_ogre_1_1_d3_d11_render_system.html#a5d8f84c242a383d007beabf72b11ef76", null ],
+    [ "getRenderSystemEvents", "class_ogre_1_1_d3_d11_render_system.html#aeca02905d47fa75bfb87a4c07e68d02d", null ],
     [ "getRSDepthRange", "class_ogre_1_1_d3_d11_render_system.html#a4be8db64459468925237b45d87958f26", null ],
-    [ "getSharedListener", "class_ogre_1_1_d3_d11_render_system.html#af759d985eae38988d9a5b381b81dd22e", null ],
-    [ "getStencilBufferParams", "class_ogre_1_1_d3_d11_render_system.html#a18884872c80f71ca0fb55e3b287b39af", null ],
+    [ "getStencilBufferParams", "class_ogre_1_1_d3_d11_render_system.html#a0a9b24e0640279f6b6fa90613727d585", null ],
     [ "getSwitchingFullscreenCounter", "class_ogre_1_1_d3_d11_render_system.html#a299abea89b152bf7ec7377b184727843", null ],
-    [ "getTextureGpuManager", "class_ogre_1_1_d3_d11_render_system.html#a85439e6174450882b61a78b85f27bfda", null ],
-    [ "getVaoManager", "class_ogre_1_1_d3_d11_render_system.html#a09e99446064460fd33ccfb4712b82407", null ],
+    [ "getTextureGpuManager", "class_ogre_1_1_d3_d11_render_system.html#a2fc23c559d6e15f6a2d0841bbdf7135a", null ],
+    [ "getVaoManager", "class_ogre_1_1_d3_d11_render_system.html#adacd8a9cdfaf24b2aab87289de657189", null ],
     [ "getVerticalTexelOffset", "class_ogre_1_1_d3_d11_render_system.html#a4d9151c508a7d1d7c15a64c6d874ada3", null ],
     [ "getWBufferEnabled", "class_ogre_1_1_d3_d11_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
     [ "handleDeviceLost", "class_ogre_1_1_d3_d11_render_system.html#afcc899b2dbf8c5dfa081cedc0e1d508e", null ],
@@ -167,24 +177,27 @@ var class_ogre_1_1_d3_d11_render_system =
     [ "initRenderSystem", "class_ogre_1_1_d3_d11_render_system.html#a4ae0f324bcc1a167b3dd11228df11369", null ],
     [ "isGpuProgramBound", "class_ogre_1_1_d3_d11_render_system.html#a1ac003196b5b51384f714924a0041081", null ],
     [ "isReverseDepth", "class_ogre_1_1_d3_d11_render_system.html#a780e5c6941c2f5d1f699dbf3e8c5b869", null ],
+    [ "isSameLayout", "class_ogre_1_1_d3_d11_render_system.html#a387d5fa07b1c096496ce6a97c4f68505", null ],
     [ "isStaticBufferLockable", "class_ogre_1_1_d3_d11_render_system.html#a319564dc746b19bb9a1490a473227b20", null ],
+    [ "loadRenderDocApi", "class_ogre_1_1_d3_d11_render_system.html#ab750bf02b8afe5aefce3a4594541904d", null ],
     [ "markProfileEvent", "class_ogre_1_1_d3_d11_render_system.html#a7342cb7a73ff462a89189aebf8035017", null ],
     [ "operator delete", "class_ogre_1_1_d3_d11_render_system.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
     [ "operator delete", "class_ogre_1_1_d3_d11_render_system.html#acb46d4b0a597156d9ba5abc39d127792", null ],
     [ "operator delete", "class_ogre_1_1_d3_d11_render_system.html#a1c727e879a260c37b00ce5505fe8e144", null ],
     [ "operator delete[]", "class_ogre_1_1_d3_d11_render_system.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
     [ "operator delete[]", "class_ogre_1_1_d3_d11_render_system.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-    [ "operator new", "class_ogre_1_1_d3_d11_render_system.html#ac4bdf968b7b9af8a5239a27da73d5711", null ],
-    [ "operator new", "class_ogre_1_1_d3_d11_render_system.html#a421b197ca3a38da17e2eb1531a645fa2", null ],
-    [ "operator new", "class_ogre_1_1_d3_d11_render_system.html#ab78a921e54419be677839cdf15d1f0b8", null ],
-    [ "operator new[]", "class_ogre_1_1_d3_d11_render_system.html#afa2943846ba6a2b5824a12857139cf5e", null ],
-    [ "operator new[]", "class_ogre_1_1_d3_d11_render_system.html#a4be37baef81876985aa1071ad5acc6dd", null ],
+    [ "operator new", "class_ogre_1_1_d3_d11_render_system.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
+    [ "operator new", "class_ogre_1_1_d3_d11_render_system.html#ab422c67a2c8844f410fe822a357cba3b", null ],
+    [ "operator new", "class_ogre_1_1_d3_d11_render_system.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
+    [ "operator new[]", "class_ogre_1_1_d3_d11_render_system.html#adce32528577d71b228692df906ecd17c", null ],
+    [ "operator new[]", "class_ogre_1_1_d3_d11_render_system.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
     [ "postExtraThreadsStarted", "class_ogre_1_1_d3_d11_render_system.html#ad4377ca9759ef65902a521747bb4a9fb", null ],
     [ "preExtraThreadsStarted", "class_ogre_1_1_d3_d11_render_system.html#a2f7492cd8867ab290b77b0e7d7000fc6", null ],
     [ "queueBindUAVs", "class_ogre_1_1_d3_d11_render_system.html#abd681ab591e98cfe37c76bdac2357d6e", null ],
     [ "registerThread", "class_ogre_1_1_d3_d11_render_system.html#a37015e208e5c0f268b37335540ec661b", null ],
     [ "reinitialise", "class_ogre_1_1_d3_d11_render_system.html#a0708f1a8dafa62e6293bbeb1f0ee2ce2", null ],
     [ "removeListener", "class_ogre_1_1_d3_d11_render_system.html#a7d9e3b4369f98e46dbea4cb4b9390f9d", null ],
+    [ "removeSharedListener", "class_ogre_1_1_d3_d11_render_system.html#a0c9650fccf5a5e54b8b933786bdbe4fb", null ],
     [ "resetClipPlanes", "class_ogre_1_1_d3_d11_render_system.html#a46a9b1385638112a80bf22fa1a5bf531", null ],
     [ "reverseCompareFunction", "class_ogre_1_1_d3_d11_render_system.html#a6a34f2ded473d4cbaeda6e954f76dbaf", null ],
     [ "setClipPlane", "class_ogre_1_1_d3_d11_render_system.html#a7f2f491968034d83d3c4c02d2adee196", null ],
@@ -202,13 +215,13 @@ var class_ogre_1_1_d3_d11_render_system =
     [ "setMetricsRecordingEnabled", "class_ogre_1_1_d3_d11_render_system.html#aabd963520ca3e4e48ad5d64eabc4d76d", null ],
     [ "setNormaliseNormals", "class_ogre_1_1_d3_d11_render_system.html#afcb37fb68532bbdd75dd1628684e001c", null ],
     [ "setShadingType", "class_ogre_1_1_d3_d11_render_system.html#a0c656abdfd9a0c433e315fa10b64fd4d", null ],
-    [ "setSharedListener", "class_ogre_1_1_d3_d11_render_system.html#ad4936a78d447c0e8be978117c47e9f98", null ],
     [ "setStencilBufferParams", "class_ogre_1_1_d3_d11_render_system.html#a0446eae7ec8f45fa8e023ead267cf631", null ],
     [ "setSubroutine", "class_ogre_1_1_d3_d11_render_system.html#a833eb12f8569b566e4148d738926879d", null ],
     [ "setSubroutine", "class_ogre_1_1_d3_d11_render_system.html#a86d5c9fc07860291152c63770e3b52ef", null ],
     [ "setUavStartingSlot", "class_ogre_1_1_d3_d11_render_system.html#a2d0de2f7b75ffb2d4048534ebe90bb73", null ],
     [ "setWBufferEnabled", "class_ogre_1_1_d3_d11_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
     [ "shutdown", "class_ogre_1_1_d3_d11_render_system.html#ab0a3fd2d052c5eaaca2c24a9111407d6", null ],
+    [ "startGpuDebuggerFrameCapture", "class_ogre_1_1_d3_d11_render_system.html#afe7705e26f10dccebf2e6db0b3d6859e", null ],
     [ "unregisterThread", "class_ogre_1_1_d3_d11_render_system.html#ac5013457ddd4eefb71e031332294fadf", null ],
     [ "updateCompositorManager", "class_ogre_1_1_d3_d11_render_system.html#a41328026d8be0e7143402a914f707cf9", null ],
     [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_d3_d11_render_system.html#a6219a2d1f92be5548983a03de9522365", null ],
