@@ -105,7 +105,6 @@ var class_ogre_1_1_light =
     [ "getSpotlightTanHalfAngle", "class_ogre_1_1_light.html#a20900182d64a3aebaddbb34e9717badc", null ],
     [ "getTexture", "class_ogre_1_1_light.html#a68adbcfd66dbe03705a046f383ce587f", null ],
     [ "getType", "class_ogre_1_1_light.html#a8ef572fd5d20b366328cbdb0eb71b4a0", null ],
-    [ "getTypeFlags", "class_ogre_1_1_light.html#a4dfd204f10889876a729263099d9bd03", null ],
     [ "getUserObjectBindings", "class_ogre_1_1_light.html#aa6ae8d976be50b007ba1e87732a6397d", null ],
     [ "getUserObjectBindings", "class_ogre_1_1_light.html#a27eb8980ee187b42ea619c582eaebf73", null ],
     [ "getVisibilityFlags", "class_ogre_1_1_light.html#a19bf2951b97744064509c13068143f3d", null ],
@@ -116,8 +115,6 @@ var class_ogre_1_1_light =
     [ "getWorldRadiusUpdated", "class_ogre_1_1_light.html#ad42ba158cac70430c34f8a9eac94b237", null ],
     [ "instanceBatchCullFrustumThreaded", "class_ogre_1_1_light.html#a2d62d2c3d09910210c948fc660468c46", null ],
     [ "isAttached", "class_ogre_1_1_light.html#aef2a2634077942a2939514a6c1114d32", null ],
-    [ "isInLightRange", "class_ogre_1_1_light.html#a555aaeda1762a4820baf9648a2189b85", null ],
-    [ "isInLightRange", "class_ogre_1_1_light.html#a690b8626f9bc29d87dce0ac536276bb1", null ],
     [ "isStatic", "class_ogre_1_1_light.html#a2e3e690195e9d7e14c6ad4e1fe7ba9e5", null ],
     [ "isVisible", "class_ogre_1_1_light.html#a6c4003f6b67540727844dc33c20714f7", null ],
     [ "notifyTextureChanged", "class_ogre_1_1_light.html#a074b1b671ccfcd0883155be8ab439b17", null ],
