@@ -5,7 +5,11 @@ var class_ogre_1_1_vulkan_support =
     [ "addConfig", "class_ogre_1_1_vulkan_support.html#afc956785bff8c4a1446bc768b372999b", null ],
     [ "getConfigOptions", "class_ogre_1_1_vulkan_support.html#a97b72f6fcab0c9513c6c2b8aace60476", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_vulkan_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9", null ],
+    [ "getInterfaceName", "class_ogre_1_1_vulkan_support.html#a9baf3e657b4ef34f76709cfc0751ff50", null ],
+    [ "getInterfaceNameStr", "class_ogre_1_1_vulkan_support.html#a892fd0e6f60c161825d5bb06f2cb8eba", null ],
     [ "getSelectedDeviceIdx", "class_ogre_1_1_vulkan_support.html#a86bef7a792e9c3450da2fd697ff766c4", null ],
+    [ "isSupported", "class_ogre_1_1_vulkan_support.html#a36fba22aab78a8edf13890ca94622f21", null ],
     [ "setConfigOption", "class_ogre_1_1_vulkan_support.html#a8fe7e04815023b25d4be5454386f6ac2", null ],
+    [ "setSupported", "class_ogre_1_1_vulkan_support.html#abce0d5d7a77ce2824d5186dfe303d976", null ],
     [ "validateConfigOptions", "class_ogre_1_1_vulkan_support.html#a86746d239ebe765693db1f1b46f55fd7", null ]
 ];
\ No newline at end of file
