@@ -4,7 +4,11 @@ var class_ogre_1_1_vulkan_win32_support =
     [ "addConfig", "class_ogre_1_1_vulkan_win32_support.html#a6094e391cfa31b2c6ff4c6fc7696b2b1", null ],
     [ "getConfigOptions", "class_ogre_1_1_vulkan_win32_support.html#a97b72f6fcab0c9513c6c2b8aace60476", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_vulkan_win32_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9", null ],
+    [ "getInterfaceName", "class_ogre_1_1_vulkan_win32_support.html#a7f07eb14fd8792dac968a09c6434cdb0", null ],
+    [ "getInterfaceNameStr", "class_ogre_1_1_vulkan_win32_support.html#adcc864490a8e79fb7526045d5326777b", null ],
     [ "getSelectedDeviceIdx", "class_ogre_1_1_vulkan_win32_support.html#a86bef7a792e9c3450da2fd697ff766c4", null ],
+    [ "isSupported", "class_ogre_1_1_vulkan_win32_support.html#a36fba22aab78a8edf13890ca94622f21", null ],
     [ "setConfigOption", "class_ogre_1_1_vulkan_win32_support.html#a4642b454eea1ff29326cd2642ef113ad", null ],
+    [ "setSupported", "class_ogre_1_1_vulkan_win32_support.html#abce0d5d7a77ce2824d5186dfe303d976", null ],
     [ "validateConfigOptions", "class_ogre_1_1_vulkan_win32_support.html#a86746d239ebe765693db1f1b46f55fd7", null ]
 ];
\ No newline at end of file
