@@ -4,7 +4,11 @@ var class_ogre_1_1_vulkan_xcb_support =
     [ "addConfig", "class_ogre_1_1_vulkan_xcb_support.html#a8f4cc0f02165e1529bd27c75f1aff645", null ],
     [ "getConfigOptions", "class_ogre_1_1_vulkan_xcb_support.html#a97b72f6fcab0c9513c6c2b8aace60476", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_vulkan_xcb_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9", null ],
+    [ "getInterfaceName", "class_ogre_1_1_vulkan_xcb_support.html#a9564750c269290683f26799f561effea", null ],
+    [ "getInterfaceNameStr", "class_ogre_1_1_vulkan_xcb_support.html#a895ceaaa6a6a699a59c8f03cf73b5eeb", null ],
     [ "getSelectedDeviceIdx", "class_ogre_1_1_vulkan_xcb_support.html#a86bef7a792e9c3450da2fd697ff766c4", null ],
+    [ "isSupported", "class_ogre_1_1_vulkan_xcb_support.html#a36fba22aab78a8edf13890ca94622f21", null ],
     [ "setConfigOption", "class_ogre_1_1_vulkan_xcb_support.html#abcb12df33945325331c3cc0b704688ed", null ],
+    [ "setSupported", "class_ogre_1_1_vulkan_xcb_support.html#abce0d5d7a77ce2824d5186dfe303d976", null ],
     [ "validateConfigOptions", "class_ogre_1_1_vulkan_xcb_support.html#a86746d239ebe765693db1f1b46f55fd7", null ]
 ];
\ No newline at end of file
