@@ -148,35 +148,27 @@ var manual =
         [ "Execution mask", "compositor.html#CompositorWorkspacesStereoExecutionMask", null ],
         [ "Default values", "compositor.html#CompositorWorkspacesStereoDefaultValues", null ]
       ] ],
-      [ "Advanced MSAA", "compositor.html#autotoc_md70", [
-        [ "What is MSAA?", "compositor.html#autotoc_md71", [
-          [ "Supersampling Antialiasing (SSAA) vs MSAA", "compositor.html#autotoc_md72", null ],
-          [ "MSAA approach to the problem", "compositor.html#autotoc_md73", null ]
+      [ "Advanced MSAA", "compositor.html#autotoc_md76", [
+        [ "What is MSAA?", "compositor.html#autotoc_md77", [
+          [ "Supersampling Antialiasing (SSAA) vs MSAA", "compositor.html#autotoc_md78", null ],
+          [ "MSAA approach to the problem", "compositor.html#autotoc_md79", null ]
         ] ],
-        [ "Ogre + MSAA with Implicit Resolves", "compositor.html#autotoc_md74", null ],
-        [ "Ogre + MSAA with Explicit Resolves", "compositor.html#autotoc_md75", null ]
+        [ "Ogre + MSAA with Implicit Resolves", "compositor.html#autotoc_md80", null ],
+        [ "Ogre + MSAA with Explicit Resolves", "compositor.html#autotoc_md81", null ]
       ] ]
     ] ],
-    [ "Global Illumination Methods", "_gi_methods.html", [
-      [ "Ambient Lighting", "_gi_methods.html#GiAmbientLighting", [
-        [ "Flat", "_gi_methods.html#GiAmbientLightingFlat", null ],
-        [ "Hemisphere", "_gi_methods.html#GiAmbientLightingHemisphere", null ],
-        [ "Spherical Harmonics", "_gi_methods.html#GiAmbientLightingSH", null ]
+    [ "Global Illumination Methods", "_gi_methods.html", "_gi_methods" ],
+    [ "Image Voxel Cone Tracing", "_image_voxel_cone_tracing.html", [
+      [ "Step 1: Image Voxelizer", "_image_voxel_cone_tracing.html#IVCT_Step1", [
+        [ "Downside", "_image_voxel_cone_tracing.html#IVCT_Step1_Downside", [
+          [ "Non-researched solutions:", "_image_voxel_cone_tracing.html#autotoc_md29", null ]
+        ] ],
+        [ "Trivia", "_image_voxel_cone_tracing.html#autotoc_md30", null ]
       ] ],
-      [ "Parallax Corrected Cubemaps (PCC)", "_gi_methods.html#GiPCC", [
-        [ "Auto PCC", "_gi_methods.html#GiPCCAuto", null ],
-        [ "Manual PCC", "_gi_methods.html#GiPCCManual", null ]
-      ] ],
-      [ "Per Pixel PCC", "_gi_methods.html#GiPPPCC", [
-        [ "PCC Per Pixel Grid Placement", "_gi_methods.html#GiPPGridPlacement", null ]
-      ] ],
-      [ "Instant Radiosity", "_gi_methods.html#GiInstantRadiosity", null ],
-      [ "Irradiance Volume", "_gi_methods.html#GiIrradianceVolume", null ],
-      [ "Voxel Cone Tracing (aka VCT)", "_gi_methods.html#GiVCT", [
-        [ "VCT + Per Pixel PCC Hybrid", "_gi_methods.html#GiVCTPlusPPPCC", null ]
-      ] ],
-      [ "Irradiance Field with Depth (IFD)", "_gi_methods.html#GiIFD", null ],
-      [ "What technique should I choose?", "_gi_methods.html#GiWhatTechniqueChoose", null ]
+      [ "Step 2: Row Translation", "_image_voxel_cone_tracing.html#IVCT_Step2", null ],
+      [ "Step 3: Cascades", "_image_voxel_cone_tracing.html#IVCT_Step3", null ],
+      [ "Wait isn't this what UE5's Lumen does?", "_image_voxel_cone_tracing.html#autotoc_md31", null ],
+      [ "Wait isn't this what Godot does?", "_image_voxel_cone_tracing.html#autotoc_md32", null ]
     ] ],
     [ "Instancing", "instancing.html", [
       [ "What is instancing?", "instancing.html#WhatIsInstancing", null ],
@@ -286,72 +278,73 @@ var manual =
       [ "Post-processing the command buffer", "commandbuffer.html#CommandBufferPostProcessing", null ]
     ] ],
     [ "Terra System", "_terra_system.html", [
-      [ "Vertex-bufferless rendering", "_terra_system.html#autotoc_md61", null ],
-      [ "Vertex Trick in Terra", "_terra_system.html#autotoc_md62", null ],
-      [ "Terra cells", "_terra_system.html#autotoc_md63", [
-        [ "First layer, the 4x4 block", "_terra_system.html#autotoc_md64", null ],
-        [ "Outer layers", "_terra_system.html#autotoc_md65", null ]
+      [ "Vertex-bufferless rendering", "_terra_system.html#autotoc_md67", null ],
+      [ "Vertex Trick in Terra", "_terra_system.html#autotoc_md68", null ],
+      [ "Terra cells", "_terra_system.html#autotoc_md69", [
+        [ "First layer, the 4x4 block", "_terra_system.html#autotoc_md70", null ],
+        [ "Outer layers", "_terra_system.html#autotoc_md71", null ]
       ] ],
-      [ "Skirts", "_terra_system.html#autotoc_md66", null ],
-      [ "Shadows", "_terra_system.html#autotoc_md67", null ],
-      [ "Shading", "_terra_system.html#autotoc_md68", null ],
-      [ "Why is it not a component?", "_terra_system.html#autotoc_md69", null ]
+      [ "Skirts", "_terra_system.html#autotoc_md72", null ],
+      [ "Shadows", "_terra_system.html#autotoc_md73", null ],
+      [ "Shading", "_terra_system.html#autotoc_md74", null ],
+      [ "Why is it not a component?", "_terra_system.html#autotoc_md75", null ]
     ] ],
     [ "Tunning memory consumption and resources", "_tuning_memory_resources.html", [
       [ "Grouping textures by type", "_tuning_memory_resources.html#GroupingTexturesByType", null ],
       [ "Dynamic vs Default buffers", "_tuning_memory_resources.html#DynamicVsDefaultBuffers", null ],
       [ "Tweaking default memory consumption by VaoManager", "_tuning_memory_resources.html#TweakingVaoManager", [
-        [ "Vulkan and <tt>TEXTURES_OPTIMAL</tt>", "_tuning_memory_resources.html#autotoc_md28", null ]
+        [ "Vulkan and <tt>TEXTURES_OPTIMAL</tt>", "_tuning_memory_resources.html#autotoc_md33", null ]
       ] ]
     ] ],
     [ "What's new in Ogre 2.2", "_ogre22_changes.html", [
-      [ "Load Store semantics", "_ogre22_changes.html#autotoc_md29", [
-        [ "Now that we’ve explained how TBDRs work, we can explain load and store actions", "_ogre22_changes.html#autotoc_md30", null ]
+      [ "Load Store semantics", "_ogre22_changes.html#autotoc_md34", [
+        [ "Now that we’ve explained how TBDRs work, we can explain load and store actions", "_ogre22_changes.html#autotoc_md35", null ]
       ] ],
-      [ "More control over MSAA", "_ogre22_changes.html#autotoc_md31", null ],
-      [ "Porting to Ogre 2.2 from 2.1", "_ogre22_changes.html#autotoc_md32", [
-        [ "PixelFormats", "_ogre22_changes.html#autotoc_md33", [
-          [ "Common pixel format equivalencies", "_ogre22_changes.html#autotoc_md34", null ]
+      [ "More control over MSAA", "_ogre22_changes.html#autotoc_md36", null ],
+      [ "Porting to Ogre 2.2 from 2.1", "_ogre22_changes.html#autotoc_md37", [
+        [ "PixelFormats", "_ogre22_changes.html#autotoc_md38", [
+          [ "Common pixel format equivalencies", "_ogre22_changes.html#autotoc_md39", null ]
         ] ],
-        [ "Useful code snippets", "_ogre22_changes.html#autotoc_md35", [
-          [ "Create a TextureGpu based on a file", "_ogre22_changes.html#autotoc_md36", null ],
-          [ "Create a TextureGpu based that you manually fill", "_ogre22_changes.html#autotoc_md37", null ],
-          [ "Uploading data to a TextureGpu", "_ogre22_changes.html#autotoc_md38", null ],
-          [ "Upload streaming", "_ogre22_changes.html#autotoc_md39", null ],
-          [ "Downloading data from TextureGpu into CPU", "_ogre22_changes.html#autotoc_md40", null ],
-          [ "Downloading streaming", "_ogre22_changes.html#autotoc_md41", null ]
+        [ "Useful code snippets", "_ogre22_changes.html#autotoc_md40", [
+          [ "Create a TextureGpu based on a file", "_ogre22_changes.html#autotoc_md41", null ],
+          [ "Create a TextureGpu based that you manually fill", "_ogre22_changes.html#autotoc_md42", null ],
+          [ "Uploading data to a TextureGpu", "_ogre22_changes.html#autotoc_md43", null ],
+          [ "Upload streaming", "_ogre22_changes.html#autotoc_md44", null ],
+          [ "Downloading data from TextureGpu into CPU", "_ogre22_changes.html#autotoc_md45", null ],
+          [ "Downloading streaming", "_ogre22_changes.html#autotoc_md46", null ]
         ] ]
       ] ],
-      [ "Difference between depth, numSlices and depthOrSlices", "_ogre22_changes.html#autotoc_md42", null ],
-      [ "Memory layout of textures and images", "_ogre22_changes.html#autotoc_md43", null ],
-      [ "Troubleshooting errors", "_ogre22_changes.html#autotoc_md44", null ],
-      [ "RenderPassDescriptors", "_ogre22_changes.html#autotoc_md45", null ],
-      [ "DescriptorSetTexture & co.", "_ogre22_changes.html#autotoc_md46", null ],
-      [ "Does 2.2 interoperate well with the HLMS texture arrays?", "_ogre22_changes.html#autotoc_md47", null ],
-      [ "Hlms porting", "_ogre22_changes.html#autotoc_md48", null ],
-      [ "Things to watch out when porting", "_ogre22_changes.html#autotoc_md49", null ]
+      [ "Difference between depth, numSlices and depthOrSlices", "_ogre22_changes.html#autotoc_md47", null ],
+      [ "Memory layout of textures and images", "_ogre22_changes.html#autotoc_md48", null ],
+      [ "Troubleshooting errors", "_ogre22_changes.html#autotoc_md49", null ],
+      [ "RenderPassDescriptors", "_ogre22_changes.html#autotoc_md50", null ],
+      [ "DescriptorSetTexture & co.", "_ogre22_changes.html#autotoc_md51", null ],
+      [ "Does 2.2 interoperate well with the HLMS texture arrays?", "_ogre22_changes.html#autotoc_md52", null ],
+      [ "Hlms porting", "_ogre22_changes.html#autotoc_md53", null ],
+      [ "Things to watch out when porting", "_ogre22_changes.html#autotoc_md54", null ]
     ] ],
     [ "Behavor of StagingTexture in D3D11", "_behavor_staging_texture_d3_d11.html", [
-      [ "Attempting to be contiguous", "_behavor_staging_texture_d3_d11.html#autotoc_md17", null ],
-      [ "Slicing in 3", "_behavor_staging_texture_d3_d11.html#autotoc_md18", null ],
-      [ "Slicing in the middle", "_behavor_staging_texture_d3_d11.html#autotoc_md19", null ]
+      [ "Attempting to be contiguous", "_behavor_staging_texture_d3_d11.html#autotoc_md18", null ],
+      [ "Slicing in 3", "_behavor_staging_texture_d3_d11.html#autotoc_md19", null ],
+      [ "Slicing in the middle", "_behavor_staging_texture_d3_d11.html#autotoc_md20", null ]
     ] ],
     [ "What's new in Ogre 2.3", "_ogre23_changes.html", [
-      [ "Switch importV1 to createByImportingV1", "_ogre23_changes.html#autotoc_md50", null ],
-      [ "Shadow's Normal Offset Bias", "_ogre23_changes.html#autotoc_md51", null ],
-      [ "Unlit vertex and pixel shaders unified", "_ogre23_changes.html#autotoc_md52", null ],
-      [ "Added HlmsMacroblock::mDepthClamp", "_ogre23_changes.html#autotoc_md53", null ],
-      [ "Added shadow pancaking", "_ogre23_changes.html#autotoc_md54", null ],
-      [ "Other relevant information when porting", "_ogre23_changes.html#autotoc_md55", [
-        [ "Do not call notifyDataIsReady more than needed", "_ogre23_changes.html#autotoc_md56", null ],
-        [ "Global changes for Vulkan compatibility:", "_ogre23_changes.html#autotoc_md57", null ]
+      [ "Switch importV1 to createByImportingV1", "_ogre23_changes.html#autotoc_md55", null ],
+      [ "Shadow's Normal Offset Bias", "_ogre23_changes.html#autotoc_md56", null ],
+      [ "Unlit vertex and pixel shaders unified", "_ogre23_changes.html#autotoc_md57", null ],
+      [ "Added HlmsMacroblock::mDepthClamp", "_ogre23_changes.html#autotoc_md58", null ],
+      [ "Added shadow pancaking", "_ogre23_changes.html#autotoc_md59", null ],
+      [ "PluginOptional", "_ogre23_changes.html#autotoc_md60", null ],
+      [ "Other relevant information when porting", "_ogre23_changes.html#autotoc_md61", [
+        [ "Do not call notifyDataIsReady more than needed", "_ogre23_changes.html#autotoc_md62", null ],
+        [ "Global changes for Vulkan compatibility:", "_ogre23_changes.html#autotoc_md63", null ]
       ] ]
     ] ],
     [ "Root Layouts", "_root_layouts.html", [
       [ "Old APIs (i.e. D3D11 and GL)", "_root_layouts.html#RootLayoutsOldAPIs", null ],
       [ "New APIs and Root Layouts", "_root_layouts.html#RootLayoutsNewAPIs", null ],
       [ "Setting up root layouts", "_root_layouts.html#RootLayoutsSettingUp", [
-        [ "Could you have used e.g. \"const_buffers\" : [0,7] instead of [4,7]?", "_root_layouts.html#autotoc_md58", null ]
+        [ "Could you have used e.g. \"const_buffers\" : [0,7] instead of [4,7]?", "_root_layouts.html#autotoc_md64", null ]
       ] ],
       [ "Declaring Root Layouts in shaders", "_root_layouts.html#RootLayoutsDeclaringInShaders", null ],
       [ "Baked sets", "_root_layouts.html#RootLayoutsBakedSets", null ],
@@ -362,8 +355,8 @@ var manual =
         [ "Automatic", "_root_layouts.html#RootLayoutsAoTAuto", null ],
         [ "Making GLSL shaders compatible with both Vulkan and OpenGL", "_root_layouts.html#RootLayoutsGLSLForGLandVK", [
           [ "Example:", "_root_layouts.html#RootLayoutsGLSLForGLandVKExample", [
-            [ "OpenGL", "_root_layouts.html#autotoc_md59", null ],
-            [ "Vulkan", "_root_layouts.html#autotoc_md60", null ]
+            [ "OpenGL", "_root_layouts.html#autotoc_md65", null ],
+            [ "Vulkan", "_root_layouts.html#autotoc_md66", null ]
           ] ]
         ] ]
       ] ]
