@@ -1,50 +1,5 @@
 var NAVTREEINDEX10 =
 {
-"_s_s_e2_2_single_2_ogre_boolean_mask_8h.html":[8,0,302],
-"_samples.html":[3,0],
-"_samples.html#SMAA":[3,0,47],
-"_samples.html#animationtagpoints":[3,0,5],
-"_samples.html#arealighapprox":[3,0,6],
-"_samples.html#autolod":[3,0,16],
-"_samples.html#autopcc":[3,0,18],
-"_samples.html#compute01":[3,0,39],
-"_samples.html#compute02":[3,0,40],
-"_samples.html#customrenderable":[3,0,7],
-"_samples.html#decals":[3,0,8],
-"_samples.html#dynamicgeometry":[3,0,9],
-"_samples.html#dyncubemap":[3,0,42],
-"_samples.html#eglheadless":[3,0,43],
-"_samples.html#forward3d":[3,0,0],
-"_samples.html#hdr":[3,0,1],
-"_samples.html#hdrsmaa":[3,0,2],
-"_samples.html#iesprofiles":[3,0,10],
-"_samples.html#instancedstero":[3,0,12],
-"_samples.html#instantradiosity":[3,0,13],
-"_samples.html#localcubemaps":[3,0,14],
-"_samples.html#localcubemapsmp":[3,0,15],
-"_samples.html#morphanimation":[3,0,17],
-"_samples.html#onmanualobject":[3,0,30],
-"_samples.html#openVR":[3,0,44],
-"_samples.html#pbsmaterials":[3,0,3],
-"_samples.html#planarreflections":[3,0,19],
-"_samples.html#postprocessing":[3,0,4],
-"_samples.html#reconpfromd":[3,0,45],
-"_samples.html#refractions":[3,0,20],
-"_samples.html#sceneformat":[3,0,21],
-"_samples.html#shadowdebug":[3,0,23],
-"_samples.html#shadowfromcode":[3,0,24],
-"_samples.html#sharedskeleton":[3,0,11],
-"_samples.html#skypost":[3,0,46],
-"_samples.html#ssao":[3,0,48],
-"_samples.html#ssreflections":[3,0,22],
-"_samples.html#staticshadowmap":[3,0,25],
-"_samples.html#stenciltest":[3,0,26],
-"_samples.html#stereorendering":[3,0,27],
-"_samples.html#terrain":[3,0,49],
-"_samples.html#texturebaking":[3,0,50],
-"_samples.html#tut_distortion":[3,0,41],
-"_samples.html#tutorial00":[3,0,32],
-"_samples.html#tutorial01":[3,0,33],
 "_samples.html#tutorial02":[3,0,34],
 "_samples.html#tutorial03":[3,0,35],
 "_samples.html#tutorial04":[3,0,36],
@@ -91,42 +46,43 @@ var NAVTREEINDEX10 =
 "_technical_overview.html#RenderTargetUpdate":[3,2,4],
 "_technical_overview.html#SIMDCoherence":[3,2,0,0],
 "_technical_overview.html#TechnicalOverviewOverview":[3,2,0],
-"_terra_system.html":[3,11],
-"_terra_system.html#autotoc_md61":[3,11,0],
-"_terra_system.html#autotoc_md62":[3,11,1],
-"_terra_system.html#autotoc_md63":[3,11,2],
-"_terra_system.html#autotoc_md64":[3,11,2,0],
-"_terra_system.html#autotoc_md65":[3,11,2,1],
-"_terra_system.html#autotoc_md66":[3,11,3],
-"_terra_system.html#autotoc_md67":[3,11,4],
-"_terra_system.html#autotoc_md68":[3,11,5],
-"_terra_system.html#autotoc_md69":[3,11,6],
-"_tuning_memory_resources.html":[3,12],
-"_tuning_memory_resources.html#DynamicVsDefaultBuffers":[3,12,1],
-"_tuning_memory_resources.html#GroupingTexturesByType":[3,12,0],
-"_tuning_memory_resources.html#TweakingVaoManager":[3,12,2],
-"_tuning_memory_resources.html#autotoc_md28":[3,12,2,0],
+"_terra_system.html":[3,12],
+"_terra_system.html#autotoc_md67":[3,12,0],
+"_terra_system.html#autotoc_md68":[3,12,1],
+"_terra_system.html#autotoc_md69":[3,12,2],
+"_terra_system.html#autotoc_md70":[3,12,2,0],
+"_terra_system.html#autotoc_md71":[3,12,2,1],
+"_terra_system.html#autotoc_md72":[3,12,3],
+"_terra_system.html#autotoc_md73":[3,12,4],
+"_terra_system.html#autotoc_md74":[3,12,5],
+"_terra_system.html#autotoc_md75":[3,12,6],
+"_tuning_memory_resources.html":[3,13],
+"_tuning_memory_resources.html#DynamicVsDefaultBuffers":[3,13,1],
+"_tuning_memory_resources.html#GroupingTexturesByType":[3,13,0],
+"_tuning_memory_resources.html#TweakingVaoManager":[3,13,2],
+"_tuning_memory_resources.html#autotoc_md33":[3,13,2,0],
 "_using_ogre_in_your_app.html":[2],
-"_using_ogre_in_your_app.html#AnoteaboutcopiedfilesfromSamples_20_Common":[2,1,1,0],
-"_using_ogre_in_your_app.html#CreatingYourApplication":[2,1,1],
+"_using_ogre_in_your_app.html#AnoteaboutcopiedfilesfromSamples_20_Common":[2,1,2,0],
+"_using_ogre_in_your_app.html#CreatingYourApplication":[2,1,2],
 "_using_ogre_in_your_app.html#SmallNoteAbout_iOS":[2,1,0],
 "_using_ogre_in_your_app.html#SpeedingThingsUp":[2,1],
-"_using_ogre_in_your_app.html#SupportingMultithreadingLoopsFromTheGetGo":[2,1,2],
+"_using_ogre_in_your_app.html#SupportingMultithreadingLoopsFromTheGetGo":[2,1,3],
 "_using_ogre_in_your_app.html#UsingOgreInYourAppOverview":[2,0],
-"_vao_2_ogre_g_l3_plus_vertex_array_object_8h.html":[8,0,790],
-"_vao_2_ogre_g_l_e_s2_vertex_array_object_8h.html":[8,0,892],
-"_w_i_n32_2_ogre_config_dialog_imp_8h.html":[8,0,186],
-"_w_i_n32_2_ogre_config_dialog_imp_8h.html#ac7bef5d85e3dcd73eef56ad39ffc84a9":[8,0,186,0],
-"_w_i_n32_2_ogre_error_dialog_imp_8h.html":[8,0,194],
-"_w_i_n32_2_ogre_error_dialog_imp_8h.html#ac7bef5d85e3dcd73eef56ad39ffc84a9":[8,0,194,0],
-"_w_i_n32_2_ogre_timer_imp_8h.html":[8,0,201],
-"_w_i_n32_2_ogre_timer_imp_8h.html#ac7bef5d85e3dcd73eef56ad39ffc84a9":[8,0,201,0],
+"_using_ogre_in_your_app.html#autotoc_md17":[2,1,1],
+"_vao_2_ogre_g_l3_plus_vertex_array_object_8h.html":[8,0,3,2,0,2,11],
+"_vao_2_ogre_g_l_e_s2_vertex_array_object_8h.html":[8,0,3,3,0,2,8],
+"_w_i_n32_2_ogre_config_dialog_imp_8h.html":[8,0,2,0,15,1],
+"_w_i_n32_2_ogre_config_dialog_imp_8h.html#ac7bef5d85e3dcd73eef56ad39ffc84a9":[8,0,2,0,15,1,0],
+"_w_i_n32_2_ogre_error_dialog_imp_8h.html":[8,0,2,0,15,3],
+"_w_i_n32_2_ogre_error_dialog_imp_8h.html#ac7bef5d85e3dcd73eef56ad39ffc84a9":[8,0,2,0,15,3,0],
+"_w_i_n32_2_ogre_timer_imp_8h.html":[8,0,2,0,15,6],
+"_w_i_n32_2_ogre_timer_imp_8h.html#ac7bef5d85e3dcd73eef56ad39ffc84a9":[8,0,2,0,15,6,0],
 "annotated.html":[7,0],
-"azdo.html":[3,9],
-"azdo.html#RenderQueue":[3,9,1],
-"azdo.html#V2AndV1Objects":[3,9,0],
-"azdo.html#V2AndV1ObjectsV1Longevity":[3,9,0,0],
-"azdo.html#VaoMaanger":[3,9,2],
+"azdo.html":[3,10],
+"azdo.html#RenderQueue":[3,10,1],
+"azdo.html#V2AndV1Objects":[3,10,0],
+"azdo.html#V2AndV1ObjectsV1Longevity":[3,10,0,0],
+"azdo.html#VaoMaanger":[3,10,2],
 "class_display.html":[7,0,6],
 "class_not_pointer_atom.html":[7,0,10],
 "class_ogre_1_1_a_p_k_file_system_archive.html":[7,0,0,22],
@@ -137,36 +93,36 @@ var NAVTREEINDEX10 =
 "class_ogre_1_1_a_p_k_file_system_archive.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,22,17],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a2674d48fac32a3db65c7acd7811d244d":[6,0,0,49,9],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a2674d48fac32a3db65c7acd7811d244d":[7,0,0,22,9],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a3229d2fd6c8d3236f68f7a3f1baedeec":[7,0,0,22,10],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a3229d2fd6c8d3236f68f7a3f1baedeec":[6,0,0,49,10],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a370bbf433be7cda33f045ad2e70215a3":[6,0,0,49,1],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a3229d2fd6c8d3236f68f7a3f1baedeec":[7,0,0,22,10],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a370bbf433be7cda33f045ad2e70215a3":[7,0,0,22,1],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a370bbf433be7cda33f045ad2e70215a3":[6,0,0,49,1],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a3bf1d801c67ee89e48d8a3299cfc0a7e":[6,0,0,49,6],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a3bf1d801c67ee89e48d8a3299cfc0a7e":[7,0,0,22,6],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a485335b676e26fd6570a40213273b549":[6,0,0,49,0],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a485335b676e26fd6570a40213273b549":[7,0,0,22,0],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a485335b676e26fd6570a40213273b549":[6,0,0,49,0],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,22,19],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,49,19],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,49,22],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,22,22],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a6fde30e44c6eae7c922fcc9ae21e4d7c":[6,0,0,49,12],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a6fde30e44c6eae7c922fcc9ae21e4d7c":[7,0,0,22,12],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a6fde30e44c6eae7c922fcc9ae21e4d7c":[6,0,0,49,12],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,49,15],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,22,15],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a8bc93ec9170e9504de6293096585d8a7":[6,0,0,49,11],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a8bc93ec9170e9504de6293096585d8a7":[7,0,0,22,11],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a8bc93ec9170e9504de6293096585d8a7":[6,0,0,49,11],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a92ad2416e5441af919314a6334f009f9":[7,0,0,22,3],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a92ad2416e5441af919314a6334f009f9":[6,0,0,49,3],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,49,18],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,22,18],
-"class_ogre_1_1_a_p_k_file_system_archive.html#aab0eeb38f3941f9aedd66c858d86fc8a":[6,0,0,49,26],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aab0eeb38f3941f9aedd66c858d86fc8a":[7,0,0,22,26],
+"class_ogre_1_1_a_p_k_file_system_archive.html#aab0eeb38f3941f9aedd66c858d86fc8a":[6,0,0,49,26],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aafaac74ffb9b0b5563215a6b9f825a2f":[6,0,0,49,5],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aafaac74ffb9b0b5563215a6b9f825a2f":[7,0,0,22,5],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ab13cace971069f901cd80e73da8f8cc6":[6,0,0,49,2],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ab13cace971069f901cd80e73da8f8cc6":[7,0,0,22,2],
-"class_ogre_1_1_a_p_k_file_system_archive.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,49,21],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,22,21],
+"class_ogre_1_1_a_p_k_file_system_archive.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,49,21],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ab63e6a2843a2db30eef7855616ff3440":[7,0,0,22,8],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ab63e6a2843a2db30eef7855616ff3440":[6,0,0,49,8],
 "class_ogre_1_1_a_p_k_file_system_archive.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,49,16],
@@ -179,75 +135,119 @@ var NAVTREEINDEX10 =
 "class_ogre_1_1_a_p_k_file_system_archive.html#adce32528577d71b228692df906ecd17c":[6,0,0,49,23],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ae0182ce37e2f1e05799760ad7d997b41":[6,0,0,49,14],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ae0182ce37e2f1e05799760ad7d997b41":[7,0,0,22,14],
-"class_ogre_1_1_a_p_k_file_system_archive.html#ae31318ec0679e136a0e79016c8aba26b":[6,0,0,49,4],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ae31318ec0679e136a0e79016c8aba26b":[7,0,0,22,4],
-"class_ogre_1_1_a_p_k_file_system_archive.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,22,24],
+"class_ogre_1_1_a_p_k_file_system_archive.html#ae31318ec0679e136a0e79016c8aba26b":[6,0,0,49,4],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,49,24],
+"class_ogre_1_1_a_p_k_file_system_archive.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,22,24],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aee650b957194abaf771ea81b41da36fe":[7,0,0,22,7],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aee650b957194abaf771ea81b41da36fe":[6,0,0,49,7],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html":[7,0,0,23],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html":[6,0,0,50],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[6,0,0,50,3],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html":[7,0,0,23],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[7,0,0,23,3],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,23,9],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[6,0,0,50,3],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,50,9],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,23,9],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a3479b271af0b6a05d3126bd6d7bfbeb0":[7,0,0,23,2],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a3479b271af0b6a05d3126bd6d7bfbeb0":[6,0,0,50,2],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a49d76c0adee87f3761b47ba3f9423a95":[7,0,0,23,1],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a49d76c0adee87f3761b47ba3f9423a95":[6,0,0,50,1],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a4d5cddcc806fd73f22987db34c14e9c9":[6,0,0,50,5],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a4d5cddcc806fd73f22987db34c14e9c9":[7,0,0,23,5],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,23,11],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,50,11],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,23,14],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,23,11],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,50,14],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a6a325ed3acfc868300befde9a2270ff4":[6,0,0,50,0],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,23,14],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a6a325ed3acfc868300befde9a2270ff4":[7,0,0,23,0],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,50,7],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a6a325ed3acfc868300befde9a2270ff4":[6,0,0,50,0],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,23,7],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,50,10],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,50,7],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,23,10],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#aac6ff8be0211440930ff787558b9be5a":[6,0,0,50,6],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,50,10],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#aac6ff8be0211440930ff787558b9be5a":[7,0,0,23,6],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#aac6ff8be0211440930ff787558b9be5a":[6,0,0,50,6],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,23,13],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,50,13],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,50,8],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,23,8],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,23,12],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,50,8],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,50,12],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,23,12],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#adce32528577d71b228692df906ecd17c":[6,0,0,50,15],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#adce32528577d71b228692df906ecd17c":[7,0,0,23,15],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#ae826041f38f1896e6a5f800f35aaa638":[6,0,0,50,4],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#ae826041f38f1896e6a5f800f35aaa638":[7,0,0,23,4],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,50,16],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,23,16],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html":[7,0,0,24],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,50,16],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html":[6,0,0,51],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html":[7,0,0,24],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[6,0,0,51,5],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[7,0,0,24,5],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,24,11],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,51,11],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a2ce05ec837366adb88a8b9f573085478":[6,0,0,51,19],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,24,11],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a2ce05ec837366adb88a8b9f573085478":[7,0,0,24,19],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,24,13],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a2ce05ec837366adb88a8b9f573085478":[6,0,0,51,19],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,51,13],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,24,13],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,24,16],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,51,16],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a6a5765a963cb0c13df4df82f356960e0":[7,0,0,24,2],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a6a5765a963cb0c13df4df82f356960e0":[6,0,0,51,2],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a6a5765a963cb0c13df4df82f356960e0":[7,0,0,24,2],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a6daf2b72dc3cb321c51ea3a09b3c0162":[7,0,0,24,6],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a6daf2b72dc3cb321c51ea3a09b3c0162":[6,0,0,51,6],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a7d9d8eab82dfeb8f1ee47fb83379bd6d":[7,0,0,24,8],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a7d9d8eab82dfeb8f1ee47fb83379bd6d":[6,0,0,51,8],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,51,9],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a7d9d8eab82dfeb8f1ee47fb83379bd6d":[7,0,0,24,8],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,24,9],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,51,9],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a84f0bbc7ca53b6e525a9a774a03341fe":[6,0,0,51,7],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a84f0bbc7ca53b6e525a9a774a03341fe":[7,0,0,24,7],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,51,12],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,24,12],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,51,12],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a9ef899ac1ebf7ab54f115c8ced9ff433":[6,0,0,51,0],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a9ef899ac1ebf7ab54f115c8ced9ff433":[7,0,0,24,0],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#aa2c388afbb8ff7dfb301bbe95495ed6b":[7,0,0,24,3],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#aa2c388afbb8ff7dfb301bbe95495ed6b":[6,0,0,51,3],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,51,15]
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#aa2c388afbb8ff7dfb301bbe95495ed6b":[7,0,0,24,3],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,51,15],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,24,15],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#ab985302e640d95d40059570ace8b7759":[7,0,0,24,4],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#ab985302e640d95d40059570ace8b7759":[6,0,0,51,4],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#ac6b4ff7bd7d6d755fd806c6b2bd7600f":[7,0,0,24,1],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#ac6b4ff7bd7d6d755fd806c6b2bd7600f":[6,0,0,51,1],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,24,10],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,51,10],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,24,14],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,51,14],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#adce32528577d71b228692df906ecd17c":[6,0,0,51,17],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#adce32528577d71b228692df906ecd17c":[7,0,0,24,17],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,51,18],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,24,18],
+"class_ogre_1_1_a_s_t_c_codec.html":[5,2,3,0],
+"class_ogre_1_1_a_s_t_c_codec.html#a02c09d20cedebbd768784f4a07b1d528":[5,2,3,0,14],
+"class_ogre_1_1_a_s_t_c_codec.html#a06fa1827bc57846191e27849555b76e7":[5,2,3,0,29],
+"class_ogre_1_1_a_s_t_c_codec.html#a113b5f2d31e4ab38817b3cae401e9b44":[5,2,3,0,4],
+"class_ogre_1_1_a_s_t_c_codec.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,3,0,20],
+"class_ogre_1_1_a_s_t_c_codec.html#a217e39b5c41d63eb4a800352485e1306":[5,2,3,0,3],
+"class_ogre_1_1_a_s_t_c_codec.html#a21f4b8a16d070793d576f827c9fee218":[5,2,3,0,1],
+"class_ogre_1_1_a_s_t_c_codec.html#a270be35471eb9ef28fdbd4b7dced21b9":[5,2,3,0,16],
+"class_ogre_1_1_a_s_t_c_codec.html#a29e31ad112b08ea7fb648b63f426ff1f":[5,2,3,0,0],
+"class_ogre_1_1_a_s_t_c_codec.html#a2b2a0333da2b5dcb5b6399afbefc4447":[5,2,3,0,13],
+"class_ogre_1_1_a_s_t_c_codec.html#a37968d655c2950f0420bbaa3eeaa0f60":[5,2,3,0,11],
+"class_ogre_1_1_a_s_t_c_codec.html#a3d41ee013b8d13485188f3b43de8a3c5":[5,2,3,0,30],
+"class_ogre_1_1_a_s_t_c_codec.html#a55bf1d49e91958f8e412a583666bbd58":[5,2,3,0,10],
+"class_ogre_1_1_a_s_t_c_codec.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,3,0,22],
+"class_ogre_1_1_a_s_t_c_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1":[5,2,3,0,12],
+"class_ogre_1_1_a_s_t_c_codec.html#a60f445cc6919df56af6611fd14eec47d":[5,2,3,0,28],
+"class_ogre_1_1_a_s_t_c_codec.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,3,0,25],
+"class_ogre_1_1_a_s_t_c_codec.html#a7aa2599cd9db05e590fb7f7786076852":[5,2,3,0,31],
+"class_ogre_1_1_a_s_t_c_codec.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,3,0,18],
+"class_ogre_1_1_a_s_t_c_codec.html#a85f9220e2412fe03cfaf56650dd862fb":[5,2,3,0,6],
+"class_ogre_1_1_a_s_t_c_codec.html#a8cc81c85bd7d4e25393aa153c5e01454":[5,2,3,0,2],
+"class_ogre_1_1_a_s_t_c_codec.html#a938a753e65d5153ef2a3787eb7fe3630":[5,2,3,0,8],
+"class_ogre_1_1_a_s_t_c_codec.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,3,0,21],
+"class_ogre_1_1_a_s_t_c_codec.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,3,0,24],
+"class_ogre_1_1_a_s_t_c_codec.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,3,0,19],
+"class_ogre_1_1_a_s_t_c_codec.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,3,0,23],
+"class_ogre_1_1_a_s_t_c_codec.html#ad5d492ef5f8b9d5f813d53484507baf7":[5,2,3,0,5],
+"class_ogre_1_1_a_s_t_c_codec.html#ad9072a8530d43873924eb02ebae91569":[5,2,3,0,17],
+"class_ogre_1_1_a_s_t_c_codec.html#adce32528577d71b228692df906ecd17c":[5,2,3,0,26],
+"class_ogre_1_1_a_s_t_c_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557":[5,2,3,0,15],
+"class_ogre_1_1_a_s_t_c_codec.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,3,0,27]
 };
