@@ -1,93 +1,49 @@
 var NAVTREEINDEX11 =
 {
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,24,15],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#ab985302e640d95d40059570ace8b7759":[7,0,0,24,4],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#ab985302e640d95d40059570ace8b7759":[6,0,0,51,4],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#ac6b4ff7bd7d6d755fd806c6b2bd7600f":[7,0,0,24,1],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#ac6b4ff7bd7d6d755fd806c6b2bd7600f":[6,0,0,51,1],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,24,10],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,51,10],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,51,14],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,24,14],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#adce32528577d71b228692df906ecd17c":[7,0,0,24,17],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#adce32528577d71b228692df906ecd17c":[6,0,0,51,17],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,51,18],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,24,18],
-"class_ogre_1_1_a_s_t_c_codec.html":[5,2,3,0],
-"class_ogre_1_1_a_s_t_c_codec.html#a02c09d20cedebbd768784f4a07b1d528":[5,2,3,0,14],
-"class_ogre_1_1_a_s_t_c_codec.html#a06fa1827bc57846191e27849555b76e7":[5,2,3,0,29],
-"class_ogre_1_1_a_s_t_c_codec.html#a113b5f2d31e4ab38817b3cae401e9b44":[5,2,3,0,4],
-"class_ogre_1_1_a_s_t_c_codec.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,3,0,20],
-"class_ogre_1_1_a_s_t_c_codec.html#a217e39b5c41d63eb4a800352485e1306":[5,2,3,0,3],
-"class_ogre_1_1_a_s_t_c_codec.html#a21f4b8a16d070793d576f827c9fee218":[5,2,3,0,1],
-"class_ogre_1_1_a_s_t_c_codec.html#a270be35471eb9ef28fdbd4b7dced21b9":[5,2,3,0,16],
-"class_ogre_1_1_a_s_t_c_codec.html#a29e31ad112b08ea7fb648b63f426ff1f":[5,2,3,0,0],
-"class_ogre_1_1_a_s_t_c_codec.html#a2b2a0333da2b5dcb5b6399afbefc4447":[5,2,3,0,13],
-"class_ogre_1_1_a_s_t_c_codec.html#a37968d655c2950f0420bbaa3eeaa0f60":[5,2,3,0,11],
-"class_ogre_1_1_a_s_t_c_codec.html#a3d41ee013b8d13485188f3b43de8a3c5":[5,2,3,0,30],
-"class_ogre_1_1_a_s_t_c_codec.html#a55bf1d49e91958f8e412a583666bbd58":[5,2,3,0,10],
-"class_ogre_1_1_a_s_t_c_codec.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,3,0,22],
-"class_ogre_1_1_a_s_t_c_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1":[5,2,3,0,12],
-"class_ogre_1_1_a_s_t_c_codec.html#a60f445cc6919df56af6611fd14eec47d":[5,2,3,0,28],
-"class_ogre_1_1_a_s_t_c_codec.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,3,0,25],
-"class_ogre_1_1_a_s_t_c_codec.html#a7aa2599cd9db05e590fb7f7786076852":[5,2,3,0,31],
-"class_ogre_1_1_a_s_t_c_codec.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,3,0,18],
-"class_ogre_1_1_a_s_t_c_codec.html#a85f9220e2412fe03cfaf56650dd862fb":[5,2,3,0,6],
-"class_ogre_1_1_a_s_t_c_codec.html#a8cc81c85bd7d4e25393aa153c5e01454":[5,2,3,0,2],
-"class_ogre_1_1_a_s_t_c_codec.html#a938a753e65d5153ef2a3787eb7fe3630":[5,2,3,0,8],
-"class_ogre_1_1_a_s_t_c_codec.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,3,0,21],
-"class_ogre_1_1_a_s_t_c_codec.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,3,0,24],
-"class_ogre_1_1_a_s_t_c_codec.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,3,0,19],
-"class_ogre_1_1_a_s_t_c_codec.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,3,0,23],
-"class_ogre_1_1_a_s_t_c_codec.html#ad5d492ef5f8b9d5f813d53484507baf7":[5,2,3,0,5],
-"class_ogre_1_1_a_s_t_c_codec.html#ad9072a8530d43873924eb02ebae91569":[5,2,3,0,17],
-"class_ogre_1_1_a_s_t_c_codec.html#adce32528577d71b228692df906ecd17c":[5,2,3,0,26],
-"class_ogre_1_1_a_s_t_c_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557":[5,2,3,0,15],
-"class_ogre_1_1_a_s_t_c_codec.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,3,0,27],
 "class_ogre_1_1_a_s_t_c_codec.html#aedb803489bfc3bcbf600ee6dfa2caf8a":[5,2,3,0,9],
 "class_ogre_1_1_a_s_t_c_codec.html#af1c042a5f0846bff06d46cd0ad2ad0a4":[5,2,3,0,7],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html":[7,0,0,7],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html":[6,0,0,34],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html":[7,0,0,7],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0098d5fc0cd4c47a77a1fdcb386adbf5":[6,0,0,34,3],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0098d5fc0cd4c47a77a1fdcb386adbf5":[7,0,0,7,3],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[6,0,0,34,1],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[7,0,0,7,1],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0ccfb0445484d40af5e3d5fb346e1bdd":[6,0,0,34,0],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[6,0,0,34,1],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0ccfb0445484d40af5e3d5fb346e1bdd":[7,0,0,7,0],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a12d52482bc1560fe43b3572d9cfb49ae":[6,0,0,34,8],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0ccfb0445484d40af5e3d5fb346e1bdd":[6,0,0,34,0],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a12d52482bc1560fe43b3572d9cfb49ae":[7,0,0,7,8],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,34,11],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a12d52482bc1560fe43b3572d9cfb49ae":[6,0,0,34,8],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,7,11],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,34,11],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a2400dc929b5f7727f0d69336b3b1e05d":[7,0,0,7,7],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a2400dc929b5f7727f0d69336b3b1e05d":[6,0,0,34,7],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a280ee76e313e85dbd47d46fcf38ce1fd":[7,0,0,7,20],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a280ee76e313e85dbd47d46fcf38ce1fd":[6,0,0,34,20],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[7,0,0,7,19],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a280ee76e313e85dbd47d46fcf38ce1fd":[7,0,0,7,20],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[6,0,0,34,19],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[7,0,0,7,19],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,34,13],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,7,13],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,34,16],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,7,16],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,7,9],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,34,9],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a8c5503af3d0b705e1bf05849b68051a7":[6,0,0,34,4],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,7,9],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a8c5503af3d0b705e1bf05849b68051a7":[7,0,0,7,4],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a8c5503af3d0b705e1bf05849b68051a7":[6,0,0,34,4],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,34,12],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,7,12],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,34,15],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,7,15],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ac42ff485cbc07a6f48ad1cbc8347270e":[7,0,0,7,6],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ac42ff485cbc07a6f48ad1cbc8347270e":[6,0,0,34,6],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ac42ff485cbc07a6f48ad1cbc8347270e":[7,0,0,7,6],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,7,10],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,34,10],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,7,14],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,34,14],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#adce32528577d71b228692df906ecd17c":[7,0,0,7,17],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,7,14],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#adce32528577d71b228692df906ecd17c":[6,0,0,34,17],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[6,0,0,34,5],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#adce32528577d71b228692df906ecd17c":[7,0,0,7,17],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[7,0,0,7,5],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,7,18],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[6,0,0,34,5],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,34,18],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,7,18],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#afcbca1aed7b649a98adc3393ce177fc7":[7,0,0,7,2],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#afcbca1aed7b649a98adc3393ce177fc7":[6,0,0,34,2],
 "class_ogre_1_1_abstract_node.html":[5,2,2,2],
@@ -129,20 +85,20 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_allocated_object.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,7,3,11],
 "class_ogre_1_1_android_e_g_l_context.html":[6,0,0,39],
 "class_ogre_1_1_android_e_g_l_context.html":[7,0,0,12],
-"class_ogre_1_1_android_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[6,0,0,39,6],
+"class_ogre_1_1_android_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[7,0,0,12,6],
 "class_ogre_1_1_android_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[6,0,0,39,5],
 "class_ogre_1_1_android_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[7,0,0,12,5],
-"class_ogre_1_1_android_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[7,0,0,12,6],
+"class_ogre_1_1_android_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[6,0,0,39,6],
 "class_ogre_1_1_android_e_g_l_context.html#a0f2b47f53f419897c04ccf676ace35e5":[6,0,0,39,3],
 "class_ogre_1_1_android_e_g_l_context.html#a0f2b47f53f419897c04ccf676ace35e5":[7,0,0,12,3],
-"class_ogre_1_1_android_e_g_l_context.html#a15cc115c6f857dad066218f1225c4283":[7,0,0,12,11],
 "class_ogre_1_1_android_e_g_l_context.html#a15cc115c6f857dad066218f1225c4283":[6,0,0,39,11],
-"class_ogre_1_1_android_e_g_l_context.html#a1773206dd73cb2d134a18f0c90db2335":[6,0,0,39,7],
+"class_ogre_1_1_android_e_g_l_context.html#a15cc115c6f857dad066218f1225c4283":[7,0,0,12,11],
 "class_ogre_1_1_android_e_g_l_context.html#a1773206dd73cb2d134a18f0c90db2335":[7,0,0,12,7],
-"class_ogre_1_1_android_e_g_l_context.html#a1adbc39dc51e3c5dd91795544c2fa352":[6,0,0,39,10],
+"class_ogre_1_1_android_e_g_l_context.html#a1773206dd73cb2d134a18f0c90db2335":[6,0,0,39,7],
 "class_ogre_1_1_android_e_g_l_context.html#a1adbc39dc51e3c5dd91795544c2fa352":[7,0,0,12,10],
-"class_ogre_1_1_android_e_g_l_context.html#a291525177116254970385db2fab2536d":[7,0,0,12,14],
+"class_ogre_1_1_android_e_g_l_context.html#a1adbc39dc51e3c5dd91795544c2fa352":[6,0,0,39,10],
 "class_ogre_1_1_android_e_g_l_context.html#a291525177116254970385db2fab2536d":[6,0,0,39,14],
+"class_ogre_1_1_android_e_g_l_context.html#a291525177116254970385db2fab2536d":[7,0,0,12,14],
 "class_ogre_1_1_android_e_g_l_context.html#a4617a92f1b93caadfe83219e859367e0":[7,0,0,12,0],
 "class_ogre_1_1_android_e_g_l_context.html#a4617a92f1b93caadfe83219e859367e0":[6,0,0,39,0],
 "class_ogre_1_1_android_e_g_l_context.html#a50dbaace067890a718d0b2f272a7036a":[7,0,0,12,4],
@@ -151,24 +107,24 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_android_e_g_l_context.html#a72100630f6f905882efe0c172b7617dc":[6,0,0,39,1],
 "class_ogre_1_1_android_e_g_l_context.html#aa7b87d8031a667931b402d8f96346da8":[7,0,0,12,2],
 "class_ogre_1_1_android_e_g_l_context.html#aa7b87d8031a667931b402d8f96346da8":[6,0,0,39,2],
-"class_ogre_1_1_android_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[6,0,0,39,12],
 "class_ogre_1_1_android_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[7,0,0,12,12],
 "class_ogre_1_1_android_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[7,0,0,12,13],
+"class_ogre_1_1_android_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[6,0,0,39,12],
 "class_ogre_1_1_android_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[6,0,0,39,13],
 "class_ogre_1_1_android_e_g_l_context.html#aae3d4471c090572da0ced04cde4b87bf":[7,0,0,12,15],
 "class_ogre_1_1_android_e_g_l_context.html#aae3d4471c090572da0ced04cde4b87bf":[6,0,0,39,15],
-"class_ogre_1_1_android_e_g_l_context.html#abd71a4bfddbdf111e429e9ff825af985":[7,0,0,12,9],
 "class_ogre_1_1_android_e_g_l_context.html#abd71a4bfddbdf111e429e9ff825af985":[6,0,0,39,9],
+"class_ogre_1_1_android_e_g_l_context.html#abd71a4bfddbdf111e429e9ff825af985":[7,0,0,12,9],
 "class_ogre_1_1_android_e_g_l_context.html#acc5f8635eda869d7848234b6c35659ca":[7,0,0,12,8],
 "class_ogre_1_1_android_e_g_l_context.html#acc5f8635eda869d7848234b6c35659ca":[6,0,0,39,8],
 "class_ogre_1_1_android_e_g_l_context.html#ae0deff82440f162380917cbc211ad800":[7,0,0,12,16],
 "class_ogre_1_1_android_e_g_l_context.html#ae0deff82440f162380917cbc211ad800":[6,0,0,39,16],
-"class_ogre_1_1_android_e_g_l_support.html":[6,0,0,40],
 "class_ogre_1_1_android_e_g_l_support.html":[7,0,0,13],
-"class_ogre_1_1_android_e_g_l_support.html#a07c4b0572b1adc4104e6a5d6044cd30b":[6,0,0,40,19],
+"class_ogre_1_1_android_e_g_l_support.html":[6,0,0,40],
 "class_ogre_1_1_android_e_g_l_support.html#a07c4b0572b1adc4104e6a5d6044cd30b":[7,0,0,13,19],
-"class_ogre_1_1_android_e_g_l_support.html#a17408d3e5d0fbb9ee32c85b477fa6b9c":[7,0,0,13,5],
+"class_ogre_1_1_android_e_g_l_support.html#a07c4b0572b1adc4104e6a5d6044cd30b":[6,0,0,40,19],
 "class_ogre_1_1_android_e_g_l_support.html#a17408d3e5d0fbb9ee32c85b477fa6b9c":[6,0,0,40,5],
+"class_ogre_1_1_android_e_g_l_support.html#a17408d3e5d0fbb9ee32c85b477fa6b9c":[7,0,0,13,5],
 "class_ogre_1_1_android_e_g_l_support.html#a179eed10000b178274bd13713a2afa6c":[6,0,0,40,0],
 "class_ogre_1_1_android_e_g_l_support.html#a179eed10000b178274bd13713a2afa6c":[7,0,0,13,0],
 "class_ogre_1_1_android_e_g_l_support.html#a1b2f582872d8c79698d93e7aa02ba4c6":[7,0,0,13,21],
@@ -179,10 +135,10 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_android_e_g_l_support.html#a3231189db20cf0b36594703aaafbabd2":[7,0,0,13,4],
 "class_ogre_1_1_android_e_g_l_support.html#a396d18d9c6fd316f8a032386735ad6bc":[7,0,0,13,24],
 "class_ogre_1_1_android_e_g_l_support.html#a396d18d9c6fd316f8a032386735ad6bc":[6,0,0,40,24],
-"class_ogre_1_1_android_e_g_l_support.html#a3bb7ba22015a2517d13d48fb94d7c236":[6,0,0,40,15],
 "class_ogre_1_1_android_e_g_l_support.html#a3bb7ba22015a2517d13d48fb94d7c236":[7,0,0,13,15],
-"class_ogre_1_1_android_e_g_l_support.html#a43d180a4897f40c624a7213fadb15798":[6,0,0,40,31],
+"class_ogre_1_1_android_e_g_l_support.html#a3bb7ba22015a2517d13d48fb94d7c236":[6,0,0,40,15],
 "class_ogre_1_1_android_e_g_l_support.html#a43d180a4897f40c624a7213fadb15798":[7,0,0,13,31],
+"class_ogre_1_1_android_e_g_l_support.html#a43d180a4897f40c624a7213fadb15798":[6,0,0,40,31],
 "class_ogre_1_1_android_e_g_l_support.html#a47ed5f3e606d96a913494b7831a4db0c":[7,0,0,13,28],
 "class_ogre_1_1_android_e_g_l_support.html#a47ed5f3e606d96a913494b7831a4db0c":[6,0,0,40,28],
 "class_ogre_1_1_android_e_g_l_support.html#a4c4122eb5ca0cd660c95e593e35e684b":[7,0,0,13,12],
@@ -193,26 +149,26 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_android_e_g_l_support.html#a5437bee6dd8c3593db1d77466ac90fc1":[6,0,0,40,30],
 "class_ogre_1_1_android_e_g_l_support.html#a5812077a3463f0ad9ca639a9ec768d6d":[7,0,0,13,32],
 "class_ogre_1_1_android_e_g_l_support.html#a5812077a3463f0ad9ca639a9ec768d6d":[6,0,0,40,32],
-"class_ogre_1_1_android_e_g_l_support.html#a5c66bf066aa060d4b62c3e8653b18dd1":[7,0,0,13,22],
 "class_ogre_1_1_android_e_g_l_support.html#a5c66bf066aa060d4b62c3e8653b18dd1":[6,0,0,40,22],
-"class_ogre_1_1_android_e_g_l_support.html#a80901e793c70a24a680064a9836dd022":[6,0,0,40,16],
+"class_ogre_1_1_android_e_g_l_support.html#a5c66bf066aa060d4b62c3e8653b18dd1":[7,0,0,13,22],
 "class_ogre_1_1_android_e_g_l_support.html#a80901e793c70a24a680064a9836dd022":[7,0,0,13,16],
+"class_ogre_1_1_android_e_g_l_support.html#a80901e793c70a24a680064a9836dd022":[6,0,0,40,16],
 "class_ogre_1_1_android_e_g_l_support.html#a9045ff50fe96c0cc75f846a701958969":[6,0,0,40,3],
 "class_ogre_1_1_android_e_g_l_support.html#a9045ff50fe96c0cc75f846a701958969":[7,0,0,13,3],
 "class_ogre_1_1_android_e_g_l_support.html#a95d41b6cdcaae14ef909a0a230c4b273":[7,0,0,13,25],
 "class_ogre_1_1_android_e_g_l_support.html#a95d41b6cdcaae14ef909a0a230c4b273":[6,0,0,40,25],
-"class_ogre_1_1_android_e_g_l_support.html#a9d9194fbf90d661ea24d3714bef59579":[7,0,0,13,2],
 "class_ogre_1_1_android_e_g_l_support.html#a9d9194fbf90d661ea24d3714bef59579":[6,0,0,40,2],
+"class_ogre_1_1_android_e_g_l_support.html#a9d9194fbf90d661ea24d3714bef59579":[7,0,0,13,2],
 "class_ogre_1_1_android_e_g_l_support.html#aa52a532cd85238d5227f23d4b3de35e4":[7,0,0,13,26],
 "class_ogre_1_1_android_e_g_l_support.html#aa52a532cd85238d5227f23d4b3de35e4":[6,0,0,40,26],
-"class_ogre_1_1_android_e_g_l_support.html#aa5e7365bb25af2e2e4694d9e1053487e":[7,0,0,13,13],
 "class_ogre_1_1_android_e_g_l_support.html#aa5e7365bb25af2e2e4694d9e1053487e":[6,0,0,40,13],
-"class_ogre_1_1_android_e_g_l_support.html#aa6270b9b75c58546e3a56b342172f3e3":[6,0,0,40,11],
+"class_ogre_1_1_android_e_g_l_support.html#aa5e7365bb25af2e2e4694d9e1053487e":[7,0,0,13,13],
 "class_ogre_1_1_android_e_g_l_support.html#aa6270b9b75c58546e3a56b342172f3e3":[7,0,0,13,11],
+"class_ogre_1_1_android_e_g_l_support.html#aa6270b9b75c58546e3a56b342172f3e3":[6,0,0,40,11],
 "class_ogre_1_1_android_e_g_l_support.html#aac4192667d89adb4ecdd72bd4e00621c":[6,0,0,40,6],
 "class_ogre_1_1_android_e_g_l_support.html#aac4192667d89adb4ecdd72bd4e00621c":[7,0,0,13,6],
-"class_ogre_1_1_android_e_g_l_support.html#aba7b889aca8da4dcfd98d5864aca3eaf":[6,0,0,40,23],
 "class_ogre_1_1_android_e_g_l_support.html#aba7b889aca8da4dcfd98d5864aca3eaf":[7,0,0,13,23],
+"class_ogre_1_1_android_e_g_l_support.html#aba7b889aca8da4dcfd98d5864aca3eaf":[6,0,0,40,23],
 "class_ogre_1_1_android_e_g_l_support.html#ac3b4eec713bd275e2094c034622db0eb":[6,0,0,40,8],
 "class_ogre_1_1_android_e_g_l_support.html#ac3b4eec713bd275e2094c034622db0eb":[7,0,0,13,8],
 "class_ogre_1_1_android_e_g_l_support.html#ac8559d5d6fbb007a30774351e3eb0741":[7,0,0,13,29],
@@ -221,33 +177,77 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_android_e_g_l_support.html#ad12641ba43f0854420d9fa09fa63b7a3":[6,0,0,40,1],
 "class_ogre_1_1_android_e_g_l_support.html#adb8f0defd0f73cc88ab4e3809f87ab69":[7,0,0,13,14],
 "class_ogre_1_1_android_e_g_l_support.html#adb8f0defd0f73cc88ab4e3809f87ab69":[6,0,0,40,14],
-"class_ogre_1_1_android_e_g_l_support.html#ae1ce9edd38de8894aa362964c1329998":[7,0,0,13,20],
 "class_ogre_1_1_android_e_g_l_support.html#ae1ce9edd38de8894aa362964c1329998":[6,0,0,40,20],
-"class_ogre_1_1_android_e_g_l_support.html#ae4373407c04f1cab7743ae4c99bfd3cb":[7,0,0,13,10],
+"class_ogre_1_1_android_e_g_l_support.html#ae1ce9edd38de8894aa362964c1329998":[7,0,0,13,20],
 "class_ogre_1_1_android_e_g_l_support.html#ae4373407c04f1cab7743ae4c99bfd3cb":[6,0,0,40,10],
+"class_ogre_1_1_android_e_g_l_support.html#ae4373407c04f1cab7743ae4c99bfd3cb":[7,0,0,13,10],
 "class_ogre_1_1_android_e_g_l_support.html#ae7e90590f2038fbc475d2d857add5e2e":[7,0,0,13,9],
 "class_ogre_1_1_android_e_g_l_support.html#ae7e90590f2038fbc475d2d857add5e2e":[6,0,0,40,9],
 "class_ogre_1_1_android_e_g_l_support.html#aee9a5957c98ac70592dc9ec82a862d68":[6,0,0,40,27],
 "class_ogre_1_1_android_e_g_l_support.html#aee9a5957c98ac70592dc9ec82a862d68":[7,0,0,13,27],
-"class_ogre_1_1_android_e_g_l_support.html#af910fe0f36bcec0b5908fdb9be22ad7f":[6,0,0,40,17],
 "class_ogre_1_1_android_e_g_l_support.html#af910fe0f36bcec0b5908fdb9be22ad7f":[7,0,0,13,17],
-"class_ogre_1_1_android_e_g_l_window.html":[6,0,0,41],
+"class_ogre_1_1_android_e_g_l_support.html#af910fe0f36bcec0b5908fdb9be22ad7f":[6,0,0,40,17],
 "class_ogre_1_1_android_e_g_l_window.html":[7,0,0,14],
-"class_ogre_1_1_android_e_g_l_window.html#a008f63c8d729fe7328366170b5ed2d72":[6,0,0,41,10],
+"class_ogre_1_1_android_e_g_l_window.html":[6,0,0,41],
 "class_ogre_1_1_android_e_g_l_window.html#a008f63c8d729fe7328366170b5ed2d72":[7,0,0,14,10],
-"class_ogre_1_1_android_e_g_l_window.html#a03ae803c4754c6008fb5b898fb8090b8":[6,0,0,41,129],
-"class_ogre_1_1_android_e_g_l_window.html#a03ae803c4754c6008fb5b898fb8090b8":[7,0,0,14,129],
-"class_ogre_1_1_android_e_g_l_window.html#a0411214c1513cf32e55edc5be3008ec0":[6,0,0,41,77],
+"class_ogre_1_1_android_e_g_l_window.html#a008f63c8d729fe7328366170b5ed2d72":[6,0,0,41,10],
+"class_ogre_1_1_android_e_g_l_window.html#a03ae803c4754c6008fb5b898fb8090b8":[6,0,0,41,128],
+"class_ogre_1_1_android_e_g_l_window.html#a03ae803c4754c6008fb5b898fb8090b8":[7,0,0,14,128],
 "class_ogre_1_1_android_e_g_l_window.html#a0411214c1513cf32e55edc5be3008ec0":[7,0,0,14,77],
-"class_ogre_1_1_android_e_g_l_window.html#a0c00ca9d1ba7f3efc248ae86511fbff9":[7,0,0,14,107],
+"class_ogre_1_1_android_e_g_l_window.html#a0411214c1513cf32e55edc5be3008ec0":[6,0,0,41,77],
 "class_ogre_1_1_android_e_g_l_window.html#a0c00ca9d1ba7f3efc248ae86511fbff9":[6,0,0,41,107],
-"class_ogre_1_1_android_e_g_l_window.html#a0d3f944eab02d9dccb9e937e7f534e10":[7,0,0,14,35],
+"class_ogre_1_1_android_e_g_l_window.html#a0c00ca9d1ba7f3efc248ae86511fbff9":[7,0,0,14,107],
 "class_ogre_1_1_android_e_g_l_window.html#a0d3f944eab02d9dccb9e937e7f534e10":[6,0,0,41,35],
-"class_ogre_1_1_android_e_g_l_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[7,0,0,14,122],
-"class_ogre_1_1_android_e_g_l_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,41,122],
-"class_ogre_1_1_android_e_g_l_window.html#a0fcddbd42767a6f35d3660e3bd5f02be":[7,0,0,14,28],
+"class_ogre_1_1_android_e_g_l_window.html#a0d3f944eab02d9dccb9e937e7f534e10":[7,0,0,14,35],
+"class_ogre_1_1_android_e_g_l_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[7,0,0,14,121],
+"class_ogre_1_1_android_e_g_l_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,41,121],
 "class_ogre_1_1_android_e_g_l_window.html#a0fcddbd42767a6f35d3660e3bd5f02be":[6,0,0,41,28],
-"class_ogre_1_1_android_e_g_l_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,41,58],
+"class_ogre_1_1_android_e_g_l_window.html#a0fcddbd42767a6f35d3660e3bd5f02be":[7,0,0,14,28],
 "class_ogre_1_1_android_e_g_l_window.html#a12411d378aa0623e29287964eeb261c4":[7,0,0,14,58],
-"class_ogre_1_1_android_e_g_l_window.html#a154bf76eb66058a0135bad1e7be04bd1":[7,0,0,14,127]
+"class_ogre_1_1_android_e_g_l_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,41,58],
+"class_ogre_1_1_android_e_g_l_window.html#a154bf76eb66058a0135bad1e7be04bd1":[7,0,0,14,126],
+"class_ogre_1_1_android_e_g_l_window.html#a154bf76eb66058a0135bad1e7be04bd1":[6,0,0,41,126],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490":[6,0,0,41,1],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490":[7,0,0,14,1],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a18416c60c9b82d928db766bef672ecea":[7,0,0,14,1,6],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a18416c60c9b82d928db766bef672ecea":[6,0,0,41,1,6],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a19ef0adeaa177d49fc4ca4c9b87adec1":[7,0,0,14,1,5],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a19ef0adeaa177d49fc4ca4c9b87adec1":[6,0,0,41,1,5],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a1f0cd329c7ff6d5d81b2162c65d04afa":[6,0,0,41,1,1],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a1f0cd329c7ff6d5d81b2162c65d04afa":[7,0,0,14,1,1],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a5ee29312d754f2244987dc0d1f5894e8":[7,0,0,14,1,2],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a5ee29312d754f2244987dc0d1f5894e8":[6,0,0,41,1,2],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a6df94556ae07dfa0384808dca8dedb64":[7,0,0,14,1,0],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a6df94556ae07dfa0384808dca8dedb64":[6,0,0,41,1,0],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490aba6283bc81ca4e5e6cd2b85497a2cc2f":[7,0,0,14,1,4],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490aba6283bc81ca4e5e6cd2b85497a2cc2f":[6,0,0,41,1,4],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490ac08101cb24d35c29eb7064886081e386":[6,0,0,41,1,3],
+"class_ogre_1_1_android_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490ac08101cb24d35c29eb7064886081e386":[7,0,0,14,1,3],
+"class_ogre_1_1_android_e_g_l_window.html#a1799514a8ad7958919ca48c654a47e8e":[6,0,0,41,16],
+"class_ogre_1_1_android_e_g_l_window.html#a1799514a8ad7958919ca48c654a47e8e":[7,0,0,14,16],
+"class_ogre_1_1_android_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[6,0,0,41,135],
+"class_ogre_1_1_android_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[6,0,0,41,136],
+"class_ogre_1_1_android_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[7,0,0,14,136],
+"class_ogre_1_1_android_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[7,0,0,14,135],
+"class_ogre_1_1_android_e_g_l_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,41,89],
+"class_ogre_1_1_android_e_g_l_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,41,90],
+"class_ogre_1_1_android_e_g_l_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,14,90],
+"class_ogre_1_1_android_e_g_l_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,14,89],
+"class_ogre_1_1_android_e_g_l_window.html#a1d8e7ae222973449defdfe63d3981c70":[7,0,0,14,74],
+"class_ogre_1_1_android_e_g_l_window.html#a1d8e7ae222973449defdfe63d3981c70":[6,0,0,41,74],
+"class_ogre_1_1_android_e_g_l_window.html#a206f786f94627bd90664c801acced5be":[6,0,0,41,21],
+"class_ogre_1_1_android_e_g_l_window.html#a206f786f94627bd90664c801acced5be":[7,0,0,14,21],
+"class_ogre_1_1_android_e_g_l_window.html#a22779bbfb123c76e922942ba876e330a":[6,0,0,41,76],
+"class_ogre_1_1_android_e_g_l_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,14,76],
+"class_ogre_1_1_android_e_g_l_window.html#a24b847657d58db6ab5e14f7972e38a5d":[7,0,0,14,122],
+"class_ogre_1_1_android_e_g_l_window.html#a24b847657d58db6ab5e14f7972e38a5d":[6,0,0,41,122],
+"class_ogre_1_1_android_e_g_l_window.html#a279914cf4611a750e94b6fb54bc1b2d1":[6,0,0,41,115],
+"class_ogre_1_1_android_e_g_l_window.html#a279914cf4611a750e94b6fb54bc1b2d1":[7,0,0,14,115],
+"class_ogre_1_1_android_e_g_l_window.html#a2ba802f4884b0db42bd5248a79696f3b":[6,0,0,41,130],
+"class_ogre_1_1_android_e_g_l_window.html#a2ba802f4884b0db42bd5248a79696f3b":[7,0,0,14,130],
+"class_ogre_1_1_android_e_g_l_window.html#a2bdfaa76a186e49b807b06c7a92b720e":[6,0,0,41,123],
+"class_ogre_1_1_android_e_g_l_window.html#a2bdfaa76a186e49b807b06c7a92b720e":[7,0,0,14,123],
+"class_ogre_1_1_android_e_g_l_window.html#a2fe16ffcf13b12bcf7d16022c47e645e":[6,0,0,41,52],
+"class_ogre_1_1_android_e_g_l_window.html#a2fe16ffcf13b12bcf7d16022c47e645e":[7,0,0,14,52],
+"class_ogre_1_1_android_e_g_l_window.html#a32f2e646a09dcdaef810ea402bc92155":[7,0,0,14,25]
 };
