@@ -1,65 +1,5 @@
 var NAVTREEINDEX125 =
 {
-"class_ogre_1_1_grid2_d_page_strategy_data.html#af9383aed6dc9c82576ae39f4b3ee99f8":[5,1,0,1,33],
-"class_ogre_1_1_grid2_d_page_strategy_data.html#afd52bf3abb9eedcef1bee548679cb035":[5,1,0,1,8],
-"class_ogre_1_1_grid2_d_page_strategy_data.html#aff88059babd2ffe69b5df6bae444bc6c":[5,1,0,1,35],
-"class_ogre_1_1_grid3_d_page_strategy.html":[5,1,4],
-"class_ogre_1_1_grid3_d_page_strategy.html#a1c727e879a260c37b00ce5505fe8e144":[5,1,4,12],
-"class_ogre_1_1_grid3_d_page_strategy.html#a595ea4c05da8aa987d3800e65d23355d":[5,1,4,14],
-"class_ogre_1_1_grid3_d_page_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,1,4,17],
-"class_ogre_1_1_grid3_d_page_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,1,4,10],
-"class_ogre_1_1_grid3_d_page_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,1,4,13],
-"class_ogre_1_1_grid3_d_page_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[5,1,4,16],
-"class_ogre_1_1_grid3_d_page_strategy.html#acb46d4b0a597156d9ba5abc39d127792":[5,1,4,11],
-"class_ogre_1_1_grid3_d_page_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,1,4,15],
-"class_ogre_1_1_grid3_d_page_strategy.html#adce32528577d71b228692df906ecd17c":[5,1,4,18],
-"class_ogre_1_1_grid3_d_page_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,1,4,19],
-"class_ogre_1_1_grid3_d_page_strategy_data.html":[5,1,5],
-"class_ogre_1_1_grid3_d_page_strategy_data.html#a1c727e879a260c37b00ce5505fe8e144":[5,1,5,21],
-"class_ogre_1_1_grid3_d_page_strategy_data.html#a595ea4c05da8aa987d3800e65d23355d":[5,1,5,23],
-"class_ogre_1_1_grid3_d_page_strategy_data.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,1,5,26],
-"class_ogre_1_1_grid3_d_page_strategy_data.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,1,5,19],
-"class_ogre_1_1_grid3_d_page_strategy_data.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,1,5,22],
-"class_ogre_1_1_grid3_d_page_strategy_data.html#ab422c67a2c8844f410fe822a357cba3b":[5,1,5,25],
-"class_ogre_1_1_grid3_d_page_strategy_data.html#acb46d4b0a597156d9ba5abc39d127792":[5,1,5,20],
-"class_ogre_1_1_grid3_d_page_strategy_data.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,1,5,24],
-"class_ogre_1_1_grid3_d_page_strategy_data.html#adce32528577d71b228692df906ecd17c":[5,1,5,27],
-"class_ogre_1_1_grid3_d_page_strategy_data.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,1,5,28],
-"class_ogre_1_1_hardware_occlusion_query.html":[5,2,10,3],
-"class_ogre_1_1_hardware_occlusion_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,10,3,8],
-"class_ogre_1_1_hardware_occlusion_query.html#a40efe70ae4a5877fadd5ef40b2e5fcf3":[5,2,10,3,2],
-"class_ogre_1_1_hardware_occlusion_query.html#a4d2546c8e312ca97b34e9563d2bfb0a3":[5,2,10,3,0],
-"class_ogre_1_1_hardware_occlusion_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,10,3,10],
-"class_ogre_1_1_hardware_occlusion_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,10,3,13],
-"class_ogre_1_1_hardware_occlusion_query.html#a713fc5b2a2e0ab14843fc381f8d93f99":[5,2,10,3,1],
-"class_ogre_1_1_hardware_occlusion_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,10,3,6],
-"class_ogre_1_1_hardware_occlusion_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,10,3,9],
-"class_ogre_1_1_hardware_occlusion_query.html#aae324a11ce1f97199024d1ee38a297c2":[5,2,10,3,3],
-"class_ogre_1_1_hardware_occlusion_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,10,3,12],
-"class_ogre_1_1_hardware_occlusion_query.html#abdc85b8e78de55492c8d2d730150e08d":[5,2,10,3,5],
-"class_ogre_1_1_hardware_occlusion_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,10,3,7],
-"class_ogre_1_1_hardware_occlusion_query.html#ad1c71c786e262908a3aa805287b815e3":[5,2,10,3,4],
-"class_ogre_1_1_hardware_occlusion_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,10,3,11],
-"class_ogre_1_1_hardware_occlusion_query.html#adce32528577d71b228692df906ecd17c":[5,2,10,3,14],
-"class_ogre_1_1_hardware_occlusion_query.html#ae30ceda53d771c5db266fdcfd14e6c9c":[5,2,10,3,16],
-"class_ogre_1_1_hardware_occlusion_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,10,3,15],
-"class_ogre_1_1_hashed_vector.html":[5,2,2,53],
-"class_ogre_1_1_hashed_vector.html#a026e68fffa283192435e5bbdfb84ec9a":[5,2,2,53,16],
-"class_ogre_1_1_hashed_vector.html#a126b57c573ec7654ed6a848ff6818303":[5,2,2,53,21],
-"class_ogre_1_1_hashed_vector.html#a19d63298713a0fd765ce7d719d0aec8b":[5,2,2,53,20],
-"class_ogre_1_1_hashed_vector.html#a1ae2dca4d5b82a3c011c81da8f14bcc3":[5,2,2,53,48],
-"class_ogre_1_1_hashed_vector.html#a1fef36de46568409f0f342a8ca3b313b":[5,2,2,53,39],
-"class_ogre_1_1_hashed_vector.html#a27d63b7efd2f5df731fd837f541c3a15":[5,2,2,53,14],
-"class_ogre_1_1_hashed_vector.html#a294a0322a7a212e1101e47050627425b":[5,2,2,53,38],
-"class_ogre_1_1_hashed_vector.html#a3ad011d104e03019a4e9b9840439ef17":[5,2,2,53,6],
-"class_ogre_1_1_hashed_vector.html#a3f4e73221e49df80e2ec1c531fe6916d":[5,2,2,53,9],
-"class_ogre_1_1_hashed_vector.html#a3faaf2671367bdad36a616ca16439d15":[5,2,2,53,37],
-"class_ogre_1_1_hashed_vector.html#a41eb64e4ae34f0d1f5d413ff1ee959ba":[5,2,2,53,18],
-"class_ogre_1_1_hashed_vector.html#a424ccf9cdafb55c00df022b9d8460750":[5,2,2,53,10],
-"class_ogre_1_1_hashed_vector.html#a48cfce70d045598aae0d826dfe476730":[5,2,2,53,30],
-"class_ogre_1_1_hashed_vector.html#a48e330da70c4af1d72e23070dea24a2e":[5,2,2,53,34],
-"class_ogre_1_1_hashed_vector.html#a4c557ff148491776fd9c89aa7d55eed4":[5,2,2,53,27],
-"class_ogre_1_1_hashed_vector.html#a576ba91ab5ef4d1623fb71d1925518b4":[5,2,2,53,3],
 "class_ogre_1_1_hashed_vector.html#a5dacfefaa1717baf51697a3ef42102e0":[5,2,2,53,36],
 "class_ogre_1_1_hashed_vector.html#a5dd25a33826e2a0970eca2d4745db779":[5,2,2,53,47],
 "class_ogre_1_1_hashed_vector.html#a60b694e07c1dfeee89d09ea378a4f2a3":[5,2,2,53,26],
@@ -249,5 +189,65 @@ var NAVTREEINDEX125 =
 "class_ogre_1_1_high_level_gpu_program_manager.html#a04d94cd96f9a6ea563f2f88290a68203":[5,2,11,59,7],
 "class_ogre_1_1_high_level_gpu_program_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[5,2,11,59,25],
 "class_ogre_1_1_high_level_gpu_program_manager.html#a117a3887bbf9e83e0585777beb0501dc":[5,2,11,59,5],
-"class_ogre_1_1_high_level_gpu_program_manager.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,11,59,35]
+"class_ogre_1_1_high_level_gpu_program_manager.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,11,59,35],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[5,2,11,59,60],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[5,2,11,59,3],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[5,2,11,59,2],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a2cf457c70ea86892b1bec52028c96237":[5,2,11,59,58],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a350cd47b10995cac75ab1c4f570da41b":[5,2,11,59,0],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a3f92489910e40e3756606a35618d7b06":[5,2,11,59,48],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a40769092850d5b296e1d1a9190631700":[5,2,11,59,9],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a42f172a8ed1625011d510b081eee66dd":[5,2,11,59,20],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a4305a2c91eebfef33c0a4fe042df1789":[5,2,11,59,28],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a48c565d0e63b286c6388439ae73417df":[5,2,11,59,12],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a4d3289d4636168230da11c1c9794db59":[5,2,11,59,24],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[5,2,11,59,47],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[5,2,11,59,4],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a4fc12d0a6460a6a86ccf26c74fefbf9f":[5,2,11,59,6],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a54d1843a43aebb13542312cd17134e6a":[5,2,11,59,10],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a57e22b305d763f9ede5bda93f31051ca":[5,2,11,59,26],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,11,59,37],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a610d333f2c2ed9957de5716b93275fc4":[5,2,11,59,52],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,59,40],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[5,2,11,59,23],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[5,2,11,59,53],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[5,2,11,59,51],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[5,2,11,59,15],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[5,2,11,59,43],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,11,59,33],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[5,2,11,59,46],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a900744260df0ceb1e1eec502a9e06d1d":[5,2,11,59,31],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[5,2,11,59,61],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,11,59,36],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[5,2,11,59,59],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a957aea341de6dd79bce5c5fc8d62dc30":[5,2,11,59,29],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a992de8146fdd698d1cd6774fb15a2001":[5,2,11,59,13],
+"class_ogre_1_1_high_level_gpu_program_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[5,2,11,59,54],
+"class_ogre_1_1_high_level_gpu_program_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[5,2,11,59,22],
+"class_ogre_1_1_high_level_gpu_program_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[5,2,11,59,57],
+"class_ogre_1_1_high_level_gpu_program_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[5,2,11,59,56],
+"class_ogre_1_1_high_level_gpu_program_manager.html#aa8b761abb06d74347e9636550307ccd9":[5,2,11,59,17],
+"class_ogre_1_1_high_level_gpu_program_manager.html#aa9608544a7beb1b0e43835877ab62788":[5,2,11,59,45],
+"class_ogre_1_1_high_level_gpu_program_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[5,2,11,59,18],
+"class_ogre_1_1_high_level_gpu_program_manager.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,11,59,39],
+"class_ogre_1_1_high_level_gpu_program_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[5,2,11,59,63],
+"class_ogre_1_1_high_level_gpu_program_manager.html#abfb0022b18d022a7605f0d19a966f00f":[5,2,11,59,49],
+"class_ogre_1_1_high_level_gpu_program_manager.html#ac22655af03ecea85d863a1d1d561778c":[5,2,11,59,50],
+"class_ogre_1_1_high_level_gpu_program_manager.html#ac8f7ee61606730572a8590060d8896a0":[5,2,11,59,21],
+"class_ogre_1_1_high_level_gpu_program_manager.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,11,59,34],
+"class_ogre_1_1_high_level_gpu_program_manager.html#acd4223279e97a7687e2f9994f05e2491":[5,2,11,59,14],
+"class_ogre_1_1_high_level_gpu_program_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,11,59,38],
+"class_ogre_1_1_high_level_gpu_program_manager.html#ad6d63fe7126510bf10fd337705cb0b29":[5,2,11,59,32],
+"class_ogre_1_1_high_level_gpu_program_manager.html#ad95dcf667a304b0d59f8e09e69beef5b":[5,2,11,59,11],
+"class_ogre_1_1_high_level_gpu_program_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[5,2,11,59,55],
+"class_ogre_1_1_high_level_gpu_program_manager.html#adce32528577d71b228692df906ecd17c":[5,2,11,59,41],
+"class_ogre_1_1_high_level_gpu_program_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[5,2,11,59,44],
+"class_ogre_1_1_high_level_gpu_program_manager.html#aeaa1410333b7bcea14b00c360112a528":[5,2,11,59,62],
+"class_ogre_1_1_high_level_gpu_program_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,11,59,42],
+"class_ogre_1_1_high_level_gpu_program_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[5,2,11,59,8],
+"class_ogre_1_1_high_level_gpu_program_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[5,2,11,59,1],
+"class_ogre_1_1_high_level_gpu_program_manager.html#af96b58b31c152a8ae3c6152ee3ea12e7":[5,2,11,59,30],
+"class_ogre_1_1_hlms.html":[5,2,11,60],
+"class_ogre_1_1_hlms.html#a029b71d6801fc4acbb682d362cf4a1bd":[5,2,11,60,20],
+"class_ogre_1_1_hlms.html#a07774a51c7d3025aa5fb508a5e7e2ea5":[5,2,11,60,32]
 };
