@@ -1,68 +1,22 @@
 var NAVTREEINDEX14 =
 {
-"class_ogre_1_1_array_aabb.html#a384d1fb5b871efa2de493dfa343fe86d":[5,2,6,2,48],
-"class_ogre_1_1_array_aabb.html#a542f4c0f695c6732ae40c8c52d820403":[5,2,6,2,57],
-"class_ogre_1_1_array_aabb.html#a58a021488fc74ae87cabab7e852952c5":[5,2,6,2,25],
-"class_ogre_1_1_array_aabb.html#a58a021488fc74ae87cabab7e852952c5":[5,2,6,2,26],
-"class_ogre_1_1_array_aabb.html#a58a021488fc74ae87cabab7e852952c5":[5,2,6,2,24],
-"class_ogre_1_1_array_aabb.html#a5af3916040d0b4a1926cdc4a4243b944":[5,2,6,2,45],
-"class_ogre_1_1_array_aabb.html#a5af3916040d0b4a1926cdc4a4243b944":[5,2,6,2,46],
-"class_ogre_1_1_array_aabb.html#a5af3916040d0b4a1926cdc4a4243b944":[5,2,6,2,47],
-"class_ogre_1_1_array_aabb.html#a5fcf5aac4c93a3795b9ac306c5ca6ebe":[5,2,6,2,30],
-"class_ogre_1_1_array_aabb.html#a5fcf5aac4c93a3795b9ac306c5ca6ebe":[5,2,6,2,31],
-"class_ogre_1_1_array_aabb.html#a5fcf5aac4c93a3795b9ac306c5ca6ebe":[5,2,6,2,32],
-"class_ogre_1_1_array_aabb.html#a634edd8238e051c392b6d1e01a65b050":[5,2,6,2,35],
-"class_ogre_1_1_array_aabb.html#a634edd8238e051c392b6d1e01a65b050":[5,2,6,2,34],
-"class_ogre_1_1_array_aabb.html#a634edd8238e051c392b6d1e01a65b050":[5,2,6,2,33],
-"class_ogre_1_1_array_aabb.html#a7e166349561727c9661170ddbf5dba78":[5,2,6,2,38],
-"class_ogre_1_1_array_aabb.html#a7e166349561727c9661170ddbf5dba78":[5,2,6,2,37],
-"class_ogre_1_1_array_aabb.html#a7e166349561727c9661170ddbf5dba78":[5,2,6,2,36],
-"class_ogre_1_1_array_aabb.html#a7e553a74e25a6d3bfcf45bf22285620f":[5,2,6,2,18],
-"class_ogre_1_1_array_aabb.html#a7e553a74e25a6d3bfcf45bf22285620f":[5,2,6,2,20],
-"class_ogre_1_1_array_aabb.html#a7e553a74e25a6d3bfcf45bf22285620f":[5,2,6,2,19],
-"class_ogre_1_1_array_aabb.html#a7ec2d8bd35e5014f95a090393dbef693":[5,2,6,2,42],
-"class_ogre_1_1_array_aabb.html#a7ec2d8bd35e5014f95a090393dbef693":[5,2,6,2,43],
-"class_ogre_1_1_array_aabb.html#a7ec2d8bd35e5014f95a090393dbef693":[5,2,6,2,44],
-"class_ogre_1_1_array_aabb.html#a95fa1ef93d6ff80615b7232a22622f21":[5,2,6,2,1],
-"class_ogre_1_1_array_aabb.html#a95fa1ef93d6ff80615b7232a22622f21":[5,2,6,2,5],
-"class_ogre_1_1_array_aabb.html#a95fa1ef93d6ff80615b7232a22622f21":[5,2,6,2,3],
-"class_ogre_1_1_array_aabb.html#ac00b7f25584c4bedd763ccc2bb5cb815":[5,2,6,2,39],
-"class_ogre_1_1_array_aabb.html#ac00b7f25584c4bedd763ccc2bb5cb815":[5,2,6,2,40],
-"class_ogre_1_1_array_aabb.html#ac00b7f25584c4bedd763ccc2bb5cb815":[5,2,6,2,41],
-"class_ogre_1_1_array_aabb.html#ac24b657e92288c56e381541bef3fcb41":[5,2,6,2,56],
-"class_ogre_1_1_array_aabb.html#ac7e2e02c4157dd5f59e6655e1bcf761d":[5,2,6,2,14],
-"class_ogre_1_1_array_aabb.html#ac7e2e02c4157dd5f59e6655e1bcf761d":[5,2,6,2,13],
-"class_ogre_1_1_array_aabb.html#ac7e2e02c4157dd5f59e6655e1bcf761d":[5,2,6,2,12],
-"class_ogre_1_1_array_aabb.html#ad0be8d1ebe6201e68ae5caef5ad756f0":[5,2,6,2,29],
-"class_ogre_1_1_array_aabb.html#ad0be8d1ebe6201e68ae5caef5ad756f0":[5,2,6,2,28],
-"class_ogre_1_1_array_aabb.html#ad0be8d1ebe6201e68ae5caef5ad756f0":[5,2,6,2,27],
-"class_ogre_1_1_array_aabb.html#ad30b614b3e01dccea145613b36fbce5a":[5,2,6,2,51],
-"class_ogre_1_1_array_aabb.html#ad30b614b3e01dccea145613b36fbce5a":[5,2,6,2,52],
-"class_ogre_1_1_array_aabb.html#ad30b614b3e01dccea145613b36fbce5a":[5,2,6,2,53],
-"class_ogre_1_1_array_aabb.html#ae2dc8dd876986aa00b92c78c49c03ed6":[5,2,6,2,8],
-"class_ogre_1_1_array_aabb.html#ae2dc8dd876986aa00b92c78c49c03ed6":[5,2,6,2,6],
-"class_ogre_1_1_array_aabb.html#ae2dc8dd876986aa00b92c78c49c03ed6":[5,2,6,2,7],
-"class_ogre_1_1_array_aabb.html#af4cbdaebc1e8afcc7fa6e8cb06cb61b7":[5,2,6,2,15],
-"class_ogre_1_1_array_aabb.html#af4cbdaebc1e8afcc7fa6e8cb06cb61b7":[5,2,6,2,16],
-"class_ogre_1_1_array_aabb.html#af4cbdaebc1e8afcc7fa6e8cb06cb61b7":[5,2,6,2,17],
-"class_ogre_1_1_array_aabb.html#af60970530d444414d0c9de75cdbdc7ad":[5,2,6,2,55],
 "class_ogre_1_1_array_aabb.html#af6adc0a598a7518f5f860f25b211ce74":[5,2,6,2,54],
-"class_ogre_1_1_array_aabb.html#af6cce5a6680360aca28dab72143428c7":[5,2,6,2,21],
-"class_ogre_1_1_array_aabb.html#af6cce5a6680360aca28dab72143428c7":[5,2,6,2,22],
 "class_ogre_1_1_array_aabb.html#af6cce5a6680360aca28dab72143428c7":[5,2,6,2,23],
+"class_ogre_1_1_array_aabb.html#af6cce5a6680360aca28dab72143428c7":[5,2,6,2,22],
+"class_ogre_1_1_array_aabb.html#af6cce5a6680360aca28dab72143428c7":[5,2,6,2,21],
 "class_ogre_1_1_array_matrix4.html":[5,2,6,3],
 "class_ogre_1_1_array_matrix4.html#a13b4b2d1d78147f679e78801807041f7":[5,2,6,3,23],
-"class_ogre_1_1_array_matrix4.html#a13b4b2d1d78147f679e78801807041f7":[5,2,6,3,22],
 "class_ogre_1_1_array_matrix4.html#a13b4b2d1d78147f679e78801807041f7":[5,2,6,3,21],
+"class_ogre_1_1_array_matrix4.html#a13b4b2d1d78147f679e78801807041f7":[5,2,6,3,22],
+"class_ogre_1_1_array_matrix4.html#a19c3a035709b3e29a5d90db76acd4449":[5,2,6,3,31],
 "class_ogre_1_1_array_matrix4.html#a19c3a035709b3e29a5d90db76acd4449":[5,2,6,3,32],
 "class_ogre_1_1_array_matrix4.html#a19c3a035709b3e29a5d90db76acd4449":[5,2,6,3,30],
-"class_ogre_1_1_array_matrix4.html#a19c3a035709b3e29a5d90db76acd4449":[5,2,6,3,31],
+"class_ogre_1_1_array_matrix4.html#a248749ab68684c0f5638acb51df5e6d0":[5,2,6,3,41],
 "class_ogre_1_1_array_matrix4.html#a248749ab68684c0f5638acb51df5e6d0":[5,2,6,3,39],
 "class_ogre_1_1_array_matrix4.html#a248749ab68684c0f5638acb51df5e6d0":[5,2,6,3,40],
-"class_ogre_1_1_array_matrix4.html#a248749ab68684c0f5638acb51df5e6d0":[5,2,6,3,41],
-"class_ogre_1_1_array_matrix4.html#a2bd11504369c2de5285f5f41430105bd":[5,2,6,3,1],
-"class_ogre_1_1_array_matrix4.html#a2bd11504369c2de5285f5f41430105bd":[5,2,6,3,3],
 "class_ogre_1_1_array_matrix4.html#a2bd11504369c2de5285f5f41430105bd":[5,2,6,3,5],
+"class_ogre_1_1_array_matrix4.html#a2bd11504369c2de5285f5f41430105bd":[5,2,6,3,3],
+"class_ogre_1_1_array_matrix4.html#a2bd11504369c2de5285f5f41430105bd":[5,2,6,3,1],
 "class_ogre_1_1_array_matrix4.html#a2c55df3235f7d6b01e83641aa2aa6ea1":[5,2,6,3,52],
 "class_ogre_1_1_array_matrix4.html#a2f6d57e521dc047c5e5b9933ce3dff5e":[5,2,6,3,2],
 "class_ogre_1_1_array_matrix4.html#a2f6d57e521dc047c5e5b9933ce3dff5e":[5,2,6,3,4],
@@ -74,60 +28,60 @@ var NAVTREEINDEX14 =
 "class_ogre_1_1_array_matrix4.html#a3cff98756e40389205f83da2521122ed":[5,2,6,3,8],
 "class_ogre_1_1_array_matrix4.html#a3cff98756e40389205f83da2521122ed":[5,2,6,3,7],
 "class_ogre_1_1_array_matrix4.html#a3cff98756e40389205f83da2521122ed":[5,2,6,3,6],
+"class_ogre_1_1_array_matrix4.html#a5226230ba09f0f49a29f3d1345352849":[5,2,6,3,26],
 "class_ogre_1_1_array_matrix4.html#a5226230ba09f0f49a29f3d1345352849":[5,2,6,3,25],
 "class_ogre_1_1_array_matrix4.html#a5226230ba09f0f49a29f3d1345352849":[5,2,6,3,24],
-"class_ogre_1_1_array_matrix4.html#a5226230ba09f0f49a29f3d1345352849":[5,2,6,3,26],
 "class_ogre_1_1_array_matrix4.html#a886c5c794b993dfdbd8bdc902f68c6e2":[5,2,6,3,42],
 "class_ogre_1_1_array_matrix4.html#a886c5c794b993dfdbd8bdc902f68c6e2":[5,2,6,3,43],
 "class_ogre_1_1_array_matrix4.html#a886c5c794b993dfdbd8bdc902f68c6e2":[5,2,6,3,44],
-"class_ogre_1_1_array_matrix4.html#a9ad5e41974f37356e8e3e645d94911e5":[5,2,6,3,11],
-"class_ogre_1_1_array_matrix4.html#a9ad5e41974f37356e8e3e645d94911e5":[5,2,6,3,10],
 "class_ogre_1_1_array_matrix4.html#a9ad5e41974f37356e8e3e645d94911e5":[5,2,6,3,9],
+"class_ogre_1_1_array_matrix4.html#a9ad5e41974f37356e8e3e645d94911e5":[5,2,6,3,10],
+"class_ogre_1_1_array_matrix4.html#a9ad5e41974f37356e8e3e645d94911e5":[5,2,6,3,11],
 "class_ogre_1_1_array_matrix4.html#aa884f38a7800606c51839e6ce9330481":[5,2,6,3,17],
-"class_ogre_1_1_array_matrix4.html#aa884f38a7800606c51839e6ce9330481":[5,2,6,3,15],
 "class_ogre_1_1_array_matrix4.html#aa884f38a7800606c51839e6ce9330481":[5,2,6,3,16],
-"class_ogre_1_1_array_matrix4.html#ab3c8379a7764651cfc24e40c0c518d02":[5,2,6,3,20],
+"class_ogre_1_1_array_matrix4.html#aa884f38a7800606c51839e6ce9330481":[5,2,6,3,15],
 "class_ogre_1_1_array_matrix4.html#ab3c8379a7764651cfc24e40c0c518d02":[5,2,6,3,19],
 "class_ogre_1_1_array_matrix4.html#ab3c8379a7764651cfc24e40c0c518d02":[5,2,6,3,18],
-"class_ogre_1_1_array_matrix4.html#ad2b9632c6e457596359d52df0c34ad07":[5,2,6,3,45],
-"class_ogre_1_1_array_matrix4.html#ad2b9632c6e457596359d52df0c34ad07":[5,2,6,3,46],
+"class_ogre_1_1_array_matrix4.html#ab3c8379a7764651cfc24e40c0c518d02":[5,2,6,3,20],
 "class_ogre_1_1_array_matrix4.html#ad2b9632c6e457596359d52df0c34ad07":[5,2,6,3,47],
+"class_ogre_1_1_array_matrix4.html#ad2b9632c6e457596359d52df0c34ad07":[5,2,6,3,46],
+"class_ogre_1_1_array_matrix4.html#ad2b9632c6e457596359d52df0c34ad07":[5,2,6,3,45],
 "class_ogre_1_1_array_matrix4.html#ad4cb3731a9161893d012db6738af00cd":[5,2,6,3,33],
 "class_ogre_1_1_array_matrix4.html#ad4cb3731a9161893d012db6738af00cd":[5,2,6,3,34],
 "class_ogre_1_1_array_matrix4.html#ad4cb3731a9161893d012db6738af00cd":[5,2,6,3,35],
 "class_ogre_1_1_array_matrix4.html#ae2a85219ae7561cdbee4a810a1ef9476":[5,2,6,3,48],
-"class_ogre_1_1_array_matrix4.html#ae2a85219ae7561cdbee4a810a1ef9476":[5,2,6,3,49],
 "class_ogre_1_1_array_matrix4.html#ae2a85219ae7561cdbee4a810a1ef9476":[5,2,6,3,50],
-"class_ogre_1_1_array_matrix4.html#af283b136e401dda8034365eb4ac0bb38":[5,2,6,3,12],
+"class_ogre_1_1_array_matrix4.html#ae2a85219ae7561cdbee4a810a1ef9476":[5,2,6,3,49],
 "class_ogre_1_1_array_matrix4.html#af283b136e401dda8034365eb4ac0bb38":[5,2,6,3,13],
 "class_ogre_1_1_array_matrix4.html#af283b136e401dda8034365eb4ac0bb38":[5,2,6,3,14],
+"class_ogre_1_1_array_matrix4.html#af283b136e401dda8034365eb4ac0bb38":[5,2,6,3,12],
 "class_ogre_1_1_array_matrix4.html#afe9bd81ade656a721c6b411481129e08":[5,2,6,3,38],
-"class_ogre_1_1_array_matrix4.html#afe9bd81ade656a721c6b411481129e08":[5,2,6,3,37],
 "class_ogre_1_1_array_matrix4.html#afe9bd81ade656a721c6b411481129e08":[5,2,6,3,36],
+"class_ogre_1_1_array_matrix4.html#afe9bd81ade656a721c6b411481129e08":[5,2,6,3,37],
 "class_ogre_1_1_array_matrix_af4x3.html":[5,2,6,4],
-"class_ogre_1_1_array_matrix_af4x3.html#a03e30cee9c49121adcee2be8665c85cf":[5,2,6,4,42],
-"class_ogre_1_1_array_matrix_af4x3.html#a03e30cee9c49121adcee2be8665c85cf":[5,2,6,4,43],
 "class_ogre_1_1_array_matrix_af4x3.html#a03e30cee9c49121adcee2be8665c85cf":[5,2,6,4,44],
+"class_ogre_1_1_array_matrix_af4x3.html#a03e30cee9c49121adcee2be8665c85cf":[5,2,6,4,43],
+"class_ogre_1_1_array_matrix_af4x3.html#a03e30cee9c49121adcee2be8665c85cf":[5,2,6,4,42],
 "class_ogre_1_1_array_matrix_af4x3.html#a137d186b82e91edf1db1fcd9031898d5":[5,2,6,4,55],
 "class_ogre_1_1_array_matrix_af4x3.html#a137d186b82e91edf1db1fcd9031898d5":[5,2,6,4,56],
 "class_ogre_1_1_array_matrix_af4x3.html#a1b1b5ad7c56d85c51462c3cd7ae7abac":[5,2,6,4,3],
 "class_ogre_1_1_array_matrix_af4x3.html#a1b1b5ad7c56d85c51462c3cd7ae7abac":[5,2,6,4,4],
 "class_ogre_1_1_array_matrix_af4x3.html#a1b1b5ad7c56d85c51462c3cd7ae7abac":[5,2,6,4,5],
-"class_ogre_1_1_array_matrix_af4x3.html#a28a18d864c185dd802c04185d50361e3":[5,2,6,4,33],
 "class_ogre_1_1_array_matrix_af4x3.html#a28a18d864c185dd802c04185d50361e3":[5,2,6,4,34],
+"class_ogre_1_1_array_matrix_af4x3.html#a28a18d864c185dd802c04185d50361e3":[5,2,6,4,33],
 "class_ogre_1_1_array_matrix_af4x3.html#a28a18d864c185dd802c04185d50361e3":[5,2,6,4,35],
 "class_ogre_1_1_array_matrix_af4x3.html#a32694ca633160b751668336511854a90":[5,2,6,4,39],
 "class_ogre_1_1_array_matrix_af4x3.html#a32694ca633160b751668336511854a90":[5,2,6,4,40],
 "class_ogre_1_1_array_matrix_af4x3.html#a32694ca633160b751668336511854a90":[5,2,6,4,41],
-"class_ogre_1_1_array_matrix_af4x3.html#a4022055cf3d2680bc5554e0664b312bf":[5,2,6,4,53],
-"class_ogre_1_1_array_matrix_af4x3.html#a4022055cf3d2680bc5554e0664b312bf":[5,2,6,4,52],
 "class_ogre_1_1_array_matrix_af4x3.html#a4022055cf3d2680bc5554e0664b312bf":[5,2,6,4,51],
-"class_ogre_1_1_array_matrix_af4x3.html#a40abb1b6861d2f8618143c5d0b993de4":[5,2,6,4,19],
+"class_ogre_1_1_array_matrix_af4x3.html#a4022055cf3d2680bc5554e0664b312bf":[5,2,6,4,52],
+"class_ogre_1_1_array_matrix_af4x3.html#a4022055cf3d2680bc5554e0664b312bf":[5,2,6,4,53],
 "class_ogre_1_1_array_matrix_af4x3.html#a40abb1b6861d2f8618143c5d0b993de4":[5,2,6,4,20],
+"class_ogre_1_1_array_matrix_af4x3.html#a40abb1b6861d2f8618143c5d0b993de4":[5,2,6,4,19],
 "class_ogre_1_1_array_matrix_af4x3.html#a40abb1b6861d2f8618143c5d0b993de4":[5,2,6,4,18],
+"class_ogre_1_1_array_matrix_af4x3.html#a497e95f427dede222f9cfeebdcb82a4b":[5,2,6,4,24],
 "class_ogre_1_1_array_matrix_af4x3.html#a497e95f427dede222f9cfeebdcb82a4b":[5,2,6,4,25],
 "class_ogre_1_1_array_matrix_af4x3.html#a497e95f427dede222f9cfeebdcb82a4b":[5,2,6,4,26],
-"class_ogre_1_1_array_matrix_af4x3.html#a497e95f427dede222f9cfeebdcb82a4b":[5,2,6,4,24],
 "class_ogre_1_1_array_matrix_af4x3.html#a58cdb74e2283ff197c26202b094f8c81":[5,2,6,4,45],
 "class_ogre_1_1_array_matrix_af4x3.html#a58cdb74e2283ff197c26202b094f8c81":[5,2,6,4,46],
 "class_ogre_1_1_array_matrix_af4x3.html#a58cdb74e2283ff197c26202b094f8c81":[5,2,6,4,47],
@@ -137,33 +91,33 @@ var NAVTREEINDEX14 =
 "class_ogre_1_1_array_matrix_af4x3.html#a8c30361f0010b1c13d434d49caa4bf22":[5,2,6,4,48],
 "class_ogre_1_1_array_matrix_af4x3.html#a8c30361f0010b1c13d434d49caa4bf22":[5,2,6,4,49],
 "class_ogre_1_1_array_matrix_af4x3.html#a8c30361f0010b1c13d434d49caa4bf22":[5,2,6,4,50],
-"class_ogre_1_1_array_matrix_af4x3.html#a8cec3411431d274afe484808a992f01b":[5,2,6,4,9],
-"class_ogre_1_1_array_matrix_af4x3.html#a8cec3411431d274afe484808a992f01b":[5,2,6,4,10],
 "class_ogre_1_1_array_matrix_af4x3.html#a8cec3411431d274afe484808a992f01b":[5,2,6,4,11],
-"class_ogre_1_1_array_matrix_af4x3.html#aa06bf5ad9d9bd15f1a2efa82bf067eaa":[5,2,6,4,38],
-"class_ogre_1_1_array_matrix_af4x3.html#aa06bf5ad9d9bd15f1a2efa82bf067eaa":[5,2,6,4,37],
+"class_ogre_1_1_array_matrix_af4x3.html#a8cec3411431d274afe484808a992f01b":[5,2,6,4,10],
+"class_ogre_1_1_array_matrix_af4x3.html#a8cec3411431d274afe484808a992f01b":[5,2,6,4,9],
 "class_ogre_1_1_array_matrix_af4x3.html#aa06bf5ad9d9bd15f1a2efa82bf067eaa":[5,2,6,4,36],
+"class_ogre_1_1_array_matrix_af4x3.html#aa06bf5ad9d9bd15f1a2efa82bf067eaa":[5,2,6,4,37],
+"class_ogre_1_1_array_matrix_af4x3.html#aa06bf5ad9d9bd15f1a2efa82bf067eaa":[5,2,6,4,38],
 "class_ogre_1_1_array_matrix_af4x3.html#aac3841269af026e2c3fe9062d8fc6d7a":[5,2,6,4,58],
-"class_ogre_1_1_array_matrix_af4x3.html#ab2a741f543ffa1cc9a8ad78960d36541":[5,2,6,4,12],
-"class_ogre_1_1_array_matrix_af4x3.html#ab2a741f543ffa1cc9a8ad78960d36541":[5,2,6,4,13],
 "class_ogre_1_1_array_matrix_af4x3.html#ab2a741f543ffa1cc9a8ad78960d36541":[5,2,6,4,14],
+"class_ogre_1_1_array_matrix_af4x3.html#ab2a741f543ffa1cc9a8ad78960d36541":[5,2,6,4,13],
+"class_ogre_1_1_array_matrix_af4x3.html#ab2a741f543ffa1cc9a8ad78960d36541":[5,2,6,4,12],
 "class_ogre_1_1_array_matrix_af4x3.html#ab2bed29b37b4216d21e8d2b1cf1c84a1":[5,2,6,4,57],
-"class_ogre_1_1_array_matrix_af4x3.html#abae10b4f1afe6de2cdf9899cb805f9d9":[5,2,6,4,2],
 "class_ogre_1_1_array_matrix_af4x3.html#abae10b4f1afe6de2cdf9899cb805f9d9":[5,2,6,4,0],
 "class_ogre_1_1_array_matrix_af4x3.html#abae10b4f1afe6de2cdf9899cb805f9d9":[5,2,6,4,1],
-"class_ogre_1_1_array_matrix_af4x3.html#ad1729c5af1a5b527c79a60072145fea6":[5,2,6,4,17],
-"class_ogre_1_1_array_matrix_af4x3.html#ad1729c5af1a5b527c79a60072145fea6":[5,2,6,4,16],
+"class_ogre_1_1_array_matrix_af4x3.html#abae10b4f1afe6de2cdf9899cb805f9d9":[5,2,6,4,2],
 "class_ogre_1_1_array_matrix_af4x3.html#ad1729c5af1a5b527c79a60072145fea6":[5,2,6,4,15],
+"class_ogre_1_1_array_matrix_af4x3.html#ad1729c5af1a5b527c79a60072145fea6":[5,2,6,4,16],
+"class_ogre_1_1_array_matrix_af4x3.html#ad1729c5af1a5b527c79a60072145fea6":[5,2,6,4,17],
 "class_ogre_1_1_array_matrix_af4x3.html#ad5b7e1047a24b908492cb1f09f3955fb":[5,2,6,4,30],
 "class_ogre_1_1_array_matrix_af4x3.html#ad65d4618db3ee91122348f8b7064b88c":[5,2,6,4,54],
-"class_ogre_1_1_array_matrix_af4x3.html#adc523942e11e9163478332fdcd45ec35":[5,2,6,4,6],
-"class_ogre_1_1_array_matrix_af4x3.html#adc523942e11e9163478332fdcd45ec35":[5,2,6,4,7],
 "class_ogre_1_1_array_matrix_af4x3.html#adc523942e11e9163478332fdcd45ec35":[5,2,6,4,8],
+"class_ogre_1_1_array_matrix_af4x3.html#adc523942e11e9163478332fdcd45ec35":[5,2,6,4,7],
+"class_ogre_1_1_array_matrix_af4x3.html#adc523942e11e9163478332fdcd45ec35":[5,2,6,4,6],
 "class_ogre_1_1_array_matrix_af4x3.html#ae9d1b8008bbf7aab6d1e8e4e8a49d8e9":[5,2,6,4,23],
 "class_ogre_1_1_array_matrix_af4x3.html#ae9d1b8008bbf7aab6d1e8e4e8a49d8e9":[5,2,6,4,22],
 "class_ogre_1_1_array_matrix_af4x3.html#ae9d1b8008bbf7aab6d1e8e4e8a49d8e9":[5,2,6,4,21],
-"class_ogre_1_1_array_matrix_af4x3.html#aefd4b573fd192ea5cc53bb62d1b7cd1a":[5,2,6,4,31],
 "class_ogre_1_1_array_matrix_af4x3.html#aefd4b573fd192ea5cc53bb62d1b7cd1a":[5,2,6,4,32],
+"class_ogre_1_1_array_matrix_af4x3.html#aefd4b573fd192ea5cc53bb62d1b7cd1a":[5,2,6,4,31],
 "class_ogre_1_1_array_memory_manager.html":[5,2,7,4],
 "class_ogre_1_1_array_memory_manager.html#a1483bb4f495abd37502c209eecc08881":[5,2,7,4,9],
 "class_ogre_1_1_array_memory_manager.html#a42fe5a861ebd6b4610189ce2be86b032":[5,2,7,4,10],
@@ -183,61 +137,61 @@ var NAVTREEINDEX14 =
 "class_ogre_1_1_array_memory_manager_1_1_rebase_listener.html#a4d3c6c480b79a8757e1348de53c80adb":[5,2,7,4,0,2],
 "class_ogre_1_1_array_memory_manager_1_1_rebase_listener.html#aefcfd7751701e774e0ba3ba51935438d":[5,2,7,4,0,0],
 "class_ogre_1_1_array_quaternion.html":[5,2,6,5],
-"class_ogre_1_1_array_quaternion.html#a01544ef11e2d8cf78eb4d1f99d49cc7d":[5,2,6,5,48],
-"class_ogre_1_1_array_quaternion.html#a01544ef11e2d8cf78eb4d1f99d49cc7d":[5,2,6,5,49],
 "class_ogre_1_1_array_quaternion.html#a01544ef11e2d8cf78eb4d1f99d49cc7d":[5,2,6,5,50],
-"class_ogre_1_1_array_quaternion.html#a184a4368428259f5ba79ab73de221966":[5,2,6,5,46],
+"class_ogre_1_1_array_quaternion.html#a01544ef11e2d8cf78eb4d1f99d49cc7d":[5,2,6,5,49],
+"class_ogre_1_1_array_quaternion.html#a01544ef11e2d8cf78eb4d1f99d49cc7d":[5,2,6,5,48],
 "class_ogre_1_1_array_quaternion.html#a184a4368428259f5ba79ab73de221966":[5,2,6,5,47],
+"class_ogre_1_1_array_quaternion.html#a184a4368428259f5ba79ab73de221966":[5,2,6,5,46],
 "class_ogre_1_1_array_quaternion.html#a184a4368428259f5ba79ab73de221966":[5,2,6,5,45],
+"class_ogre_1_1_array_quaternion.html#a1963a40cd1a3367e0c3da73ddb372eb5":[5,2,6,5,38],
 "class_ogre_1_1_array_quaternion.html#a1963a40cd1a3367e0c3da73ddb372eb5":[5,2,6,5,36],
 "class_ogre_1_1_array_quaternion.html#a1963a40cd1a3367e0c3da73ddb372eb5":[5,2,6,5,37],
-"class_ogre_1_1_array_quaternion.html#a1963a40cd1a3367e0c3da73ddb372eb5":[5,2,6,5,38],
 "class_ogre_1_1_array_quaternion.html#a1c0d250b5a3fb15890e419554db554c7":[5,2,6,5,107],
-"class_ogre_1_1_array_quaternion.html#a254f9edf7bd534889a58731b1bc4b7af":[5,2,6,5,94],
 "class_ogre_1_1_array_quaternion.html#a254f9edf7bd534889a58731b1bc4b7af":[5,2,6,5,93],
+"class_ogre_1_1_array_quaternion.html#a254f9edf7bd534889a58731b1bc4b7af":[5,2,6,5,94],
 "class_ogre_1_1_array_quaternion.html#a254f9edf7bd534889a58731b1bc4b7af":[5,2,6,5,95],
 "class_ogre_1_1_array_quaternion.html#a291c62e6eeb6a73e0265ecc599db6951":[5,2,6,5,56],
-"class_ogre_1_1_array_quaternion.html#a291c62e6eeb6a73e0265ecc599db6951":[5,2,6,5,54],
 "class_ogre_1_1_array_quaternion.html#a291c62e6eeb6a73e0265ecc599db6951":[5,2,6,5,55],
-"class_ogre_1_1_array_quaternion.html#a2c08e0fa391a98a684011a1605fc728b":[5,2,6,5,33],
-"class_ogre_1_1_array_quaternion.html#a2c08e0fa391a98a684011a1605fc728b":[5,2,6,5,34],
+"class_ogre_1_1_array_quaternion.html#a291c62e6eeb6a73e0265ecc599db6951":[5,2,6,5,54],
 "class_ogre_1_1_array_quaternion.html#a2c08e0fa391a98a684011a1605fc728b":[5,2,6,5,35],
+"class_ogre_1_1_array_quaternion.html#a2c08e0fa391a98a684011a1605fc728b":[5,2,6,5,34],
+"class_ogre_1_1_array_quaternion.html#a2c08e0fa391a98a684011a1605fc728b":[5,2,6,5,33],
+"class_ogre_1_1_array_quaternion.html#a2deffabdf04eff99282f1f23ec789012":[5,2,6,5,5],
 "class_ogre_1_1_array_quaternion.html#a2deffabdf04eff99282f1f23ec789012":[5,2,6,5,1],
 "class_ogre_1_1_array_quaternion.html#a2deffabdf04eff99282f1f23ec789012":[5,2,6,5,3],
-"class_ogre_1_1_array_quaternion.html#a2deffabdf04eff99282f1f23ec789012":[5,2,6,5,5],
 "class_ogre_1_1_array_quaternion.html#a3448a741c10d57a7ad6d23fc5eb10543":[5,2,6,5,105],
 "class_ogre_1_1_array_quaternion.html#a357bd979bf98ff8cfd5c1ffa9501597d":[5,2,6,5,77],
-"class_ogre_1_1_array_quaternion.html#a357bd979bf98ff8cfd5c1ffa9501597d":[5,2,6,5,76],
 "class_ogre_1_1_array_quaternion.html#a357bd979bf98ff8cfd5c1ffa9501597d":[5,2,6,5,75],
+"class_ogre_1_1_array_quaternion.html#a357bd979bf98ff8cfd5c1ffa9501597d":[5,2,6,5,76],
 "class_ogre_1_1_array_quaternion.html#a3cd4d3f42af2a8331282988de78d98ad":[5,2,6,5,6],
 "class_ogre_1_1_array_quaternion.html#a3cd4d3f42af2a8331282988de78d98ad":[5,2,6,5,7],
 "class_ogre_1_1_array_quaternion.html#a3cd4d3f42af2a8331282988de78d98ad":[5,2,6,5,8],
-"class_ogre_1_1_array_quaternion.html#a3d92191c55ff3ef7341fd6e25f7d6f33":[5,2,6,5,99],
-"class_ogre_1_1_array_quaternion.html#a3d92191c55ff3ef7341fd6e25f7d6f33":[5,2,6,5,100],
 "class_ogre_1_1_array_quaternion.html#a3d92191c55ff3ef7341fd6e25f7d6f33":[5,2,6,5,101],
+"class_ogre_1_1_array_quaternion.html#a3d92191c55ff3ef7341fd6e25f7d6f33":[5,2,6,5,100],
+"class_ogre_1_1_array_quaternion.html#a3d92191c55ff3ef7341fd6e25f7d6f33":[5,2,6,5,99],
 "class_ogre_1_1_array_quaternion.html#a43d157351ade034c073f9c7c5ef77a38":[5,2,6,5,102],
 "class_ogre_1_1_array_quaternion.html#a43d909969db69130ef7cd35c94a60e7e":[5,2,6,5,59],
-"class_ogre_1_1_array_quaternion.html#a43d909969db69130ef7cd35c94a60e7e":[5,2,6,5,58],
 "class_ogre_1_1_array_quaternion.html#a43d909969db69130ef7cd35c94a60e7e":[5,2,6,5,57],
+"class_ogre_1_1_array_quaternion.html#a43d909969db69130ef7cd35c94a60e7e":[5,2,6,5,58],
+"class_ogre_1_1_array_quaternion.html#a48fa346863dc235e8a457582dd7f1a5a":[5,2,6,5,84],
 "class_ogre_1_1_array_quaternion.html#a48fa346863dc235e8a457582dd7f1a5a":[5,2,6,5,86],
 "class_ogre_1_1_array_quaternion.html#a48fa346863dc235e8a457582dd7f1a5a":[5,2,6,5,85],
-"class_ogre_1_1_array_quaternion.html#a48fa346863dc235e8a457582dd7f1a5a":[5,2,6,5,84],
-"class_ogre_1_1_array_quaternion.html#a497e06d0ba8d4d550e781446b595a159":[5,2,6,5,79],
 "class_ogre_1_1_array_quaternion.html#a497e06d0ba8d4d550e781446b595a159":[5,2,6,5,78],
 "class_ogre_1_1_array_quaternion.html#a497e06d0ba8d4d550e781446b595a159":[5,2,6,5,80],
+"class_ogre_1_1_array_quaternion.html#a497e06d0ba8d4d550e781446b595a159":[5,2,6,5,79],
+"class_ogre_1_1_array_quaternion.html#a682e95327f327b963d4305e0f0a4343a":[5,2,6,5,90],
 "class_ogre_1_1_array_quaternion.html#a682e95327f327b963d4305e0f0a4343a":[5,2,6,5,91],
 "class_ogre_1_1_array_quaternion.html#a682e95327f327b963d4305e0f0a4343a":[5,2,6,5,92],
-"class_ogre_1_1_array_quaternion.html#a682e95327f327b963d4305e0f0a4343a":[5,2,6,5,90],
 "class_ogre_1_1_array_quaternion.html#a6df750766959b256298e2f1d96b5014a":[5,2,6,5,23],
-"class_ogre_1_1_array_quaternion.html#a6df750766959b256298e2f1d96b5014a":[5,2,6,5,22],
 "class_ogre_1_1_array_quaternion.html#a6df750766959b256298e2f1d96b5014a":[5,2,6,5,21],
-"class_ogre_1_1_array_quaternion.html#a7149452ca76a609114893c3acba577d8":[5,2,6,5,26],
-"class_ogre_1_1_array_quaternion.html#a7149452ca76a609114893c3acba577d8":[5,2,6,5,25],
+"class_ogre_1_1_array_quaternion.html#a6df750766959b256298e2f1d96b5014a":[5,2,6,5,22],
 "class_ogre_1_1_array_quaternion.html#a7149452ca76a609114893c3acba577d8":[5,2,6,5,24],
+"class_ogre_1_1_array_quaternion.html#a7149452ca76a609114893c3acba577d8":[5,2,6,5,25],
+"class_ogre_1_1_array_quaternion.html#a7149452ca76a609114893c3acba577d8":[5,2,6,5,26],
 "class_ogre_1_1_array_quaternion.html#a729eb2869c3578c682049f3d5522f25a":[5,2,6,5,108],
-"class_ogre_1_1_array_quaternion.html#a73dd9290ccad5b8dcb89c90910f5a2aa":[5,2,6,5,96],
-"class_ogre_1_1_array_quaternion.html#a73dd9290ccad5b8dcb89c90910f5a2aa":[5,2,6,5,97],
 "class_ogre_1_1_array_quaternion.html#a73dd9290ccad5b8dcb89c90910f5a2aa":[5,2,6,5,98],
+"class_ogre_1_1_array_quaternion.html#a73dd9290ccad5b8dcb89c90910f5a2aa":[5,2,6,5,97],
+"class_ogre_1_1_array_quaternion.html#a73dd9290ccad5b8dcb89c90910f5a2aa":[5,2,6,5,96],
 "class_ogre_1_1_array_quaternion.html#a74c441156545245b730c48b449058153":[5,2,6,5,41],
 "class_ogre_1_1_array_quaternion.html#a74c441156545245b730c48b449058153":[5,2,6,5,40],
 "class_ogre_1_1_array_quaternion.html#a74c441156545245b730c48b449058153":[5,2,6,5,39],
@@ -245,9 +199,55 @@ var NAVTREEINDEX14 =
 "class_ogre_1_1_array_quaternion.html#a9474055c4dcefaf7a9a976f3ca746aed":[5,2,6,5,29],
 "class_ogre_1_1_array_quaternion.html#a9474055c4dcefaf7a9a976f3ca746aed":[5,2,6,5,28],
 "class_ogre_1_1_array_quaternion.html#a9474055c4dcefaf7a9a976f3ca746aed":[5,2,6,5,27],
-"class_ogre_1_1_array_quaternion.html#aa3387ee1eccd427a777e1a1392ab70af":[5,2,6,5,74],
 "class_ogre_1_1_array_quaternion.html#aa3387ee1eccd427a777e1a1392ab70af":[5,2,6,5,72],
+"class_ogre_1_1_array_quaternion.html#aa3387ee1eccd427a777e1a1392ab70af":[5,2,6,5,74],
 "class_ogre_1_1_array_quaternion.html#aa3387ee1eccd427a777e1a1392ab70af":[5,2,6,5,73],
 "class_ogre_1_1_array_quaternion.html#aae37c7c02cacd3a4fa56d061b97511aa":[5,2,6,5,71],
-"class_ogre_1_1_array_quaternion.html#aae37c7c02cacd3a4fa56d061b97511aa":[5,2,6,5,70]
+"class_ogre_1_1_array_quaternion.html#aae37c7c02cacd3a4fa56d061b97511aa":[5,2,6,5,70],
+"class_ogre_1_1_array_quaternion.html#aae37c7c02cacd3a4fa56d061b97511aa":[5,2,6,5,69],
+"class_ogre_1_1_array_quaternion.html#aae7e321f11bc1df7ab26e7c12129332d":[5,2,6,5,52],
+"class_ogre_1_1_array_quaternion.html#aae7e321f11bc1df7ab26e7c12129332d":[5,2,6,5,51],
+"class_ogre_1_1_array_quaternion.html#aae7e321f11bc1df7ab26e7c12129332d":[5,2,6,5,53],
+"class_ogre_1_1_array_quaternion.html#ab7809bad5ea7c50f837f153a31d36cbd":[5,2,6,5,106],
+"class_ogre_1_1_array_quaternion.html#ab7cb890f59abb1a736195e3911f3350a":[5,2,6,5,42],
+"class_ogre_1_1_array_quaternion.html#ab7cb890f59abb1a736195e3911f3350a":[5,2,6,5,43],
+"class_ogre_1_1_array_quaternion.html#ab7cb890f59abb1a736195e3911f3350a":[5,2,6,5,44],
+"class_ogre_1_1_array_quaternion.html#ab9ccdab4853c21aadee9c8aeead56d1b":[5,2,6,5,81],
+"class_ogre_1_1_array_quaternion.html#ab9ccdab4853c21aadee9c8aeead56d1b":[5,2,6,5,82],
+"class_ogre_1_1_array_quaternion.html#ab9ccdab4853c21aadee9c8aeead56d1b":[5,2,6,5,83],
+"class_ogre_1_1_array_quaternion.html#ac5cdd7d6ef89c47c0e83049543b8c360":[5,2,6,5,89],
+"class_ogre_1_1_array_quaternion.html#ac5cdd7d6ef89c47c0e83049543b8c360":[5,2,6,5,87],
+"class_ogre_1_1_array_quaternion.html#ac5cdd7d6ef89c47c0e83049543b8c360":[5,2,6,5,88],
+"class_ogre_1_1_array_quaternion.html#acb7e62d03a2376bc7ac21cbbc5542073":[5,2,6,5,15],
+"class_ogre_1_1_array_quaternion.html#acb7e62d03a2376bc7ac21cbbc5542073":[5,2,6,5,16],
+"class_ogre_1_1_array_quaternion.html#acb7e62d03a2376bc7ac21cbbc5542073":[5,2,6,5,17],
+"class_ogre_1_1_array_quaternion.html#acd3067d55aa91af284d851e278a82a8c":[5,2,6,5,61],
+"class_ogre_1_1_array_quaternion.html#acd3067d55aa91af284d851e278a82a8c":[5,2,6,5,62],
+"class_ogre_1_1_array_quaternion.html#acd3067d55aa91af284d851e278a82a8c":[5,2,6,5,60],
+"class_ogre_1_1_array_quaternion.html#acde78171ef7f96a8d853559694204ba1":[5,2,6,5,10],
+"class_ogre_1_1_array_quaternion.html#acde78171ef7f96a8d853559694204ba1":[5,2,6,5,11],
+"class_ogre_1_1_array_quaternion.html#acde78171ef7f96a8d853559694204ba1":[5,2,6,5,9],
+"class_ogre_1_1_array_quaternion.html#ad05188f884f78a61d38c84e968a03456":[5,2,6,5,65],
+"class_ogre_1_1_array_quaternion.html#ad05188f884f78a61d38c84e968a03456":[5,2,6,5,64],
+"class_ogre_1_1_array_quaternion.html#ad05188f884f78a61d38c84e968a03456":[5,2,6,5,63],
+"class_ogre_1_1_array_quaternion.html#ada0dfedd0f952d031bffad28795f5134":[5,2,6,5,0],
+"class_ogre_1_1_array_quaternion.html#ada0dfedd0f952d031bffad28795f5134":[5,2,6,5,4],
+"class_ogre_1_1_array_quaternion.html#ada0dfedd0f952d031bffad28795f5134":[5,2,6,5,2],
+"class_ogre_1_1_array_quaternion.html#ade01356789f8bdc781a30892d8926fb8":[5,2,6,5,12],
+"class_ogre_1_1_array_quaternion.html#ade01356789f8bdc781a30892d8926fb8":[5,2,6,5,13],
+"class_ogre_1_1_array_quaternion.html#ade01356789f8bdc781a30892d8926fb8":[5,2,6,5,14],
+"class_ogre_1_1_array_quaternion.html#aeaaa0bf0e7ca5c5d82d83c470fb76f99":[5,2,6,5,103],
+"class_ogre_1_1_array_quaternion.html#aeded466c835c4cbdd843bbc255cd5835":[5,2,6,5,68],
+"class_ogre_1_1_array_quaternion.html#aeded466c835c4cbdd843bbc255cd5835":[5,2,6,5,66],
+"class_ogre_1_1_array_quaternion.html#aeded466c835c4cbdd843bbc255cd5835":[5,2,6,5,67],
+"class_ogre_1_1_array_quaternion.html#af351f7a0080aed25e11cd73228a68e4e":[5,2,6,5,20],
+"class_ogre_1_1_array_quaternion.html#af351f7a0080aed25e11cd73228a68e4e":[5,2,6,5,18],
+"class_ogre_1_1_array_quaternion.html#af351f7a0080aed25e11cd73228a68e4e":[5,2,6,5,19],
+"class_ogre_1_1_array_quaternion.html#af55151968302f10e0482901a3945e77b":[5,2,6,5,31],
+"class_ogre_1_1_array_quaternion.html#af55151968302f10e0482901a3945e77b":[5,2,6,5,30],
+"class_ogre_1_1_array_quaternion.html#af55151968302f10e0482901a3945e77b":[5,2,6,5,32],
+"class_ogre_1_1_array_ray.html":[6,0,0,61],
+"class_ogre_1_1_array_ray.html":[7,0,0,34],
+"class_ogre_1_1_array_ray.html#a02dae7456aa0b438426344fb16eb2dc5":[7,0,0,34,4],
+"class_ogre_1_1_array_ray.html#a02dae7456aa0b438426344fb16eb2dc5":[6,0,0,61,4]
 };
