@@ -1,121 +1,59 @@
 var NAVTREEINDEX144 =
 {
-"class_ogre_1_1_manual_object_1_1_manual_object_section.html#af3e51a107eb23f1324ef79a2f21168cc":[7,0,0,606,0,27],
-"class_ogre_1_1_manual_object_1_1_manual_object_section.html#af630e6230261ecca2ecbfcf0b0ee9ce9":[6,0,0,633,0,29],
-"class_ogre_1_1_manual_object_1_1_manual_object_section.html#af630e6230261ecca2ecbfcf0b0ee9ce9":[7,0,0,606,0,29],
-"class_ogre_1_1_manual_object_1_1_manual_object_section.html#af85238872bb197dea36acf21a578ecec":[6,0,0,633,0,35],
-"class_ogre_1_1_manual_object_1_1_manual_object_section.html#af85238872bb197dea36acf21a578ecec":[7,0,0,606,0,35],
-"class_ogre_1_1_manual_object_1_1_manual_object_section.html#afcbf4cb36d5911a9d40a40c57e94f23b":[6,0,0,633,0,51],
-"class_ogre_1_1_manual_object_1_1_manual_object_section.html#afcbf4cb36d5911a9d40a40c57e94f23b":[7,0,0,606,0,51],
-"class_ogre_1_1_manual_object_factory.html":[6,0,0,634],
-"class_ogre_1_1_manual_object_factory.html":[7,0,0,607],
-"class_ogre_1_1_manual_object_factory.html#a17fec4f461f88f160ddf4d049fb3b604":[6,0,0,634,15],
-"class_ogre_1_1_manual_object_factory.html#a17fec4f461f88f160ddf4d049fb3b604":[7,0,0,607,15],
-"class_ogre_1_1_manual_object_factory.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,634,7],
-"class_ogre_1_1_manual_object_factory.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,607,7],
-"class_ogre_1_1_manual_object_factory.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,607,9],
-"class_ogre_1_1_manual_object_factory.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,634,9],
-"class_ogre_1_1_manual_object_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,634,12],
-"class_ogre_1_1_manual_object_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,607,12],
-"class_ogre_1_1_manual_object_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,634,5],
-"class_ogre_1_1_manual_object_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,607,5],
-"class_ogre_1_1_manual_object_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,634,8],
-"class_ogre_1_1_manual_object_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,607,8],
-"class_ogre_1_1_manual_object_factory.html#aa560f7c52cdc8a091dbcb743005fb613":[7,0,0,607,4],
-"class_ogre_1_1_manual_object_factory.html#aa560f7c52cdc8a091dbcb743005fb613":[6,0,0,634,4],
-"class_ogre_1_1_manual_object_factory.html#aada4dab11e551ca13355df254ac0305b":[6,0,0,634,1],
-"class_ogre_1_1_manual_object_factory.html#aada4dab11e551ca13355df254ac0305b":[7,0,0,607,1],
-"class_ogre_1_1_manual_object_factory.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,634,11],
-"class_ogre_1_1_manual_object_factory.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,607,11],
-"class_ogre_1_1_manual_object_factory.html#abcaadec45f403cb7d358fdb9e519de25":[7,0,0,607,3],
-"class_ogre_1_1_manual_object_factory.html#abcaadec45f403cb7d358fdb9e519de25":[6,0,0,634,3],
-"class_ogre_1_1_manual_object_factory.html#abd16dae5dd18b58f57d2e0d8bdbb26e0":[7,0,0,607,2],
-"class_ogre_1_1_manual_object_factory.html#abd16dae5dd18b58f57d2e0d8bdbb26e0":[6,0,0,634,2],
-"class_ogre_1_1_manual_object_factory.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,607,6],
-"class_ogre_1_1_manual_object_factory.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,634,6],
-"class_ogre_1_1_manual_object_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,607,10],
-"class_ogre_1_1_manual_object_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,634,10],
-"class_ogre_1_1_manual_object_factory.html#adce32528577d71b228692df906ecd17c":[7,0,0,607,13],
-"class_ogre_1_1_manual_object_factory.html#adce32528577d71b228692df906ecd17c":[6,0,0,634,13],
-"class_ogre_1_1_manual_object_factory.html#ae7ff8d7532887e279d5bc70a022b94a8":[6,0,0,634,0],
-"class_ogre_1_1_manual_object_factory.html#ae7ff8d7532887e279d5bc70a022b94a8":[7,0,0,607,0],
-"class_ogre_1_1_manual_object_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,634,14],
-"class_ogre_1_1_manual_object_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,607,14],
-"class_ogre_1_1_manual_resource_loader.html":[5,2,11,86],
-"class_ogre_1_1_manual_resource_loader.html#a52b91457400f54642fd3c9e0182905f5":[5,2,11,86,0],
-"class_ogre_1_1_manual_resource_loader.html#a64c9f1f9f2817de97321412c59fabb5a":[5,2,11,86,1],
-"class_ogre_1_1_manual_resource_loader.html#a7b4afd007622d165efbcc362e5566922":[5,2,11,86,3],
-"class_ogre_1_1_manual_resource_loader.html#ae04795ab21e4a46709beb6d521a75c53":[5,2,11,86,2],
-"class_ogre_1_1_map_iterator.html":[7,0,0,609],
-"class_ogre_1_1_map_iterator.html":[6,0,0,636],
-"class_ogre_1_1_map_iterator.html#a1ab2dc537e2e04c6163f5901b791e9fc":[6,0,0,636,14],
-"class_ogre_1_1_map_iterator.html#a1ab2dc537e2e04c6163f5901b791e9fc":[7,0,0,609,14],
-"class_ogre_1_1_map_iterator.html#a22c1c22fab97253a922a190d2ace205e":[6,0,0,636,1],
-"class_ogre_1_1_map_iterator.html#a22c1c22fab97253a922a190d2ace205e":[7,0,0,609,1],
-"class_ogre_1_1_map_iterator.html#a2bef2d340ae00274856261b3ad3dcdbc":[7,0,0,609,11],
-"class_ogre_1_1_map_iterator.html#a2bef2d340ae00274856261b3ad3dcdbc":[6,0,0,636,11],
-"class_ogre_1_1_map_iterator.html#a4eec47de73ce626e19d5c7321a5fcefe":[7,0,0,609,8],
-"class_ogre_1_1_map_iterator.html#a4eec47de73ce626e19d5c7321a5fcefe":[6,0,0,636,8],
-"class_ogre_1_1_map_iterator.html#a5955d5dac2bd4a84d0f7120d3fb2a2bc":[7,0,0,609,9],
-"class_ogre_1_1_map_iterator.html#a5955d5dac2bd4a84d0f7120d3fb2a2bc":[6,0,0,636,9],
-"class_ogre_1_1_map_iterator.html#a649a4446fa5696bd95ed4ec5c3c9208a":[6,0,0,636,5],
-"class_ogre_1_1_map_iterator.html#a649a4446fa5696bd95ed4ec5c3c9208a":[7,0,0,609,5],
-"class_ogre_1_1_map_iterator.html#a69f5d04fa24319d698b69da3da118d36":[6,0,0,636,6],
-"class_ogre_1_1_map_iterator.html#a69f5d04fa24319d698b69da3da118d36":[7,0,0,609,6],
-"class_ogre_1_1_map_iterator.html#a704ce78ef948a2730b4774b4ba0cea69":[7,0,0,609,0],
-"class_ogre_1_1_map_iterator.html#a704ce78ef948a2730b4774b4ba0cea69":[6,0,0,636,0],
-"class_ogre_1_1_map_iterator.html#a7d788cb5bce74b71aafeee0c13340f7c":[6,0,0,636,10],
-"class_ogre_1_1_map_iterator.html#a7d788cb5bce74b71aafeee0c13340f7c":[7,0,0,609,10],
-"class_ogre_1_1_map_iterator.html#a9853756cc9d465e44272d69643d2c5ed":[7,0,0,609,3],
-"class_ogre_1_1_map_iterator.html#a9853756cc9d465e44272d69643d2c5ed":[6,0,0,636,3],
-"class_ogre_1_1_map_iterator.html#aad79b04aa34d0901590bc5229b196c92":[7,0,0,609,16],
-"class_ogre_1_1_map_iterator.html#aad79b04aa34d0901590bc5229b196c92":[6,0,0,636,16],
-"class_ogre_1_1_map_iterator.html#aae9d34883001f20e7b977fcf2bbaa38c":[6,0,0,636,15],
-"class_ogre_1_1_map_iterator.html#aae9d34883001f20e7b977fcf2bbaa38c":[7,0,0,609,15],
-"class_ogre_1_1_map_iterator.html#aaf01f897bea391797dc2bb9fb8374a5f":[6,0,0,636,13],
-"class_ogre_1_1_map_iterator.html#aaf01f897bea391797dc2bb9fb8374a5f":[7,0,0,609,13],
-"class_ogre_1_1_map_iterator.html#aba5a8ef400da4e0338f9b257727e9377":[6,0,0,636,2],
-"class_ogre_1_1_map_iterator.html#aba5a8ef400da4e0338f9b257727e9377":[7,0,0,609,2],
-"class_ogre_1_1_map_iterator.html#abd1f3f1f5143828a6296347d5b0b9d04":[7,0,0,609,12],
-"class_ogre_1_1_map_iterator.html#abd1f3f1f5143828a6296347d5b0b9d04":[6,0,0,636,12],
-"class_ogre_1_1_map_iterator.html#acae97fd0a5ae45d19b51ef4bd046d516":[6,0,0,636,7],
-"class_ogre_1_1_map_iterator.html#acae97fd0a5ae45d19b51ef4bd046d516":[7,0,0,609,7],
-"class_ogre_1_1_map_iterator.html#aeec13b7cd63fbc88d204df876a48393c":[7,0,0,609,4],
-"class_ogre_1_1_map_iterator.html#aeec13b7cd63fbc88d204df876a48393c":[6,0,0,636,4],
-"class_ogre_1_1_map_iterator_wrapper.html":[6,0,0,637],
-"class_ogre_1_1_map_iterator_wrapper.html":[7,0,0,610],
-"class_ogre_1_1_map_iterator_wrapper.html#a1ab2dc537e2e04c6163f5901b791e9fc":[6,0,0,637,13],
-"class_ogre_1_1_map_iterator_wrapper.html#a1ab2dc537e2e04c6163f5901b791e9fc":[7,0,0,610,13],
-"class_ogre_1_1_map_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e":[7,0,0,610,1],
-"class_ogre_1_1_map_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e":[6,0,0,637,1],
-"class_ogre_1_1_map_iterator_wrapper.html#a2bef2d340ae00274856261b3ad3dcdbc":[6,0,0,637,10],
-"class_ogre_1_1_map_iterator_wrapper.html#a2bef2d340ae00274856261b3ad3dcdbc":[7,0,0,610,10],
-"class_ogre_1_1_map_iterator_wrapper.html#a3ae82a852790d4ccf429958639672765":[7,0,0,610,6],
-"class_ogre_1_1_map_iterator_wrapper.html#a3ae82a852790d4ccf429958639672765":[6,0,0,637,6],
-"class_ogre_1_1_map_iterator_wrapper.html#a4eec47de73ce626e19d5c7321a5fcefe":[7,0,0,610,7],
-"class_ogre_1_1_map_iterator_wrapper.html#a4eec47de73ce626e19d5c7321a5fcefe":[6,0,0,637,7],
-"class_ogre_1_1_map_iterator_wrapper.html#a5955d5dac2bd4a84d0f7120d3fb2a2bc":[6,0,0,637,8],
-"class_ogre_1_1_map_iterator_wrapper.html#a5955d5dac2bd4a84d0f7120d3fb2a2bc":[7,0,0,610,8],
-"class_ogre_1_1_map_iterator_wrapper.html#a649a4446fa5696bd95ed4ec5c3c9208a":[6,0,0,637,5],
-"class_ogre_1_1_map_iterator_wrapper.html#a649a4446fa5696bd95ed4ec5c3c9208a":[7,0,0,610,5],
-"class_ogre_1_1_map_iterator_wrapper.html#a704ce78ef948a2730b4774b4ba0cea69":[7,0,0,610,0],
-"class_ogre_1_1_map_iterator_wrapper.html#a704ce78ef948a2730b4774b4ba0cea69":[6,0,0,637,0],
-"class_ogre_1_1_map_iterator_wrapper.html#a7d788cb5bce74b71aafeee0c13340f7c":[7,0,0,610,9],
-"class_ogre_1_1_map_iterator_wrapper.html#a7d788cb5bce74b71aafeee0c13340f7c":[6,0,0,637,9],
-"class_ogre_1_1_map_iterator_wrapper.html#a9853756cc9d465e44272d69643d2c5ed":[6,0,0,637,3],
-"class_ogre_1_1_map_iterator_wrapper.html#a9853756cc9d465e44272d69643d2c5ed":[7,0,0,610,3],
-"class_ogre_1_1_map_iterator_wrapper.html#aad79b04aa34d0901590bc5229b196c92":[6,0,0,637,15],
-"class_ogre_1_1_map_iterator_wrapper.html#aad79b04aa34d0901590bc5229b196c92":[7,0,0,610,15],
-"class_ogre_1_1_map_iterator_wrapper.html#aae9d34883001f20e7b977fcf2bbaa38c":[6,0,0,637,14],
-"class_ogre_1_1_map_iterator_wrapper.html#aae9d34883001f20e7b977fcf2bbaa38c":[7,0,0,610,14],
-"class_ogre_1_1_map_iterator_wrapper.html#aaf01f897bea391797dc2bb9fb8374a5f":[6,0,0,637,12],
-"class_ogre_1_1_map_iterator_wrapper.html#aaf01f897bea391797dc2bb9fb8374a5f":[7,0,0,610,12],
-"class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[6,0,0,637,2],
-"class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[7,0,0,610,2],
-"class_ogre_1_1_map_iterator_wrapper.html#abd1f3f1f5143828a6296347d5b0b9d04":[7,0,0,610,11],
-"class_ogre_1_1_map_iterator_wrapper.html#abd1f3f1f5143828a6296347d5b0b9d04":[6,0,0,637,11],
-"class_ogre_1_1_map_iterator_wrapper.html#aeec13b7cd63fbc88d204df876a48393c":[6,0,0,637,4],
-"class_ogre_1_1_map_iterator_wrapper.html#aeec13b7cd63fbc88d204df876a48393c":[7,0,0,610,4],
+"class_ogre_1_1_map_iterator.html#a704ce78ef948a2730b4774b4ba0cea69":[6,0,0,634,0],
+"class_ogre_1_1_map_iterator.html#a704ce78ef948a2730b4774b4ba0cea69":[7,0,0,607,0],
+"class_ogre_1_1_map_iterator.html#a7d788cb5bce74b71aafeee0c13340f7c":[7,0,0,607,10],
+"class_ogre_1_1_map_iterator.html#a7d788cb5bce74b71aafeee0c13340f7c":[6,0,0,634,10],
+"class_ogre_1_1_map_iterator.html#a9853756cc9d465e44272d69643d2c5ed":[6,0,0,634,3],
+"class_ogre_1_1_map_iterator.html#a9853756cc9d465e44272d69643d2c5ed":[7,0,0,607,3],
+"class_ogre_1_1_map_iterator.html#aad79b04aa34d0901590bc5229b196c92":[7,0,0,607,16],
+"class_ogre_1_1_map_iterator.html#aad79b04aa34d0901590bc5229b196c92":[6,0,0,634,16],
+"class_ogre_1_1_map_iterator.html#aae9d34883001f20e7b977fcf2bbaa38c":[6,0,0,634,15],
+"class_ogre_1_1_map_iterator.html#aae9d34883001f20e7b977fcf2bbaa38c":[7,0,0,607,15],
+"class_ogre_1_1_map_iterator.html#aaf01f897bea391797dc2bb9fb8374a5f":[7,0,0,607,13],
+"class_ogre_1_1_map_iterator.html#aaf01f897bea391797dc2bb9fb8374a5f":[6,0,0,634,13],
+"class_ogre_1_1_map_iterator.html#aba5a8ef400da4e0338f9b257727e9377":[6,0,0,634,2],
+"class_ogre_1_1_map_iterator.html#aba5a8ef400da4e0338f9b257727e9377":[7,0,0,607,2],
+"class_ogre_1_1_map_iterator.html#abd1f3f1f5143828a6296347d5b0b9d04":[6,0,0,634,12],
+"class_ogre_1_1_map_iterator.html#abd1f3f1f5143828a6296347d5b0b9d04":[7,0,0,607,12],
+"class_ogre_1_1_map_iterator.html#acae97fd0a5ae45d19b51ef4bd046d516":[7,0,0,607,7],
+"class_ogre_1_1_map_iterator.html#acae97fd0a5ae45d19b51ef4bd046d516":[6,0,0,634,7],
+"class_ogre_1_1_map_iterator.html#aeec13b7cd63fbc88d204df876a48393c":[7,0,0,607,4],
+"class_ogre_1_1_map_iterator.html#aeec13b7cd63fbc88d204df876a48393c":[6,0,0,634,4],
+"class_ogre_1_1_map_iterator_wrapper.html":[6,0,0,635],
+"class_ogre_1_1_map_iterator_wrapper.html":[7,0,0,608],
+"class_ogre_1_1_map_iterator_wrapper.html#a1ab2dc537e2e04c6163f5901b791e9fc":[6,0,0,635,13],
+"class_ogre_1_1_map_iterator_wrapper.html#a1ab2dc537e2e04c6163f5901b791e9fc":[7,0,0,608,13],
+"class_ogre_1_1_map_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e":[6,0,0,635,1],
+"class_ogre_1_1_map_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e":[7,0,0,608,1],
+"class_ogre_1_1_map_iterator_wrapper.html#a2bef2d340ae00274856261b3ad3dcdbc":[6,0,0,635,10],
+"class_ogre_1_1_map_iterator_wrapper.html#a2bef2d340ae00274856261b3ad3dcdbc":[7,0,0,608,10],
+"class_ogre_1_1_map_iterator_wrapper.html#a3ae82a852790d4ccf429958639672765":[7,0,0,608,6],
+"class_ogre_1_1_map_iterator_wrapper.html#a3ae82a852790d4ccf429958639672765":[6,0,0,635,6],
+"class_ogre_1_1_map_iterator_wrapper.html#a4eec47de73ce626e19d5c7321a5fcefe":[6,0,0,635,7],
+"class_ogre_1_1_map_iterator_wrapper.html#a4eec47de73ce626e19d5c7321a5fcefe":[7,0,0,608,7],
+"class_ogre_1_1_map_iterator_wrapper.html#a5955d5dac2bd4a84d0f7120d3fb2a2bc":[6,0,0,635,8],
+"class_ogre_1_1_map_iterator_wrapper.html#a5955d5dac2bd4a84d0f7120d3fb2a2bc":[7,0,0,608,8],
+"class_ogre_1_1_map_iterator_wrapper.html#a649a4446fa5696bd95ed4ec5c3c9208a":[6,0,0,635,5],
+"class_ogre_1_1_map_iterator_wrapper.html#a649a4446fa5696bd95ed4ec5c3c9208a":[7,0,0,608,5],
+"class_ogre_1_1_map_iterator_wrapper.html#a704ce78ef948a2730b4774b4ba0cea69":[7,0,0,608,0],
+"class_ogre_1_1_map_iterator_wrapper.html#a704ce78ef948a2730b4774b4ba0cea69":[6,0,0,635,0],
+"class_ogre_1_1_map_iterator_wrapper.html#a7d788cb5bce74b71aafeee0c13340f7c":[6,0,0,635,9],
+"class_ogre_1_1_map_iterator_wrapper.html#a7d788cb5bce74b71aafeee0c13340f7c":[7,0,0,608,9],
+"class_ogre_1_1_map_iterator_wrapper.html#a9853756cc9d465e44272d69643d2c5ed":[6,0,0,635,3],
+"class_ogre_1_1_map_iterator_wrapper.html#a9853756cc9d465e44272d69643d2c5ed":[7,0,0,608,3],
+"class_ogre_1_1_map_iterator_wrapper.html#aad79b04aa34d0901590bc5229b196c92":[7,0,0,608,15],
+"class_ogre_1_1_map_iterator_wrapper.html#aad79b04aa34d0901590bc5229b196c92":[6,0,0,635,15],
+"class_ogre_1_1_map_iterator_wrapper.html#aae9d34883001f20e7b977fcf2bbaa38c":[6,0,0,635,14],
+"class_ogre_1_1_map_iterator_wrapper.html#aae9d34883001f20e7b977fcf2bbaa38c":[7,0,0,608,14],
+"class_ogre_1_1_map_iterator_wrapper.html#aaf01f897bea391797dc2bb9fb8374a5f":[6,0,0,635,12],
+"class_ogre_1_1_map_iterator_wrapper.html#aaf01f897bea391797dc2bb9fb8374a5f":[7,0,0,608,12],
+"class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[6,0,0,635,2],
+"class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[7,0,0,608,2],
+"class_ogre_1_1_map_iterator_wrapper.html#abd1f3f1f5143828a6296347d5b0b9d04":[6,0,0,635,11],
+"class_ogre_1_1_map_iterator_wrapper.html#abd1f3f1f5143828a6296347d5b0b9d04":[7,0,0,608,11],
+"class_ogre_1_1_map_iterator_wrapper.html#aeec13b7cd63fbc88d204df876a48393c":[6,0,0,635,4],
+"class_ogre_1_1_map_iterator_wrapper.html#aeec13b7cd63fbc88d204df876a48393c":[7,0,0,608,4],
 "class_ogre_1_1_material.html":[5,2,5,14],
 "class_ogre_1_1_material.html#a008c264b3fa918677120621d6a112f99":[5,2,5,14,96],
 "class_ogre_1_1_material.html#a00967b56ec980480ba12dc6002462c3b":[5,2,5,14,58],
@@ -249,5 +187,67 @@ var NAVTREEINDEX144 =
 "class_ogre_1_1_material_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[5,2,5,15,2],
 "class_ogre_1_1_material_manager.html#a2cf457c70ea86892b1bec52028c96237":[5,2,5,15,67],
 "class_ogre_1_1_material_manager.html#a3068599a5b10421e6203d568006f5f93":[5,2,5,15,18],
-"class_ogre_1_1_material_manager.html#a39d14d6f640b2dd089a16a9c0b149222":[5,2,5,15,39]
+"class_ogre_1_1_material_manager.html#a39d14d6f640b2dd089a16a9c0b149222":[5,2,5,15,39],
+"class_ogre_1_1_material_manager.html#a3e170600b0358e8b4c27c79c343ed225":[5,2,5,15,24],
+"class_ogre_1_1_material_manager.html#a3f92489910e40e3756606a35618d7b06":[5,2,5,15,56],
+"class_ogre_1_1_material_manager.html#a40769092850d5b296e1d1a9190631700":[5,2,5,15,15],
+"class_ogre_1_1_material_manager.html#a42f172a8ed1625011d510b081eee66dd":[5,2,5,15,28],
+"class_ogre_1_1_material_manager.html#a48c565d0e63b286c6388439ae73417df":[5,2,5,15,19],
+"class_ogre_1_1_material_manager.html#a492f18490f58482ff4698ea6cafc3472":[5,2,5,15,11],
+"class_ogre_1_1_material_manager.html#a4d3289d4636168230da11c1c9794db59":[5,2,5,15,32],
+"class_ogre_1_1_material_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[5,2,5,15,55],
+"class_ogre_1_1_material_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[5,2,5,15,4],
+"class_ogre_1_1_material_manager.html#a54d1843a43aebb13542312cd17134e6a":[5,2,5,15,16],
+"class_ogre_1_1_material_manager.html#a57e22b305d763f9ede5bda93f31051ca":[5,2,5,15,34],
+"class_ogre_1_1_material_manager.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,5,15,45],
+"class_ogre_1_1_material_manager.html#a59f93c2d8ee5924ff0e2ccad8c36d690":[5,2,5,15,37],
+"class_ogre_1_1_material_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,5,15,48],
+"class_ogre_1_1_material_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[5,2,5,15,31],
+"class_ogre_1_1_material_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[5,2,5,15,61],
+"class_ogre_1_1_material_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[5,2,5,15,59],
+"class_ogre_1_1_material_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[5,2,5,15,21],
+"class_ogre_1_1_material_manager.html#a7e3d13469f80b5814e20f9f959384119":[5,2,5,15,51],
+"class_ogre_1_1_material_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,5,15,41],
+"class_ogre_1_1_material_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[5,2,5,15,54],
+"class_ogre_1_1_material_manager.html#a88fbd340847931e3dae4aa57cf21ad6b":[5,2,5,15,8],
+"class_ogre_1_1_material_manager.html#a8ac18f4bd2e6302f1d92ae8f64195694":[5,2,5,15,17],
+"class_ogre_1_1_material_manager.html#a8b2aa864d83fe5e423c3ebd4f2295b63":[5,2,5,15,13],
+"class_ogre_1_1_material_manager.html#a8d14d2e8450b0886c6b72c9996200b17":[5,2,5,15,60],
+"class_ogre_1_1_material_manager.html#a8effa67ee128c4edecb7db1c3a318bf7":[5,2,5,15,26],
+"class_ogre_1_1_material_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[5,2,5,15,70],
+"class_ogre_1_1_material_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,5,15,44],
+"class_ogre_1_1_material_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[5,2,5,15,68],
+"class_ogre_1_1_material_manager.html#a95decc3900f547bb68b74ba28d3013e0":[5,2,5,15,64],
+"class_ogre_1_1_material_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[5,2,5,15,62],
+"class_ogre_1_1_material_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[5,2,5,15,30],
+"class_ogre_1_1_material_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[5,2,5,15,66],
+"class_ogre_1_1_material_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[5,2,5,15,65],
+"class_ogre_1_1_material_manager.html#aa8b761abb06d74347e9636550307ccd9":[5,2,5,15,23],
+"class_ogre_1_1_material_manager.html#aa9608544a7beb1b0e43835877ab62788":[5,2,5,15,53],
+"class_ogre_1_1_material_manager.html#aabb8080830988a13ac1ee7fa12898e39":[5,2,5,15,7],
+"class_ogre_1_1_material_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[5,2,5,15,25],
+"class_ogre_1_1_material_manager.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,5,15,47],
+"class_ogre_1_1_material_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[5,2,5,15,73],
+"class_ogre_1_1_material_manager.html#abfb0022b18d022a7605f0d19a966f00f":[5,2,5,15,57],
+"class_ogre_1_1_material_manager.html#ac1c82898c82556003eb8314aea1a0a3c":[5,2,5,15,12],
+"class_ogre_1_1_material_manager.html#ac22655af03ecea85d863a1d1d561778c":[5,2,5,15,58],
+"class_ogre_1_1_material_manager.html#ac70230fa9f123976d7f2b1257bd94bd4":[5,2,5,15,27],
+"class_ogre_1_1_material_manager.html#ac8f7ee61606730572a8590060d8896a0":[5,2,5,15,29],
+"class_ogre_1_1_material_manager.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,5,15,42],
+"class_ogre_1_1_material_manager.html#acd4223279e97a7687e2f9994f05e2491":[5,2,5,15,20],
+"class_ogre_1_1_material_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,5,15,46],
+"class_ogre_1_1_material_manager.html#ad6d63fe7126510bf10fd337705cb0b29":[5,2,5,15,40],
+"class_ogre_1_1_material_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[5,2,5,15,63],
+"class_ogre_1_1_material_manager.html#adce32528577d71b228692df906ecd17c":[5,2,5,15,49],
+"class_ogre_1_1_material_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[5,2,5,15,52],
+"class_ogre_1_1_material_manager.html#ae755a83a5d2d1dea391d8c1c74371e4f":[5,2,5,15,36],
+"class_ogre_1_1_material_manager.html#aea9231e6fc04369c0440b16c65c8bb69":[5,2,5,15,10],
+"class_ogre_1_1_material_manager.html#aeaa1410333b7bcea14b00c360112a528":[5,2,5,15,71],
+"class_ogre_1_1_material_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,5,15,50],
+"class_ogre_1_1_material_manager.html#aef0e85acfedd02d09bc78829607725b9":[5,2,5,15,6],
+"class_ogre_1_1_material_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[5,2,5,15,14],
+"class_ogre_1_1_material_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[5,2,5,15,1],
+"class_ogre_1_1_material_manager.html#af96b58b31c152a8ae3c6152ee3ea12e7":[5,2,5,15,38],
+"class_ogre_1_1_material_manager_1_1_listener.html":[5,2,5,15,0],
+"class_ogre_1_1_material_manager_1_1_listener.html#a46125aa4d08dc36a9b5759f805c6dbd7":[5,2,5,15,0,1]
 };
