@@ -1,65 +1,5 @@
 var NAVTREEINDEX183 =
 {
-"class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#ae856178ef392e5f8b082cea81b15c141":[5,2,12,35,24],
-"class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#aea92d3872f6f0f8bbab04eb8f0474fa2":[5,2,12,35,2],
-"class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#aea92d3872f6f0f8bbab04eb8f0474fa2":[5,0,1,35,2],
-"class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,35,23],
-"class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,35,23],
-"class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#af7283157442184a861fcd6947a63bf4d":[5,0,1,35,29],
-"class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#af7283157442184a861fcd6947a63bf4d":[5,2,12,35,29],
-"class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#affbbc8885fc753e53b9ce1f9fe6e891f":[5,0,1,35,7],
-"class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#affbbc8885fc753e53b9ce1f9fe6e891f":[5,2,12,35,7],
-"class_ogre_1_1_p_v_r_t_c_codec.html":[5,2,3,21],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,3,21,19],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a21f4b8a16d070793d576f827c9fee218":[5,2,3,21,1],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a270be35471eb9ef28fdbd4b7dced21b9":[5,2,3,21,15],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a29e31ad112b08ea7fb648b63f426ff1f":[5,2,3,21,0],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a37968d655c2950f0420bbaa3eeaa0f60":[5,2,3,21,11],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a55bf1d49e91958f8e412a583666bbd58":[5,2,3,21,10],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,3,21,21],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a5ce8a89e2e6cab4536b4273b87518fec":[5,2,3,21,4],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a5faa60b11adc70d045cf999b39028dd5":[5,2,3,21,7],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1":[5,2,3,21,12],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a60f445cc6919df56af6611fd14eec47d":[5,2,3,21,27],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a62bd5a2e37af02c2701cdf33040d8c6f":[5,2,3,21,28],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,3,21,24],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a6bd4ffa897d98a88839a693f00f9601e":[5,2,3,21,3],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a723481657bfed71fdbdb8669020bebfb":[5,2,3,21,6],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a7aa2599cd9db05e590fb7f7786076852":[5,2,3,21,30],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,3,21,17],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a839c01a137e0c72abd646a9a80461799":[5,2,3,21,5],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a8cc81c85bd7d4e25393aa153c5e01454":[5,2,3,21,2],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a938a753e65d5153ef2a3787eb7fe3630":[5,2,3,21,8],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,3,21,20],
-"class_ogre_1_1_p_v_r_t_c_codec.html#a9909076c79f9534d2d185a48f7219204":[5,2,3,21,13],
-"class_ogre_1_1_p_v_r_t_c_codec.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,3,21,23],
-"class_ogre_1_1_p_v_r_t_c_codec.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,3,21,18],
-"class_ogre_1_1_p_v_r_t_c_codec.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,3,21,22],
-"class_ogre_1_1_p_v_r_t_c_codec.html#ad2bb763bae77c3ac206e528ec2c68a4e":[5,2,3,21,16],
-"class_ogre_1_1_p_v_r_t_c_codec.html#adce32528577d71b228692df906ecd17c":[5,2,3,21,25],
-"class_ogre_1_1_p_v_r_t_c_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557":[5,2,3,21,14],
-"class_ogre_1_1_p_v_r_t_c_codec.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,3,21,26],
-"class_ogre_1_1_p_v_r_t_c_codec.html#aedb803489bfc3bcbf600ee6dfa2caf8a":[5,2,3,21,9],
-"class_ogre_1_1_p_v_r_t_c_codec.html#af31db2aa5603b320067943574b1eea86":[5,2,3,21,29],
-"class_ogre_1_1_page.html":[5,1,0,2],
-"class_ogre_1_1_page.html#a022e11e15f1bf7715e2f9b58db3a72f0":[5,1,0,2,12],
-"class_ogre_1_1_page.html#a126724f388586df070971c3d7bc67eed":[5,1,0,2,1],
-"class_ogre_1_1_page.html#a1881c61300af0fb73a879b9316aef0e3":[5,1,0,2,22],
-"class_ogre_1_1_page.html#a1c1a835365a73cef716c3fba097d43b0":[5,1,0,2,17],
-"class_ogre_1_1_page.html#a1c727e879a260c37b00ce5505fe8e144":[5,1,0,2,28],
-"class_ogre_1_1_page.html#a376bbf6ea8fb5420e5054b7a8ee8fbbf":[5,1,0,2,40],
-"class_ogre_1_1_page.html#a3d71c404efc53ee4188a1cc3da596d97":[5,1,0,2,0],
-"class_ogre_1_1_page.html#a3e963a28826407a7cb45f6c8fdaab4ce":[5,1,0,2,5],
-"class_ogre_1_1_page.html#a3f837b9ed9685e48b469a26a31759d70":[5,1,0,2,39],
-"class_ogre_1_1_page.html#a453f4bbee5590c407ca6a4dd7dc61e32":[5,1,0,2,36],
-"class_ogre_1_1_page.html#a4aa1aaaeb7449c1f0693f44807ed6466":[5,1,0,2,13],
-"class_ogre_1_1_page.html#a4f44abbd1ab98cda665f26c45f339000":[5,1,0,2,41],
-"class_ogre_1_1_page.html#a5707ad53db103e123ff17a4837925c40":[5,1,0,2,44],
-"class_ogre_1_1_page.html#a595ea4c05da8aa987d3800e65d23355d":[5,1,0,2,30],
-"class_ogre_1_1_page.html#a5dfd6c79d344e709f5084be205bed2d4":[5,1,0,2,15],
-"class_ogre_1_1_page.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,1,0,2,33],
-"class_ogre_1_1_page.html#a6bb0e50b1d6056d204dbd95f58cbdc45":[5,1,0,2,42],
-"class_ogre_1_1_page.html#a77938af13dcb2d153383f5f182dda771":[5,1,0,2,16],
 "class_ogre_1_1_page.html#a78a47f9c61eec2ad33423d526a0e4153":[5,1,0,2,18],
 "class_ogre_1_1_page.html#a7b0cd70b09d2fe5134a57cb70ebe080d":[5,1,0,2,11],
 "class_ogre_1_1_page.html#a7d54d0141d86f76a8ef49ecd3c48aeea":[5,1,0,2,7],
@@ -249,5 +189,65 @@ var NAVTREEINDEX183 =
 "class_ogre_1_1_page_provider.html#a21e0f99d400fea63fb6dd4024c873834":[5,1,0,11,2],
 "class_ogre_1_1_page_provider.html#a65af0f29f55d90f754ddf3e28a2a1c8b":[5,1,0,11,8],
 "class_ogre_1_1_page_provider.html#a66ee65df7701f813b055ed09aeaa7949":[5,1,0,11,7],
-"class_ogre_1_1_page_provider.html#a673e0105f4c2a4cb4f4a1631ebfe48c8":[5,1,0,11,3]
+"class_ogre_1_1_page_provider.html#a673e0105f4c2a4cb4f4a1631ebfe48c8":[5,1,0,11,3],
+"class_ogre_1_1_page_provider.html#ab0f1061b31c84bb8b730ac848a8241e7":[5,1,0,11,1],
+"class_ogre_1_1_page_provider.html#ab796c764ed717dc1f5f4f70b9fd7f3f2":[5,1,0,11,0],
+"class_ogre_1_1_page_provider.html#ac99a05c6c06b2e8fe332aca37e1fa795":[5,1,0,11,4],
+"class_ogre_1_1_page_provider.html#adf7b09b8f6185a7832cbb1bcff83207e":[5,1,0,11,9],
+"class_ogre_1_1_page_provider.html#ae164fead87b9512b924b2ad3e20dba97":[5,1,0,11,6],
+"class_ogre_1_1_page_strategy.html":[5,1,6],
+"class_ogre_1_1_page_strategy.html#a1c727e879a260c37b00ce5505fe8e144":[5,1,6,12],
+"class_ogre_1_1_page_strategy.html#a595ea4c05da8aa987d3800e65d23355d":[5,1,6,14],
+"class_ogre_1_1_page_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,1,6,17],
+"class_ogre_1_1_page_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,1,6,10],
+"class_ogre_1_1_page_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,1,6,13],
+"class_ogre_1_1_page_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[5,1,6,16],
+"class_ogre_1_1_page_strategy.html#acb46d4b0a597156d9ba5abc39d127792":[5,1,6,11],
+"class_ogre_1_1_page_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,1,6,15],
+"class_ogre_1_1_page_strategy.html#adce32528577d71b228692df906ecd17c":[5,1,6,18],
+"class_ogre_1_1_page_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,1,6,19],
+"class_ogre_1_1_page_strategy_data.html":[5,1,7],
+"class_ogre_1_1_page_strategy_data.html#a1c727e879a260c37b00ce5505fe8e144":[5,1,7,5],
+"class_ogre_1_1_page_strategy_data.html#a595ea4c05da8aa987d3800e65d23355d":[5,1,7,7],
+"class_ogre_1_1_page_strategy_data.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,1,7,10],
+"class_ogre_1_1_page_strategy_data.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,1,7,3],
+"class_ogre_1_1_page_strategy_data.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,1,7,6],
+"class_ogre_1_1_page_strategy_data.html#ab422c67a2c8844f410fe822a357cba3b":[5,1,7,9],
+"class_ogre_1_1_page_strategy_data.html#acb46d4b0a597156d9ba5abc39d127792":[5,1,7,4],
+"class_ogre_1_1_page_strategy_data.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,1,7,8],
+"class_ogre_1_1_page_strategy_data.html#adce32528577d71b228692df906ecd17c":[5,1,7,11],
+"class_ogre_1_1_page_strategy_data.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,1,7,12],
+"class_ogre_1_1_paged_world.html":[5,1,0,7],
+"class_ogre_1_1_paged_world.html#a01a47d516ddcd57334b25ba2d017c1e3":[5,1,0,7,13],
+"class_ogre_1_1_paged_world.html#a055cb59b6a45c854b88ea09946e14eaf":[5,1,0,7,19],
+"class_ogre_1_1_paged_world.html#a0fa22b0759b2ce34f2277b304af216e0":[5,1,0,7,39],
+"class_ogre_1_1_paged_world.html#a1c727e879a260c37b00ce5505fe8e144":[5,1,0,7,29],
+"class_ogre_1_1_paged_world.html#a22c0313ee4f22c41c592aec526aedce6":[5,1,0,7,43],
+"class_ogre_1_1_paged_world.html#a2d5608ae695c810f26cfbb12acb79270":[5,1,0,7,5],
+"class_ogre_1_1_paged_world.html#a2fba1259191ba2d10e4d9b47ca527b0b":[5,1,0,7,20],
+"class_ogre_1_1_paged_world.html#a3599a7b6e9ac77f796d9b411fef98430":[5,1,0,7,18],
+"class_ogre_1_1_paged_world.html#a49b41e388c206a84817d40adbf8de6ea":[5,1,0,7,11],
+"class_ogre_1_1_paged_world.html#a4b445ba01d57f979566ba08df16e63c3":[5,1,0,7,14],
+"class_ogre_1_1_paged_world.html#a4d5c5043aa8077c10a353075c62812c9":[5,1,0,7,16],
+"class_ogre_1_1_paged_world.html#a5040e60ba4d96ef63af185d314753684":[5,1,0,7,4],
+"class_ogre_1_1_paged_world.html#a595ea4c05da8aa987d3800e65d23355d":[5,1,0,7,31],
+"class_ogre_1_1_paged_world.html#a5aed8fa0270feca86392300faff64764":[5,1,0,7,44],
+"class_ogre_1_1_paged_world.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,1,0,7,34],
+"class_ogre_1_1_paged_world.html#a72ebc44da81eac9c605bc012e89501ce":[5,1,0,7,3],
+"class_ogre_1_1_paged_world.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,1,0,7,27],
+"class_ogre_1_1_paged_world.html#a86df6ac79d172998e074b8da3935ee6b":[5,1,0,7,1],
+"class_ogre_1_1_paged_world.html#a8d190d8740520e75dd2e63ef58102d31":[5,1,0,7,22],
+"class_ogre_1_1_paged_world.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,1,0,7,30],
+"class_ogre_1_1_paged_world.html#a9932a5a510988ba09f5ed9aaf0c3e564":[5,1,0,7,38],
+"class_ogre_1_1_paged_world.html#a9b0c9840ce776233a3fbcdcba370f39d":[5,1,0,7,21],
+"class_ogre_1_1_paged_world.html#a9e1c5509c70c0941f75e1233b7c219a1":[5,1,0,7,12],
+"class_ogre_1_1_paged_world.html#aa25f1c7ea55a2a4e0059f32c5c3ca826":[5,1,0,7,7],
+"class_ogre_1_1_paged_world.html#aa998277396620588752029c88710dbd7":[5,1,0,7,2],
+"class_ogre_1_1_paged_world.html#aae8d55a56f80cd98c81e9be35abb1703":[5,1,0,7,42],
+"class_ogre_1_1_paged_world.html#aaf79972d420d07010e4f4da64338a176":[5,1,0,7,0],
+"class_ogre_1_1_paged_world.html#ab422c67a2c8844f410fe822a357cba3b":[5,1,0,7,33],
+"class_ogre_1_1_paged_world.html#ac0ef8449d591776b726577f2b4f84605":[5,1,0,7,23],
+"class_ogre_1_1_paged_world.html#acad473ad0512414571f6c509715065f1":[5,1,0,7,25],
+"class_ogre_1_1_paged_world.html#acb46d4b0a597156d9ba5abc39d127792":[5,1,0,7,28],
+"class_ogre_1_1_paged_world.html#acb8ecc03b04c2b56fa15cd3d6d9a8fcf":[5,1,0,7,41]
 };
