@@ -1,90 +1,32 @@
 var NAVTREEINDEX189 =
 {
-"class_ogre_1_1_pass.html#ae6756a522ba2aae4601c8153f38594d4":[5,2,5,18,77],
-"class_ogre_1_1_pass.html#ae8c6cd9d16220e8ef358f8b3e072d261":[5,2,5,18,142],
-"class_ogre_1_1_pass.html#ae92e29ff81e188b72cadcbb64fd0be8d":[5,2,5,18,52],
-"class_ogre_1_1_pass.html#aeaf906d8abba9a4b4dde83f87daa0f4e":[5,2,5,18,59],
-"class_ogre_1_1_pass.html#aec3f262fe893114ab6428644c256dda1":[5,2,5,18,29],
-"class_ogre_1_1_pass.html#aec98c9346a22a4a98acdaf5b8849a5c1":[5,2,5,18,145],
-"class_ogre_1_1_pass.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,5,18,123],
-"class_ogre_1_1_pass.html#af18dc0bd11d49aacbd053c4772511650":[5,2,5,18,74],
-"class_ogre_1_1_pass.html#af23f6b1ae56f9acdcb05f8cbcf0e9153":[5,2,5,18,111],
-"class_ogre_1_1_pass.html#af2643f7594c827d2f1b8785029de280f":[5,2,5,18,102],
-"class_ogre_1_1_pass.html#af5b7c49466e2ae106ef3ef0c25862e65":[5,2,5,18,72],
-"class_ogre_1_1_pass.html#af5e358a5fd8a944c9845f8aee4ba54a6":[5,2,5,18,107],
-"class_ogre_1_1_pass.html#af6b2aab96fb146a8e92043c7dc771de4":[5,2,5,18,143],
-"class_ogre_1_1_pass.html#af70ccd332a1df548058917c31021f7df":[5,2,5,18,62],
-"class_ogre_1_1_pass.html#afaa52a3826a08569b8263834f043a83f":[5,2,5,18,9],
-"class_ogre_1_1_pass.html#afb3b4e8c3d0058a43cd2b855fc22199c":[5,2,5,18,42],
-"class_ogre_1_1_pass.html#afb8ee56b37e2c2f00289d0e12c259e85":[5,2,5,18,7],
-"class_ogre_1_1_pass.html#afc41cb1fe9251448002a2405405b8bd9":[5,2,5,18,178],
-"class_ogre_1_1_pass.html#afd45b897ebc29d3ee40a2ee307682f35":[5,2,5,18,144],
-"class_ogre_1_1_pass_translator.html":[5,2,2,79],
-"class_ogre_1_1_pass_translator.html#a0359452063bcbdc46c2b5fd5002f257a":[5,2,2,79,0],
-"class_ogre_1_1_pass_translator.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,79,3],
-"class_ogre_1_1_pass_translator.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,2,79,5],
-"class_ogre_1_1_pass_translator.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,2,79,8],
-"class_ogre_1_1_pass_translator.html#a7c5b13a924dcc5de002744b2633cd426":[5,2,2,79,11],
-"class_ogre_1_1_pass_translator.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,2,79,1],
-"class_ogre_1_1_pass_translator.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,2,79,4],
-"class_ogre_1_1_pass_translator.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,2,79,7],
-"class_ogre_1_1_pass_translator.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,2,79,2],
-"class_ogre_1_1_pass_translator.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,2,79,6],
-"class_ogre_1_1_pass_translator.html#adce32528577d71b228692df906ecd17c":[5,2,2,79,9],
-"class_ogre_1_1_pass_translator.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,2,79,10],
-"class_ogre_1_1_passthrough_controller_function.html":[5,2,2,78],
-"class_ogre_1_1_passthrough_controller_function.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,78,4],
-"class_ogre_1_1_passthrough_controller_function.html#a25693ebdf658f1d1a393a3964a32e949":[5,2,2,78,1],
-"class_ogre_1_1_passthrough_controller_function.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,2,78,6],
-"class_ogre_1_1_passthrough_controller_function.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,2,78,9],
-"class_ogre_1_1_passthrough_controller_function.html#a7596d4806e925e3c6e519f613d94031b":[5,2,2,78,0],
-"class_ogre_1_1_passthrough_controller_function.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,2,78,2],
-"class_ogre_1_1_passthrough_controller_function.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,2,78,5],
-"class_ogre_1_1_passthrough_controller_function.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,2,78,8],
-"class_ogre_1_1_passthrough_controller_function.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,2,78,3],
-"class_ogre_1_1_passthrough_controller_function.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,2,78,7],
-"class_ogre_1_1_passthrough_controller_function.html#adce32528577d71b228692df906ecd17c":[5,2,2,78,10],
-"class_ogre_1_1_passthrough_controller_function.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,2,78,11],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html":[7,0,0,763],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html":[6,0,0,790],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a00078578492e222229de4a6caa5fa367":[6,0,0,790,6],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a00078578492e222229de4a6caa5fa367":[7,0,0,763,6],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a0036d309ecd4164c56de0fca5c4516ca":[7,0,0,763,4],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a0036d309ecd4164c56de0fca5c4516ca":[6,0,0,790,4],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a015d3187c71883caa5c28acd3f365344":[6,0,0,790,7],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a015d3187c71883caa5c28acd3f365344":[7,0,0,763,7],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a1bb883732dccbbe6fdea7aa28a51537f":[6,0,0,790,3],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a1bb883732dccbbe6fdea7aa28a51537f":[7,0,0,763,3],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a2d61c05a0a42d379da804bdf260d14fe":[6,0,0,790,11],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a2d61c05a0a42d379da804bdf260d14fe":[7,0,0,763,11],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a3a8f0c9bb113456db6c36741d73e4daa":[7,0,0,763,18],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a3a8f0c9bb113456db6c36741d73e4daa":[6,0,0,790,18],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a475cfc98745d04539575861c511c571a":[6,0,0,790,2],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a475cfc98745d04539575861c511c571a":[7,0,0,763,2],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a4cb4b52bd12c755554ed42cba2b738aa":[6,0,0,790,1],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a4cb4b52bd12c755554ed42cba2b738aa":[7,0,0,763,1],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a4fdcddbb7d2a7878ff1a0aee56d8beed":[7,0,0,763,5],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a4fdcddbb7d2a7878ff1a0aee56d8beed":[6,0,0,790,5],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a5ec8c3b5990717a1afac302b67356fc6":[6,0,0,790,15],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a5ec8c3b5990717a1afac302b67356fc6":[7,0,0,763,15],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a6037100498c0cd0079988984a7d87f13":[6,0,0,790,9],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a6037100498c0cd0079988984a7d87f13":[7,0,0,763,9],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a6f2274011ddf2fa609339a06089d83e7":[7,0,0,763,12],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a6f2274011ddf2fa609339a06089d83e7":[6,0,0,790,12],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a7ea92f946843b0fe4b358ea7d3d711f4":[7,0,0,763,10],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a7ea92f946843b0fe4b358ea7d3d711f4":[6,0,0,790,10],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a93392f3dbbd10f324dbeed2806b55135":[7,0,0,763,14],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a93392f3dbbd10f324dbeed2806b55135":[6,0,0,790,14],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#aa40eaf124caabf407529cdb14bfb0d2a":[7,0,0,763,0],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#aa40eaf124caabf407529cdb14bfb0d2a":[6,0,0,790,0],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#acc55cee31ecef33fb8ca31f97ac0548a":[7,0,0,763,13],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#acc55cee31ecef33fb8ca31f97ac0548a":[6,0,0,790,13],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#ace6f80f8122a3a86b9d4a711ee6ba310":[7,0,0,763,16],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#ace6f80f8122a3a86b9d4a711ee6ba310":[6,0,0,790,16],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#ada834debc302bdbd001e042a96b21a14":[7,0,0,763,17],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#ada834debc302bdbd001e042a96b21a14":[6,0,0,790,17],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#aed6feb92ffd56d1b821e7c7381ff3eb0":[6,0,0,790,8],
-"class_ogre_1_1_pcc_per_pixel_grid_placement.html#aed6feb92ffd56d1b821e7c7381ff3eb0":[7,0,0,763,8],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a3a8f0c9bb113456db6c36741d73e4daa":[6,0,0,788,18],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a475cfc98745d04539575861c511c571a":[7,0,0,761,2],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a475cfc98745d04539575861c511c571a":[6,0,0,788,2],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a4cb4b52bd12c755554ed42cba2b738aa":[7,0,0,761,1],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a4cb4b52bd12c755554ed42cba2b738aa":[6,0,0,788,1],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a4fdcddbb7d2a7878ff1a0aee56d8beed":[7,0,0,761,5],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a4fdcddbb7d2a7878ff1a0aee56d8beed":[6,0,0,788,5],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a5ec8c3b5990717a1afac302b67356fc6":[6,0,0,788,15],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a5ec8c3b5990717a1afac302b67356fc6":[7,0,0,761,15],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a6037100498c0cd0079988984a7d87f13":[6,0,0,788,9],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a6037100498c0cd0079988984a7d87f13":[7,0,0,761,9],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a6f2274011ddf2fa609339a06089d83e7":[7,0,0,761,12],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a6f2274011ddf2fa609339a06089d83e7":[6,0,0,788,12],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a7ea92f946843b0fe4b358ea7d3d711f4":[7,0,0,761,10],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a7ea92f946843b0fe4b358ea7d3d711f4":[6,0,0,788,10],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a93392f3dbbd10f324dbeed2806b55135":[7,0,0,761,14],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#a93392f3dbbd10f324dbeed2806b55135":[6,0,0,788,14],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#aa40eaf124caabf407529cdb14bfb0d2a":[6,0,0,788,0],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#aa40eaf124caabf407529cdb14bfb0d2a":[7,0,0,761,0],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#acc55cee31ecef33fb8ca31f97ac0548a":[7,0,0,761,13],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#acc55cee31ecef33fb8ca31f97ac0548a":[6,0,0,788,13],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#ace6f80f8122a3a86b9d4a711ee6ba310":[7,0,0,761,16],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#ace6f80f8122a3a86b9d4a711ee6ba310":[6,0,0,788,16],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#ada834debc302bdbd001e042a96b21a14":[7,0,0,761,17],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#ada834debc302bdbd001e042a96b21a14":[6,0,0,788,17],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#aed6feb92ffd56d1b821e7c7381ff3eb0":[7,0,0,761,8],
+"class_ogre_1_1_pcc_per_pixel_grid_placement.html#aed6feb92ffd56d1b821e7c7381ff3eb0":[6,0,0,788,8],
 "class_ogre_1_1_pixel_box.html":[5,2,3,17],
 "class_ogre_1_1_pixel_box.html#a098dfd052183aeb4025794758ed59021":[5,2,3,17,10],
 "class_ogre_1_1_pixel_box.html#a196c57b3cf61c1545c46896cff269efb":[5,2,3,17,0],
@@ -249,5 +191,63 @@ var NAVTREEINDEX189 =
 "class_ogre_1_1_pixel_util.html#a9fc6dbbd70a1f24b18db99cb1d2dae5d":[5,2,3,20,7],
 "class_ogre_1_1_pixel_util.html#aa6a3f3c1e6b98b537ce6dfed949afa3c":[5,2,3,20,31],
 "class_ogre_1_1_pixel_util.html#ac4fcce8523b25011939624bfe2572314":[5,2,3,20,26],
-"class_ogre_1_1_pixel_util.html#aca8f1f4de7db504bd9a6c781cca28a42":[5,2,3,20,32]
+"class_ogre_1_1_pixel_util.html#aca8f1f4de7db504bd9a6c781cca28a42":[5,2,3,20,32],
+"class_ogre_1_1_pixel_util.html#acb83c9058ba34602be4e07e4d7ce1d2d":[5,2,3,20,33],
+"class_ogre_1_1_pixel_util.html#acbe531d3eabd46c52a860a16a3b779a3":[5,2,3,20,5],
+"class_ogre_1_1_pixel_util.html#ad27d6389824bcfe21185f6728af8974e":[5,2,3,20,4],
+"class_ogre_1_1_pixel_util.html#ae0c13cd6390b11bc851c9e2ba1201f40":[5,2,3,20,14],
+"class_ogre_1_1_pixel_util.html#ae127c3e6145af784e7d2d3734681a75a":[5,2,3,20,15],
+"class_ogre_1_1_pixel_util.html#ae1448ad9a222ed03918f2e94a057612c":[5,2,3,20,38],
+"class_ogre_1_1_pixel_util.html#ae81ba2514ca7f5a53c84bb515de2ade0":[5,2,3,20,10],
+"class_ogre_1_1_pixel_util.html#aec27f7358f77fabc0c9e68ce35b5af69":[5,2,3,20,17],
+"class_ogre_1_1_pixel_util.html#af0658994fbf0337d455ac9aa74ee8084":[5,2,3,20,36],
+"class_ogre_1_1_pixel_util.html#af2eb99dcaf73f5f8196733ad3f3c8958":[5,2,3,20,20],
+"class_ogre_1_1_pixel_util.html#afbd54e9abc204019624bf99bc8cdb3c1":[5,2,3,20,8],
+"class_ogre_1_1_pixel_util.html#aff946ff2d852db7eb850c31164e812ea":[5,2,3,20,19],
+"class_ogre_1_1_planar_reflection_actor.html":[5,0,0,22],
+"class_ogre_1_1_planar_reflection_actor.html#a0fd1fddd8058848f053673fca7bbd381":[5,0,0,22,5],
+"class_ogre_1_1_planar_reflection_actor.html#a50b118948760de21abf5428953999c0a":[5,0,0,22,1],
+"class_ogre_1_1_planar_reflection_actor.html#a5448554cd473c3bda5d6e3373fc6ec6c":[5,0,0,22,8],
+"class_ogre_1_1_planar_reflection_actor.html#a61302ea400f8031a982274826b6d9c12":[5,0,0,22,10],
+"class_ogre_1_1_planar_reflection_actor.html#a63f0f6c050e70fc198c844fe9a790bb1":[5,0,0,22,11],
+"class_ogre_1_1_planar_reflection_actor.html#a6c4e5ee254de0333bc96e99cc21da301":[5,0,0,22,4],
+"class_ogre_1_1_planar_reflection_actor.html#a789e47bc8715ed2e7d58055b26fa667e":[5,0,0,22,0],
+"class_ogre_1_1_planar_reflection_actor.html#a8c52eaae01ba7d6deaa7da830c5f3402":[5,0,0,22,9],
+"class_ogre_1_1_planar_reflection_actor.html#a94952b0dcc95c180fe102b3db9c2d01d":[5,0,0,22,7],
+"class_ogre_1_1_planar_reflection_actor.html#ab10d422d6fa05a96cb53e5782c539668":[5,0,0,22,6],
+"class_ogre_1_1_planar_reflection_actor.html#adb1d1cc2811d7b79cf88eb6bdaabacce":[5,0,0,22,2],
+"class_ogre_1_1_planar_reflection_actor.html#ae4c51d8303a4664a3a9d5e91e18043b3":[5,0,0,22,3],
+"class_ogre_1_1_planar_reflection_actor.html#ae77682cf581dd2630cd2f75250473d2d":[5,0,0,22,12],
+"class_ogre_1_1_planar_reflections.html":[5,0,0,23],
+"class_ogre_1_1_planar_reflections.html#a08baa1e192558155350dc4cae0779c39":[5,0,0,23,9],
+"class_ogre_1_1_planar_reflections.html#a115bdf1bc345cec24869a367e2d14fcc":[5,0,0,23,19],
+"class_ogre_1_1_planar_reflections.html#a1b6e9c4ba6c9805abc9c530848857d3d":[5,0,0,23,20],
+"class_ogre_1_1_planar_reflections.html#a216041e0cac9583d98a4023051981296":[5,0,0,23,14],
+"class_ogre_1_1_planar_reflections.html#a263fc6936942eb8fd5162a5c6d3566dd":[5,0,0,23,3],
+"class_ogre_1_1_planar_reflections.html#a2771ce1222f8acb51cda2d9c84274d85":[5,0,0,23,24],
+"class_ogre_1_1_planar_reflections.html#a348398b976bbd1bc920a1949cb6daa0e":[5,0,0,23,22],
+"class_ogre_1_1_planar_reflections.html#a3a58842a57fece487fd4601d1845f8f2":[5,0,0,23,23],
+"class_ogre_1_1_planar_reflections.html#a3e77bc1097363a43c816bb61b4c4def8":[5,0,0,23,16],
+"class_ogre_1_1_planar_reflections.html#a44003f3183c9912fc8bd0dbe08130dc4":[5,0,0,23,10],
+"class_ogre_1_1_planar_reflections.html#a50aeb6eec3120373b6d5316909128235":[5,0,0,23,7],
+"class_ogre_1_1_planar_reflections.html#a6b97bf4ca49cb975146865babaebd38c":[5,0,0,23,13],
+"class_ogre_1_1_planar_reflections.html#a7c96969df4853b0d5c1e3f0c6adae41a":[5,0,0,23,25],
+"class_ogre_1_1_planar_reflections.html#a893c5a907aa1a9137733da536fd81c72":[5,0,0,23,11],
+"class_ogre_1_1_planar_reflections.html#a97c05aeec8d1c4307a78d98e45a5cbc1":[5,0,0,23,2],
+"class_ogre_1_1_planar_reflections.html#aa9c304509b595687e7af5ae0d513973a":[5,0,0,23,4],
+"class_ogre_1_1_planar_reflections.html#ab3c42759975878d5744bfd2bebc313a4":[5,0,0,23,5],
+"class_ogre_1_1_planar_reflections.html#ab4446a0ebad33a188b5768db4c2ea813":[5,0,0,23,21],
+"class_ogre_1_1_planar_reflections.html#ab6b4e4365e298e1964114c9f88affca4":[5,0,0,23,12],
+"class_ogre_1_1_planar_reflections.html#ad57f5c1c97d776977f0ac26dae2cb023":[5,0,0,23,17],
+"class_ogre_1_1_planar_reflections.html#ad67ceb649027af939376cbd4f3b62f9f":[5,0,0,23,6],
+"class_ogre_1_1_planar_reflections.html#ae093845778350033e17071693735d09b":[5,0,0,23,18],
+"class_ogre_1_1_planar_reflections.html#ae4592b5013e603bd0343181395bfcc81":[5,0,0,23,8],
+"class_ogre_1_1_planar_reflections.html#ae8585442d3a502ca1b714b399708e8c3":[5,0,0,23,15],
+"class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144":[5,0,0,23,1],
+"class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144a5ed119fb61ead1864d8eab0da69f2541":[5,0,0,23,1,2],
+"class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144a8e1d29960d0fddea25d2490406ce8147":[5,0,0,23,1,0],
+"class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144aa08ad430b01d82bb98e6b001f4d316ca":[5,0,0,23,1,1],
+"class_ogre_1_1_plane.html":[5,2,6,19],
+"class_ogre_1_1_plane.html#a090aae792b4fecc6e8b1b5810f029edf":[5,2,6,19,10],
+"class_ogre_1_1_plane.html#a115540f9bb7a88c0f22dcbc0ca087a68":[5,2,6,19,7]
 };
