@@ -1,63 +1,5 @@
 var NAVTREEINDEX190 =
 {
-"class_ogre_1_1_pixel_util.html#acb83c9058ba34602be4e07e4d7ce1d2d":[5,2,3,20,33],
-"class_ogre_1_1_pixel_util.html#acbe531d3eabd46c52a860a16a3b779a3":[5,2,3,20,5],
-"class_ogre_1_1_pixel_util.html#ad27d6389824bcfe21185f6728af8974e":[5,2,3,20,4],
-"class_ogre_1_1_pixel_util.html#ae0c13cd6390b11bc851c9e2ba1201f40":[5,2,3,20,14],
-"class_ogre_1_1_pixel_util.html#ae127c3e6145af784e7d2d3734681a75a":[5,2,3,20,15],
-"class_ogre_1_1_pixel_util.html#ae1448ad9a222ed03918f2e94a057612c":[5,2,3,20,38],
-"class_ogre_1_1_pixel_util.html#ae81ba2514ca7f5a53c84bb515de2ade0":[5,2,3,20,10],
-"class_ogre_1_1_pixel_util.html#aec27f7358f77fabc0c9e68ce35b5af69":[5,2,3,20,17],
-"class_ogre_1_1_pixel_util.html#af0658994fbf0337d455ac9aa74ee8084":[5,2,3,20,36],
-"class_ogre_1_1_pixel_util.html#af2eb99dcaf73f5f8196733ad3f3c8958":[5,2,3,20,20],
-"class_ogre_1_1_pixel_util.html#afbd54e9abc204019624bf99bc8cdb3c1":[5,2,3,20,8],
-"class_ogre_1_1_pixel_util.html#aff946ff2d852db7eb850c31164e812ea":[5,2,3,20,19],
-"class_ogre_1_1_planar_reflection_actor.html":[5,0,0,22],
-"class_ogre_1_1_planar_reflection_actor.html#a0fd1fddd8058848f053673fca7bbd381":[5,0,0,22,5],
-"class_ogre_1_1_planar_reflection_actor.html#a50b118948760de21abf5428953999c0a":[5,0,0,22,1],
-"class_ogre_1_1_planar_reflection_actor.html#a5448554cd473c3bda5d6e3373fc6ec6c":[5,0,0,22,8],
-"class_ogre_1_1_planar_reflection_actor.html#a61302ea400f8031a982274826b6d9c12":[5,0,0,22,10],
-"class_ogre_1_1_planar_reflection_actor.html#a63f0f6c050e70fc198c844fe9a790bb1":[5,0,0,22,11],
-"class_ogre_1_1_planar_reflection_actor.html#a6c4e5ee254de0333bc96e99cc21da301":[5,0,0,22,4],
-"class_ogre_1_1_planar_reflection_actor.html#a789e47bc8715ed2e7d58055b26fa667e":[5,0,0,22,0],
-"class_ogre_1_1_planar_reflection_actor.html#a8c52eaae01ba7d6deaa7da830c5f3402":[5,0,0,22,9],
-"class_ogre_1_1_planar_reflection_actor.html#a94952b0dcc95c180fe102b3db9c2d01d":[5,0,0,22,7],
-"class_ogre_1_1_planar_reflection_actor.html#ab10d422d6fa05a96cb53e5782c539668":[5,0,0,22,6],
-"class_ogre_1_1_planar_reflection_actor.html#adb1d1cc2811d7b79cf88eb6bdaabacce":[5,0,0,22,2],
-"class_ogre_1_1_planar_reflection_actor.html#ae4c51d8303a4664a3a9d5e91e18043b3":[5,0,0,22,3],
-"class_ogre_1_1_planar_reflection_actor.html#ae77682cf581dd2630cd2f75250473d2d":[5,0,0,22,12],
-"class_ogre_1_1_planar_reflections.html":[5,0,0,23],
-"class_ogre_1_1_planar_reflections.html#a08baa1e192558155350dc4cae0779c39":[5,0,0,23,9],
-"class_ogre_1_1_planar_reflections.html#a115bdf1bc345cec24869a367e2d14fcc":[5,0,0,23,19],
-"class_ogre_1_1_planar_reflections.html#a1b6e9c4ba6c9805abc9c530848857d3d":[5,0,0,23,20],
-"class_ogre_1_1_planar_reflections.html#a216041e0cac9583d98a4023051981296":[5,0,0,23,14],
-"class_ogre_1_1_planar_reflections.html#a263fc6936942eb8fd5162a5c6d3566dd":[5,0,0,23,3],
-"class_ogre_1_1_planar_reflections.html#a2771ce1222f8acb51cda2d9c84274d85":[5,0,0,23,24],
-"class_ogre_1_1_planar_reflections.html#a348398b976bbd1bc920a1949cb6daa0e":[5,0,0,23,22],
-"class_ogre_1_1_planar_reflections.html#a3a58842a57fece487fd4601d1845f8f2":[5,0,0,23,23],
-"class_ogre_1_1_planar_reflections.html#a3e77bc1097363a43c816bb61b4c4def8":[5,0,0,23,16],
-"class_ogre_1_1_planar_reflections.html#a44003f3183c9912fc8bd0dbe08130dc4":[5,0,0,23,10],
-"class_ogre_1_1_planar_reflections.html#a50aeb6eec3120373b6d5316909128235":[5,0,0,23,7],
-"class_ogre_1_1_planar_reflections.html#a6b97bf4ca49cb975146865babaebd38c":[5,0,0,23,13],
-"class_ogre_1_1_planar_reflections.html#a7c96969df4853b0d5c1e3f0c6adae41a":[5,0,0,23,25],
-"class_ogre_1_1_planar_reflections.html#a893c5a907aa1a9137733da536fd81c72":[5,0,0,23,11],
-"class_ogre_1_1_planar_reflections.html#a97c05aeec8d1c4307a78d98e45a5cbc1":[5,0,0,23,2],
-"class_ogre_1_1_planar_reflections.html#aa9c304509b595687e7af5ae0d513973a":[5,0,0,23,4],
-"class_ogre_1_1_planar_reflections.html#ab3c42759975878d5744bfd2bebc313a4":[5,0,0,23,5],
-"class_ogre_1_1_planar_reflections.html#ab4446a0ebad33a188b5768db4c2ea813":[5,0,0,23,21],
-"class_ogre_1_1_planar_reflections.html#ab6b4e4365e298e1964114c9f88affca4":[5,0,0,23,12],
-"class_ogre_1_1_planar_reflections.html#ad57f5c1c97d776977f0ac26dae2cb023":[5,0,0,23,17],
-"class_ogre_1_1_planar_reflections.html#ad67ceb649027af939376cbd4f3b62f9f":[5,0,0,23,6],
-"class_ogre_1_1_planar_reflections.html#ae093845778350033e17071693735d09b":[5,0,0,23,18],
-"class_ogre_1_1_planar_reflections.html#ae4592b5013e603bd0343181395bfcc81":[5,0,0,23,8],
-"class_ogre_1_1_planar_reflections.html#ae8585442d3a502ca1b714b399708e8c3":[5,0,0,23,15],
-"class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144":[5,0,0,23,1],
-"class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144a5ed119fb61ead1864d8eab0da69f2541":[5,0,0,23,1,2],
-"class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144a8e1d29960d0fddea25d2490406ce8147":[5,0,0,23,1,0],
-"class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144aa08ad430b01d82bb98e6b001f4d316ca":[5,0,0,23,1,1],
-"class_ogre_1_1_plane.html":[5,2,6,19],
-"class_ogre_1_1_plane.html#a090aae792b4fecc6e8b1b5810f029edf":[5,2,6,19,10],
-"class_ogre_1_1_plane.html#a115540f9bb7a88c0f22dcbc0ca087a68":[5,2,6,19,7],
 "class_ogre_1_1_plane.html#a1530cc182a2a783e072eabe44f536149":[5,2,6,19,1],
 "class_ogre_1_1_plane.html#a1f4b68ae4354cd7b0cc63374497461cb":[5,2,6,19,8],
 "class_ogre_1_1_plane.html#a1f5ace6a3a4bedc91a283895fb77a6a8":[5,2,6,19,13],
@@ -91,60 +33,60 @@ var NAVTREEINDEX190 =
 "class_ogre_1_1_plane_bounded_volume.html#ac92a3d627da4cadbc9ebe7331b368e6e":[5,2,6,20,3],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html":[5,0,1,33],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html":[5,2,12,33],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,0,1,33,0],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,2,12,33,0],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,33,0,2],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,0,1,33,0],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,0,1,33,0,2],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,33,0,2],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,0,1,33,0,1],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,2,12,33,0,1],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,0,1,33,0,0],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,2,12,33,0,0],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,0,1,33,0,0],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,2,12,33,0,4],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,0,1,33,0,4],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,2,12,33,0,3],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,0,1,33,0,3],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,2,12,33,0,3],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,33,13],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,33,13],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,2,12,33,3],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,0,1,33,3],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a20e200f7a33292e6644a44bf882ae8f6":[5,0,1,33,4],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a20e200f7a33292e6644a44bf882ae8f6":[5,2,12,33,4],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a37f0a7cdf7bdb53bfa98c9e3c8541c41":[5,0,1,33,2],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a20e200f7a33292e6644a44bf882ae8f6":[5,0,1,33,4],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a37f0a7cdf7bdb53bfa98c9e3c8541c41":[5,2,12,33,2],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a37f0a7cdf7bdb53bfa98c9e3c8541c41":[5,0,1,33,2],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,2,12,33,27],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,0,1,33,27],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,0,1,33,21],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,2,12,33,21],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,0,1,33,21],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,33,15],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,33,15],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,33,18],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,33,18],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,0,1,33,8],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,2,12,33,8],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,33,11],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,0,1,33,8],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,33,11],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,33,11],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,2,12,33,6],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,0,1,33,6],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,33,14],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,33,14],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,2,12,33,5],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,0,1,33,5],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,33,17],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,2,12,33,5],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,33,17],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ac7f81d455b20245603c5d51f4b00ea90":[5,2,12,33,1],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,33,17],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ac7f81d455b20245603c5d51f4b00ea90":[5,0,1,33,1],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,33,12],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ac7f81d455b20245603c5d51f4b00ea90":[5,2,12,33,1],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,33,12],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,33,12],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,2,12,33,10],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,0,1,33,10],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,33,16],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,33,16],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,0,1,33,23],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,12,33,23],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,33,19],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,0,1,33,23],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#adce32528577d71b228692df906ecd17c":[5,2,12,33,19],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#adfd70f00b13654735336f4360af84995":[5,2,12,33,26],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,33,19],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#adfd70f00b13654735336f4360af84995":[5,0,1,33,26],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#adfd70f00b13654735336f4360af84995":[5,2,12,33,26],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,2,12,33,22],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,0,1,33,22],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,1,33,25],
@@ -161,36 +103,36 @@ var NAVTREEINDEX190 =
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html":[5,2,12,34],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a0fdd507e53ed2fecb42080c9c9fe85ec":[5,0,1,34,1],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a0fdd507e53ed2fecb42080c9c9fe85ec":[5,2,12,34,1],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,34,7],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,34,7],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a4711539f8fe2386bfdeb18bda84862ee":[5,0,1,34,4],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,34,7],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a4711539f8fe2386bfdeb18bda84862ee":[5,2,12,34,4],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,34,9],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a4711539f8fe2386bfdeb18bda84862ee":[5,0,1,34,4],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,34,9],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,34,9],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,2,12,34,2],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,0,1,34,2],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,34,12],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,34,12],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,0,1,34,15],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,2,12,34,15],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,0,1,34,15],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,34,5],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,34,5],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a84aeb5d693cf9235080fc84031ec881f":[5,2,12,34,0],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a84aeb5d693cf9235080fc84031ec881f":[5,0,1,34,0],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,34,8],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a84aeb5d693cf9235080fc84031ec881f":[5,2,12,34,0],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,34,8],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,34,8],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,34,11],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,34,11],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,34,6],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,34,6],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,34,10],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,34,10],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,0,1,34,3],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,2,12,34,3],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,0,1,34,3],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,0,1,34,13],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,2,12,34,13],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,34,14],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,34,14],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,34,14],
 "class_ogre_1_1_platform_information.html":[5,2,2,80],
 "class_ogre_1_1_platform_information.html#a1b64c69682054e5e3d1563067fa19f68":[5,2,2,80,2],
 "class_ogre_1_1_platform_information.html#a9c975bf5f74c9c085a7ff073cacf6834":[5,2,2,80,3],
@@ -198,16 +140,28 @@ var NAVTREEINDEX190 =
 "class_ogre_1_1_platform_information.html#ab397833e2f858920d32be590c714336a":[5,2,2,80,4],
 "class_ogre_1_1_platform_information.html#ae04f524bd9f4e399eeb5307a39ab1f56":[5,2,2,80,5],
 "class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807":[5,2,2,80,0],
-"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a1bea16c1677fe68834a2d76b968562d7":[5,2,2,80,0,0],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a15cd1f4c0b74a9fa9f9e5b9a74ab1616":[5,2,2,80,0,4],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a171794d6739d25f3bcf5f5f1ddffdfb1":[5,2,2,80,0,6],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a1ae4263f68c419342c129ca694878307":[5,2,2,80,0,0],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a1bea16c1677fe68834a2d76b968562d7":[5,2,2,80,0,12],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a5fc4873770d764423e744f0c38205f9a":[5,2,2,80,0,9],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a8b9a9e995ae9886ef33500254536cc6e":[5,2,2,80,0,1],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a926da4b4266e9394a740a5b5d737abf2":[5,2,2,80,0,11],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807aa607177ead91f654dbc5c2444c5999b9":[5,2,2,80,0,2],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807ab02aebd522397209dc00ab5e580e1cd6":[5,2,2,80,0,5],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807ab8dc79e9c3f35aa7befa143234048020":[5,2,2,80,0,8],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807ac13691e4b73cb7643a41163944a9a5a5":[5,2,2,80,0,7],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807adb21fcf38fa8c6da129b284fe6098138":[5,2,2,80,0,10],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807af1d5c5e48b069e9cdfb96167836f5f8f":[5,2,2,80,0,3],
 "class_ogre_1_1_plugin.html":[5,2,2,81],
 "class_ogre_1_1_plugin.html#a02890fc726dd3163721bdbec1c60339a":[5,2,2,81,0],
 "class_ogre_1_1_plugin.html#a0e0115ae4937a5df6548758c9f1ef4b5":[5,2,2,81,2],
 "class_ogre_1_1_plugin.html#a17fe6741c49a0fb9153797c70bdb884b":[5,2,2,81,15],
 "class_ogre_1_1_plugin.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,81,7],
 "class_ogre_1_1_plugin.html#a47748105a90ce86b7e0f99a6910bd31d":[5,2,2,81,16],
-"class_ogre_1_1_plugin.html#a556fd0c6a5a05cce82dc7df998c99c0f":[5,2,2,81,4],
 "class_ogre_1_1_plugin.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,2,81,9],
 "class_ogre_1_1_plugin.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,2,81,12],
+"class_ogre_1_1_plugin.html#a6b24a7a7634a32b14b95a0d1969fbbab":[5,2,2,81,4],
 "class_ogre_1_1_plugin.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,2,81,5],
 "class_ogre_1_1_plugin.html#a890da15775afd75c14e81bc6207de81f":[5,2,2,81,3],
 "class_ogre_1_1_plugin.html#a8f531cb7678768d34140e1aa15335f57":[5,2,2,81,1],
@@ -238,16 +192,62 @@ var NAVTREEINDEX190 =
 "class_ogre_1_1_polygon.html#a9d80e759f5c77ba5a308d298c8b498c2":[5,2,6,21,9],
 "class_ogre_1_1_polygon.html#a9db9518c3381e7a840610bf181d65b73":[5,2,6,21,16],
 "class_ogre_1_1_polygon.html#ac32b2d0a6e7c0cee21471fdaf6da13c4":[5,2,6,21,10],
-"class_ogre_1_1_pool.html":[7,0,0,779],
-"class_ogre_1_1_pool.html":[6,0,0,806],
-"class_ogre_1_1_pool.html#a31c74c47be2a3c8e5abe93a8ac061bc7":[6,0,0,806,4],
-"class_ogre_1_1_pool.html#a31c74c47be2a3c8e5abe93a8ac061bc7":[7,0,0,779,4],
-"class_ogre_1_1_pool.html#a4fb09f4b25feb32de79b6f578359aab1":[6,0,0,806,1],
-"class_ogre_1_1_pool.html#a4fb09f4b25feb32de79b6f578359aab1":[7,0,0,779,1],
-"class_ogre_1_1_pool.html#a7bd667e735a8fdaf2e7017d436ba75a6":[7,0,0,779,0],
-"class_ogre_1_1_pool.html#a7bd667e735a8fdaf2e7017d436ba75a6":[6,0,0,806,0],
-"class_ogre_1_1_pool.html#abafd7c72963d86ef829c0373fe50aa7f":[6,0,0,806,2],
-"class_ogre_1_1_pool.html#abafd7c72963d86ef829c0373fe50aa7f":[7,0,0,779,2],
-"class_ogre_1_1_pool.html#af399adb462aa706c25e1e961cdfb5a1e":[7,0,0,779,3],
-"class_ogre_1_1_pool.html#af399adb462aa706c25e1e961cdfb5a1e":[6,0,0,806,3]
+"class_ogre_1_1_pool.html":[7,0,0,777],
+"class_ogre_1_1_pool.html":[6,0,0,804],
+"class_ogre_1_1_pool.html#a31c74c47be2a3c8e5abe93a8ac061bc7":[6,0,0,804,4],
+"class_ogre_1_1_pool.html#a31c74c47be2a3c8e5abe93a8ac061bc7":[7,0,0,777,4],
+"class_ogre_1_1_pool.html#a4fb09f4b25feb32de79b6f578359aab1":[6,0,0,804,1],
+"class_ogre_1_1_pool.html#a4fb09f4b25feb32de79b6f578359aab1":[7,0,0,777,1],
+"class_ogre_1_1_pool.html#a7bd667e735a8fdaf2e7017d436ba75a6":[6,0,0,804,0],
+"class_ogre_1_1_pool.html#a7bd667e735a8fdaf2e7017d436ba75a6":[7,0,0,777,0],
+"class_ogre_1_1_pool.html#abafd7c72963d86ef829c0373fe50aa7f":[6,0,0,804,2],
+"class_ogre_1_1_pool.html#abafd7c72963d86ef829c0373fe50aa7f":[7,0,0,777,2],
+"class_ogre_1_1_pool.html#af399adb462aa706c25e1e961cdfb5a1e":[6,0,0,804,3],
+"class_ogre_1_1_pool.html#af399adb462aa706c25e1e961cdfb5a1e":[7,0,0,777,3],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html":[5,2,2,82],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a298f1b128634bef5d5964726097278e8":[5,2,2,82,2],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a403617d0cc5f8e8bffccca4012dd6fb1":[5,2,2,82,1],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a7fe96a9aaef9359e8077bdb0c234db2f":[5,2,2,82,3],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#ae83d6b4f8c27207b09f2bae4e7c51ce6":[5,2,2,82,4],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#af8a79ba69d0bd18034a45efd19e6a43f":[5,2,2,82,0],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html":[5,2,2,83],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#a4e7e3b1f5f8a2d9005f243729cd5367b":[5,2,2,83,0],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#a51a223dead21c6a2ddfa66f75d508553":[5,2,2,83,2],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#a6743ef063ddf25f8ccaa1fc95465e0c6":[5,2,2,83,1],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#ab4e31bae208b7526e183369be3acb410":[5,2,2,83,3],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#ae83d6b4f8c27207b09f2bae4e7c51ce6":[5,2,2,83,4],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html":[5,2,2,84],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#a3c4bdfcd9e3758d5281dfe0ed7d8e5fc":[5,2,2,84,2],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#a93b2fb455dd0deec91a7f16a3a91c55e":[5,2,2,84,1],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#a9df601b04eff55b09762484c8eac6082":[5,2,2,84,3],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#ad65384a6b5c01e1ce69a4d452d45745f":[5,2,2,84,4],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#ae83d6b4f8c27207b09f2bae4e7c51ce6":[5,2,2,84,5],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1acc":[5,2,2,84,0],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1acca79d98608fb92fdd1ff492f56d86b2ba1":[5,2,2,84,0,5],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1acca89eafbeaac332dd99da1acf69bcd5e28":[5,2,2,84,0,0],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1acca95b66677cfc85cf4875592e2b8e55711":[5,2,2,84,0,4],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1acca98aba562da4701af0723b20487e3e72e":[5,2,2,84,0,1],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1accaaae64117ec8b4d891a58fbd343d50b0f":[5,2,2,84,0,2],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1accaabd3c5bc93c929d3d7b43d05aa728db8":[5,2,2,84,0,3],
+"class_ogre_1_1_profile.html":[5,2,2,85],
+"class_ogre_1_1_profile.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,85,4],
+"class_ogre_1_1_profile.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,2,85,6],
+"class_ogre_1_1_profile.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,2,85,9],
+"class_ogre_1_1_profile.html#a7a94c7b3e9f8cbdd8f266c91dab8c4be":[5,2,2,85,0],
+"class_ogre_1_1_profile.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,2,85,2],
+"class_ogre_1_1_profile.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,2,85,5],
+"class_ogre_1_1_profile.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,2,85,8],
+"class_ogre_1_1_profile.html#ab6e88cfb8d5fa50fb9ea8ff31f74e93c":[5,2,2,85,1],
+"class_ogre_1_1_profile.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,2,85,3],
+"class_ogre_1_1_profile.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,2,85,7],
+"class_ogre_1_1_profile.html#adce32528577d71b228692df906ecd17c":[5,2,2,85,10],
+"class_ogre_1_1_profile.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,2,85,11],
+"class_ogre_1_1_profile_instance.html":[5,2,2,88],
+"class_ogre_1_1_profile_instance.html#a08c87da13e23c3899052faab7680da30":[5,2,2,88,28],
+"class_ogre_1_1_profile_instance.html#a0d07b5ee2f25241fed784e92accd86c1":[5,2,2,88,1],
+"class_ogre_1_1_profile_instance.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,88,8],
+"class_ogre_1_1_profile_instance.html#a1fd3ce0a1a19f9721d712c9a1426b515":[5,2,2,88,19],
+"class_ogre_1_1_profile_instance.html#a27bde362d885b8aab267d0635b0c30ae":[5,2,2,88,22],
+"class_ogre_1_1_profile_instance.html#a40b76f9c74bd13e1b07db0559af27dc5":[5,2,2,88,29],
+"class_ogre_1_1_profile_instance.html#a41f4675a0f1e9bebe386851423f2e682":[5,2,2,88,4]
 };
