@@ -1,51 +1,5 @@
 var NAVTREEINDEX191 =
 {
-"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html":[5,2,2,82],
-"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a298f1b128634bef5d5964726097278e8":[5,2,2,82,2],
-"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a403617d0cc5f8e8bffccca4012dd6fb1":[5,2,2,82,1],
-"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a7fe96a9aaef9359e8077bdb0c234db2f":[5,2,2,82,3],
-"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#ae83d6b4f8c27207b09f2bae4e7c51ce6":[5,2,2,82,4],
-"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#af8a79ba69d0bd18034a45efd19e6a43f":[5,2,2,82,0],
-"class_ogre_1_1_process_name_exclusion_script_compiler_event.html":[5,2,2,83],
-"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#a4e7e3b1f5f8a2d9005f243729cd5367b":[5,2,2,83,0],
-"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#a51a223dead21c6a2ddfa66f75d508553":[5,2,2,83,2],
-"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#a6743ef063ddf25f8ccaa1fc95465e0c6":[5,2,2,83,1],
-"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#ab4e31bae208b7526e183369be3acb410":[5,2,2,83,3],
-"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#ae83d6b4f8c27207b09f2bae4e7c51ce6":[5,2,2,83,4],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html":[5,2,2,84],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#a3c4bdfcd9e3758d5281dfe0ed7d8e5fc":[5,2,2,84,2],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#a93b2fb455dd0deec91a7f16a3a91c55e":[5,2,2,84,1],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#a9df601b04eff55b09762484c8eac6082":[5,2,2,84,3],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#ad65384a6b5c01e1ce69a4d452d45745f":[5,2,2,84,4],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#ae83d6b4f8c27207b09f2bae4e7c51ce6":[5,2,2,84,5],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1acc":[5,2,2,84,0],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1acca79d98608fb92fdd1ff492f56d86b2ba1":[5,2,2,84,0,5],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1acca89eafbeaac332dd99da1acf69bcd5e28":[5,2,2,84,0,0],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1acca95b66677cfc85cf4875592e2b8e55711":[5,2,2,84,0,4],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1acca98aba562da4701af0723b20487e3e72e":[5,2,2,84,0,1],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1accaaae64117ec8b4d891a58fbd343d50b0f":[5,2,2,84,0,2],
-"class_ogre_1_1_process_resource_name_script_compiler_event.html#afd04c7f48ef0823ba70812b83fde1accaabd3c5bc93c929d3d7b43d05aa728db8":[5,2,2,84,0,3],
-"class_ogre_1_1_profile.html":[5,2,2,85],
-"class_ogre_1_1_profile.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,85,4],
-"class_ogre_1_1_profile.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,2,85,6],
-"class_ogre_1_1_profile.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,2,85,9],
-"class_ogre_1_1_profile.html#a7a94c7b3e9f8cbdd8f266c91dab8c4be":[5,2,2,85,0],
-"class_ogre_1_1_profile.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,2,85,2],
-"class_ogre_1_1_profile.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,2,85,5],
-"class_ogre_1_1_profile.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,2,85,8],
-"class_ogre_1_1_profile.html#ab6e88cfb8d5fa50fb9ea8ff31f74e93c":[5,2,2,85,1],
-"class_ogre_1_1_profile.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,2,85,3],
-"class_ogre_1_1_profile.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,2,85,7],
-"class_ogre_1_1_profile.html#adce32528577d71b228692df906ecd17c":[5,2,2,85,10],
-"class_ogre_1_1_profile.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,2,85,11],
-"class_ogre_1_1_profile_instance.html":[5,2,2,88],
-"class_ogre_1_1_profile_instance.html#a08c87da13e23c3899052faab7680da30":[5,2,2,88,28],
-"class_ogre_1_1_profile_instance.html#a0d07b5ee2f25241fed784e92accd86c1":[5,2,2,88,1],
-"class_ogre_1_1_profile_instance.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,88,8],
-"class_ogre_1_1_profile_instance.html#a1fd3ce0a1a19f9721d712c9a1426b515":[5,2,2,88,19],
-"class_ogre_1_1_profile_instance.html#a27bde362d885b8aab267d0635b0c30ae":[5,2,2,88,22],
-"class_ogre_1_1_profile_instance.html#a40b76f9c74bd13e1b07db0559af27dc5":[5,2,2,88,29],
-"class_ogre_1_1_profile_instance.html#a41f4675a0f1e9bebe386851423f2e682":[5,2,2,88,4],
 "class_ogre_1_1_profile_instance.html#a4921211276e29e72155077235687cf54":[5,2,2,88,2],
 "class_ogre_1_1_profile_instance.html#a57bcfc956ed84e6e4a85bf485a98d7c3":[5,2,2,88,0],
 "class_ogre_1_1_profile_instance.html#a584eaa396f1b06fd16c666e5a9e42730":[5,2,2,88,17],
@@ -87,46 +41,47 @@ var NAVTREEINDEX191 =
 "class_ogre_1_1_profile_session_listener.html#ae1e613f73f9d96f4a9a6531f58a25262":[5,2,2,90,6],
 "class_ogre_1_1_profiler.html":[5,2,2,89],
 "class_ogre_1_1_profiler.html#a01413a02e5af48736c96284ee973cfd2":[5,2,2,89,2],
-"class_ogre_1_1_profiler.html#a0693fe06be3837662419669528bf4811":[5,2,2,89,31],
+"class_ogre_1_1_profiler.html#a0693fe06be3837662419669528bf4811":[5,2,2,89,32],
 "class_ogre_1_1_profiler.html#a144fc3944f41b1198a44590beda4ce3f":[5,2,2,89,6],
-"class_ogre_1_1_profiler.html#a1539975bc729be95d410cda274e1dd4e":[5,2,2,89,14],
-"class_ogre_1_1_profiler.html#a190afc6d10a430fbf37d2b4297e59507":[5,2,2,89,19],
+"class_ogre_1_1_profiler.html#a1539975bc729be95d410cda274e1dd4e":[5,2,2,89,15],
+"class_ogre_1_1_profiler.html#a190afc6d10a430fbf37d2b4297e59507":[5,2,2,89,20],
 "class_ogre_1_1_profiler.html#a1c4d43eaf4b909cd9970836709f50caa":[5,2,2,89,5],
-"class_ogre_1_1_profiler.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,89,22],
+"class_ogre_1_1_profiler.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,89,23],
 "class_ogre_1_1_profiler.html#a43b5da14797ed9b7e48da4638207ca84":[5,2,2,89,11],
-"class_ogre_1_1_profiler.html#a456a0f133ccea3eb515626edd22963ec":[5,2,2,89,18],
+"class_ogre_1_1_profiler.html#a456a0f133ccea3eb515626edd22963ec":[5,2,2,89,19],
 "class_ogre_1_1_profiler.html#a45e1f8ac11468a9322148be4e22e85de":[5,2,2,89,1],
 "class_ogre_1_1_profiler.html#a52e2f0d3530febbbf7199173d91ad4e2":[5,2,2,89,7],
-"class_ogre_1_1_profiler.html#a53a2d2681a3995555df6d789c5596381":[5,2,2,89,34],
+"class_ogre_1_1_profiler.html#a53a2d2681a3995555df6d789c5596381":[5,2,2,89,35],
 "class_ogre_1_1_profiler.html#a5800006ecf74193bb6683428542b60b5":[5,2,2,89,3],
-"class_ogre_1_1_profiler.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,2,89,24],
-"class_ogre_1_1_profiler.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,2,89,27],
-"class_ogre_1_1_profiler.html#a6ae2234ea1b43d5afc18243d491f8910":[5,2,2,89,15],
-"class_ogre_1_1_profiler.html#a72f5610e6fffc382e660c3a301d4a5d1":[5,2,2,89,40],
-"class_ogre_1_1_profiler.html#a78dcc907495fd0cb3d58520b1f2975d8":[5,2,2,89,30],
-"class_ogre_1_1_profiler.html#a8147f54c4af90377e9cde1a0d9608a58":[5,2,2,89,13],
-"class_ogre_1_1_profiler.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,2,89,20],
-"class_ogre_1_1_profiler.html#a8d4362f2e2322a0323e67df82101b1b9":[5,2,2,89,17],
-"class_ogre_1_1_profiler.html#a8e0b586d75f5a8108178fcd75342aa7e":[5,2,2,89,12],
-"class_ogre_1_1_profiler.html#a91c40e21a3fc96003504ea21fec80d77":[5,2,2,89,32],
-"class_ogre_1_1_profiler.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,2,89,23],
+"class_ogre_1_1_profiler.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,2,89,25],
+"class_ogre_1_1_profiler.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,2,89,28],
+"class_ogre_1_1_profiler.html#a6ae2234ea1b43d5afc18243d491f8910":[5,2,2,89,16],
+"class_ogre_1_1_profiler.html#a72f5610e6fffc382e660c3a301d4a5d1":[5,2,2,89,41],
+"class_ogre_1_1_profiler.html#a78dcc907495fd0cb3d58520b1f2975d8":[5,2,2,89,31],
+"class_ogre_1_1_profiler.html#a8147f54c4af90377e9cde1a0d9608a58":[5,2,2,89,14],
+"class_ogre_1_1_profiler.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,2,89,21],
+"class_ogre_1_1_profiler.html#a8d4362f2e2322a0323e67df82101b1b9":[5,2,2,89,18],
+"class_ogre_1_1_profiler.html#a8e0b586d75f5a8108178fcd75342aa7e":[5,2,2,89,13],
+"class_ogre_1_1_profiler.html#a91c40e21a3fc96003504ea21fec80d77":[5,2,2,89,33],
+"class_ogre_1_1_profiler.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,2,89,24],
 "class_ogre_1_1_profiler.html#aa35c96681ded2faf493defa432ce6a04":[5,2,2,89,0],
-"class_ogre_1_1_profiler.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,2,89,26],
+"class_ogre_1_1_profiler.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,2,89,27],
 "class_ogre_1_1_profiler.html#abe681ebc8892d4475940301a0319fe83":[5,2,2,89,10],
-"class_ogre_1_1_profiler.html#abeddcc5a800e355c1ee09ce2d38fd16d":[5,2,2,89,36],
+"class_ogre_1_1_profiler.html#abeddcc5a800e355c1ee09ce2d38fd16d":[5,2,2,89,37],
 "class_ogre_1_1_profiler.html#abefd86977f9c58ef76e8c92eb17ec9c8":[5,2,2,89,9],
 "class_ogre_1_1_profiler.html#ac08272286cf01c6c24aacb91b6800be3":[5,2,2,89,4],
-"class_ogre_1_1_profiler.html#ac29d425e0f0b531f2c7f643907c9402d":[5,2,2,89,35],
-"class_ogre_1_1_profiler.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,2,89,21],
+"class_ogre_1_1_profiler.html#ac29d425e0f0b531f2c7f643907c9402d":[5,2,2,89,36],
+"class_ogre_1_1_profiler.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,2,89,22],
 "class_ogre_1_1_profiler.html#ace158cd7cd820a3176755ce3b84601c3":[5,2,2,89,8],
-"class_ogre_1_1_profiler.html#ad19bcccfdf69b21b9953488cb58de764":[5,2,2,89,33],
-"class_ogre_1_1_profiler.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,2,89,25],
-"class_ogre_1_1_profiler.html#ad37efd3a99cf736a0424fd0c1c92efb4":[5,2,2,89,39],
-"class_ogre_1_1_profiler.html#adce32528577d71b228692df906ecd17c":[5,2,2,89,28],
-"class_ogre_1_1_profiler.html#adfd868a7f9213baece5687bd36e23279":[5,2,2,89,37],
-"class_ogre_1_1_profiler.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,2,89,29],
-"class_ogre_1_1_profiler.html#af2ee3ac48da6f0ae5b39b80e7f99ef56":[5,2,2,89,16],
-"class_ogre_1_1_profiler.html#afc737d10ba6b5732df9a538a196ee3e6":[5,2,2,89,38],
+"class_ogre_1_1_profiler.html#ad19bcccfdf69b21b9953488cb58de764":[5,2,2,89,34],
+"class_ogre_1_1_profiler.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,2,89,26],
+"class_ogre_1_1_profiler.html#ad37efd3a99cf736a0424fd0c1c92efb4":[5,2,2,89,40],
+"class_ogre_1_1_profiler.html#adce32528577d71b228692df906ecd17c":[5,2,2,89,29],
+"class_ogre_1_1_profiler.html#adfd868a7f9213baece5687bd36e23279":[5,2,2,89,38],
+"class_ogre_1_1_profiler.html#ae6b99366788276bb361fb6b621d2cca5":[5,2,2,89,12],
+"class_ogre_1_1_profiler.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,2,89,30],
+"class_ogre_1_1_profiler.html#af2ee3ac48da6f0ae5b39b80e7f99ef56":[5,2,2,89,17],
+"class_ogre_1_1_profiler.html#afc737d10ba6b5732df9a538a196ee3e6":[5,2,2,89,39],
 "class_ogre_1_1_property.html":[5,1,1,1],
 "class_ogre_1_1_property.html#a06f442becff5384a8fd99c21eeb0234b":[5,1,1,1,2],
 "class_ogre_1_1_property.html#a12487350ad5d420e7c607551da33bb2c":[5,1,1,1,3],
@@ -249,5 +204,50 @@ var NAVTREEINDEX191 =
 "class_ogre_1_1_pso_cache_helper.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,11,107,8],
 "class_ogre_1_1_pso_cache_helper.html#a230f6e2e4d1421258c32cf6366c0608e":[5,2,11,107,5],
 "class_ogre_1_1_pso_cache_helper.html#a241dc6283b69aff14cb6cac0a94a8e9b":[5,2,11,107,16],
-"class_ogre_1_1_pso_cache_helper.html#a2c42036817973cdf31f0007beda3426b":[5,2,11,107,17]
+"class_ogre_1_1_pso_cache_helper.html#a2c42036817973cdf31f0007beda3426b":[5,2,11,107,17],
+"class_ogre_1_1_pso_cache_helper.html#a2cf5647fb77ed43b8246af90ed80665b":[5,2,11,107,0],
+"class_ogre_1_1_pso_cache_helper.html#a2e6c46d268ae457843aa10aac3a2fa1f":[5,2,11,107,1],
+"class_ogre_1_1_pso_cache_helper.html#a50c3710135758e86e41a407a1440789e":[5,2,11,107,21],
+"class_ogre_1_1_pso_cache_helper.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,11,107,10],
+"class_ogre_1_1_pso_cache_helper.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,107,13],
+"class_ogre_1_1_pso_cache_helper.html#a7ae3346100de461609296b037e92fe42":[5,2,11,107,19],
+"class_ogre_1_1_pso_cache_helper.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,11,107,6],
+"class_ogre_1_1_pso_cache_helper.html#a8e47255d7cbcac1ab8fb9a5e0912b4c0":[5,2,11,107,3],
+"class_ogre_1_1_pso_cache_helper.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,11,107,9],
+"class_ogre_1_1_pso_cache_helper.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,11,107,12],
+"class_ogre_1_1_pso_cache_helper.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,11,107,7],
+"class_ogre_1_1_pso_cache_helper.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,11,107,11],
+"class_ogre_1_1_pso_cache_helper.html#ad8da16c8ef8977ef74d562305fb75d4c":[5,2,11,107,4],
+"class_ogre_1_1_pso_cache_helper.html#adce32528577d71b228692df906ecd17c":[5,2,11,107,14],
+"class_ogre_1_1_pso_cache_helper.html#adf9e2127cf6d10e5fa9fb4e58aac5772":[5,2,11,107,2],
+"class_ogre_1_1_pso_cache_helper.html#ae18fbff8dd7393c89fdb1c3412d3525c":[5,2,11,107,20],
+"class_ogre_1_1_pso_cache_helper.html#aec6cde2771419d0e7add22c9062726ce":[5,2,11,107,18],
+"class_ogre_1_1_pso_cache_helper.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,11,107,15],
+"class_ogre_1_1_quaternion.html":[5,2,6,22],
+"class_ogre_1_1_quaternion.html#a0528f264ccc686c5315981d19b75aa0e":[5,2,6,22,34],
+"class_ogre_1_1_quaternion.html#a1140011dc0793a81c55f2d078c8c964c":[5,2,6,22,4],
+"class_ogre_1_1_quaternion.html#a15c912e62c9abcb3335de205cdf30c2d":[5,2,6,22,16],
+"class_ogre_1_1_quaternion.html#a16987149991882e148170fe3f1c7da4b":[5,2,6,22,21],
+"class_ogre_1_1_quaternion.html#a1ca81bd9d57e43cf23582c898e5fdd34":[5,2,6,22,6],
+"class_ogre_1_1_quaternion.html#a24b15dc994247753b7a8064b6a13e2d6":[5,2,6,22,29],
+"class_ogre_1_1_quaternion.html#a25fb3bc0f11e6a676fb5c47347a79579":[5,2,6,22,38],
+"class_ogre_1_1_quaternion.html#a2fb2913d70c7c4ea6e0799187746401b":[5,2,6,22,41],
+"class_ogre_1_1_quaternion.html#a2fd01476d5136662031156707b2b3879":[5,2,6,22,27],
+"class_ogre_1_1_quaternion.html#a31ec84a931236554c0c17e37bf5ace97":[5,2,6,22,57],
+"class_ogre_1_1_quaternion.html#a32c5680516b41bc4ba3159bf4d4abaf1":[5,2,6,22,55],
+"class_ogre_1_1_quaternion.html#a353aafd21ec10c8c07f04472ae6c32b8":[5,2,6,22,22],
+"class_ogre_1_1_quaternion.html#a365bc3b10308318721199a829db03887":[5,2,6,22,11],
+"class_ogre_1_1_quaternion.html#a390c026412bb0e687f20cfe1bc0ada66":[5,2,6,22,33],
+"class_ogre_1_1_quaternion.html#a3c41f8bb4147db31ff9674a70de1aad5":[5,2,6,22,49],
+"class_ogre_1_1_quaternion.html#a3ccc60338011887023b397a02a7f3336":[5,2,6,22,5],
+"class_ogre_1_1_quaternion.html#a441b8d52549e1dedec27420325a313ef":[5,2,6,22,52],
+"class_ogre_1_1_quaternion.html#a44f3c000c8f1ea2759c2e724e04bf86b":[5,2,6,22,58],
+"class_ogre_1_1_quaternion.html#a4f89136f9dcb79fef8c47dc418e3e55f":[5,2,6,22,20],
+"class_ogre_1_1_quaternion.html#a535ef1c199eee303753507a4a78ddf22":[5,2,6,22,26],
+"class_ogre_1_1_quaternion.html#a54dcd575915c7b7ddb65b8cb249de521":[5,2,6,22,40],
+"class_ogre_1_1_quaternion.html#a58a45c5dd46ceee8dbf81dfced570dbe":[5,2,6,22,47],
+"class_ogre_1_1_quaternion.html#a5f43da8b8aa579e02035eecff89e16a5":[5,2,6,22,39],
+"class_ogre_1_1_quaternion.html#a6005735392c9b07901b8fe160c959f46":[5,2,6,22,45],
+"class_ogre_1_1_quaternion.html#a6b53296360cc166c62533cff8f1edcc2":[5,2,6,22,53],
+"class_ogre_1_1_quaternion.html#a7ad7ad40e38bf351485c2a906c3949bb":[5,2,6,22,12]
 };
