@@ -1,50 +1,5 @@
 var NAVTREEINDEX192 =
 {
-"class_ogre_1_1_pso_cache_helper.html#a2cf5647fb77ed43b8246af90ed80665b":[5,2,11,107,0],
-"class_ogre_1_1_pso_cache_helper.html#a2e6c46d268ae457843aa10aac3a2fa1f":[5,2,11,107,1],
-"class_ogre_1_1_pso_cache_helper.html#a50c3710135758e86e41a407a1440789e":[5,2,11,107,21],
-"class_ogre_1_1_pso_cache_helper.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,11,107,10],
-"class_ogre_1_1_pso_cache_helper.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,107,13],
-"class_ogre_1_1_pso_cache_helper.html#a7ae3346100de461609296b037e92fe42":[5,2,11,107,19],
-"class_ogre_1_1_pso_cache_helper.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,11,107,6],
-"class_ogre_1_1_pso_cache_helper.html#a8e47255d7cbcac1ab8fb9a5e0912b4c0":[5,2,11,107,3],
-"class_ogre_1_1_pso_cache_helper.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,11,107,9],
-"class_ogre_1_1_pso_cache_helper.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,11,107,12],
-"class_ogre_1_1_pso_cache_helper.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,11,107,7],
-"class_ogre_1_1_pso_cache_helper.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,11,107,11],
-"class_ogre_1_1_pso_cache_helper.html#ad8da16c8ef8977ef74d562305fb75d4c":[5,2,11,107,4],
-"class_ogre_1_1_pso_cache_helper.html#adce32528577d71b228692df906ecd17c":[5,2,11,107,14],
-"class_ogre_1_1_pso_cache_helper.html#adf9e2127cf6d10e5fa9fb4e58aac5772":[5,2,11,107,2],
-"class_ogre_1_1_pso_cache_helper.html#ae18fbff8dd7393c89fdb1c3412d3525c":[5,2,11,107,20],
-"class_ogre_1_1_pso_cache_helper.html#aec6cde2771419d0e7add22c9062726ce":[5,2,11,107,18],
-"class_ogre_1_1_pso_cache_helper.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,11,107,15],
-"class_ogre_1_1_quaternion.html":[5,2,6,22],
-"class_ogre_1_1_quaternion.html#a0528f264ccc686c5315981d19b75aa0e":[5,2,6,22,34],
-"class_ogre_1_1_quaternion.html#a1140011dc0793a81c55f2d078c8c964c":[5,2,6,22,4],
-"class_ogre_1_1_quaternion.html#a15c912e62c9abcb3335de205cdf30c2d":[5,2,6,22,16],
-"class_ogre_1_1_quaternion.html#a16987149991882e148170fe3f1c7da4b":[5,2,6,22,21],
-"class_ogre_1_1_quaternion.html#a1ca81bd9d57e43cf23582c898e5fdd34":[5,2,6,22,6],
-"class_ogre_1_1_quaternion.html#a24b15dc994247753b7a8064b6a13e2d6":[5,2,6,22,29],
-"class_ogre_1_1_quaternion.html#a25fb3bc0f11e6a676fb5c47347a79579":[5,2,6,22,38],
-"class_ogre_1_1_quaternion.html#a2fb2913d70c7c4ea6e0799187746401b":[5,2,6,22,41],
-"class_ogre_1_1_quaternion.html#a2fd01476d5136662031156707b2b3879":[5,2,6,22,27],
-"class_ogre_1_1_quaternion.html#a31ec84a931236554c0c17e37bf5ace97":[5,2,6,22,57],
-"class_ogre_1_1_quaternion.html#a32c5680516b41bc4ba3159bf4d4abaf1":[5,2,6,22,55],
-"class_ogre_1_1_quaternion.html#a353aafd21ec10c8c07f04472ae6c32b8":[5,2,6,22,22],
-"class_ogre_1_1_quaternion.html#a365bc3b10308318721199a829db03887":[5,2,6,22,11],
-"class_ogre_1_1_quaternion.html#a390c026412bb0e687f20cfe1bc0ada66":[5,2,6,22,33],
-"class_ogre_1_1_quaternion.html#a3c41f8bb4147db31ff9674a70de1aad5":[5,2,6,22,49],
-"class_ogre_1_1_quaternion.html#a3ccc60338011887023b397a02a7f3336":[5,2,6,22,5],
-"class_ogre_1_1_quaternion.html#a441b8d52549e1dedec27420325a313ef":[5,2,6,22,52],
-"class_ogre_1_1_quaternion.html#a44f3c000c8f1ea2759c2e724e04bf86b":[5,2,6,22,58],
-"class_ogre_1_1_quaternion.html#a4f89136f9dcb79fef8c47dc418e3e55f":[5,2,6,22,20],
-"class_ogre_1_1_quaternion.html#a535ef1c199eee303753507a4a78ddf22":[5,2,6,22,26],
-"class_ogre_1_1_quaternion.html#a54dcd575915c7b7ddb65b8cb249de521":[5,2,6,22,40],
-"class_ogre_1_1_quaternion.html#a58a45c5dd46ceee8dbf81dfced570dbe":[5,2,6,22,47],
-"class_ogre_1_1_quaternion.html#a5f43da8b8aa579e02035eecff89e16a5":[5,2,6,22,39],
-"class_ogre_1_1_quaternion.html#a6005735392c9b07901b8fe160c959f46":[5,2,6,22,45],
-"class_ogre_1_1_quaternion.html#a6b53296360cc166c62533cff8f1edcc2":[5,2,6,22,53],
-"class_ogre_1_1_quaternion.html#a7ad7ad40e38bf351485c2a906c3949bb":[5,2,6,22,12],
 "class_ogre_1_1_quaternion.html#a7f25c623d95186b58f6367dcd097a5ba":[5,2,6,22,3],
 "class_ogre_1_1_quaternion.html#a814829e953cbf810c80a8b87626f6324":[5,2,6,22,42],
 "class_ogre_1_1_quaternion.html#a821a464cce9a81d5d20c620025043851":[5,2,6,22,46],
@@ -249,5 +204,50 @@ var NAVTREEINDEX192 =
 "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7aec8acb4ef3c6c9a1992b46fdb2953301":[5,2,9,3,0,49],
 "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7aecd484d76771c40cb1bf66e4e65ff626":[5,2,9,3,0,43],
 "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7af0826e11ede54b12a73d5ab258fc36d8":[5,2,9,3,0,10],
-"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7af09d1f2a6a6cc697b944875ed41c8a46":[5,2,9,3,0,79]
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7af09d1f2a6a6cc697b944875ed41c8a46":[5,2,9,3,0,79],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7af656a236e44e9b0e7e217e0a43764149":[5,2,9,3,0,118],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7af6a7b1ca46334e44892c971443e5bcb9":[5,2,9,3,0,39],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7af79c051d708f88de2dd66ea5b715773c":[5,2,9,3,0,128],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7afae348fe8b17f9822851e73db5bfca97":[5,2,9,3,0,5],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7afc269115e68796e473c0c6ac9e63cc8b":[5,2,9,3,0,57],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7afc6af58cc0cb82ef1037a899b9fac4b7":[5,2,9,3,0,23],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a5619ee392f00630f3391f7dff49a43b6":[5,2,9,3,6],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,9,3,17],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,9,3,20],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a66737b9982cbf8778c4114082d8ab496":[5,2,9,3,5],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a6cfdeab93ec4d977ce82b27fd2237874":[5,2,9,3,10],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,9,3,13],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a83a641fd3be8b42222c1a5988c5c74fd":[5,2,9,3,9],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a90eda7480a0c6a7f6c5657f2297c0672":[5,2,9,3,3],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312":[5,2,9,3,1],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312a1749fc49b1811bf3f129c722a6e8bd51":[5,2,9,3,1,4],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312a9b746851560ab52d22335755dd36a0ea":[5,2,9,3,1,2],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312aa0daafd54236a0c331bad11ad0450483":[5,2,9,3,1,9],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312aa27b75d58d2ae680d71d5eda917c5783":[5,2,9,3,1,8],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312aacb3f8c7623415a9398f1d0aeb0849d9":[5,2,9,3,1,6],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312abfddaa99b1d15933e549af52af916c86":[5,2,9,3,1,5],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312ac887733af706c0769dcbb9215f7e8b50":[5,2,9,3,1,1],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312ace9a03298936fc08b7474848ca2ce7b3":[5,2,9,3,1,0],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312ad9ee9f8d6b6508f5e0402140afe2f655":[5,2,9,3,1,3],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312af67c3c93adcb32edbb0b93fa6ac21ac0":[5,2,9,3,1,7],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,9,3,16],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,9,3,19],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#ab8ed4fa20a94d4dc3b964ee20d56769f":[5,2,9,3,4],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,9,3,14],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,9,3,18],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#adce32528577d71b228692df906ecd17c":[5,2,9,3,21],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#aeacadad2424b2f76c78a6c7b86c31ead":[5,2,9,3,12],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,9,3,22],
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#aefb06f44383244d59e3832f691d9f7b6":[5,2,9,3,8],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html":[5,2,9,4],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,9,4,9],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,9,4,11],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,9,4,14],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,9,4,7],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,9,4,10],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,9,4,13],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,9,4,8],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,9,4,12],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#adce32528577d71b228692df906ecd17c":[5,2,9,4,15],
+"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,9,4,16]
 };
