@@ -1,67 +1,24 @@
 var NAVTREEINDEX215 =
 {
-"class_ogre_1_1_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,51,16],
-"class_ogre_1_1_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,51,16],
-"class_ogre_1_1_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,12,51,4],
-"class_ogre_1_1_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,0,1,51,4],
-"class_ogre_1_1_scene_query_listener.html":[5,2,12,52],
-"class_ogre_1_1_scene_query_listener.html":[5,0,1,52],
-"class_ogre_1_1_scene_query_listener.html#a70936d2cd7413dd284faef05528ddb92":[5,2,12,52,1],
-"class_ogre_1_1_scene_query_listener.html#a70936d2cd7413dd284faef05528ddb92":[5,0,1,52,1],
-"class_ogre_1_1_scene_query_listener.html#ac17a072217f44693bb45ecbcd1623611":[5,0,1,52,2],
-"class_ogre_1_1_scene_query_listener.html#ac17a072217f44693bb45ecbcd1623611":[5,2,12,52,2],
-"class_ogre_1_1_scene_query_listener.html#ad0ea5280ec1032a5170999eb7ae3fb2b":[5,2,12,52,0],
-"class_ogre_1_1_scene_query_listener.html#ad0ea5280ec1032a5170999eb7ae3fb2b":[5,0,1,52,0],
-"class_ogre_1_1_scoped_lock.html":[6,0,0,893],
-"class_ogre_1_1_scoped_lock.html":[7,0,0,866],
-"class_ogre_1_1_scoped_lock.html#a7fe0c08bd1bc6afbca5fa28cd6dfbf15":[6,0,0,893,0],
-"class_ogre_1_1_scoped_lock.html#a7fe0c08bd1bc6afbca5fa28cd6dfbf15":[7,0,0,866,0],
-"class_ogre_1_1_scoped_lock.html#ab88bcddc017034e6da204a72c3385034":[6,0,0,893,1],
-"class_ogre_1_1_scoped_lock.html#ab88bcddc017034e6da204a72c3385034":[7,0,0,866,1],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html":[7,0,0,867],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html":[6,0,0,894],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[7,0,0,867,1],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[6,0,0,894,1],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,867,11],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,894,11],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a23ece09087d2a35c762e436fdec227c5":[7,0,0,867,8],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a23ece09087d2a35c762e436fdec227c5":[6,0,0,894,8],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a2400dc929b5f7727f0d69336b3b1e05d":[6,0,0,894,7],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a2400dc929b5f7727f0d69336b3b1e05d":[7,0,0,867,7],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a280ee76e313e85dbd47d46fcf38ce1fd":[6,0,0,894,20],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a280ee76e313e85dbd47d46fcf38ce1fd":[7,0,0,867,20],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a46a920a23f3f459a84fa675d7df0f906":[7,0,0,867,3],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a46a920a23f3f459a84fa675d7df0f906":[6,0,0,894,3],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[7,0,0,867,19],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[6,0,0,894,19],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,867,13],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,894,13],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,894,16],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,867,16],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a67c3bc6755c75d797e0478b3f226eb33":[6,0,0,894,6],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a67c3bc6755c75d797e0478b3f226eb33":[7,0,0,867,6],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a73d681b5f30d71ace485b8290eacd660":[6,0,0,894,0],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a73d681b5f30d71ace485b8290eacd660":[7,0,0,867,0],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a75779c55ad34f69cd8c86de504a01e52":[7,0,0,867,4],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a75779c55ad34f69cd8c86de504a01e52":[6,0,0,894,4],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,894,9],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,867,9],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,894,12],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,867,12],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,867,15],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,894,15],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,894,10],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,867,10],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,867,14],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,894,14],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adce32528577d71b228692df906ecd17c":[7,0,0,867,17],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adce32528577d71b228692df906ecd17c":[6,0,0,894,17],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[7,0,0,867,5],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[6,0,0,894,5],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,867,18],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,894,18],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#afcbca1aed7b649a98adc3393ce177fc7":[7,0,0,867,2],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#afcbca1aed7b649a98adc3393ce177fc7":[6,0,0,894,2],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a75779c55ad34f69cd8c86de504a01e52":[7,0,0,865,4],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,865,9],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,892,9],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,865,12],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,892,12],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,892,15],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,865,15],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,865,10],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,892,10],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,892,14],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,865,14],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adce32528577d71b228692df906ecd17c":[7,0,0,865,17],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adce32528577d71b228692df906ecd17c":[6,0,0,892,17],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[6,0,0,892,5],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[7,0,0,865,5],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,865,18],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,892,18],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#afcbca1aed7b649a98adc3393ce177fc7":[6,0,0,892,2],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#afcbca1aed7b649a98adc3393ce177fc7":[7,0,0,865,2],
 "class_ogre_1_1_script_compiler.html":[5,2,2,99],
 "class_ogre_1_1_script_compiler.html#a0fb27db0a80a4243e9376702e402f469":[5,2,2,99,6],
 "class_ogre_1_1_script_compiler.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,99,18],
@@ -234,14 +191,14 @@ var NAVTREEINDEX215 =
 "class_ogre_1_1_shader_params.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,0,24,18],
 "class_ogre_1_1_shadow_camera_setup.html":[5,2,12,54],
 "class_ogre_1_1_shadow_camera_setup.html":[5,0,1,54],
-"class_ogre_1_1_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,54,7],
 "class_ogre_1_1_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,54,7],
-"class_ogre_1_1_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,54,9],
+"class_ogre_1_1_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,54,7],
 "class_ogre_1_1_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,54,9],
-"class_ogre_1_1_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,2,12,54,2],
+"class_ogre_1_1_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,54,9],
 "class_ogre_1_1_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,0,1,54,2],
-"class_ogre_1_1_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,54,12],
+"class_ogre_1_1_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,2,12,54,2],
 "class_ogre_1_1_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,54,12],
+"class_ogre_1_1_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,54,12],
 "class_ogre_1_1_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,2,12,54,15],
 "class_ogre_1_1_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,0,1,54,15],
 "class_ogre_1_1_shadow_camera_setup.html#a790a06721a8e3c6f48218aa659c334ef":[5,0,1,54,1],
@@ -249,5 +206,48 @@ var NAVTREEINDEX215 =
 "class_ogre_1_1_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,54,5],
 "class_ogre_1_1_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,54,5],
 "class_ogre_1_1_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,54,8],
-"class_ogre_1_1_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,54,8]
+"class_ogre_1_1_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,54,8],
+"class_ogre_1_1_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,54,11],
+"class_ogre_1_1_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,54,11],
+"class_ogre_1_1_shadow_camera_setup.html#ab6e8a9669102634c5a9a1273133f8240":[5,0,1,54,4],
+"class_ogre_1_1_shadow_camera_setup.html#ab6e8a9669102634c5a9a1273133f8240":[5,2,12,54,4],
+"class_ogre_1_1_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,54,6],
+"class_ogre_1_1_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,54,6],
+"class_ogre_1_1_shadow_camera_setup.html#acdd9ee220860b6c914feb28de74e3304":[5,0,1,54,0],
+"class_ogre_1_1_shadow_camera_setup.html#acdd9ee220860b6c914feb28de74e3304":[5,2,12,54,0],
+"class_ogre_1_1_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,54,10],
+"class_ogre_1_1_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,54,10],
+"class_ogre_1_1_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,0,1,54,3],
+"class_ogre_1_1_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,2,12,54,3],
+"class_ogre_1_1_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,0,1,54,13],
+"class_ogre_1_1_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,2,12,54,13],
+"class_ogre_1_1_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,54,14],
+"class_ogre_1_1_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,54,14],
+"class_ogre_1_1_shadow_node_helper.html":[5,2,1,50],
+"class_ogre_1_1_shadow_node_helper.html#a365e9a945dc2cdb574d0e1424e82113a":[5,2,1,50,2],
+"class_ogre_1_1_shadow_node_helper.html#a4625121cc23dc52f31c9dc2821a08faa":[5,2,1,50,3],
+"class_ogre_1_1_shadow_texture_definition.html":[5,2,1,51],
+"class_ogre_1_1_shadow_texture_definition.html#a02f3d90da7a3f58246359cde30a89662":[5,2,1,51,4],
+"class_ogre_1_1_shadow_texture_definition.html#a0a064093cc25f4311d05d83119264cde":[5,2,1,51,22],
+"class_ogre_1_1_shadow_texture_definition.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,1,51,7],
+"class_ogre_1_1_shadow_texture_definition.html#a1c82ba62c6bd28831012501ece8a226d":[5,2,1,51,24],
+"class_ogre_1_1_shadow_texture_definition.html#a1cd3c1275e1b00eb38cbf805d25646b2":[5,2,1,51,27],
+"class_ogre_1_1_shadow_texture_definition.html#a3159585f3a32eae40af7d5f38a70b75b":[5,2,1,51,3],
+"class_ogre_1_1_shadow_texture_definition.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,1,51,9],
+"class_ogre_1_1_shadow_texture_definition.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,1,51,12],
+"class_ogre_1_1_shadow_texture_definition.html#a6b5048cef58070a4608897ab718eb9c4":[5,2,1,51,29],
+"class_ogre_1_1_shadow_texture_definition.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,1,51,5],
+"class_ogre_1_1_shadow_texture_definition.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,1,51,8],
+"class_ogre_1_1_shadow_texture_definition.html#a9415b07e2e36a433b61767818fa214d8":[5,2,1,51,30],
+"class_ogre_1_1_shadow_texture_definition.html#a9507bb87ab7eb7b43aa7b76617d8c453":[5,2,1,51,17],
+"class_ogre_1_1_shadow_texture_definition.html#a95f59e0cb3cb10ecdb6ef1c2f2ac3779":[5,2,1,51,0],
+"class_ogre_1_1_shadow_texture_definition.html#a99d411e1fb173b3305c170d04b5b3db2":[5,2,1,51,20],
+"class_ogre_1_1_shadow_texture_definition.html#a9b5126de096e92c457fdb3e9eb568f1b":[5,2,1,51,28],
+"class_ogre_1_1_shadow_texture_definition.html#a9e5b8c6d0098da31d67c40d1bb5a28c1":[5,2,1,51,15],
+"class_ogre_1_1_shadow_texture_definition.html#aa100d786a6ad8f23afa531ef669c2f50":[5,2,1,51,16],
+"class_ogre_1_1_shadow_texture_definition.html#aa3ac2972f9e469cd082cd53192c9413e":[5,2,1,51,26],
+"class_ogre_1_1_shadow_texture_definition.html#aa3dc808f23fdd0c33b1fcf1f02bc5783":[5,2,1,51,1],
+"class_ogre_1_1_shadow_texture_definition.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,1,51,11],
+"class_ogre_1_1_shadow_texture_definition.html#abbe758473936c89544c7c181e087eb6c":[5,2,1,51,18],
+"class_ogre_1_1_shadow_texture_definition.html#ac05b4994513eb9bad227e3e14baa5573":[5,2,1,51,2]
 };
