@@ -1,48 +1,6 @@
 var NAVTREEINDEX222 =
 {
-"class_ogre_1_1_stream_serialiser.html#ad81be1455eacc97d5fcd1df06cbe1b93":[5,2,11,124,11],
-"class_ogre_1_1_stream_serialiser.html#ad9bed5f1d3e5a1ffe15a8a95eaa83f31":[5,2,11,124,12],
-"class_ogre_1_1_stream_serialiser.html#ada08984a52a07febc6ddd531c60adbd6":[5,2,11,124,61],
-"class_ogre_1_1_stream_serialiser.html#adce32528577d71b228692df906ecd17c":[5,2,11,124,21],
-"class_ogre_1_1_stream_serialiser.html#ae287158dbf1c109012cb165bfc0cf1e8":[5,2,11,124,7],
-"class_ogre_1_1_stream_serialiser.html#ae955dfcf39b9a0d7407289e2073d45e0":[5,2,11,124,41],
-"class_ogre_1_1_stream_serialiser.html#aea616ff03daa17c34ac1e38682a501c2":[5,2,11,124,40],
-"class_ogre_1_1_stream_serialiser.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,11,124,22],
-"class_ogre_1_1_stream_serialiser.html#aee0e00b95f550cc324cbb5fef1a3766b":[5,2,11,124,39],
-"class_ogre_1_1_stream_serialiser.html#af8fe1551fa5a1dc26317c9b57b8ef1f6":[5,2,11,124,25],
-"class_ogre_1_1_string_converter.html":[5,2,2,120],
-"class_ogre_1_1_string_converter.html#a0356f16ae84fb3a715c7a5cd98fb5ff3":[5,2,2,120,2],
-"class_ogre_1_1_string_converter.html#a041e06bfaeca7a8950bbd04176d1b826":[5,2,2,120,15],
-"class_ogre_1_1_string_converter.html#a0759107b842b8483abbce915a74dd5e1":[5,2,2,120,18],
-"class_ogre_1_1_string_converter.html#a0cdfb81eecf49efe65f33593f2251b39":[5,2,2,120,13],
-"class_ogre_1_1_string_converter.html#a167f9319fa721f66e393d963de145c6c":[5,2,2,120,6],
-"class_ogre_1_1_string_converter.html#a16f86bf7f546c9a6c0d3477e84f12024":[5,2,2,120,39],
-"class_ogre_1_1_string_converter.html#a17b3ccc053e6d9cb1e6f0fbd754984b5":[5,2,2,120,37],
-"class_ogre_1_1_string_converter.html#a184e73275f33b8191a756dad27e391b2":[5,2,2,120,40],
-"class_ogre_1_1_string_converter.html#a18abdb1754749134d685e023b5a52bd3":[5,2,2,120,36],
-"class_ogre_1_1_string_converter.html#a1a53ab0f54bc753ae2748909696d0b32":[5,2,2,120,25],
-"class_ogre_1_1_string_converter.html#a1dbc8f24c3d8611f4e9431f3b2122a2e":[5,2,2,120,8],
-"class_ogre_1_1_string_converter.html#a2b0bf2b7d279c782d175797ecccdb769":[5,2,2,120,14],
-"class_ogre_1_1_string_converter.html#a40baf295547f60d3d0efcf279268d8dc":[5,2,2,120,31],
-"class_ogre_1_1_string_converter.html#a41d15619e971971f2025052e1a6d7c5a":[5,2,2,120,32],
-"class_ogre_1_1_string_converter.html#a4591e8414fc653e18ac7c3b427c5f093":[5,2,2,120,9],
-"class_ogre_1_1_string_converter.html#a49e815a4951a685b0434bcb561fa3a37":[5,2,2,120,5],
-"class_ogre_1_1_string_converter.html#a4de896cef79f4620355149a42c43dff6":[5,2,2,120,19],
-"class_ogre_1_1_string_converter.html#a54b489bc08f1542fe9dd0b9d57fbfbca":[5,2,2,120,30],
-"class_ogre_1_1_string_converter.html#a61def841d7130942b8133508bfa50b12":[5,2,2,120,33],
-"class_ogre_1_1_string_converter.html#a6fb788b88702ece1e667c145204f7640":[5,2,2,120,17],
-"class_ogre_1_1_string_converter.html#a739e93c69c8fb5a8ffd91471437516f5":[5,2,2,120,22],
-"class_ogre_1_1_string_converter.html#a77d05cbca629795de8b9496b31b0de33":[5,2,2,120,7],
-"class_ogre_1_1_string_converter.html#a7dd1a2f936cced85559abb1f948bdecb":[5,2,2,120,20],
-"class_ogre_1_1_string_converter.html#a801a44b0eb1b8e700b6de9e225f415a8":[5,2,2,120,21],
-"class_ogre_1_1_string_converter.html#a8d3fd443406ecfc3556dc0195385bb22":[5,2,2,120,16],
-"class_ogre_1_1_string_converter.html#a95d05930b54167f5353733ec36668f65":[5,2,2,120,1],
-"class_ogre_1_1_string_converter.html#a9601d02e62790f039128170a3ed4d5da":[5,2,2,120,38],
-"class_ogre_1_1_string_converter.html#a9633e8a5b340ca0c3b36aa51efb4cc5d":[5,2,2,120,12],
-"class_ogre_1_1_string_converter.html#a9ceacfd6e4f13f89c1ec03f5ef754b58":[5,2,2,120,10],
-"class_ogre_1_1_string_converter.html#aa05c075b14b73fbdc82f477d6da359f8":[5,2,2,120,28],
-"class_ogre_1_1_string_converter.html#aa0a2d5fb724610a66f1949511e1fb478":[5,2,2,120,27],
-"class_ogre_1_1_string_converter.html#aa1378ae68227b869fc21b4bb9110d2db":[5,2,2,120,41],
+"class_ogre_1_1_string_converter.html#aa1378ae68227b869fc21b4bb9110d2db":[5,2,2,120,42],
 "class_ogre_1_1_string_converter.html#aa671980d27b86d09a0f568b451ba677d":[5,2,2,120,23],
 "class_ogre_1_1_string_converter.html#ab6f7c4fb9bf4be031282c8ccf5b38727":[5,2,2,120,29],
 "class_ogre_1_1_string_converter.html#abe53e5d97672c4986cb4cfb1d510faac":[5,2,2,120,34],
@@ -80,48 +38,48 @@ var NAVTREEINDEX222 =
 "class_ogre_1_1_string_util.html#aa08af119e6752852489de475559252a0":[5,2,2,122,9],
 "class_ogre_1_1_string_util.html#ab936109efdb3b4f224cdddbb37704cd0":[5,2,2,122,8],
 "class_ogre_1_1_string_util.html#ae36e8b6e19fef623f59d56772ed1dd7e":[5,2,2,122,14],
-"class_ogre_1_1_sub_item.html":[5,0,1,58],
 "class_ogre_1_1_sub_item.html":[5,2,12,58],
-"class_ogre_1_1_sub_item.html#a02e8c5cc62dadc7db0ead1cccdefdb65":[5,0,1,58,40],
+"class_ogre_1_1_sub_item.html":[5,0,1,58],
 "class_ogre_1_1_sub_item.html#a02e8c5cc62dadc7db0ead1cccdefdb65":[5,2,12,58,40],
-"class_ogre_1_1_sub_item.html#a040f6de2d0aa0b483acac3e69608c47c":[5,0,1,58,4],
+"class_ogre_1_1_sub_item.html#a02e8c5cc62dadc7db0ead1cccdefdb65":[5,0,1,58,40],
 "class_ogre_1_1_sub_item.html#a040f6de2d0aa0b483acac3e69608c47c":[5,2,12,58,4],
+"class_ogre_1_1_sub_item.html#a040f6de2d0aa0b483acac3e69608c47c":[5,0,1,58,4],
 "class_ogre_1_1_sub_item.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,0,1,58,56],
 "class_ogre_1_1_sub_item.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,2,12,58,56],
-"class_ogre_1_1_sub_item.html#a0c7563dc12f2d0032121403cb4c6f5c2":[5,2,12,58,35],
 "class_ogre_1_1_sub_item.html#a0c7563dc12f2d0032121403cb4c6f5c2":[5,0,1,58,35],
+"class_ogre_1_1_sub_item.html#a0c7563dc12f2d0032121403cb4c6f5c2":[5,2,12,58,35],
 "class_ogre_1_1_sub_item.html#a0f642341b106ea12f9c99cda5eb0cd52":[5,2,12,58,13],
 "class_ogre_1_1_sub_item.html#a0f642341b106ea12f9c99cda5eb0cd52":[5,0,1,58,13],
 "class_ogre_1_1_sub_item.html#a117563eda1d3affcd4a64c6bf4f8663a":[5,2,12,58,0],
 "class_ogre_1_1_sub_item.html#a117563eda1d3affcd4a64c6bf4f8663a":[5,0,1,58,0],
-"class_ogre_1_1_sub_item.html#a11ff15a191d963643c979bd222de2aaf":[5,2,12,58,41],
 "class_ogre_1_1_sub_item.html#a11ff15a191d963643c979bd222de2aaf":[5,0,1,58,41],
+"class_ogre_1_1_sub_item.html#a11ff15a191d963643c979bd222de2aaf":[5,2,12,58,41],
 "class_ogre_1_1_sub_item.html#a13f1bbc23e57df9084bed76acb3b5500":[5,2,12,58,38],
 "class_ogre_1_1_sub_item.html#a13f1bbc23e57df9084bed76acb3b5500":[5,0,1,58,38],
 "class_ogre_1_1_sub_item.html#a173800458c92ecefcff9d037be54afea":[5,2,12,58,62],
 "class_ogre_1_1_sub_item.html#a173800458c92ecefcff9d037be54afea":[5,0,1,58,62],
 "class_ogre_1_1_sub_item.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,58,46],
 "class_ogre_1_1_sub_item.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,58,46],
-"class_ogre_1_1_sub_item.html#a2064249d3f0de7c0c838af8e3e712ac0":[5,2,12,58,19],
 "class_ogre_1_1_sub_item.html#a2064249d3f0de7c0c838af8e3e712ac0":[5,0,1,58,19],
-"class_ogre_1_1_sub_item.html#a2108dfc322953a7bd429be8b62811e56":[5,2,12,58,64],
+"class_ogre_1_1_sub_item.html#a2064249d3f0de7c0c838af8e3e712ac0":[5,2,12,58,19],
 "class_ogre_1_1_sub_item.html#a2108dfc322953a7bd429be8b62811e56":[5,0,1,58,64],
-"class_ogre_1_1_sub_item.html#a21d95904b985b26f99f88696958891c3":[5,2,12,58,58],
+"class_ogre_1_1_sub_item.html#a2108dfc322953a7bd429be8b62811e56":[5,2,12,58,64],
 "class_ogre_1_1_sub_item.html#a21d95904b985b26f99f88696958891c3":[5,0,1,58,58],
-"class_ogre_1_1_sub_item.html#a284464b0561a6f2915f04b0245b987f0":[5,0,1,58,72],
+"class_ogre_1_1_sub_item.html#a21d95904b985b26f99f88696958891c3":[5,2,12,58,58],
 "class_ogre_1_1_sub_item.html#a284464b0561a6f2915f04b0245b987f0":[5,2,12,58,72],
+"class_ogre_1_1_sub_item.html#a284464b0561a6f2915f04b0245b987f0":[5,0,1,58,72],
 "class_ogre_1_1_sub_item.html#a2a7a3226009eb5f5387be146898dab90":[5,0,1,58,32],
 "class_ogre_1_1_sub_item.html#a2a7a3226009eb5f5387be146898dab90":[5,2,12,58,32],
-"class_ogre_1_1_sub_item.html#a2f92a5741b1c1123f7f76ce2a551c9c8":[5,0,1,58,5],
 "class_ogre_1_1_sub_item.html#a2f92a5741b1c1123f7f76ce2a551c9c8":[5,2,12,58,5],
-"class_ogre_1_1_sub_item.html#a3a8fafedc41616f8ae8306409443c3e4":[5,0,1,58,10],
+"class_ogre_1_1_sub_item.html#a2f92a5741b1c1123f7f76ce2a551c9c8":[5,0,1,58,5],
 "class_ogre_1_1_sub_item.html#a3a8fafedc41616f8ae8306409443c3e4":[5,2,12,58,10],
-"class_ogre_1_1_sub_item.html#a3bee104c7359ba6c41d65d88cfc3d418":[5,2,12,58,37],
+"class_ogre_1_1_sub_item.html#a3a8fafedc41616f8ae8306409443c3e4":[5,0,1,58,10],
 "class_ogre_1_1_sub_item.html#a3bee104c7359ba6c41d65d88cfc3d418":[5,0,1,58,37],
-"class_ogre_1_1_sub_item.html#a4136ce4b9d3add5203339327015d872d":[5,0,1,58,68],
+"class_ogre_1_1_sub_item.html#a3bee104c7359ba6c41d65d88cfc3d418":[5,2,12,58,37],
 "class_ogre_1_1_sub_item.html#a4136ce4b9d3add5203339327015d872d":[5,2,12,58,68],
-"class_ogre_1_1_sub_item.html#a41b58fe7a0d317cbc00052e6668cf4ef":[5,2,12,58,12],
+"class_ogre_1_1_sub_item.html#a4136ce4b9d3add5203339327015d872d":[5,0,1,58,68],
 "class_ogre_1_1_sub_item.html#a41b58fe7a0d317cbc00052e6668cf4ef":[5,0,1,58,12],
+"class_ogre_1_1_sub_item.html#a41b58fe7a0d317cbc00052e6668cf4ef":[5,2,12,58,12],
 "class_ogre_1_1_sub_item.html#a45267a8b4917f3bbe76a2dc14f7122be":[5,2,12,58,28],
 "class_ogre_1_1_sub_item.html#a45267a8b4917f3bbe76a2dc14f7122be":[5,0,1,58,28],
 "class_ogre_1_1_sub_item.html#a47508d27a6c799998047c50ec43e9897":[5,2,12,58,21],
@@ -130,16 +88,16 @@ var NAVTREEINDEX222 =
 "class_ogre_1_1_sub_item.html#a4af66c22373c90b388d2117ee904a92b":[5,2,12,58,74],
 "class_ogre_1_1_sub_item.html#a4c2ae8ae38d7910d9730c025999f6b83":[5,2,12,58,14],
 "class_ogre_1_1_sub_item.html#a4c2ae8ae38d7910d9730c025999f6b83":[5,0,1,58,14],
-"class_ogre_1_1_sub_item.html#a51ba9ae3782f39ea03bee09534a982e9":[5,2,12,58,66],
 "class_ogre_1_1_sub_item.html#a51ba9ae3782f39ea03bee09534a982e9":[5,0,1,58,66],
+"class_ogre_1_1_sub_item.html#a51ba9ae3782f39ea03bee09534a982e9":[5,2,12,58,66],
 "class_ogre_1_1_sub_item.html#a55bcfecbaab92f5836dc89da5d007586":[5,0,1,58,6],
 "class_ogre_1_1_sub_item.html#a55bcfecbaab92f5836dc89da5d007586":[5,2,12,58,6],
 "class_ogre_1_1_sub_item.html#a572c0331ef2ec650d56063fdc17435f5":[5,0,1,58,57],
 "class_ogre_1_1_sub_item.html#a572c0331ef2ec650d56063fdc17435f5":[5,2,12,58,57],
-"class_ogre_1_1_sub_item.html#a57566d0e53bb1fff6506e97d222bcd1c":[5,0,1,58,61],
 "class_ogre_1_1_sub_item.html#a57566d0e53bb1fff6506e97d222bcd1c":[5,2,12,58,61],
-"class_ogre_1_1_sub_item.html#a583dad5b16665689ced7226f21b74b73":[5,0,1,58,31],
+"class_ogre_1_1_sub_item.html#a57566d0e53bb1fff6506e97d222bcd1c":[5,0,1,58,61],
 "class_ogre_1_1_sub_item.html#a583dad5b16665689ced7226f21b74b73":[5,2,12,58,31],
+"class_ogre_1_1_sub_item.html#a583dad5b16665689ced7226f21b74b73":[5,0,1,58,31],
 "class_ogre_1_1_sub_item.html#a592f12018dc19e2022c839cb5fffa3a1":[5,0,1,58,60],
 "class_ogre_1_1_sub_item.html#a592f12018dc19e2022c839cb5fffa3a1":[5,2,12,58,60],
 "class_ogre_1_1_sub_item.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,58,48],
@@ -148,42 +106,42 @@ var NAVTREEINDEX222 =
 "class_ogre_1_1_sub_item.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,58,51],
 "class_ogre_1_1_sub_item.html#a6496cb6bcaffcbb03e25e56f4b88bf7f":[5,2,12,58,15],
 "class_ogre_1_1_sub_item.html#a6496cb6bcaffcbb03e25e56f4b88bf7f":[5,0,1,58,15],
-"class_ogre_1_1_sub_item.html#a65246f7bdb08b9b4fb169ff5d0235eaa":[5,0,1,58,17],
 "class_ogre_1_1_sub_item.html#a65246f7bdb08b9b4fb169ff5d0235eaa":[5,2,12,58,17],
-"class_ogre_1_1_sub_item.html#a667b8876930b77c9d609b80ee5fb1515":[5,2,12,58,67],
+"class_ogre_1_1_sub_item.html#a65246f7bdb08b9b4fb169ff5d0235eaa":[5,0,1,58,17],
 "class_ogre_1_1_sub_item.html#a667b8876930b77c9d609b80ee5fb1515":[5,0,1,58,67],
-"class_ogre_1_1_sub_item.html#a6d9e689659160cac9735f00ece15c0d4":[5,0,1,58,23],
+"class_ogre_1_1_sub_item.html#a667b8876930b77c9d609b80ee5fb1515":[5,2,12,58,67],
 "class_ogre_1_1_sub_item.html#a6d9e689659160cac9735f00ece15c0d4":[5,2,12,58,23],
-"class_ogre_1_1_sub_item.html#a7209f6be28cb30aa397dd7791e78c773":[5,0,1,58,3],
+"class_ogre_1_1_sub_item.html#a6d9e689659160cac9735f00ece15c0d4":[5,0,1,58,23],
 "class_ogre_1_1_sub_item.html#a7209f6be28cb30aa397dd7791e78c773":[5,2,12,58,3],
-"class_ogre_1_1_sub_item.html#a73de2dd2cc45eee54c7a9262ff6da180":[5,0,1,58,36],
+"class_ogre_1_1_sub_item.html#a7209f6be28cb30aa397dd7791e78c773":[5,0,1,58,3],
 "class_ogre_1_1_sub_item.html#a73de2dd2cc45eee54c7a9262ff6da180":[5,2,12,58,36],
-"class_ogre_1_1_sub_item.html#a77230eea8136b7c296cc0a5db1dba9ee":[5,2,12,58,54],
+"class_ogre_1_1_sub_item.html#a73de2dd2cc45eee54c7a9262ff6da180":[5,0,1,58,36],
 "class_ogre_1_1_sub_item.html#a77230eea8136b7c296cc0a5db1dba9ee":[5,0,1,58,54],
+"class_ogre_1_1_sub_item.html#a77230eea8136b7c296cc0a5db1dba9ee":[5,2,12,58,54],
 "class_ogre_1_1_sub_item.html#a7cf6161e3ebdb7e9de55d7d4463db33e":[5,2,12,58,22],
 "class_ogre_1_1_sub_item.html#a7cf6161e3ebdb7e9de55d7d4463db33e":[5,0,1,58,22],
-"class_ogre_1_1_sub_item.html#a8096988a16728c8b7e32495146111c62":[5,2,12,58,59],
 "class_ogre_1_1_sub_item.html#a8096988a16728c8b7e32495146111c62":[5,0,1,58,59],
+"class_ogre_1_1_sub_item.html#a8096988a16728c8b7e32495146111c62":[5,2,12,58,59],
 "class_ogre_1_1_sub_item.html#a812d3b0f5df694b92084a98387d8f215":[5,2,12,58,42],
 "class_ogre_1_1_sub_item.html#a812d3b0f5df694b92084a98387d8f215":[5,0,1,58,42],
 "class_ogre_1_1_sub_item.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,58,44],
 "class_ogre_1_1_sub_item.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,58,44],
 "class_ogre_1_1_sub_item.html#a862b4efee979307bbdfe2a49924d19de":[5,0,1,58,65],
 "class_ogre_1_1_sub_item.html#a862b4efee979307bbdfe2a49924d19de":[5,2,12,58,65],
-"class_ogre_1_1_sub_item.html#a869e7226c48fbff5dafef92b2b929b5e":[5,0,1,58,34],
 "class_ogre_1_1_sub_item.html#a869e7226c48fbff5dafef92b2b929b5e":[5,2,12,58,34],
+"class_ogre_1_1_sub_item.html#a869e7226c48fbff5dafef92b2b929b5e":[5,0,1,58,34],
 "class_ogre_1_1_sub_item.html#a86b362d966ed8183911b5d3835b53e2e":[5,2,12,58,30],
 "class_ogre_1_1_sub_item.html#a86b362d966ed8183911b5d3835b53e2e":[5,0,1,58,30],
 "class_ogre_1_1_sub_item.html#a89b0d57ee33c2b90392133ae9f239efe":[5,2,12,58,29],
 "class_ogre_1_1_sub_item.html#a89b0d57ee33c2b90392133ae9f239efe":[5,0,1,58,29],
-"class_ogre_1_1_sub_item.html#a8f18715b01c0851631eb9cccd1a05552":[5,0,1,58,70],
 "class_ogre_1_1_sub_item.html#a8f18715b01c0851631eb9cccd1a05552":[5,2,12,58,70],
+"class_ogre_1_1_sub_item.html#a8f18715b01c0851631eb9cccd1a05552":[5,0,1,58,70],
 "class_ogre_1_1_sub_item.html#a93424273b03dc18800f42a64e7b2cc7b":[5,2,12,58,26],
 "class_ogre_1_1_sub_item.html#a93424273b03dc18800f42a64e7b2cc7b":[5,0,1,58,26],
 "class_ogre_1_1_sub_item.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,58,47],
 "class_ogre_1_1_sub_item.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,58,47],
-"class_ogre_1_1_sub_item.html#a95441b99bdec221d2fdb800c651a11e1":[5,2,12,58,1],
 "class_ogre_1_1_sub_item.html#a95441b99bdec221d2fdb800c651a11e1":[5,0,1,58,1],
+"class_ogre_1_1_sub_item.html#a95441b99bdec221d2fdb800c651a11e1":[5,2,12,58,1],
 "class_ogre_1_1_sub_item.html#a9ea8c7833f3cdb031e9dae7cccf1413f":[5,0,1,58,2],
 "class_ogre_1_1_sub_item.html#a9ea8c7833f3cdb031e9dae7cccf1413f":[5,2,12,58,2],
 "class_ogre_1_1_sub_item.html#aab5e636e36b57dda7d301d7fa30c1d1e":[5,2,12,58,20],
@@ -200,26 +158,26 @@ var NAVTREEINDEX222 =
 "class_ogre_1_1_sub_item.html#abbdb6bfe33b416976de33ee15d467674":[5,0,1,58,24],
 "class_ogre_1_1_sub_item.html#abc10ce7cf20904a17baf3934914dbf92":[5,2,12,58,16],
 "class_ogre_1_1_sub_item.html#abc10ce7cf20904a17baf3934914dbf92":[5,0,1,58,16],
-"class_ogre_1_1_sub_item.html#abeed4a14f5d63264d9619c1fe507c018":[5,2,12,58,9],
 "class_ogre_1_1_sub_item.html#abeed4a14f5d63264d9619c1fe507c018":[5,0,1,58,9],
-"class_ogre_1_1_sub_item.html#ac511b8fdb7fc312f6d763fae3bbfa842":[5,2,12,58,75],
+"class_ogre_1_1_sub_item.html#abeed4a14f5d63264d9619c1fe507c018":[5,2,12,58,9],
 "class_ogre_1_1_sub_item.html#ac511b8fdb7fc312f6d763fae3bbfa842":[5,0,1,58,75],
-"class_ogre_1_1_sub_item.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,58,45],
+"class_ogre_1_1_sub_item.html#ac511b8fdb7fc312f6d763fae3bbfa842":[5,2,12,58,75],
 "class_ogre_1_1_sub_item.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,58,45],
+"class_ogre_1_1_sub_item.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,58,45],
 "class_ogre_1_1_sub_item.html#ad1b31f45654ad2ba2ed0b80646fb6edd":[5,2,12,58,18],
 "class_ogre_1_1_sub_item.html#ad1b31f45654ad2ba2ed0b80646fb6edd":[5,0,1,58,18],
-"class_ogre_1_1_sub_item.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,58,49],
 "class_ogre_1_1_sub_item.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,58,49],
+"class_ogre_1_1_sub_item.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,58,49],
 "class_ogre_1_1_sub_item.html#ad22289842e973a7a6b727c8cd32e9be9":[5,2,12,58,25],
 "class_ogre_1_1_sub_item.html#ad22289842e973a7a6b727c8cd32e9be9":[5,0,1,58,25],
 "class_ogre_1_1_sub_item.html#ad4d284fd219351af7f1ef9f9e9acab1e":[5,0,1,58,11],
 "class_ogre_1_1_sub_item.html#ad4d284fd219351af7f1ef9f9e9acab1e":[5,2,12,58,11],
-"class_ogre_1_1_sub_item.html#adce32528577d71b228692df906ecd17c":[5,2,12,58,52],
 "class_ogre_1_1_sub_item.html#adce32528577d71b228692df906ecd17c":[5,0,1,58,52],
-"class_ogre_1_1_sub_item.html#ade9262ffb93cbaf4460a44a78c49c12e":[5,2,12,58,8],
+"class_ogre_1_1_sub_item.html#adce32528577d71b228692df906ecd17c":[5,2,12,58,52],
 "class_ogre_1_1_sub_item.html#ade9262ffb93cbaf4460a44a78c49c12e":[5,0,1,58,8],
-"class_ogre_1_1_sub_item.html#adf2a2570b7d6c5dbdb80d8f98e620cbd":[5,2,12,58,63],
+"class_ogre_1_1_sub_item.html#ade9262ffb93cbaf4460a44a78c49c12e":[5,2,12,58,8],
 "class_ogre_1_1_sub_item.html#adf2a2570b7d6c5dbdb80d8f98e620cbd":[5,0,1,58,63],
+"class_ogre_1_1_sub_item.html#adf2a2570b7d6c5dbdb80d8f98e620cbd":[5,2,12,58,63],
 "class_ogre_1_1_sub_item.html#ae53cff42a16304f582ef83ad3017d614":[5,0,1,58,69],
 "class_ogre_1_1_sub_item.html#ae53cff42a16304f582ef83ad3017d614":[5,2,12,58,69],
 "class_ogre_1_1_sub_item.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,58,53],
@@ -230,10 +188,10 @@ var NAVTREEINDEX222 =
 "class_ogre_1_1_sub_item.html#af630e6230261ecca2ecbfcf0b0ee9ce9":[5,0,1,58,33],
 "class_ogre_1_1_sub_item.html#af85238872bb197dea36acf21a578ecec":[5,0,1,58,39],
 "class_ogre_1_1_sub_item.html#af85238872bb197dea36acf21a578ecec":[5,2,12,58,39],
-"class_ogre_1_1_sub_item.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,0,1,58,55],
 "class_ogre_1_1_sub_item.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,2,12,58,55],
-"class_ogre_1_1_sub_item.html#affce28947124dd4573fb224a975fdce9":[5,2,12,58,27],
+"class_ogre_1_1_sub_item.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,0,1,58,55],
 "class_ogre_1_1_sub_item.html#affce28947124dd4573fb224a975fdce9":[5,0,1,58,27],
+"class_ogre_1_1_sub_item.html#affce28947124dd4573fb224a975fdce9":[5,2,12,58,27],
 "class_ogre_1_1_sub_mesh.html":[5,2,11,125],
 "class_ogre_1_1_sub_mesh.html#a08d3d4d7b7500f255c0836f34fd9fc2c":[5,2,11,125,18],
 "class_ogre_1_1_sub_mesh.html#a09a8bc953f8068f23c1c891785f8a6d8":[5,2,11,125,13],
@@ -249,5 +207,47 @@ var NAVTREEINDEX222 =
 "class_ogre_1_1_sub_mesh.html#a3e4676723a592f7c425cddc1b66c66e3":[5,2,11,125,17],
 "class_ogre_1_1_sub_mesh.html#a44703fb108188ae7730ef1b59c2f3298":[5,2,11,125,23],
 "class_ogre_1_1_sub_mesh.html#a48305c54a01e0c7a3376ea0a077c467f":[5,2,11,125,41],
-"class_ogre_1_1_sub_mesh.html#a5648159f138681dc17e4f4250ae1a576":[5,2,11,125,39]
+"class_ogre_1_1_sub_mesh.html#a5648159f138681dc17e4f4250ae1a576":[5,2,11,125,39],
+"class_ogre_1_1_sub_mesh.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,11,125,33],
+"class_ogre_1_1_sub_mesh.html#a59d711dfd113890bad98d0fe8662078b":[5,2,11,125,9],
+"class_ogre_1_1_sub_mesh.html#a5e7f7fb993cf797e96184620fcae0f71":[5,2,11,125,44],
+"class_ogre_1_1_sub_mesh.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,125,36],
+"class_ogre_1_1_sub_mesh.html#a6a63d3660c6dd9f2b0bfe70333ae468d":[5,2,11,125,28],
+"class_ogre_1_1_sub_mesh.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,11,125,29],
+"class_ogre_1_1_sub_mesh.html#a91a1a17293763d5e854b75ed12d71a42":[5,2,11,125,27],
+"class_ogre_1_1_sub_mesh.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,11,125,32],
+"class_ogre_1_1_sub_mesh.html#a96f16aa21a9ed331f82957057af27248":[5,2,11,125,1],
+"class_ogre_1_1_sub_mesh.html#a9bcf1bdb2de0eef158017da7be0c82b9":[5,2,11,125,42],
+"class_ogre_1_1_sub_mesh.html#aa41a130f156b145bffb3f4b5172c4c93":[5,2,11,125,40],
+"class_ogre_1_1_sub_mesh.html#aa5e04097716119c5cfed229c8425fc60":[5,2,11,125,4],
+"class_ogre_1_1_sub_mesh.html#aaa37dfcd68b3707d91f4f71588f61efd":[5,2,11,125,20],
+"class_ogre_1_1_sub_mesh.html#aabb9329bbb4f4d4e75254cbdf87c4512":[5,2,11,125,45],
+"class_ogre_1_1_sub_mesh.html#ab385b56e46db91e005c02bb4123785e5":[5,2,11,125,12],
+"class_ogre_1_1_sub_mesh.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,11,125,35],
+"class_ogre_1_1_sub_mesh.html#ab4fa9187dd2a96ec0f90ebfe4a90d10c":[5,2,11,125,2],
+"class_ogre_1_1_sub_mesh.html#abdd303710ef1131801f5017ef2eda1f2":[5,2,11,125,14],
+"class_ogre_1_1_sub_mesh.html#abef0947bb29f195d87d822b5b2f8ee8a":[5,2,11,125,6],
+"class_ogre_1_1_sub_mesh.html#ac26fd24799be0297fe0974d3247eb130":[5,2,11,125,21],
+"class_ogre_1_1_sub_mesh.html#ac9cc28e9a11b69a815fa9b3e52cd76f7":[5,2,11,125,43],
+"class_ogre_1_1_sub_mesh.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,11,125,30],
+"class_ogre_1_1_sub_mesh.html#acc12dd4a452669f7376210e86c578638":[5,2,11,125,22],
+"class_ogre_1_1_sub_mesh.html#acd127d162c4271ac6b844161e1ea777a":[5,2,11,125,11],
+"class_ogre_1_1_sub_mesh.html#ad0a51b024271c2042968e9e967dd39e8":[5,2,11,125,5],
+"class_ogre_1_1_sub_mesh.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,11,125,34],
+"class_ogre_1_1_sub_mesh.html#adce32528577d71b228692df906ecd17c":[5,2,11,125,37],
+"class_ogre_1_1_sub_mesh.html#ade3da69a088d8de443dd1dddefcd1892":[5,2,11,125,7],
+"class_ogre_1_1_sub_mesh.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,11,125,38],
+"class_ogre_1_1_sub_mesh.html#af2ca759beb92c9fc8a42b22d14b71f32":[5,2,11,125,3],
+"class_ogre_1_1_sub_string_ref.html":[5,2,11,126],
+"class_ogre_1_1_sub_string_ref.html#a05957958d248c51b1383702cc805ee19":[5,2,11,126,13],
+"class_ogre_1_1_sub_string_ref.html#a090016348a3edb9d6ea9f81889c21682":[5,2,11,126,11],
+"class_ogre_1_1_sub_string_ref.html#a1bd8577576c33506d834e6499040ef0b":[5,2,11,126,6],
+"class_ogre_1_1_sub_string_ref.html#a2bc9805e1de02777c44b06146ad54790":[5,2,11,126,15],
+"class_ogre_1_1_sub_string_ref.html#a3c56cf160135e34a119c026b32751795":[5,2,11,126,9],
+"class_ogre_1_1_sub_string_ref.html#a413b99a6ab7e5e0ce17610bf9eae44ab":[5,2,11,126,8],
+"class_ogre_1_1_sub_string_ref.html#a4b723e40b3fc4befef9a5b676bb3d8bf":[5,2,11,126,4],
+"class_ogre_1_1_sub_string_ref.html#a673204912aa84ac98f6c51ad2ee06826":[5,2,11,126,16],
+"class_ogre_1_1_sub_string_ref.html#a6eda6d376867029dafce16a7b429b7bc":[5,2,11,126,12],
+"class_ogre_1_1_sub_string_ref.html#a8cb242b287692fed11a9a6e1196969f0":[5,2,11,126,0],
+"class_ogre_1_1_sub_string_ref.html#aab1fc62b46f8b14bf95c6e3e9b3589de":[5,2,11,126,7]
 };
