@@ -1,45 +1,5 @@
 var NAVTREEINDEX228 =
 {
-"class_ogre_1_1_texture.html#a5d3962a2bef3bd77de412c8207975caf":[5,2,11,127,36],
-"class_ogre_1_1_texture.html#a5dcfc70318106dd00902b0fc945d1d0e":[5,2,11,127,54],
-"class_ogre_1_1_texture.html#a5decc0244a000c5002935c32ac301f0c":[5,2,11,127,25],
-"class_ogre_1_1_texture.html#a60ce96525ac730a0f7b466ed287beef3":[5,2,11,127,55],
-"class_ogre_1_1_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,127,74],
-"class_ogre_1_1_texture.html#a65b5bd9531c385e200482c0edafdc1c2":[5,2,11,127,29],
-"class_ogre_1_1_texture.html#a699d1c851f494a8d5d23d23b695ceb47":[5,2,11,127,63],
-"class_ogre_1_1_texture.html#a69fbdff7f241bfd0f7c4c43b267ecbb5":[5,2,11,127,52],
-"class_ogre_1_1_texture.html#a6bdd32464ce1df547d34a0739e4c3592":[5,2,11,127,66],
-"class_ogre_1_1_texture.html#a6cfc6014da843369b2619d1d7d807569":[5,2,11,127,31],
-"class_ogre_1_1_texture.html#a6ed49ed8701feb087b04b730ce1d682f":[5,2,11,127,46],
-"class_ogre_1_1_texture.html#a6f186da4d9557d958779eba68bb769a9":[5,2,11,127,35],
-"class_ogre_1_1_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[5,2,11,127,98],
-"class_ogre_1_1_texture.html#a74138c0203835513613af73cdb08890d":[5,2,11,127,57],
-"class_ogre_1_1_texture.html#a743e5059501507cd858e90532e8263f9":[5,2,11,127,23],
-"class_ogre_1_1_texture.html#a77987dd9dce1653083f3518fc43da348":[5,2,11,127,38],
-"class_ogre_1_1_texture.html#a77d5f72e02500f6db6f460bb48eac721":[5,2,11,127,7],
-"class_ogre_1_1_texture.html#a82174dc4f4a0645332483ced7904c2f6":[5,2,11,127,90],
-"class_ogre_1_1_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,11,127,67],
-"class_ogre_1_1_texture.html#a84dc53e8acb6b01bb695f96c048a1990":[5,2,11,127,26],
-"class_ogre_1_1_texture.html#a8775d611ddf70bc0ee89a9d62bac69cf":[5,2,11,127,91],
-"class_ogre_1_1_texture.html#a893c7a150edb48a25e5df700cfc194eb":[5,2,11,127,6],
-"class_ogre_1_1_texture.html#a8ab9418311a7b4a116139a7871e57a4b":[5,2,11,127,39],
-"class_ogre_1_1_texture.html#a8eb34a9034aab62fd537c021a79e3366":[5,2,11,127,61],
-"class_ogre_1_1_texture.html#a8ed6a95810f21f53aa8cbc780b680164":[5,2,11,127,27],
-"class_ogre_1_1_texture.html#a8f541900f7e1f73f4c313a732199029a":[5,2,11,127,59],
-"class_ogre_1_1_texture.html#a906f16bb83aecba3b1204d62308e419d":[5,2,11,127,17],
-"class_ogre_1_1_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,11,127,70],
-"class_ogre_1_1_texture.html#a963dca9c2ab605d51ee75c92d850a96d":[5,2,11,127,51],
-"class_ogre_1_1_texture.html#a9dffcf1a2d754e63e98770e5cf2cd9ee":[5,2,11,127,40],
-"class_ogre_1_1_texture.html#aa31bef1bfaa87731622e56f11b548e27":[5,2,11,127,100],
-"class_ogre_1_1_texture.html#aa38c4f67ab5413135d1830dd164a68e6":[5,2,11,127,83],
-"class_ogre_1_1_texture.html#aa561d8d03383bb59ecce5c4278ed8da6":[5,2,11,127,96],
-"class_ogre_1_1_texture.html#aa5c94ac282eb67a0b8cf6b32af4ccf7e":[5,2,11,127,86],
-"class_ogre_1_1_texture.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[5,2,11,127,12],
-"class_ogre_1_1_texture.html#aa7942df6419c98c2668ffb02de252cc8":[5,2,11,127,24],
-"class_ogre_1_1_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[5,2,11,127,48],
-"class_ogre_1_1_texture.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,11,127,73],
-"class_ogre_1_1_texture.html#aba6375dc3369f7d4a1aaa4e7fedd62aa":[5,2,11,127,37],
-"class_ogre_1_1_texture.html#ac129cc0a773f0d9d0eb4c3c1a1b65618":[5,2,11,127,64],
 "class_ogre_1_1_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[5,2,11,127,45],
 "class_ogre_1_1_texture.html#ac93f17feff099035542be8b22f890417":[5,2,11,127,30],
 "class_ogre_1_1_texture.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,11,127,68],
@@ -64,42 +24,42 @@ var NAVTREEINDEX228 =
 "class_ogre_1_1_texture.html#af745587ede1e8482b1edac167fbf82fd":[5,2,11,127,85],
 "class_ogre_1_1_texture.html#afcb4a61b965600a67ca2c2f060821db9":[5,2,11,127,5],
 "class_ogre_1_1_texture.html#afefa465095dd97cf22d0a43531171b51":[5,2,11,127,28],
-"class_ogre_1_1_texture_animation_controller_value.html":[6,0,0,989],
-"class_ogre_1_1_texture_animation_controller_value.html":[7,0,0,962],
-"class_ogre_1_1_texture_animation_controller_value.html#a1937d9d03d7abb3b071d23bf9b2221d5":[6,0,0,989,1],
-"class_ogre_1_1_texture_animation_controller_value.html#a1937d9d03d7abb3b071d23bf9b2221d5":[7,0,0,962,1],
-"class_ogre_1_1_texture_animation_controller_value.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,989,4],
-"class_ogre_1_1_texture_animation_controller_value.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,962,4],
-"class_ogre_1_1_texture_animation_controller_value.html#a362f9f548276119b41c049363549dcee":[7,0,0,962,0],
-"class_ogre_1_1_texture_animation_controller_value.html#a362f9f548276119b41c049363549dcee":[6,0,0,989,0],
-"class_ogre_1_1_texture_animation_controller_value.html#a3670adb6239bacb6a7820282ad10cca7":[7,0,0,962,12],
-"class_ogre_1_1_texture_animation_controller_value.html#a3670adb6239bacb6a7820282ad10cca7":[6,0,0,989,12],
-"class_ogre_1_1_texture_animation_controller_value.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,962,6],
-"class_ogre_1_1_texture_animation_controller_value.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,989,6],
-"class_ogre_1_1_texture_animation_controller_value.html#a5e8a9476f62917711643d64f1f073011":[7,0,0,962,13],
-"class_ogre_1_1_texture_animation_controller_value.html#a5e8a9476f62917711643d64f1f073011":[6,0,0,989,13],
-"class_ogre_1_1_texture_animation_controller_value.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,989,9],
-"class_ogre_1_1_texture_animation_controller_value.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,962,9],
-"class_ogre_1_1_texture_animation_controller_value.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,962,2],
-"class_ogre_1_1_texture_animation_controller_value.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,989,2],
-"class_ogre_1_1_texture_animation_controller_value.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,962,5],
-"class_ogre_1_1_texture_animation_controller_value.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,989,5],
-"class_ogre_1_1_texture_animation_controller_value.html#a97de25f53317a5b1be4f1b557f92d9e4":[7,0,0,962,15],
-"class_ogre_1_1_texture_animation_controller_value.html#a97de25f53317a5b1be4f1b557f92d9e4":[6,0,0,989,15],
-"class_ogre_1_1_texture_animation_controller_value.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,989,8],
-"class_ogre_1_1_texture_animation_controller_value.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,962,8],
-"class_ogre_1_1_texture_animation_controller_value.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,989,3],
-"class_ogre_1_1_texture_animation_controller_value.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,962,3],
-"class_ogre_1_1_texture_animation_controller_value.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,989,7],
-"class_ogre_1_1_texture_animation_controller_value.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,962,7],
-"class_ogre_1_1_texture_animation_controller_value.html#adce32528577d71b228692df906ecd17c":[7,0,0,962,10],
-"class_ogre_1_1_texture_animation_controller_value.html#adce32528577d71b228692df906ecd17c":[6,0,0,989,10],
-"class_ogre_1_1_texture_animation_controller_value.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,962,11],
-"class_ogre_1_1_texture_animation_controller_value.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,989,11],
-"class_ogre_1_1_texture_animation_controller_value.html#af33179c10f55daaa69cf95522757d26d":[7,0,0,962,14],
-"class_ogre_1_1_texture_animation_controller_value.html#af33179c10f55daaa69cf95522757d26d":[6,0,0,989,14],
-"class_ogre_1_1_texture_animation_controller_value.html#af4c78ad512914d325008c4201f4f752b":[6,0,0,989,16],
-"class_ogre_1_1_texture_animation_controller_value.html#af4c78ad512914d325008c4201f4f752b":[7,0,0,962,16],
+"class_ogre_1_1_texture_animation_controller_value.html":[7,0,0,960],
+"class_ogre_1_1_texture_animation_controller_value.html":[6,0,0,987],
+"class_ogre_1_1_texture_animation_controller_value.html#a1937d9d03d7abb3b071d23bf9b2221d5":[7,0,0,960,1],
+"class_ogre_1_1_texture_animation_controller_value.html#a1937d9d03d7abb3b071d23bf9b2221d5":[6,0,0,987,1],
+"class_ogre_1_1_texture_animation_controller_value.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,960,4],
+"class_ogre_1_1_texture_animation_controller_value.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,987,4],
+"class_ogre_1_1_texture_animation_controller_value.html#a362f9f548276119b41c049363549dcee":[7,0,0,960,0],
+"class_ogre_1_1_texture_animation_controller_value.html#a362f9f548276119b41c049363549dcee":[6,0,0,987,0],
+"class_ogre_1_1_texture_animation_controller_value.html#a3670adb6239bacb6a7820282ad10cca7":[6,0,0,987,12],
+"class_ogre_1_1_texture_animation_controller_value.html#a3670adb6239bacb6a7820282ad10cca7":[7,0,0,960,12],
+"class_ogre_1_1_texture_animation_controller_value.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,987,6],
+"class_ogre_1_1_texture_animation_controller_value.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,960,6],
+"class_ogre_1_1_texture_animation_controller_value.html#a5e8a9476f62917711643d64f1f073011":[6,0,0,987,13],
+"class_ogre_1_1_texture_animation_controller_value.html#a5e8a9476f62917711643d64f1f073011":[7,0,0,960,13],
+"class_ogre_1_1_texture_animation_controller_value.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,987,9],
+"class_ogre_1_1_texture_animation_controller_value.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,960,9],
+"class_ogre_1_1_texture_animation_controller_value.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,987,2],
+"class_ogre_1_1_texture_animation_controller_value.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,960,2],
+"class_ogre_1_1_texture_animation_controller_value.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,987,5],
+"class_ogre_1_1_texture_animation_controller_value.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,960,5],
+"class_ogre_1_1_texture_animation_controller_value.html#a97de25f53317a5b1be4f1b557f92d9e4":[7,0,0,960,15],
+"class_ogre_1_1_texture_animation_controller_value.html#a97de25f53317a5b1be4f1b557f92d9e4":[6,0,0,987,15],
+"class_ogre_1_1_texture_animation_controller_value.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,960,8],
+"class_ogre_1_1_texture_animation_controller_value.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,987,8],
+"class_ogre_1_1_texture_animation_controller_value.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,960,3],
+"class_ogre_1_1_texture_animation_controller_value.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,987,3],
+"class_ogre_1_1_texture_animation_controller_value.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,960,7],
+"class_ogre_1_1_texture_animation_controller_value.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,987,7],
+"class_ogre_1_1_texture_animation_controller_value.html#adce32528577d71b228692df906ecd17c":[6,0,0,987,10],
+"class_ogre_1_1_texture_animation_controller_value.html#adce32528577d71b228692df906ecd17c":[7,0,0,960,10],
+"class_ogre_1_1_texture_animation_controller_value.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,960,11],
+"class_ogre_1_1_texture_animation_controller_value.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,987,11],
+"class_ogre_1_1_texture_animation_controller_value.html#af33179c10f55daaa69cf95522757d26d":[7,0,0,960,14],
+"class_ogre_1_1_texture_animation_controller_value.html#af33179c10f55daaa69cf95522757d26d":[6,0,0,987,14],
+"class_ogre_1_1_texture_animation_controller_value.html#af4c78ad512914d325008c4201f4f752b":[7,0,0,960,16],
+"class_ogre_1_1_texture_animation_controller_value.html#af4c78ad512914d325008c4201f4f752b":[6,0,0,987,16],
 "class_ogre_1_1_texture_definition_base.html":[5,2,1,52],
 "class_ogre_1_1_texture_definition_base.html#a02ec073273bf07eb78122ddb2a4606f1":[5,2,1,52,11],
 "class_ogre_1_1_texture_definition_base.html#a0b832d936fde223d0e19076097e95054":[5,2,1,52,27],
@@ -183,8 +143,8 @@ var NAVTREEINDEX228 =
 "class_ogre_1_1_texture_definition_base_1_1_texture_definition.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,1,52,1,12],
 "class_ogre_1_1_texture_definition_base_1_1_texture_definition.html#af91257f5f60c05e94277db7b6ca23850":[5,2,1,52,1,1],
 "class_ogre_1_1_texture_definition_base_1_1_texture_definition.html#affe2a13b04aef3960decbf3b1b241c7c":[5,2,1,52,1,19],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html":[6,0,0,24,0],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html":[7,0,0,2,0],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html":[6,0,0,24,0],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,0,15],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,0,15],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,0,1],
@@ -193,40 +153,40 @@ var NAVTREEINDEX228 =
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,2,0,7],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,0,3],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a1d8377be08adabfbf64235918e490f67":[6,0,0,24,0,3],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#a2a99e859420c10607f648372d908343f":[6,0,0,24,0,4],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a2a99e859420c10607f648372d908343f":[7,0,0,2,0,4],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,0,9],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#a2a99e859420c10607f648372d908343f":[6,0,0,24,0,4],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,2,0,9],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,0,12],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,0,9],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,0,12],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,0,12],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,0,5],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,24,0,5],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,0,8],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,0,8],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,0,8],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#aa0b132d6786adbf030ae46d185c5be02":[6,0,0,24,0,0],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#aa0b132d6786adbf030ae46d185c5be02":[7,0,0,2,0,0],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,0,11],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,24,0,11],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,0,6],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,2,0,6],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,0,10],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,24,0,10],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,0,13],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,0,10],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#adce32528577d71b228692df906ecd17c":[6,0,0,24,0,13],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,0,14],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,0,13],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,24,0,14],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#af7b658ad3dd698ff5c59575d18bae278":[6,0,0,24,0,2],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,0,14],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#af7b658ad3dd698ff5c59575d18bae278":[7,0,0,2,0,2],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#af7b658ad3dd698ff5c59575d18bae278":[6,0,0,24,0,2],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html":[6,0,0,24,1],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html":[7,0,0,2,1],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,1,15],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,1,15],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,2,1,7],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,1,7],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,1,3],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,2,1,7],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[6,0,0,24,1,3],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a2a99e859420c10607f648372d908343f":[7,0,0,2,1,4],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,1,3],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a2a99e859420c10607f648372d908343f":[6,0,0,24,1,4],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a2a99e859420c10607f648372d908343f":[7,0,0,2,1,4],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,2,1,9],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,1,9],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,1,12],
@@ -237,17 +197,57 @@ var NAVTREEINDEX228 =
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,1,5],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a91003a67da6e06bc7b7f8f9d103f35f3":[7,0,0,2,1,0],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a91003a67da6e06bc7b7f8f9d103f35f3":[6,0,0,24,1,0],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,1,8],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,1,8],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,1,11],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,1,8],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,24,1,11],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ac7f9d8c4ac1ec6006fa88995e47fe538":[6,0,0,24,1,2],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,1,11],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ac7f9d8c4ac1ec6006fa88995e47fe538":[7,0,0,2,1,2],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,2,1,6],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ac7f9d8c4ac1ec6006fa88995e47fe538":[6,0,0,24,1,2],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,1,6],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,1,10],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,2,1,6],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,24,1,10],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,1,10],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,1,13],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#adce32528577d71b228692df906ecd17c":[6,0,0,24,1,13],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,24,1,14]
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,24,1,14],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,1,14],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html":[6,0,0,24,2],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html":[7,0,0,2,2],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,2,15],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,2,15],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a19c0b119d8138f02f25c13dc22a357d4":[6,0,0,24,2,0],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,2,0],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,2,7],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,2,2,7],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,2,2],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[6,0,0,24,2,2],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a2a99e859420c10607f648372d908343f":[6,0,0,24,2,3],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a2a99e859420c10607f648372d908343f":[7,0,0,2,2,3],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a48ad2345ced0892a122118db87b918cd":[7,0,0,2,2,1],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a48ad2345ced0892a122118db87b918cd":[6,0,0,24,2,1],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,2,9],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,2,2,9],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,2,12],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,2,12],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,2,5],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,24,2,5],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,2,8],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,2,8],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,24,2,11],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,2,11],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,2,6],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,2,2,6],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ace721c5339ef577ca1c896b8798ee847":[7,0,0,2,2,4],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ace721c5339ef577ca1c896b8798ee847":[6,0,0,24,2,4],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,24,2,10],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,2,10],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#adce32528577d71b228692df906ecd17c":[6,0,0,24,2,13],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,2,13],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,24,2,14],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,2,14],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html":[7,0,0,2,3],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html":[6,0,0,24,3],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,3,15],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,3,15],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,3,0]
 };
