@@ -1,48 +1,8 @@
 var NAVTREEINDEX229 =
 {
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,1,14],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html":[6,0,0,24,2],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html":[7,0,0,2,2],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,2,15],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,2,15],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a19c0b119d8138f02f25c13dc22a357d4":[6,0,0,24,2,0],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,2,0],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,2,2,7],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,2,7],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[6,0,0,24,2,2],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,2,2],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a2a99e859420c10607f648372d908343f":[7,0,0,2,2,3],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a2a99e859420c10607f648372d908343f":[6,0,0,24,2,3],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a48ad2345ced0892a122118db87b918cd":[6,0,0,24,2,1],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a48ad2345ced0892a122118db87b918cd":[7,0,0,2,2,1],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,2,2,9],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,2,9],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,2,12],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,2,12],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,24,2,5],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,2,5],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,2,8],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,2,8],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,24,2,11],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,2,11],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,2,2,6],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,2,6],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ace721c5339ef577ca1c896b8798ee847":[6,0,0,24,2,4],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ace721c5339ef577ca1c896b8798ee847":[7,0,0,2,2,4],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,2,10],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,24,2,10],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,2,13],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#adce32528577d71b228692df906ecd17c":[6,0,0,24,2,13],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,2,14],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,24,2,14],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html":[6,0,0,24,3],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html":[7,0,0,2,3],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,3,15],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,3,15],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,3,0],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a19c0b119d8138f02f25c13dc22a357d4":[6,0,0,24,3,0],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,3,7],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,2,3,7],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,3,7],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,3,2],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a1d8377be08adabfbf64235918e490f67":[6,0,0,24,3,2],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a2a99e859420c10607f648372d908343f":[7,0,0,2,3,3],
@@ -51,58 +11,58 @@ var NAVTREEINDEX229 =
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a35218b3111976d2c033f92ae97a1dec6":[6,0,0,24,3,4],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,2,3,9],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,3,9],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,3,12],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,3,12],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,24,3,5],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,3,12],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,3,5],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,24,3,5],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,3,8],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,3,8],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,3,11],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,24,3,11],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#ac33d9266d718465e93948e23eb657bae":[6,0,0,24,3,1],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,3,11],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#ac33d9266d718465e93948e23eb657bae":[7,0,0,2,3,1],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,3,6],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#ac33d9266d718465e93948e23eb657bae":[6,0,0,24,3,1],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,2,3,6],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,3,10],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,3,6],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,24,3,10],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,3,10],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#adce32528577d71b228692df906ecd17c":[6,0,0,24,3,13],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,3,13],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,3,14],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,24,3,14],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,3,14],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html":[7,0,0,2,4],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html":[6,0,0,24,4],
-"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,4,15],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,4,15],
-"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,4,0],
+"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,4,15],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a19c0b119d8138f02f25c13dc22a357d4":[6,0,0,24,4,0],
+"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,4,0],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,4,7],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,2,4,7],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a1d8377be08adabfbf64235918e490f67":[6,0,0,24,4,2],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,4,2],
-"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a2a99e859420c10607f648372d908343f":[6,0,0,24,4,3],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a2a99e859420c10607f648372d908343f":[7,0,0,2,4,3],
-"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a4673aa30d4742e73f093d4f3f1280e4d":[6,0,0,24,4,1],
+"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a2a99e859420c10607f648372d908343f":[6,0,0,24,4,3],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a4673aa30d4742e73f093d4f3f1280e4d":[7,0,0,2,4,1],
+"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a4673aa30d4742e73f093d4f3f1280e4d":[6,0,0,24,4,1],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a5398bf0f30e8e3f64c3bc2d2de1af782":[6,0,0,24,4,4],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a5398bf0f30e8e3f64c3bc2d2de1af782":[7,0,0,2,4,4],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,4,9],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,2,4,9],
-"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,4,12],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,4,12],
-"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,4,5],
+"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,4,12],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,24,4,5],
+"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,4,5],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,4,8],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,4,8],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,4,11],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,24,4,11],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,4,6],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,2,4,6],
-"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,24,4,10],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,4,10],
-"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,4,13],
+"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,24,4,10],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#adce32528577d71b228692df906ecd17c":[6,0,0,24,4,13],
-"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,4,14],
+"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,4,13],
 "class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,24,4,14],
+"class_ogre_1_1_texture_filter_1_1_prepare_for_normal_mapping.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,4,14],
 "class_ogre_1_1_texture_frame_controller_value.html":[5,2,2,125],
 "class_ogre_1_1_texture_frame_controller_value.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,125,4],
 "class_ogre_1_1_texture_frame_controller_value.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,2,125,6],
@@ -249,5 +209,45 @@ var NAVTREEINDEX229 =
 "class_ogre_1_1_texture_gpu_listener.html#afe11bd546cf7315f4526488e7078cc7da704ea118c7e9f0b1598b528bdcbe1b26":[5,2,11,129,0,8],
 "class_ogre_1_1_texture_gpu_listener.html#afe11bd546cf7315f4526488e7078cc7dabb2a61a0002ccca6afbde7588787e58e":[5,2,11,129,0,11],
 "class_ogre_1_1_texture_gpu_listener.html#afe11bd546cf7315f4526488e7078cc7dad4d9c6e3b7755f38d8d5f003be100257":[5,2,11,129,0,10],
-"class_ogre_1_1_texture_gpu_listener.html#afe11bd546cf7315f4526488e7078cc7dae3eb70053cbf5401f22893cdb47f81a7":[5,2,11,129,0,9]
+"class_ogre_1_1_texture_gpu_listener.html#afe11bd546cf7315f4526488e7078cc7dae3eb70053cbf5401f22893cdb47f81a7":[5,2,11,129,0,9],
+"class_ogre_1_1_texture_gpu_listener.html#afe11bd546cf7315f4526488e7078cc7dafbdd85981846de4423d48d1a0ff665e0":[5,2,11,129,0,5],
+"class_ogre_1_1_texture_gpu_manager.html":[5,2,11,130],
+"class_ogre_1_1_texture_gpu_manager.html#a017eec4324d75ffb0de6b0fc1fdd2654":[5,2,11,130,28],
+"class_ogre_1_1_texture_gpu_manager.html#a02832e2789d8fc68b4ce4586bad25010":[5,2,11,130,30],
+"class_ogre_1_1_texture_gpu_manager.html#a064b32e7db16917d223a729f3ce03a96":[5,2,11,130,50],
+"class_ogre_1_1_texture_gpu_manager.html#a0b0ab5ff277943748df853653efb8913":[5,2,11,130,34],
+"class_ogre_1_1_texture_gpu_manager.html#a0beb6964d2f52e28e852666257a30514":[5,2,11,130,77],
+"class_ogre_1_1_texture_gpu_manager.html#a0e9374e0a6a80f16ef5b3e95f38c2e44":[5,2,11,130,45],
+"class_ogre_1_1_texture_gpu_manager.html#a1146a2b41f0f3f5d3b0b1bab1e74248d":[5,2,11,130,80],
+"class_ogre_1_1_texture_gpu_manager.html#a1188e251546ab3391ef646d60f2317d8":[5,2,11,130,76],
+"class_ogre_1_1_texture_gpu_manager.html#a1427f0b635a4186cd6083a9bab879fa2":[5,2,11,130,75],
+"class_ogre_1_1_texture_gpu_manager.html#a164a5285771064ccd10c8c2d9392d9da":[5,2,11,130,69],
+"class_ogre_1_1_texture_gpu_manager.html#a18f2ab9f38f0dbf29a75a82030231a9f":[5,2,11,130,48],
+"class_ogre_1_1_texture_gpu_manager.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,11,130,57],
+"class_ogre_1_1_texture_gpu_manager.html#a243112239378b673ba9f1df5e7abdbf3":[5,2,11,130,3],
+"class_ogre_1_1_texture_gpu_manager.html#a24f8cd49c0990fb532306a1569b58f33":[5,2,11,130,25],
+"class_ogre_1_1_texture_gpu_manager.html#a25ea160f5cd58eb1569743dee3bff9cc":[5,2,11,130,36],
+"class_ogre_1_1_texture_gpu_manager.html#a2c872d542fd78e2db884ff8904d4c39d":[5,2,11,130,20],
+"class_ogre_1_1_texture_gpu_manager.html#a379578bf252f5fcf0c5168f0a88c2130":[5,2,11,130,78],
+"class_ogre_1_1_texture_gpu_manager.html#a3796bc1de6a5a6efc208620686982b54":[5,2,11,130,67],
+"class_ogre_1_1_texture_gpu_manager.html#a3886c70b1674b192547c407edeb4c67e":[5,2,11,130,46],
+"class_ogre_1_1_texture_gpu_manager.html#a38a3edb2437dae48c14a0d20c50877fa":[5,2,11,130,11],
+"class_ogre_1_1_texture_gpu_manager.html#a400906a91ef0c5b7b61329de7872c91e":[5,2,11,130,35],
+"class_ogre_1_1_texture_gpu_manager.html#a423e53613f85ab74171ac4bb291c2555":[5,2,11,130,52],
+"class_ogre_1_1_texture_gpu_manager.html#a435b32507353f22b8428e6f9d849e7e1":[5,2,11,130,13],
+"class_ogre_1_1_texture_gpu_manager.html#a45819a2f57371a1d5ae1d026a21510ab":[5,2,11,130,39],
+"class_ogre_1_1_texture_gpu_manager.html#a46f6c11e4af75070ada1e868e7b24412":[5,2,11,130,14],
+"class_ogre_1_1_texture_gpu_manager.html#a4f064af71e447dbdfa846188b27810f6":[5,2,11,130,8],
+"class_ogre_1_1_texture_gpu_manager.html#a4f6d7560d59263dc303563777b5c61e8":[5,2,11,130,17],
+"class_ogre_1_1_texture_gpu_manager.html#a4f6ee50fe51ac71c60f66e044859bf9d":[5,2,11,130,19],
+"class_ogre_1_1_texture_gpu_manager.html#a5643e2d490f3f305828e3de64e1b5934":[5,2,11,130,26],
+"class_ogre_1_1_texture_gpu_manager.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,11,130,59],
+"class_ogre_1_1_texture_gpu_manager.html#a5e938ff8fcf2cf1312e916b3b5078cfe":[5,2,11,130,41],
+"class_ogre_1_1_texture_gpu_manager.html#a614a8c355b86c01d9f7b847b670c1cd3":[5,2,11,130,65],
+"class_ogre_1_1_texture_gpu_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,130,62],
+"class_ogre_1_1_texture_gpu_manager.html#a68dec5d2c3187c3d7be56d9c5cc55fc4":[5,2,11,130,9],
+"class_ogre_1_1_texture_gpu_manager.html#a6de9d156bb0ef5a625f0f8a6f08a9b19":[5,2,11,130,73],
+"class_ogre_1_1_texture_gpu_manager.html#a6e96132817c27bfae1c0374e98d20dfc":[5,2,11,130,66],
+"class_ogre_1_1_texture_gpu_manager.html#a71e7ae62f823f48c7c4844a2d34589de":[5,2,11,130,23],
+"class_ogre_1_1_texture_gpu_manager.html#a75e42d75a1eae1a28e52e4613832edb3":[5,2,11,130,4]
 };
