@@ -1,66 +1,32 @@
 var NAVTREEINDEX244 =
 {
-"class_ogre_1_1_vulkan_dynamic_buffer.html":[7,0,0,1047],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#a0fa51bc5cdaad9c91ae3d545e30d2faa":[7,0,0,1047,3],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#a0fa51bc5cdaad9c91ae3d545e30d2faa":[6,0,0,1074,3],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#a345e4583a228d36d78bb7ddc9ae55f1d":[7,0,0,1047,0],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#a345e4583a228d36d78bb7ddc9ae55f1d":[6,0,0,1074,0],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#a34d2249c90567be33f6acf91c1395b01":[7,0,0,1047,1],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#a34d2249c90567be33f6acf91c1395b01":[6,0,0,1074,1],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#a6b8e75fbcce84d06c1e4c8870a22a211":[7,0,0,1047,6],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#a6b8e75fbcce84d06c1e4c8870a22a211":[6,0,0,1074,6],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#aa24bed0666c1554569243ba3748f52c9":[6,0,0,1074,2],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#aa24bed0666c1554569243ba3748f52c9":[7,0,0,1047,2],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#adfad704654c931d96827c49fc6165142":[6,0,0,1074,5],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#adfad704654c931d96827c49fc6165142":[7,0,0,1047,5],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#af1266978fe2a746af99b88ffb2e90598":[6,0,0,1074,4],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#af1266978fe2a746af99b88ffb2e90598":[7,0,0,1047,4],
-"class_ogre_1_1_vulkan_gpu_program_manager.html":[6,0,0,1079],
-"class_ogre_1_1_vulkan_gpu_program_manager.html":[7,0,0,1052],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[6,0,0,1079,27],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[7,0,0,1052,27],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[6,0,0,1079,46],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[7,0,0,1052,46],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a02228d2937847ffae1a620633cf0c3a3":[6,0,0,1079,49],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a02228d2937847ffae1a620633cf0c3a3":[7,0,0,1052,49],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a0b3d897dacdf542d029ea2d2a5a988c7":[7,0,0,1052,78],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a0b3d897dacdf542d029ea2d2a5a988c7":[6,0,0,1079,78],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[6,0,0,1079,41],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[7,0,0,1052,41],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a117a3887bbf9e83e0585777beb0501dc":[6,0,0,1079,7],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a117a3887bbf9e83e0585777beb0501dc":[7,0,0,1052,7],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1052,60],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1079,60],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a1eadda53bbed16d5a3804cdba2ad687e":[7,0,0,1052,23],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a1eadda53bbed16d5a3804cdba2ad687e":[6,0,0,1079,23],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[7,0,0,1052,88],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[6,0,0,1079,88],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a2208200adc00affea9fee67fec2f393e":[7,0,0,1052,19],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a2208200adc00affea9fee67fec2f393e":[6,0,0,1079,19],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[7,0,0,1052,5],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[6,0,0,1079,5],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[6,0,0,1079,4],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[7,0,0,1052,5],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[7,0,0,1052,4],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a2aebd515c488f378e859db9bded95412":[7,0,0,1052,47],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[6,0,0,1079,4],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a2aebd515c488f378e859db9bded95412":[6,0,0,1079,47],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a2aebd515c488f378e859db9bded95412":[7,0,0,1052,47],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a2bd0bbd53b5ba09b11a9217e129ec0d7":[6,0,0,1079,43],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a2bd0bbd53b5ba09b11a9217e129ec0d7":[7,0,0,1052,43],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a2cf457c70ea86892b1bec52028c96237":[6,0,0,1079,86],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a2cf457c70ea86892b1bec52028c96237":[7,0,0,1052,86],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a39cb435674c75c8e6b5f9e8aeebe6ec9":[7,0,0,1052,9],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a2cf457c70ea86892b1bec52028c96237":[6,0,0,1079,86],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a39cb435674c75c8e6b5f9e8aeebe6ec9":[6,0,0,1079,9],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a3e5398bdfcac88d573ea1dc0ba68e5aa":[6,0,0,1079,52],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a39cb435674c75c8e6b5f9e8aeebe6ec9":[7,0,0,1052,9],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a3e5398bdfcac88d573ea1dc0ba68e5aa":[7,0,0,1052,52],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a3f92489910e40e3756606a35618d7b06":[7,0,0,1052,74],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a3e5398bdfcac88d573ea1dc0ba68e5aa":[6,0,0,1079,52],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a3f92489910e40e3756606a35618d7b06":[6,0,0,1079,74],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a3fa0473ad1390af99f69325c2eced427":[6,0,0,1079,22],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a3f92489910e40e3756606a35618d7b06":[7,0,0,1052,74],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a3fa0473ad1390af99f69325c2eced427":[7,0,0,1052,22],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a40769092850d5b296e1d1a9190631700":[6,0,0,1079,13],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a3fa0473ad1390af99f69325c2eced427":[6,0,0,1079,22],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a40769092850d5b296e1d1a9190631700":[7,0,0,1052,13],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a42f172a8ed1625011d510b081eee66dd":[7,0,0,1052,34],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a40769092850d5b296e1d1a9190631700":[6,0,0,1079,13],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a42f172a8ed1625011d510b081eee66dd":[6,0,0,1079,34],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a48c565d0e63b286c6388439ae73417df":[6,0,0,1079,20],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a42f172a8ed1625011d510b081eee66dd":[7,0,0,1052,34],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a48c565d0e63b286c6388439ae73417df":[7,0,0,1052,20],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a48c565d0e63b286c6388439ae73417df":[6,0,0,1079,20],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a4d3289d4636168230da11c1c9794db59":[6,0,0,1079,40],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a4d3289d4636168230da11c1c9794db59":[7,0,0,1052,40],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a4d6b9934b69d6c0731d717b22fae5715":[7,0,0,1052,25],
@@ -69,42 +35,42 @@ var NAVTREEINDEX244 =
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a4dcdc664cfb7ec1d0a19cadc67a317db":[6,0,0,1079,10],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[7,0,0,1052,73],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[6,0,0,1079,73],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[6,0,0,1079,6],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[7,0,0,1052,6],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a54d1843a43aebb13542312cd17134e6a":[7,0,0,1052,14],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[6,0,0,1079,6],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a54d1843a43aebb13542312cd17134e6a":[6,0,0,1079,14],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a54d1843a43aebb13542312cd17134e6a":[7,0,0,1052,14],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a57e22b305d763f9ede5bda93f31051ca":[6,0,0,1079,42],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a57e22b305d763f9ede5bda93f31051ca":[7,0,0,1052,42],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a58e89a2444fd9134b9a87ec6d8f18544":[7,0,0,1052,54],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a58e89a2444fd9134b9a87ec6d8f18544":[6,0,0,1079,54],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a58e89a2444fd9134b9a87ec6d8f18544":[7,0,0,1052,54],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1079,62],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1052,62],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a5feb934731d48691738aa13c63c4518b":[7,0,0,1052,45],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a5feb934731d48691738aa13c63c4518b":[6,0,0,1079,45],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a5feb934731d48691738aa13c63c4518b":[7,0,0,1052,45],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1079,65],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1052,65],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[6,0,0,1079,39],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[7,0,0,1052,39],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[6,0,0,1079,79],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[7,0,0,1052,79],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[6,0,0,1079,77],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[6,0,0,1079,79],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[7,0,0,1052,77],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a730630d8b38183b274235966721582ed":[7,0,0,1052,29],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[6,0,0,1079,77],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a730630d8b38183b274235966721582ed":[6,0,0,1079,29],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[7,0,0,1052,26],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a730630d8b38183b274235966721582ed":[7,0,0,1052,29],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[6,0,0,1079,26],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a7e478377f0c84af297b68a6aedbdbc8e":[6,0,0,1079,91],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[7,0,0,1052,26],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a7e478377f0c84af297b68a6aedbdbc8e":[7,0,0,1052,91],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[6,0,0,1079,68],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a7e478377f0c84af297b68a6aedbdbc8e":[6,0,0,1079,91],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[7,0,0,1052,68],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[6,0,0,1079,68],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1079,58],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1052,58],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[6,0,0,1079,72],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[7,0,0,1052,72],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[6,0,0,1079,72],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a88b278890e6c8c0cc137d8053700aabe":[7,0,0,1052,21],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a88b278890e6c8c0cc137d8053700aabe":[6,0,0,1079,21],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a8b08a9cf68859ad0f7c6b723487fd118":[7,0,0,1052,2],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a8b08a9cf68859ad0f7c6b723487fd118":[6,0,0,1079,2],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a8b08a9cf68859ad0f7c6b723487fd118":[7,0,0,1052,2],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[7,0,0,1052,89],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[6,0,0,1079,89],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1052,61],
@@ -113,12 +79,12 @@ var NAVTREEINDEX244 =
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[6,0,0,1079,87],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a95ad629bcb4005c9427dbea8e24699d4":[7,0,0,1052,38],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a95ad629bcb4005c9427dbea8e24699d4":[6,0,0,1079,38],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a964ed591329cc8046c9fbab0713a35ce":[7,0,0,1052,18],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a964ed591329cc8046c9fbab0713a35ce":[6,0,0,1079,18],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a964ed591329cc8046c9fbab0713a35ce":[7,0,0,1052,18],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a9ba5ed16850087dad793713281264527":[7,0,0,1052,82],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a9ba5ed16850087dad793713281264527":[6,0,0,1079,82],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[7,0,0,1052,80],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[6,0,0,1079,80],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[7,0,0,1052,80],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aa18e33240cbe5003e3ab87ad247dd1b3":[6,0,0,1079,48],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aa18e33240cbe5003e3ab87ad247dd1b3":[7,0,0,1052,48],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aa21d703ad5720d87243b2cbb8b7dc02a":[7,0,0,1052,84],
@@ -131,36 +97,36 @@ var NAVTREEINDEX244 =
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aa4723c868424304f5bec942e9534ab4f":[6,0,0,1079,16],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[7,0,0,1052,83],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[6,0,0,1079,83],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#aa8b761abb06d74347e9636550307ccd9":[7,0,0,1052,28],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aa8b761abb06d74347e9636550307ccd9":[6,0,0,1079,28],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#aa9608544a7beb1b0e43835877ab62788":[7,0,0,1052,71],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#aa8b761abb06d74347e9636550307ccd9":[7,0,0,1052,28],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aa9608544a7beb1b0e43835877ab62788":[6,0,0,1079,71],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#aa9608544a7beb1b0e43835877ab62788":[7,0,0,1052,71],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aa97ecb7825ee46c6be15313b6592ee16":[7,0,0,1052,56],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aa97ecb7825ee46c6be15313b6592ee16":[6,0,0,1079,56],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[6,0,0,1079,30],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[7,0,0,1052,30],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[6,0,0,1079,30],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1079,64],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1052,64],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[6,0,0,1079,92],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[7,0,0,1052,92],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#abbef1ac33825efebf54416bc1c79c081":[7,0,0,1052,32],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[6,0,0,1079,92],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#abbef1ac33825efebf54416bc1c79c081":[6,0,0,1079,32],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#abeddfd4b35ef82e3e064295e13de58c2":[6,0,0,1079,44],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#abbef1ac33825efebf54416bc1c79c081":[7,0,0,1052,32],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#abeddfd4b35ef82e3e064295e13de58c2":[7,0,0,1052,44],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#abfb0022b18d022a7605f0d19a966f00f":[6,0,0,1079,75],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#abeddfd4b35ef82e3e064295e13de58c2":[6,0,0,1079,44],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#abfb0022b18d022a7605f0d19a966f00f":[7,0,0,1052,75],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#ac22655af03ecea85d863a1d1d561778c":[6,0,0,1079,76],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#abfb0022b18d022a7605f0d19a966f00f":[6,0,0,1079,75],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ac22655af03ecea85d863a1d1d561778c":[7,0,0,1052,76],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#ac22655af03ecea85d863a1d1d561778c":[6,0,0,1079,76],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ac7311b1e2dea2bdbf6d1f497edc2c4a0":[7,0,0,1052,53],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ac7311b1e2dea2bdbf6d1f497edc2c4a0":[6,0,0,1079,53],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#ac8f7ee61606730572a8590060d8896a0":[7,0,0,1052,35],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ac8f7ee61606730572a8590060d8896a0":[6,0,0,1079,35],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#ac8f7ee61606730572a8590060d8896a0":[7,0,0,1052,35],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1052,59],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1079,59],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#acc4fc3a525b714c0ec554b11af197946":[7,0,0,1052,50],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#acc4fc3a525b714c0ec554b11af197946":[6,0,0,1079,50],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#acd4223279e97a7687e2f9994f05e2491":[6,0,0,1079,24],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#acc4fc3a525b714c0ec554b11af197946":[7,0,0,1052,50],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#acd4223279e97a7687e2f9994f05e2491":[7,0,0,1052,24],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#acd4223279e97a7687e2f9994f05e2491":[6,0,0,1079,24],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#acf1a17422bc3cd1b7af27269bf4182cf":[7,0,0,1052,55],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#acf1a17422bc3cd1b7af27269bf4182cf":[6,0,0,1079,55],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1052,63],
@@ -169,85 +135,119 @@ var NAVTREEINDEX244 =
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ad38b305538ea5574fff333e420843711":[6,0,0,1079,8],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[7,0,0,1052,81],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[6,0,0,1079,81],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#adce32528577d71b228692df906ecd17c":[7,0,0,1052,66],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#adce32528577d71b228692df906ecd17c":[6,0,0,1079,66],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#adce32528577d71b228692df906ecd17c":[7,0,0,1052,66],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[7,0,0,1052,69],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[6,0,0,1079,69],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#aeaa1410333b7bcea14b00c360112a528":[7,0,0,1052,90],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aeaa1410333b7bcea14b00c360112a528":[6,0,0,1079,90],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1052,67],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#aeaa1410333b7bcea14b00c360112a528":[7,0,0,1052,90],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1079,67],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#aef34af73ab87b0b09d2707ebeb43508d":[6,0,0,1079,1],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1052,67],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aef34af73ab87b0b09d2707ebeb43508d":[7,0,0,1052,1],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#aef69278336066eb4736e0a1c6333be9d":[7,0,0,1052,33],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#aef34af73ab87b0b09d2707ebeb43508d":[6,0,0,1079,1],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#aef69278336066eb4736e0a1c6333be9d":[6,0,0,1079,33],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#af163be65b36ac8e5527ce07ac35af145":[6,0,0,1079,17],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#aef69278336066eb4736e0a1c6333be9d":[7,0,0,1052,33],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af163be65b36ac8e5527ce07ac35af145":[7,0,0,1052,17],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#af163be65b36ac8e5527ce07ac35af145":[6,0,0,1079,17],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[7,0,0,1052,12],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[6,0,0,1079,12],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#af316078ddcd71c77c2d1c90a11671f8b":[6,0,0,1079,0],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af316078ddcd71c77c2d1c90a11671f8b":[7,0,0,1052,0],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#af316078ddcd71c77c2d1c90a11671f8b":[6,0,0,1079,0],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[6,0,0,1079,3],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[7,0,0,1052,3],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af52547fa68d01c87a9eff54e076be6c0":[7,0,0,1052,11],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af52547fa68d01c87a9eff54e076be6c0":[6,0,0,1079,11],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#af591ed6c8f4a2a930c10156deb1883de":[6,0,0,1079,57],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af591ed6c8f4a2a930c10156deb1883de":[7,0,0,1052,57],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#af591ed6c8f4a2a930c10156deb1883de":[6,0,0,1079,57],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af6b1156d96165528bd587e92267cc741":[7,0,0,1052,31],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af6b1156d96165528bd587e92267cc741":[6,0,0,1079,31],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#af6b7d851600257f7cfb50f86ffb0920e":[6,0,0,1079,37],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af6b7d851600257f7cfb50f86ffb0920e":[7,0,0,1052,37],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#af6b7d851600257f7cfb50f86ffb0920e":[6,0,0,1079,37],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af907732683ee80ff14c6887acbbba156":[6,0,0,1079,70],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af907732683ee80ff14c6887acbbba156":[7,0,0,1052,70],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af96b58b31c152a8ae3c6152ee3ea12e7":[6,0,0,1079,51],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#af96b58b31c152a8ae3c6152ee3ea12e7":[7,0,0,1052,51],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#afb897c540af244c72da7ed8425159d9e":[7,0,0,1052,15],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#afb897c540af244c72da7ed8425159d9e":[6,0,0,1079,15],
-"class_ogre_1_1_vulkan_mappings.html":[7,0,0,1054],
 "class_ogre_1_1_vulkan_mappings.html":[6,0,0,1081],
-"class_ogre_1_1_vulkan_mappings.html#a0858db97f4072e5680bd6ae55aa26aef":[6,0,0,1081,20],
+"class_ogre_1_1_vulkan_mappings.html":[7,0,0,1054],
 "class_ogre_1_1_vulkan_mappings.html#a0858db97f4072e5680bd6ae55aa26aef":[7,0,0,1054,20],
-"class_ogre_1_1_vulkan_mappings.html#a0f148ac7fdaaf7a138182dccdcf1abc6":[6,0,0,1081,8],
+"class_ogre_1_1_vulkan_mappings.html#a0858db97f4072e5680bd6ae55aa26aef":[6,0,0,1081,20],
 "class_ogre_1_1_vulkan_mappings.html#a0f148ac7fdaaf7a138182dccdcf1abc6":[7,0,0,1054,8],
+"class_ogre_1_1_vulkan_mappings.html#a0f148ac7fdaaf7a138182dccdcf1abc6":[6,0,0,1081,8],
 "class_ogre_1_1_vulkan_mappings.html#a20076de8e39e2c1ff77cf81626f4d06b":[6,0,0,1081,16],
 "class_ogre_1_1_vulkan_mappings.html#a20076de8e39e2c1ff77cf81626f4d06b":[7,0,0,1054,16],
-"class_ogre_1_1_vulkan_mappings.html#a202fc90d6e85e41bce181848e2921e26":[7,0,0,1054,19],
 "class_ogre_1_1_vulkan_mappings.html#a202fc90d6e85e41bce181848e2921e26":[6,0,0,1081,19],
-"class_ogre_1_1_vulkan_mappings.html#a256cdd83a4d3f7de8705d7450c4dc50e":[7,0,0,1054,0],
+"class_ogre_1_1_vulkan_mappings.html#a202fc90d6e85e41bce181848e2921e26":[7,0,0,1054,19],
 "class_ogre_1_1_vulkan_mappings.html#a256cdd83a4d3f7de8705d7450c4dc50e":[6,0,0,1081,0],
-"class_ogre_1_1_vulkan_mappings.html#a32283a12e25561a350a4f9bfed715b1e":[6,0,0,1081,7],
+"class_ogre_1_1_vulkan_mappings.html#a256cdd83a4d3f7de8705d7450c4dc50e":[7,0,0,1054,0],
 "class_ogre_1_1_vulkan_mappings.html#a32283a12e25561a350a4f9bfed715b1e":[7,0,0,1054,7],
-"class_ogre_1_1_vulkan_mappings.html#a3d9d90713658d5cb631779dfb3e31a1f":[7,0,0,1054,11],
+"class_ogre_1_1_vulkan_mappings.html#a32283a12e25561a350a4f9bfed715b1e":[6,0,0,1081,7],
 "class_ogre_1_1_vulkan_mappings.html#a3d9d90713658d5cb631779dfb3e31a1f":[6,0,0,1081,11],
-"class_ogre_1_1_vulkan_mappings.html#a4404831b8dbed2b7187d507a54710c7c":[7,0,0,1054,13],
+"class_ogre_1_1_vulkan_mappings.html#a3d9d90713658d5cb631779dfb3e31a1f":[7,0,0,1054,11],
 "class_ogre_1_1_vulkan_mappings.html#a4404831b8dbed2b7187d507a54710c7c":[6,0,0,1081,13],
+"class_ogre_1_1_vulkan_mappings.html#a4404831b8dbed2b7187d507a54710c7c":[7,0,0,1054,13],
 "class_ogre_1_1_vulkan_mappings.html#a5890c1c074a9a0f173968116fe21ab23":[6,0,0,1081,18],
 "class_ogre_1_1_vulkan_mappings.html#a5890c1c074a9a0f173968116fe21ab23":[7,0,0,1054,18],
 "class_ogre_1_1_vulkan_mappings.html#a5ba8cc5ce12f3832241466a4cf7c400d":[6,0,0,1081,5],
 "class_ogre_1_1_vulkan_mappings.html#a5ba8cc5ce12f3832241466a4cf7c400d":[7,0,0,1054,5],
 "class_ogre_1_1_vulkan_mappings.html#a65b5860df583266448d71562648b25b5":[6,0,0,1081,3],
 "class_ogre_1_1_vulkan_mappings.html#a65b5860df583266448d71562648b25b5":[7,0,0,1054,3],
-"class_ogre_1_1_vulkan_mappings.html#a69c2d8c3726f6d841315a866c65c21f7":[6,0,0,1081,4],
 "class_ogre_1_1_vulkan_mappings.html#a69c2d8c3726f6d841315a866c65c21f7":[7,0,0,1054,4],
-"class_ogre_1_1_vulkan_mappings.html#a72ed2e6e6bd4af28e5b5a82bf716e892":[7,0,0,1054,17],
+"class_ogre_1_1_vulkan_mappings.html#a69c2d8c3726f6d841315a866c65c21f7":[6,0,0,1081,4],
 "class_ogre_1_1_vulkan_mappings.html#a72ed2e6e6bd4af28e5b5a82bf716e892":[6,0,0,1081,17],
-"class_ogre_1_1_vulkan_mappings.html#a8ae87e7e099f26cfee74df2b09b25a9f":[6,0,0,1081,14],
+"class_ogre_1_1_vulkan_mappings.html#a72ed2e6e6bd4af28e5b5a82bf716e892":[7,0,0,1054,17],
 "class_ogre_1_1_vulkan_mappings.html#a8ae87e7e099f26cfee74df2b09b25a9f":[7,0,0,1054,14],
-"class_ogre_1_1_vulkan_mappings.html#aa2c0dffa4b54346731d1def7a42b6711":[7,0,0,1054,2],
+"class_ogre_1_1_vulkan_mappings.html#a8ae87e7e099f26cfee74df2b09b25a9f":[6,0,0,1081,14],
 "class_ogre_1_1_vulkan_mappings.html#aa2c0dffa4b54346731d1def7a42b6711":[6,0,0,1081,2],
-"class_ogre_1_1_vulkan_mappings.html#ab46e29985aa18c4c92453a278f3006dd":[6,0,0,1081,1],
+"class_ogre_1_1_vulkan_mappings.html#aa2c0dffa4b54346731d1def7a42b6711":[7,0,0,1054,2],
 "class_ogre_1_1_vulkan_mappings.html#ab46e29985aa18c4c92453a278f3006dd":[7,0,0,1054,1],
+"class_ogre_1_1_vulkan_mappings.html#ab46e29985aa18c4c92453a278f3006dd":[6,0,0,1081,1],
 "class_ogre_1_1_vulkan_mappings.html#ab5fa84a5bdeead9e06b285b8f4e8f360":[7,0,0,1054,9],
 "class_ogre_1_1_vulkan_mappings.html#ab5fa84a5bdeead9e06b285b8f4e8f360":[6,0,0,1081,9],
-"class_ogre_1_1_vulkan_mappings.html#ab95dc47069925f81bc6636dfe2714fe9":[6,0,0,1081,12],
 "class_ogre_1_1_vulkan_mappings.html#ab95dc47069925f81bc6636dfe2714fe9":[7,0,0,1054,12],
+"class_ogre_1_1_vulkan_mappings.html#ab95dc47069925f81bc6636dfe2714fe9":[6,0,0,1081,12],
 "class_ogre_1_1_vulkan_mappings.html#ad1b03e16d298672b3fc87a0a80c09cf2":[7,0,0,1054,10],
 "class_ogre_1_1_vulkan_mappings.html#ad1b03e16d298672b3fc87a0a80c09cf2":[6,0,0,1081,10],
 "class_ogre_1_1_vulkan_mappings.html#adaec1630227dc46315c29129144c6ceb":[7,0,0,1054,15],
 "class_ogre_1_1_vulkan_mappings.html#adaec1630227dc46315c29129144c6ceb":[6,0,0,1081,15],
 "class_ogre_1_1_vulkan_mappings.html#af84f10d89f85caed0a7e0753946eae61":[7,0,0,1054,6],
 "class_ogre_1_1_vulkan_mappings.html#af84f10d89f85caed0a7e0753946eae61":[6,0,0,1081,6],
-"class_ogre_1_1_vulkan_pixel_format_to_shader_type.html":[6,0,0,1082],
 "class_ogre_1_1_vulkan_pixel_format_to_shader_type.html":[7,0,0,1055],
-"class_ogre_1_1_vulkan_pixel_format_to_shader_type.html#a0bf331c938c59d1fddfa05187ac26af7":[7,0,0,1055,0]
+"class_ogre_1_1_vulkan_pixel_format_to_shader_type.html":[6,0,0,1082],
+"class_ogre_1_1_vulkan_pixel_format_to_shader_type.html#a0bf331c938c59d1fddfa05187ac26af7":[7,0,0,1055,0],
+"class_ogre_1_1_vulkan_pixel_format_to_shader_type.html#a0bf331c938c59d1fddfa05187ac26af7":[6,0,0,1082,0],
+"class_ogre_1_1_vulkan_pixel_format_to_shader_type.html#a9eff33cf22336e54cd9e7d36a3fcae11":[7,0,0,1055,1],
+"class_ogre_1_1_vulkan_pixel_format_to_shader_type.html#a9eff33cf22336e54cd9e7d36a3fcae11":[6,0,0,1082,1],
+"class_ogre_1_1_vulkan_plugin.html":[7,0,0,1056],
+"class_ogre_1_1_vulkan_plugin.html":[6,0,0,1083],
+"class_ogre_1_1_vulkan_plugin.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1083,6],
+"class_ogre_1_1_vulkan_plugin.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1056,6],
+"class_ogre_1_1_vulkan_plugin.html#a436226261d9f3be9133f030918429581":[6,0,0,1083,2],
+"class_ogre_1_1_vulkan_plugin.html#a436226261d9f3be9133f030918429581":[7,0,0,1056,2],
+"class_ogre_1_1_vulkan_plugin.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1056,8],
+"class_ogre_1_1_vulkan_plugin.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1083,8],
+"class_ogre_1_1_vulkan_plugin.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1056,11],
+"class_ogre_1_1_vulkan_plugin.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1083,11],
+"class_ogre_1_1_vulkan_plugin.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1056,4],
+"class_ogre_1_1_vulkan_plugin.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1083,4],
+"class_ogre_1_1_vulkan_plugin.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1083,7],
+"class_ogre_1_1_vulkan_plugin.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1056,7],
+"class_ogre_1_1_vulkan_plugin.html#a9f9d00059273e60d2b80babc2c4e3c57":[7,0,0,1056,15],
+"class_ogre_1_1_vulkan_plugin.html#a9f9d00059273e60d2b80babc2c4e3c57":[6,0,0,1083,15],
+"class_ogre_1_1_vulkan_plugin.html#aa11181129c216da6181827bd6c2df92f":[7,0,0,1056,1],
+"class_ogre_1_1_vulkan_plugin.html#aa11181129c216da6181827bd6c2df92f":[6,0,0,1083,1],
+"class_ogre_1_1_vulkan_plugin.html#aa1fa734cd2be6c99185e0664a233faef":[6,0,0,1083,14],
+"class_ogre_1_1_vulkan_plugin.html#aa1fa734cd2be6c99185e0664a233faef":[7,0,0,1056,14],
+"class_ogre_1_1_vulkan_plugin.html#aa53a016ac7c855978b27540d50976bba":[6,0,0,1083,3],
+"class_ogre_1_1_vulkan_plugin.html#aa53a016ac7c855978b27540d50976bba":[7,0,0,1056,3],
+"class_ogre_1_1_vulkan_plugin.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1083,10],
+"class_ogre_1_1_vulkan_plugin.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1056,10],
+"class_ogre_1_1_vulkan_plugin.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1056,5],
+"class_ogre_1_1_vulkan_plugin.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1083,5],
+"class_ogre_1_1_vulkan_plugin.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1083,9],
+"class_ogre_1_1_vulkan_plugin.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1056,9],
+"class_ogre_1_1_vulkan_plugin.html#adce32528577d71b228692df906ecd17c":[6,0,0,1083,12],
+"class_ogre_1_1_vulkan_plugin.html#adce32528577d71b228692df906ecd17c":[7,0,0,1056,12],
+"class_ogre_1_1_vulkan_plugin.html#ade0fe63e9df49c9c62a16834b47dcf98":[6,0,0,1083,0]
 };
