@@ -1,59 +1,5 @@
 var NAVTREEINDEX26 =
 {
-"class_ogre_1_1_compositor_pass_ibl_specular_def.html#af08bf108f37be8e1745faac8a0866883":[5,2,1,13,44],
-"class_ogre_1_1_compositor_pass_ibl_specular_def.html#af587f9f213a712bf6dc5f02e46d5f395":[5,2,1,13,25],
-"class_ogre_1_1_compositor_pass_ibl_specular_def.html#af603f6cce02284ad5a4781c261a05137":[5,2,1,13,51],
-"class_ogre_1_1_compositor_pass_mipmap.html":[5,2,1,14],
-"class_ogre_1_1_compositor_pass_mipmap.html#a109f49cb2e6f8a9c0e1377817bcb9e6d":[5,2,1,14,12],
-"class_ogre_1_1_compositor_pass_mipmap.html#a17026f1e961ef5ab42acd2a6ac110f6e":[5,2,1,14,7],
-"class_ogre_1_1_compositor_pass_mipmap.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,1,14,18],
-"class_ogre_1_1_compositor_pass_mipmap.html#a220924c4a37f7cf458646522bc5cc72f":[5,2,1,14,10],
-"class_ogre_1_1_compositor_pass_mipmap.html#a29f55d33cf7f6ea6b8972d110f75dd70":[5,2,1,14,8],
-"class_ogre_1_1_compositor_pass_mipmap.html#a2b2aa16f1668d7d7031e0a4ff59a5c11":[5,2,1,14,5],
-"class_ogre_1_1_compositor_pass_mipmap.html#a3d94bb7e758731f7160eb7dedae69ed7":[5,2,1,14,27],
-"class_ogre_1_1_compositor_pass_mipmap.html#a4837e8afd093a37f67d708c64b793b4d":[5,2,1,14,11],
-"class_ogre_1_1_compositor_pass_mipmap.html#a4f438861e7ff9d2eaa9dcc3187095bd0":[5,2,1,14,0],
-"class_ogre_1_1_compositor_pass_mipmap.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,1,14,20],
-"class_ogre_1_1_compositor_pass_mipmap.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,1,14,23],
-"class_ogre_1_1_compositor_pass_mipmap.html#a646fca3fd4416eae2c15d4ce08943899":[5,2,1,14,2],
-"class_ogre_1_1_compositor_pass_mipmap.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,1,14,16],
-"class_ogre_1_1_compositor_pass_mipmap.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,1,14,19],
-"class_ogre_1_1_compositor_pass_mipmap.html#a9bc1cd56189d57a81b0c282b432ab9c0":[5,2,1,14,6],
-"class_ogre_1_1_compositor_pass_mipmap.html#a9f7ab3e159808c63ff31ac799e476c66":[5,2,1,14,13],
-"class_ogre_1_1_compositor_pass_mipmap.html#aa2bda339febc5ee5e09ecebabfb2a42b":[5,2,1,14,3],
-"class_ogre_1_1_compositor_pass_mipmap.html#aa41c9c365491ec61281e19c0ea510b0c":[5,2,1,14,9],
-"class_ogre_1_1_compositor_pass_mipmap.html#aabe88af37d6171865aaa1a181c3472cf":[5,2,1,14,1],
-"class_ogre_1_1_compositor_pass_mipmap.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,1,14,22],
-"class_ogre_1_1_compositor_pass_mipmap.html#ac92baa443272b1bb6a1b703b570267f3":[5,2,1,14,15],
-"class_ogre_1_1_compositor_pass_mipmap.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,1,14,17],
-"class_ogre_1_1_compositor_pass_mipmap.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,1,14,21],
-"class_ogre_1_1_compositor_pass_mipmap.html#ad4d394f598a677c18b4b653cde572957":[5,2,1,14,4],
-"class_ogre_1_1_compositor_pass_mipmap.html#ad9e0b79d8ca75e75cc94e0f00608e692":[5,2,1,14,26],
-"class_ogre_1_1_compositor_pass_mipmap.html#adce32528577d71b228692df906ecd17c":[5,2,1,14,24],
-"class_ogre_1_1_compositor_pass_mipmap.html#adde1e8ecfdf279e3d4072cf8afc1a95f":[5,2,1,14,14],
-"class_ogre_1_1_compositor_pass_mipmap.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,1,14,25],
-"class_ogre_1_1_compositor_pass_mipmap.html#afe6a90034aeaa2ed38e32d9f344e38c3":[5,2,1,14,28],
-"class_ogre_1_1_compositor_pass_mipmap_def.html":[5,2,1,15],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a03f4a196d4bc9d62b967019c5bf7c5ac":[5,2,1,15,48],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a08c66aa1c72aef43599f360cfc6ada68":[5,2,1,15,16],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a0c5cb2ce18598d9cd1a789122f3977ce":[5,2,1,15,26],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a0fdf3a38961c32069cde61f23d7ff674":[5,2,1,15,39],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a114c9c278a29353ebe78cc7d7e3fce6f":[5,2,1,15,0],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a1c2ec91e26d3a0792c113570885b47a5":[5,2,1,15,42],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,1,15,8],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a1e9e560eddce4c5ac862789a1a752909":[5,2,1,15,38],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a313d390f851cc3f0ac463ea78fe5e860":[5,2,1,15,41],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a368fcc3ba3874f5ae9f4eaf8eb46652e":[5,2,1,15,37],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a381a618da654e25c5086c9689f3c411c":[5,2,1,15,3],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a3d3261991c377fdb3ed68a4b4fd6f705":[5,2,1,15,33],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a4ba939216db7e92e0a0ba4cebe62af5b":[5,2,1,15,23],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a5044b7066a60cf46d506e1247b3a58fd":[5,2,1,15,5],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a544008d76e21be83ab7b91f96f36b3bc":[5,2,1,15,18],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,1,15,10],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a5b72f1a56bcbd829fc60fa21afde5927":[5,2,1,15,19],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,1,15,13],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a6e881a7f92659dabfe52eefec2ccf603":[5,2,1,15,35],
-"class_ogre_1_1_compositor_pass_mipmap_def.html#a70ba2384e061021d6eceb5dd20b66d47":[5,2,1,15,34],
 "class_ogre_1_1_compositor_pass_mipmap_def.html#a72990e404ac50fd8f69b4037d0336110":[5,2,1,15,29],
 "class_ogre_1_1_compositor_pass_mipmap_def.html#a733fc229b44113a73acfbda4dce01659":[5,2,1,15,2],
 "class_ogre_1_1_compositor_pass_mipmap_def.html#a7446207e62dfceb532bd3dc3cf78039b":[5,2,1,15,32],
@@ -88,14 +34,14 @@ var NAVTREEINDEX26 =
 "class_ogre_1_1_compositor_pass_mipmap_def.html#af603f6cce02284ad5a4781c261a05137":[5,2,1,15,45],
 "class_ogre_1_1_compositor_pass_provider.html":[5,0,1,8],
 "class_ogre_1_1_compositor_pass_provider.html":[5,2,12,8],
-"class_ogre_1_1_compositor_pass_provider.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,8,4],
 "class_ogre_1_1_compositor_pass_provider.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,8,4],
+"class_ogre_1_1_compositor_pass_provider.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,8,4],
 "class_ogre_1_1_compositor_pass_provider.html#a3faf3c61e46b3ca1d8dd9e40396c82df":[5,2,12,8,12],
 "class_ogre_1_1_compositor_pass_provider.html#a3faf3c61e46b3ca1d8dd9e40396c82df":[5,0,1,8,12],
-"class_ogre_1_1_compositor_pass_provider.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,8,6],
 "class_ogre_1_1_compositor_pass_provider.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,8,6],
-"class_ogre_1_1_compositor_pass_provider.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,8,9],
+"class_ogre_1_1_compositor_pass_provider.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,8,6],
 "class_ogre_1_1_compositor_pass_provider.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,8,9],
+"class_ogre_1_1_compositor_pass_provider.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,8,9],
 "class_ogre_1_1_compositor_pass_provider.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,8,2],
 "class_ogre_1_1_compositor_pass_provider.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,8,2],
 "class_ogre_1_1_compositor_pass_provider.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,8,5],
@@ -104,12 +50,12 @@ var NAVTREEINDEX26 =
 "class_ogre_1_1_compositor_pass_provider.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,8,8],
 "class_ogre_1_1_compositor_pass_provider.html#abcb0e0006a30c29f4df718365b97d6b9":[5,2,12,8,1],
 "class_ogre_1_1_compositor_pass_provider.html#abcb0e0006a30c29f4df718365b97d6b9":[5,0,1,8,1],
-"class_ogre_1_1_compositor_pass_provider.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,8,3],
 "class_ogre_1_1_compositor_pass_provider.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,8,3],
-"class_ogre_1_1_compositor_pass_provider.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,8,7],
+"class_ogre_1_1_compositor_pass_provider.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,8,3],
 "class_ogre_1_1_compositor_pass_provider.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,8,7],
-"class_ogre_1_1_compositor_pass_provider.html#adb4a50957a720e8292cd0eaba116273b":[5,2,12,8,0],
+"class_ogre_1_1_compositor_pass_provider.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,8,7],
 "class_ogre_1_1_compositor_pass_provider.html#adb4a50957a720e8292cd0eaba116273b":[5,0,1,8,0],
+"class_ogre_1_1_compositor_pass_provider.html#adb4a50957a720e8292cd0eaba116273b":[5,2,12,8,0],
 "class_ogre_1_1_compositor_pass_provider.html#adce32528577d71b228692df906ecd17c":[5,2,12,8,10],
 "class_ogre_1_1_compositor_pass_provider.html#adce32528577d71b228692df906ecd17c":[5,0,1,8,10],
 "class_ogre_1_1_compositor_pass_provider.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,8,11],
@@ -249,5 +195,59 @@ var NAVTREEINDEX26 =
 "class_ogre_1_1_compositor_pass_scene.html#afe6389c435c11fd0644d698306af0dd7":[5,2,1,18,17],
 "class_ogre_1_1_compositor_pass_scene.html#afe6a90034aeaa2ed38e32d9f344e38c3":[5,2,1,18,35],
 "class_ogre_1_1_compositor_pass_scene_def.html":[5,2,1,19],
-"class_ogre_1_1_compositor_pass_scene_def.html#a02648d48cf90fe76925818c30741809a":[5,2,1,19,70]
+"class_ogre_1_1_compositor_pass_scene_def.html#a02648d48cf90fe76925818c30741809a":[5,2,1,19,70],
+"class_ogre_1_1_compositor_pass_scene_def.html#a03f4a196d4bc9d62b967019c5bf7c5ac":[5,2,1,19,75],
+"class_ogre_1_1_compositor_pass_scene_def.html#a08c66aa1c72aef43599f360cfc6ada68":[5,2,1,19,15],
+"class_ogre_1_1_compositor_pass_scene_def.html#a09593de13ef678c0f705ea6dabf41e86":[5,2,1,19,29],
+"class_ogre_1_1_compositor_pass_scene_def.html#a0fdf3a38961c32069cde61f23d7ff674":[5,2,1,19,60],
+"class_ogre_1_1_compositor_pass_scene_def.html#a114c9c278a29353ebe78cc7d7e3fce6f":[5,2,1,19,0],
+"class_ogre_1_1_compositor_pass_scene_def.html#a125a142085fcc39304d15944c24282bf":[5,2,1,19,36],
+"class_ogre_1_1_compositor_pass_scene_def.html#a16928cb44d3328e36bdff5f88f7d567e":[5,2,1,19,54],
+"class_ogre_1_1_compositor_pass_scene_def.html#a1b01b3e46bf06f9b3c898a3206184ddd":[5,2,1,19,40],
+"class_ogre_1_1_compositor_pass_scene_def.html#a1b477927be2d888a89f23ef632c5d4a9":[5,2,1,19,41],
+"class_ogre_1_1_compositor_pass_scene_def.html#a1c2ec91e26d3a0792c113570885b47a5":[5,2,1,19,65],
+"class_ogre_1_1_compositor_pass_scene_def.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,1,19,7],
+"class_ogre_1_1_compositor_pass_scene_def.html#a1e9e560eddce4c5ac862789a1a752909":[5,2,1,19,57],
+"class_ogre_1_1_compositor_pass_scene_def.html#a21c75caa6f66a3571ccb437ac3d4755e":[5,2,1,19,37],
+"class_ogre_1_1_compositor_pass_scene_def.html#a231836aa0435fcccbbf40effd54be489":[5,2,1,19,21],
+"class_ogre_1_1_compositor_pass_scene_def.html#a313d390f851cc3f0ac463ea78fe5e860":[5,2,1,19,64],
+"class_ogre_1_1_compositor_pass_scene_def.html#a3150079cce806bf33715c78f7dcdb0df":[5,2,1,19,58],
+"class_ogre_1_1_compositor_pass_scene_def.html#a368fcc3ba3874f5ae9f4eaf8eb46652e":[5,2,1,19,56],
+"class_ogre_1_1_compositor_pass_scene_def.html#a381a618da654e25c5086c9689f3c411c":[5,2,1,19,2],
+"class_ogre_1_1_compositor_pass_scene_def.html#a46121097b8cde2e75de7a10bd7177e09":[5,2,1,19,63],
+"class_ogre_1_1_compositor_pass_scene_def.html#a49a051c360d9072103ad6babae4ff340":[5,2,1,19,23],
+"class_ogre_1_1_compositor_pass_scene_def.html#a4ba939216db7e92e0a0ba4cebe62af5b":[5,2,1,19,32],
+"class_ogre_1_1_compositor_pass_scene_def.html#a5044b7066a60cf46d506e1247b3a58fd":[5,2,1,19,4],
+"class_ogre_1_1_compositor_pass_scene_def.html#a544008d76e21be83ab7b91f96f36b3bc":[5,2,1,19,17],
+"class_ogre_1_1_compositor_pass_scene_def.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,1,19,9],
+"class_ogre_1_1_compositor_pass_scene_def.html#a5b72f1a56bcbd829fc60fa21afde5927":[5,2,1,19,25],
+"class_ogre_1_1_compositor_pass_scene_def.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,1,19,12],
+"class_ogre_1_1_compositor_pass_scene_def.html#a66b4bf89d3f8b9ab611bd03802c062dd":[5,2,1,19,1],
+"class_ogre_1_1_compositor_pass_scene_def.html#a6e881a7f92659dabfe52eefec2ccf603":[5,2,1,19,50],
+"class_ogre_1_1_compositor_pass_scene_def.html#a70ba2384e061021d6eceb5dd20b66d47":[5,2,1,19,49],
+"class_ogre_1_1_compositor_pass_scene_def.html#a7446207e62dfceb532bd3dc3cf78039b":[5,2,1,19,45],
+"class_ogre_1_1_compositor_pass_scene_def.html#a7731386fe3b2ac2cdb4a8be6e4e138b2":[5,2,1,19,66],
+"class_ogre_1_1_compositor_pass_scene_def.html#a7b6757dc80fabdbbd8d3a0808037453f":[5,2,1,19,71],
+"class_ogre_1_1_compositor_pass_scene_def.html#a822b8d01cd97e35e420cd254cea54fe9":[5,2,1,19,3],
+"class_ogre_1_1_compositor_pass_scene_def.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,1,19,5],
+"class_ogre_1_1_compositor_pass_scene_def.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,1,19,8],
+"class_ogre_1_1_compositor_pass_scene_def.html#a9debf9c0200b0d96e8197ad7969d5dbd":[5,2,1,19,19],
+"class_ogre_1_1_compositor_pass_scene_def.html#aa09e5161af218d56d46496e80d0fe60c":[5,2,1,19,42],
+"class_ogre_1_1_compositor_pass_scene_def.html#aa3381e8cd31c5ccbc33f1d1c5bf9b86c":[5,2,1,19,28],
+"class_ogre_1_1_compositor_pass_scene_def.html#aa78f703dc8c8b28cf575ac419653dc40":[5,2,1,19,72],
+"class_ogre_1_1_compositor_pass_scene_def.html#aa9377ca6479c21df519128eb6142b169":[5,2,1,19,33],
+"class_ogre_1_1_compositor_pass_scene_def.html#aa96ca6678cf0c7b4af32c3740d301dd4":[5,2,1,19,62],
+"class_ogre_1_1_compositor_pass_scene_def.html#aa9def33c89448b89c2d920d96ff55f28":[5,2,1,19,55],
+"class_ogre_1_1_compositor_pass_scene_def.html#aab55367dfa5128605bd51b10286eda67":[5,2,1,19,20],
+"class_ogre_1_1_compositor_pass_scene_def.html#aacdeaffb7cacec5f264de2be66410c67":[5,2,1,19,39],
+"class_ogre_1_1_compositor_pass_scene_def.html#ab270a145417bc6b9c95224ffc2b11c2e":[5,2,1,19,35],
+"class_ogre_1_1_compositor_pass_scene_def.html#ab2ffdf22f4204a55f24927629ec0ed5c":[5,2,1,19,53],
+"class_ogre_1_1_compositor_pass_scene_def.html#ab324757ac2e20fa4d36940527506459a":[5,2,1,19,24],
+"class_ogre_1_1_compositor_pass_scene_def.html#ab32b226a745dfd996d7b94a7197044eb":[5,2,1,19,38],
+"class_ogre_1_1_compositor_pass_scene_def.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,1,19,11],
+"class_ogre_1_1_compositor_pass_scene_def.html#ab6b2041bfd40579556b2637f9809ec62":[5,2,1,19,16],
+"class_ogre_1_1_compositor_pass_scene_def.html#abf1c159397e4fa8e205eb3461a6eec8d":[5,2,1,19,67],
+"class_ogre_1_1_compositor_pass_scene_def.html#ac2ebb8b97a0e78189b21c95170338825":[5,2,1,19,69],
+"class_ogre_1_1_compositor_pass_scene_def.html#ac2ec0baf73405179bb379e9916aafd98":[5,2,1,19,52],
+"class_ogre_1_1_compositor_pass_scene_def.html#ac99e1fd52b3aeff195fa339a29d1d0da":[5,2,1,19,48]
 };
