@@ -1,102 +1,42 @@
 var NAVTREEINDEX84 =
 {
-"class_ogre_1_1_file_stream_data_stream.html#adce32528577d71b228692df906ecd17c":[5,2,11,36,24],
-"class_ogre_1_1_file_stream_data_stream.html#ae57d5d322a93cbf21e5ffd382919f3a3":[5,2,11,36,4],
-"class_ogre_1_1_file_stream_data_stream.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,11,36,25],
-"class_ogre_1_1_file_stream_data_stream.html#af09667bef9ac4b514602baca8d08f007":[5,2,11,36,28],
-"class_ogre_1_1_file_stream_data_stream.html#af54511846463e10fe14a1addb40ada81":[5,2,11,36,8],
-"class_ogre_1_1_file_stream_data_stream.html#afe6b33013fb5457f4c43a536e3aa059e":[5,2,11,36,29],
-"class_ogre_1_1_file_stream_data_stream.html#aff0243c8ad8f5de00bf8e0887d0f034f":[5,2,11,36,15],
-"class_ogre_1_1_file_system_archive.html":[5,2,11,37],
-"class_ogre_1_1_file_system_archive.html#a197c16fb380d5d245f27ede38eadcb5a":[5,2,11,37,29],
-"class_ogre_1_1_file_system_archive.html#a19a46cfd6ea079bca9538e862042a891":[5,2,11,37,7],
-"class_ogre_1_1_file_system_archive.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,11,37,18],
-"class_ogre_1_1_file_system_archive.html#a2d9eb31d4d17fdb4b35c5ad1c739f1be":[5,2,11,37,5],
-"class_ogre_1_1_file_system_archive.html#a3229d2fd6c8d3236f68f7a3f1baedeec":[5,2,11,37,11],
-"class_ogre_1_1_file_system_archive.html#a43a6d5e4f1757cfd8616a499fa774150":[5,2,11,37,15],
-"class_ogre_1_1_file_system_archive.html#a47dc8d47bb6a6738a85f62f816bfd7f8":[5,2,11,37,4],
-"class_ogre_1_1_file_system_archive.html#a5564d16d6fce7e6a6bd80d5b0eb65801":[5,2,11,37,10],
-"class_ogre_1_1_file_system_archive.html#a5907d6e8da20de62af12d564d9fbd279":[5,2,11,37,12],
-"class_ogre_1_1_file_system_archive.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,11,37,20],
-"class_ogre_1_1_file_system_archive.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,37,23],
-"class_ogre_1_1_file_system_archive.html#a79c4957064dc9858d3abdc87ebadfe7c":[5,2,11,37,6],
-"class_ogre_1_1_file_system_archive.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,11,37,16],
-"class_ogre_1_1_file_system_archive.html#a8364eb430fccfbe249b64c0dd29c2cb5":[5,2,11,37,28],
-"class_ogre_1_1_file_system_archive.html#a886e95b80604575912e8dadecdb47ca5":[5,2,11,37,2],
-"class_ogre_1_1_file_system_archive.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,11,37,19],
-"class_ogre_1_1_file_system_archive.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,11,37,22],
-"class_ogre_1_1_file_system_archive.html#ab63e6a2843a2db30eef7855616ff3440":[5,2,11,37,9],
-"class_ogre_1_1_file_system_archive.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,11,37,17],
-"class_ogre_1_1_file_system_archive.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,11,37,21],
-"class_ogre_1_1_file_system_archive.html#ad5ae519a6d13d89a7d4dc66ea8f64875":[5,2,11,37,0],
-"class_ogre_1_1_file_system_archive.html#ad89960cb80cf490a23cab7b909ffa092":[5,2,11,37,1],
-"class_ogre_1_1_file_system_archive.html#adce32528577d71b228692df906ecd17c":[5,2,11,37,24],
-"class_ogre_1_1_file_system_archive.html#ade8a11a1b84b467ee124c8ef96bd594c":[5,2,11,37,26],
-"class_ogre_1_1_file_system_archive.html#ae1e6d89d5edc833b8ea5ef74d32a5ad1":[5,2,11,37,27],
-"class_ogre_1_1_file_system_archive.html#aebb587510a65222aca84fa6f8eb69e0f":[5,2,11,37,13],
-"class_ogre_1_1_file_system_archive.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,11,37,25],
-"class_ogre_1_1_file_system_archive.html#aee650b957194abaf771ea81b41da36fe":[5,2,11,37,8],
-"class_ogre_1_1_file_system_archive.html#af3fbf5feb7c3875831d22808b3545d75":[5,2,11,37,14],
-"class_ogre_1_1_file_system_archive.html#afa703d83c696b6b78dc7efe8114e468e":[5,2,11,37,3],
-"class_ogre_1_1_file_system_archive_factory.html":[5,2,11,38],
-"class_ogre_1_1_file_system_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[5,2,11,38,2],
-"class_ogre_1_1_file_system_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,11,38,8],
-"class_ogre_1_1_file_system_archive_factory.html#a1eb9e2ef1abd9aa441091438c44daef4":[5,2,11,38,4],
-"class_ogre_1_1_file_system_archive_factory.html#a314c50c2a0b0c8119c29f776c00060cf":[5,2,11,38,5],
-"class_ogre_1_1_file_system_archive_factory.html#a375c0b982fa94bedec0c07309158c80a":[5,2,11,38,0],
-"class_ogre_1_1_file_system_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,11,38,10],
-"class_ogre_1_1_file_system_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,38,13],
-"class_ogre_1_1_file_system_archive_factory.html#a7bd13cbe0ff9b91f2d7573038d7e62a1":[5,2,11,38,3],
-"class_ogre_1_1_file_system_archive_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,11,38,6],
-"class_ogre_1_1_file_system_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,11,38,9],
-"class_ogre_1_1_file_system_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,11,38,12],
-"class_ogre_1_1_file_system_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,11,38,7],
-"class_ogre_1_1_file_system_archive_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,11,38,11],
-"class_ogre_1_1_file_system_archive_factory.html#ad730fc7214af02a0f1a348428e197366":[5,2,11,38,1],
-"class_ogre_1_1_file_system_archive_factory.html#adce32528577d71b228692df906ecd17c":[5,2,11,38,14],
-"class_ogre_1_1_file_system_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,11,38,15],
-"class_ogre_1_1_file_system_layer.html":[7,0,0,315],
-"class_ogre_1_1_file_system_layer.html":[6,0,0,342],
-"class_ogre_1_1_file_system_layer.html#a09fa0a7da021d71cd7b6e2982d52effc":[7,0,0,315,17],
-"class_ogre_1_1_file_system_layer.html#a09fa0a7da021d71cd7b6e2982d52effc":[6,0,0,342,17],
-"class_ogre_1_1_file_system_layer.html#a0a2d92288292403038f30364043ee753":[6,0,0,342,1],
-"class_ogre_1_1_file_system_layer.html#a0a2d92288292403038f30364043ee753":[7,0,0,315,1],
-"class_ogre_1_1_file_system_layer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,342,7],
-"class_ogre_1_1_file_system_layer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,315,7],
-"class_ogre_1_1_file_system_layer.html#a1fecc5387500843ef0c0c0b732824206":[6,0,0,342,16],
-"class_ogre_1_1_file_system_layer.html#a1fecc5387500843ef0c0c0b732824206":[7,0,0,315,16],
-"class_ogre_1_1_file_system_layer.html#a2fa242f9327be916ac34f699464698af":[6,0,0,342,15],
-"class_ogre_1_1_file_system_layer.html#a2fa242f9327be916ac34f699464698af":[7,0,0,315,15],
-"class_ogre_1_1_file_system_layer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,315,9],
-"class_ogre_1_1_file_system_layer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,342,9],
-"class_ogre_1_1_file_system_layer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,315,12],
-"class_ogre_1_1_file_system_layer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,342,12],
-"class_ogre_1_1_file_system_layer.html#a6566c95649770d52628853f5dfcf8ea6":[6,0,0,342,2],
-"class_ogre_1_1_file_system_layer.html#a6566c95649770d52628853f5dfcf8ea6":[7,0,0,315,2],
-"class_ogre_1_1_file_system_layer.html#a7b8a94fb30ca04060b3c0b09b12af7c4":[6,0,0,342,0],
-"class_ogre_1_1_file_system_layer.html#a7b8a94fb30ca04060b3c0b09b12af7c4":[7,0,0,315,0],
-"class_ogre_1_1_file_system_layer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,315,5],
-"class_ogre_1_1_file_system_layer.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,342,5],
-"class_ogre_1_1_file_system_layer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,315,8],
-"class_ogre_1_1_file_system_layer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,342,8],
-"class_ogre_1_1_file_system_layer.html#aa009fabc48a3922a2148db995f79630d":[7,0,0,315,3],
-"class_ogre_1_1_file_system_layer.html#aa009fabc48a3922a2148db995f79630d":[6,0,0,342,3],
-"class_ogre_1_1_file_system_layer.html#aa2ab8206fdc0f858fbe27e94e3297dbf":[7,0,0,315,18],
-"class_ogre_1_1_file_system_layer.html#aa2ab8206fdc0f858fbe27e94e3297dbf":[6,0,0,342,18],
-"class_ogre_1_1_file_system_layer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,342,11],
-"class_ogre_1_1_file_system_layer.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,315,11],
-"class_ogre_1_1_file_system_layer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,342,6],
-"class_ogre_1_1_file_system_layer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,315,6],
-"class_ogre_1_1_file_system_layer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,342,10],
-"class_ogre_1_1_file_system_layer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,315,10],
-"class_ogre_1_1_file_system_layer.html#adce32528577d71b228692df906ecd17c":[6,0,0,342,13],
-"class_ogre_1_1_file_system_layer.html#adce32528577d71b228692df906ecd17c":[7,0,0,315,13],
-"class_ogre_1_1_file_system_layer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,315,14],
-"class_ogre_1_1_file_system_layer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,342,14],
-"class_ogre_1_1_file_system_layer.html#af4cdf165a53e560daec161f3f80aac45":[7,0,0,315,4],
-"class_ogre_1_1_file_system_layer.html#af4cdf165a53e560daec161f3f80aac45":[6,0,0,342,4],
-"class_ogre_1_1_file_system_layer.html#afeaaf6f11cd5722e589a4c793d5a98cb":[7,0,0,315,19],
-"class_ogre_1_1_file_system_layer.html#afeaaf6f11cd5722e589a4c793d5a98cb":[6,0,0,342,19],
+"class_ogre_1_1_file_system_layer.html#a0a2d92288292403038f30364043ee753":[6,0,0,340,1],
+"class_ogre_1_1_file_system_layer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,340,7],
+"class_ogre_1_1_file_system_layer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,313,7],
+"class_ogre_1_1_file_system_layer.html#a1fecc5387500843ef0c0c0b732824206":[6,0,0,340,16],
+"class_ogre_1_1_file_system_layer.html#a1fecc5387500843ef0c0c0b732824206":[7,0,0,313,16],
+"class_ogre_1_1_file_system_layer.html#a2fa242f9327be916ac34f699464698af":[6,0,0,340,15],
+"class_ogre_1_1_file_system_layer.html#a2fa242f9327be916ac34f699464698af":[7,0,0,313,15],
+"class_ogre_1_1_file_system_layer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,340,9],
+"class_ogre_1_1_file_system_layer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,313,9],
+"class_ogre_1_1_file_system_layer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,313,12],
+"class_ogre_1_1_file_system_layer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,340,12],
+"class_ogre_1_1_file_system_layer.html#a6566c95649770d52628853f5dfcf8ea6":[6,0,0,340,2],
+"class_ogre_1_1_file_system_layer.html#a6566c95649770d52628853f5dfcf8ea6":[7,0,0,313,2],
+"class_ogre_1_1_file_system_layer.html#a7b8a94fb30ca04060b3c0b09b12af7c4":[7,0,0,313,0],
+"class_ogre_1_1_file_system_layer.html#a7b8a94fb30ca04060b3c0b09b12af7c4":[6,0,0,340,0],
+"class_ogre_1_1_file_system_layer.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,340,5],
+"class_ogre_1_1_file_system_layer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,313,5],
+"class_ogre_1_1_file_system_layer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,313,8],
+"class_ogre_1_1_file_system_layer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,340,8],
+"class_ogre_1_1_file_system_layer.html#aa009fabc48a3922a2148db995f79630d":[7,0,0,313,3],
+"class_ogre_1_1_file_system_layer.html#aa009fabc48a3922a2148db995f79630d":[6,0,0,340,3],
+"class_ogre_1_1_file_system_layer.html#aa2ab8206fdc0f858fbe27e94e3297dbf":[6,0,0,340,18],
+"class_ogre_1_1_file_system_layer.html#aa2ab8206fdc0f858fbe27e94e3297dbf":[7,0,0,313,18],
+"class_ogre_1_1_file_system_layer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,340,11],
+"class_ogre_1_1_file_system_layer.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,313,11],
+"class_ogre_1_1_file_system_layer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,313,6],
+"class_ogre_1_1_file_system_layer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,340,6],
+"class_ogre_1_1_file_system_layer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,313,10],
+"class_ogre_1_1_file_system_layer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,340,10],
+"class_ogre_1_1_file_system_layer.html#adce32528577d71b228692df906ecd17c":[6,0,0,340,13],
+"class_ogre_1_1_file_system_layer.html#adce32528577d71b228692df906ecd17c":[7,0,0,313,13],
+"class_ogre_1_1_file_system_layer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,340,14],
+"class_ogre_1_1_file_system_layer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,313,14],
+"class_ogre_1_1_file_system_layer.html#af4cdf165a53e560daec161f3f80aac45":[7,0,0,313,4],
+"class_ogre_1_1_file_system_layer.html#af4cdf165a53e560daec161f3f80aac45":[6,0,0,340,4],
+"class_ogre_1_1_file_system_layer.html#afeaaf6f11cd5722e589a4c793d5a98cb":[6,0,0,340,19],
+"class_ogre_1_1_file_system_layer.html#afeaaf6f11cd5722e589a4c793d5a98cb":[7,0,0,313,19],
 "class_ogre_1_1_float_gpu_parameter_controller_value.html":[5,2,2,47],
 "class_ogre_1_1_float_gpu_parameter_controller_value.html#a15070b767a1bf1cd7c0b6a97c319d029":[5,2,2,47,13],
 "class_ogre_1_1_float_gpu_parameter_controller_value.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,47,5],
@@ -112,42 +52,42 @@ var NAVTREEINDEX84 =
 "class_ogre_1_1_float_gpu_parameter_controller_value.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,2,47,8],
 "class_ogre_1_1_float_gpu_parameter_controller_value.html#adce32528577d71b228692df906ecd17c":[5,2,2,47,11],
 "class_ogre_1_1_float_gpu_parameter_controller_value.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,2,47,12],
-"class_ogre_1_1_focused_shadow_camera_setup.html":[5,0,1,20],
 "class_ogre_1_1_focused_shadow_camera_setup.html":[5,2,12,20],
-"class_ogre_1_1_focused_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,20,8],
+"class_ogre_1_1_focused_shadow_camera_setup.html":[5,0,1,20],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,20,8],
+"class_ogre_1_1_focused_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,20,8],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,20,10],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,20,10],
-"class_ogre_1_1_focused_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,0,1,20,2],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,2,12,20,2],
-"class_ogre_1_1_focused_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,20,13],
+"class_ogre_1_1_focused_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,0,1,20,2],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,20,13],
+"class_ogre_1_1_focused_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,20,13],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,2,12,20,16],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,0,1,20,16],
-"class_ogre_1_1_focused_shadow_camera_setup.html#a75ffe6687f710f915d610777b1d15ecf":[5,2,12,20,5],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a75ffe6687f710f915d610777b1d15ecf":[5,0,1,20,5],
-"class_ogre_1_1_focused_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,20,6],
+"class_ogre_1_1_focused_shadow_camera_setup.html#a75ffe6687f710f915d610777b1d15ecf":[5,2,12,20,5],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,20,6],
-"class_ogre_1_1_focused_shadow_camera_setup.html#a8bee96cb5317cad79772e26a77ace1c4":[5,2,12,20,4],
+"class_ogre_1_1_focused_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,20,6],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a8bee96cb5317cad79772e26a77ace1c4":[5,0,1,20,4],
+"class_ogre_1_1_focused_shadow_camera_setup.html#a8bee96cb5317cad79772e26a77ace1c4":[5,2,12,20,4],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,20,9],
 "class_ogre_1_1_focused_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,20,9],
-"class_ogre_1_1_focused_shadow_camera_setup.html#aa37dc46bc1cc5a65359c66fdb539b74c":[5,2,12,20,1],
 "class_ogre_1_1_focused_shadow_camera_setup.html#aa37dc46bc1cc5a65359c66fdb539b74c":[5,0,1,20,1],
-"class_ogre_1_1_focused_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,20,12],
+"class_ogre_1_1_focused_shadow_camera_setup.html#aa37dc46bc1cc5a65359c66fdb539b74c":[5,2,12,20,1],
 "class_ogre_1_1_focused_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,20,12],
-"class_ogre_1_1_focused_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,20,7],
+"class_ogre_1_1_focused_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,20,12],
 "class_ogre_1_1_focused_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,20,7],
-"class_ogre_1_1_focused_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,20,11],
+"class_ogre_1_1_focused_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,20,7],
 "class_ogre_1_1_focused_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,20,11],
+"class_ogre_1_1_focused_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,20,11],
 "class_ogre_1_1_focused_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,2,12,20,3],
 "class_ogre_1_1_focused_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,0,1,20,3],
-"class_ogre_1_1_focused_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,0,1,20,14],
 "class_ogre_1_1_focused_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,2,12,20,14],
-"class_ogre_1_1_focused_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,20,15],
+"class_ogre_1_1_focused_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,0,1,20,14],
 "class_ogre_1_1_focused_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,20,15],
-"class_ogre_1_1_focused_shadow_camera_setup.html#af4fec2364b3404a7738e9b5ede0710e7":[5,2,12,20,0],
+"class_ogre_1_1_focused_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,20,15],
 "class_ogre_1_1_focused_shadow_camera_setup.html#af4fec2364b3404a7738e9b5ede0710e7":[5,0,1,20,0],
+"class_ogre_1_1_focused_shadow_camera_setup.html#af4fec2364b3404a7738e9b5ede0710e7":[5,2,12,20,0],
 "class_ogre_1_1_focused_shadow_camera_setup.html#af7283157442184a861fcd6947a63bf4d":[5,0,1,20,17],
 "class_ogre_1_1_focused_shadow_camera_setup.html#af7283157442184a861fcd6947a63bf4d":[5,2,12,20,17],
 "class_ogre_1_1_font.html":[5,2,11,39],
@@ -249,5 +189,65 @@ var NAVTREEINDEX84 =
 "class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7d":[5,2,11,39,7],
 "class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7da058c0eecb9f3f188fccc4d0018bf337b":[5,2,11,39,7,2],
 "class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7da218a4243be85ec9c989b777119d5ff47":[5,2,11,39,7,6],
-"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7da2b732a317de0915527e291485ca42e82":[5,2,11,39,7,0]
+"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7da2b732a317de0915527e291485ca42e82":[5,2,11,39,7,0],
+"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7da4f559ca1853a24a28b40caae1acda604":[5,2,11,39,7,7],
+"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7da55066351a26967068b944c2170e51af1":[5,2,11,39,7,3],
+"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7da58fd07194714679ed3ba9857d7656f27":[5,2,11,39,7,1],
+"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7da61729c4ae25807d6132d5bc46580ff3d":[5,2,11,39,7,4],
+"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7da704ea118c7e9f0b1598b528bdcbe1b26":[5,2,11,39,7,8],
+"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7dabb2a61a0002ccca6afbde7588787e58e":[5,2,11,39,7,11],
+"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7dad4d9c6e3b7755f38d8d5f003be100257":[5,2,11,39,7,10],
+"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7dae3eb70053cbf5401f22893cdb47f81a7":[5,2,11,39,7,9],
+"class_ogre_1_1_font.html#afe11bd546cf7315f4526488e7078cc7dafbdd85981846de4423d48d1a0ff665e0":[5,2,11,39,7,5],
+"class_ogre_1_1_font.html#aff75a40e8ca00a64f19c265e90c61733":[5,2,11,39,19],
+"class_ogre_1_1_font_manager.html":[5,2,11,40],
+"class_ogre_1_1_font_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[5,2,11,40,14],
+"class_ogre_1_1_font_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[5,2,11,40,25],
+"class_ogre_1_1_font_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[5,2,11,40,23],
+"class_ogre_1_1_font_manager.html#a117a3887bbf9e83e0585777beb0501dc":[5,2,11,40,4],
+"class_ogre_1_1_font_manager.html#a159ba6550b0c2731768db9df66472d19":[5,2,11,40,5],
+"class_ogre_1_1_font_manager.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,11,40,32],
+"class_ogre_1_1_font_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[5,2,11,40,56],
+"class_ogre_1_1_font_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[5,2,11,40,2],
+"class_ogre_1_1_font_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[5,2,11,40,1],
+"class_ogre_1_1_font_manager.html#a2cf457c70ea86892b1bec52028c96237":[5,2,11,40,54],
+"class_ogre_1_1_font_manager.html#a3f92489910e40e3756606a35618d7b06":[5,2,11,40,45],
+"class_ogre_1_1_font_manager.html#a40769092850d5b296e1d1a9190631700":[5,2,11,40,8],
+"class_ogre_1_1_font_manager.html#a42f172a8ed1625011d510b081eee66dd":[5,2,11,40,18],
+"class_ogre_1_1_font_manager.html#a48c565d0e63b286c6388439ae73417df":[5,2,11,40,11],
+"class_ogre_1_1_font_manager.html#a4d3289d4636168230da11c1c9794db59":[5,2,11,40,22],
+"class_ogre_1_1_font_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[5,2,11,40,44],
+"class_ogre_1_1_font_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[5,2,11,40,3],
+"class_ogre_1_1_font_manager.html#a54d1843a43aebb13542312cd17134e6a":[5,2,11,40,9],
+"class_ogre_1_1_font_manager.html#a57e22b305d763f9ede5bda93f31051ca":[5,2,11,40,24],
+"class_ogre_1_1_font_manager.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,11,40,34],
+"class_ogre_1_1_font_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,40,37],
+"class_ogre_1_1_font_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[5,2,11,40,21],
+"class_ogre_1_1_font_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[5,2,11,40,49],
+"class_ogre_1_1_font_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[5,2,11,40,48],
+"class_ogre_1_1_font_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[5,2,11,40,13],
+"class_ogre_1_1_font_manager.html#a7953d419aa5a23ed8c434c37065c4cc5":[5,2,11,40,26],
+"class_ogre_1_1_font_manager.html#a7b24e0e816f6ae3eb138413f94838ba5":[5,2,11,40,17],
+"class_ogre_1_1_font_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,11,40,30],
+"class_ogre_1_1_font_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[5,2,11,40,43],
+"class_ogre_1_1_font_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[5,2,11,40,57],
+"class_ogre_1_1_font_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,11,40,33],
+"class_ogre_1_1_font_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[5,2,11,40,55],
+"class_ogre_1_1_font_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[5,2,11,40,50],
+"class_ogre_1_1_font_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[5,2,11,40,20],
+"class_ogre_1_1_font_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[5,2,11,40,53],
+"class_ogre_1_1_font_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[5,2,11,40,52],
+"class_ogre_1_1_font_manager.html#aa8b761abb06d74347e9636550307ccd9":[5,2,11,40,15],
+"class_ogre_1_1_font_manager.html#aa9608544a7beb1b0e43835877ab62788":[5,2,11,40,42],
+"class_ogre_1_1_font_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[5,2,11,40,16],
+"class_ogre_1_1_font_manager.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,11,40,36],
+"class_ogre_1_1_font_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[5,2,11,40,59],
+"class_ogre_1_1_font_manager.html#abfb0022b18d022a7605f0d19a966f00f":[5,2,11,40,46],
+"class_ogre_1_1_font_manager.html#ac22655af03ecea85d863a1d1d561778c":[5,2,11,40,47],
+"class_ogre_1_1_font_manager.html#ac8f7ee61606730572a8590060d8896a0":[5,2,11,40,19],
+"class_ogre_1_1_font_manager.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,11,40,31],
+"class_ogre_1_1_font_manager.html#acd4223279e97a7687e2f9994f05e2491":[5,2,11,40,12],
+"class_ogre_1_1_font_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,11,40,35],
+"class_ogre_1_1_font_manager.html#ad6d63fe7126510bf10fd337705cb0b29":[5,2,11,40,29],
+"class_ogre_1_1_font_manager.html#ad75e17a4f44f40172e5b458e17d4e4bb":[5,2,11,40,10]
 };
