@@ -11,7 +11,7 @@ var indexSectionsWithContent =
   8: "abcdefghiklmnopqrstuvwz",
   9: "cdlnps",
   10: "abcdefghilmnoprstvw",
-  11: "_acdefghimnorstuvw",
+  11: "_acdefghimnoprstuvw",
   12: "acdegilmoprst",
   13: "abcdghilmoprstuw"
 };
