@@ -10,7 +10,7 @@ var searchData=
   ['reference_7',['reference',['../class_ogre_1_1_small_vector_template_common.html#acd7dfa3b3e065207cd1d9923c0d81745',1,'Ogre::SmallVectorTemplateCommon::reference()'],['../class_ogre_1_1_hashed_vector.html#a3ad011d104e03019a4e9b9840439ef17',1,'Ogre::HashedVector::reference()'],['../class_ogre_1_1_s_t_l_allocator.html#a5d26e2252c837f0620a51c075aeb6d56',1,'Ogre::STLAllocator::reference()']]],
   ['regioniterator_8',['RegionIterator',['../class_ogre_1_1v1_1_1_static_geometry.html#a150067d7674a4d4f37bc2df8e9048847',1,'Ogre::v1::StaticGeometry']]],
   ['regionmap_9',['RegionMap',['../class_ogre_1_1v1_1_1_static_geometry.html#ad3a97be855e9973f75a3a0ae22af56fc',1,'Ogre::v1::StaticGeometry']]],
-  ['renderablearray_10',['RenderableArray',['../group___material.html#gac2456530a54d76fba2d659954fc243c9',1,'Ogre']]],
+  ['renderablearray_10',['RenderableArray',['../group___scene.html#gac2456530a54d76fba2d659954fc243c9',1,'Ogre']]],
   ['renderqueuealloc_11',['RenderQueueAlloc',['../namespace_ogre.html#ab5b177f3272759202a585928bcd3906f',1,'Ogre']]],
   ['renderstateconstiterator_12',['RenderStateConstIterator',['../group___r_t_shader.html#ga9b53abaeb85c8e817dafe314bf1ef7e8',1,'Ogre::RTShader']]],
   ['renderstatecreateorretrieveresult_13',['RenderStateCreateOrRetrieveResult',['../class_ogre_1_1_r_t_shader_1_1_shader_generator.html#ac7eb87c69e1a22e1ad0c0c4a3a9dded1',1,'Ogre::RTShader::ShaderGenerator']]],
