@@ -36,6 +36,6 @@ var searchData=
   ['trianglefacenormallist_33',['TriangleFaceNormalList',['../class_ogre_1_1v1_1_1_edge_data.html#a9cab4a6f07b3e3ae5042bdaedf9b5c58',1,'Ogre::v1::EdgeData']]],
   ['trianglei_34',['TriangleI',['../struct_ogre_1_1_lod_data.html#aab369c84f01f678f4a8d44ae6aab63c9',1,'Ogre::LodData']]],
   ['trianglelightfacinglist_35',['TriangleLightFacingList',['../class_ogre_1_1v1_1_1_edge_data.html#a2b1d687ea4871ee5ad09891a6173e321',1,'Ogre::v1::EdgeData']]],
-  ['trianglelist_36',['TriangleList',['../class_ogre_1_1v1_1_1_edge_data.html#a45723039bb49600179299233d4306224',1,'Ogre::v1::EdgeData::TriangleList()'],['../struct_ogre_1_1_lod_data.html#a5348da65897ff8c17af1ada6f3d1be3f',1,'Ogre::LodData::TriangleList()']]],
+  ['trianglelist_36',['TriangleList',['../struct_ogre_1_1_lod_data.html#a5348da65897ff8c17af1ada6f3d1be3f',1,'Ogre::LodData::TriangleList()'],['../class_ogre_1_1v1_1_1_edge_data.html#a45723039bb49600179299233d4306224',1,'Ogre::v1::EdgeData::TriangleList()']]],
   ['type_37',['Type',['../class_ogre_1_1_com_ptr.html#acea4812003c2493f333bd710a077a32a',1,'Ogre::ComPtr']]]
 ];
