@@ -16,6 +16,10 @@ var searchData=
   ['indextoindexmap_13',['IndexToIndexMap',['../class_ogre_1_1_skeleton_def.html#abf9ea336c65d99dff6a3bb4f468e27bb',1,'Ogre::SkeletonDef']]],
   ['indextype_14',['IndexType',['../class_ogre_1_1_index_buffer_packed.html#ac7b56d6119f781930a33d74b2437c0d0',1,'Ogre::IndexBufferPacked::IndexType()'],['../class_ogre_1_1v1_1_1_hardware_index_buffer.html#a06f21d817782a7f95017e59581b9ddb5',1,'Ogre::v1::HardwareIndexBuffer::IndexType()']]],
   ['instances_15',['Instances',['../class_ogre_1_1_scene_manager_enumerator.html#a5e6ba67f2bf741283f459ed954772926',1,'Ogre::SceneManagerEnumerator']]],
-  ['intconstantlist_16',['IntConstantList',['../group___materials.html#ga0f6f75258759920f3879eb1b4b590121',1,'Ogre']]],
-  ['iterator_17',['iterator',['../class_ogre_1_1_stack_vector.html#a0e662834e1e17fc32d303de5db2f3dc0',1,'Ogre::StackVector::iterator()'],['../class_ogre_1_1_small_vector_impl.html#a9a1d14b49afc3807af68fd5f2ef6238c',1,'Ogre::SmallVectorImpl::iterator()'],['../class_ogre_1_1_small_vector_template_common.html#ad3aa63daaa8c3754f1e8be544cb617ae',1,'Ogre::SmallVectorTemplateCommon::iterator()'],['../class_ogre_1_1_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e',1,'Ogre::IteratorWrapper::iterator()'],['../class_ogre_1_1_fast_array.html#aa55de250022241d6682e83982e901cd9',1,'Ogre::FastArray::iterator()'],['../class_ogre_1_1_hashed_vector.html#a9e1f2a609eb5a7be9cc3d51b49f755df',1,'Ogre::HashedVector::iterator()'],['../struct_ogre_1_1_vector_set.html#a54ecab062478a2bbf5688744685acbeb',1,'Ogre::VectorSet::iterator()']]]
+  ['int16_16',['int16',['../namespace_ogre.html#a5c8843f6e8086a9239fed14de8b9d859',1,'Ogre']]],
+  ['int32_17',['int32',['../namespace_ogre.html#a1c37a43c04753c9ae0c17108c9e6c9d2',1,'Ogre']]],
+  ['int64_18',['int64',['../namespace_ogre.html#a0d87d229c909a3a971c1b2cea5dc1f8f',1,'Ogre']]],
+  ['int8_19',['int8',['../namespace_ogre.html#acad7c05003308f9b9be289faab5879f9',1,'Ogre']]],
+  ['intconstantlist_20',['IntConstantList',['../group___materials.html#ga0f6f75258759920f3879eb1b4b590121',1,'Ogre']]],
+  ['iterator_21',['iterator',['../struct_ogre_1_1_vector_set.html#a54ecab062478a2bbf5688744685acbeb',1,'Ogre::VectorSet::iterator()'],['../class_ogre_1_1_stack_vector.html#a0e662834e1e17fc32d303de5db2f3dc0',1,'Ogre::StackVector::iterator()'],['../class_ogre_1_1_small_vector_impl.html#a9a1d14b49afc3807af68fd5f2ef6238c',1,'Ogre::SmallVectorImpl::iterator()'],['../class_ogre_1_1_small_vector_template_common.html#ad3aa63daaa8c3754f1e8be544cb617ae',1,'Ogre::SmallVectorTemplateCommon::iterator()'],['../class_ogre_1_1_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e',1,'Ogre::IteratorWrapper::iterator()'],['../class_ogre_1_1_fast_array.html#aa55de250022241d6682e83982e901cd9',1,'Ogre::FastArray::iterator()'],['../class_ogre_1_1_hashed_vector.html#a9e1f2a609eb5a7be9cc3d51b49f755df',1,'Ogre::HashedVector::iterator()']]]
 ];
