@@ -22,7 +22,7 @@ var searchData=
   ['refreshrate_19',['RefreshRate',['../struct_d_x_g_i___s_w_a_p___c_h_a_i_n___f_u_l_l_s_c_r_e_e_n___d_e_s_c.html#abc2879bd4b21de67a4e0d06929aad9e0',1,'DXGI_SWAP_CHAIN_FULLSCREEN_DESC']]],
   ['release_20',['release',['../struct_ogre_1_1_driver_version.html#ae682f3bab912af152cb3f6e8497815f6',1,'Ogre::DriverVersion']]],
   ['rendareblehlmstypemask_21',['RendarebleHlmsTypeMask',['../struct_ogre_1_1_hlms_bits.html#aa95210cbd33619cba7e5b8b22fb291f5',1,'Ogre::HlmsBits']]],
-  ['renderable_22',['renderable',['../struct_ogre_1_1_queued_renderable.html#ad63644d36969a4f90efc8b88ec394518',1,'Ogre::QueuedRenderable::renderable()'],['../struct_ogre_1_1_cb_low_level_material.html#ac4e234229befb3dec94304c13e74e6a5',1,'Ogre::CbLowLevelMaterial::renderable()'],['../struct_ogre_1_1_planar_reflections_1_1_tracked_renderable.html#a9523732d7c8f78aad197574563f22ba6',1,'Ogre::PlanarReflections::TrackedRenderable::renderable()']]],
+  ['renderable_22',['renderable',['../struct_ogre_1_1_planar_reflections_1_1_tracked_renderable.html#a9523732d7c8f78aad197574563f22ba6',1,'Ogre::PlanarReflections::TrackedRenderable::renderable()'],['../struct_ogre_1_1_queued_renderable.html#ad63644d36969a4f90efc8b88ec394518',1,'Ogre::QueuedRenderable::renderable()'],['../struct_ogre_1_1_cb_low_level_material.html#ac4e234229befb3dec94304c13e74e6a5',1,'Ogre::CbLowLevelMaterial::renderable()']]],
   ['renderablebits_23',['RenderableBits',['../struct_ogre_1_1_hlms_bits.html#a7c4a502448a66c6373a8763b49a12980',1,'Ogre::HlmsBits']]],
   ['renderablecache_24',['renderableCache',['../struct_ogre_1_1_hlms_disk_cache_1_1_pso.html#ab474d42949e1800fb64e0b3ab378de75',1,'Ogre::HlmsDiskCache::Pso']]],
   ['renderablecenter_25',['renderableCenter',['../struct_ogre_1_1_planar_reflections_1_1_tracked_renderable.html#a557d8b10d227e322a55e19c534d0dbf9',1,'Ogre::PlanarReflections::TrackedRenderable']]],
@@ -39,7 +39,7 @@ var searchData=
   ['requestedlod_36',['requestedLod',['../struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html#aef02279bce06791298afaf3defc002b6',1,'Ogre::TerrainLodManager::LoadLodRequest']]],
   ['requestee_37',['requestee',['../struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html#afa635e167e34d5bc7a75602205410928',1,'Ogre::TerrainLodManager::LoadLodRequest']]],
   ['reserved_5fvisibility_5fflags_38',['RESERVED_VISIBILITY_FLAGS',['../namespace_ogre_1_1_visibility_flags.html#a7726a5ff6639016d642e056532a62eee',1,'Ogre::VisibilityFlags']]],
-  ['resolution_39',['resolution',['../struct_ogre_1_1_shadow_node_helper_1_1_shadow_param.html#a3c998daa711709215e80cca254bc09b0',1,'Ogre::ShadowNodeHelper::ShadowParam::resolution()'],['../struct_ogre_1_1_vct_cascade_setting.html#a8f406fa8d63afdfb14826e962a8480d2',1,'Ogre::VctCascadeSetting::resolution()'],['../struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html#a872db0ab4ff69396406a84eedf7f194a',1,'Ogre::TerrainLodManager::LodInfo::resolution()']]],
+  ['resolution_39',['resolution',['../struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html#a872db0ab4ff69396406a84eedf7f194a',1,'Ogre::TerrainLodManager::LodInfo::resolution()'],['../struct_ogre_1_1_shadow_node_helper_1_1_shadow_param.html#a3c998daa711709215e80cca254bc09b0',1,'Ogre::ShadowNodeHelper::ShadowParam::resolution()'],['../struct_ogre_1_1_vct_cascade_setting.html#a8f406fa8d63afdfb14826e962a8480d2',1,'Ogre::VctCascadeSetting::resolution()']]],
   ['resolvecolourformat_40',['resolveColourFormat',['../struct_ogre_1_1_hlms_pass_pso.html#a0eb4945bc9aa5f3a9b83bfcf1a758ae9',1,'Ogre::HlmsPassPso']]],
   ['resolvemiplevel_41',['resolveMipLevel',['../struct_ogre_1_1_render_target_view_entry.html#af49bb9dc39760c1624c994814b494560',1,'Ogre::RenderTargetViewEntry::resolveMipLevel()'],['../struct_ogre_1_1_render_pass_target_base.html#ae35b43bd7e138d99619208000d54f802',1,'Ogre::RenderPassTargetBase::resolveMipLevel()']]],
   ['resolveslice_42',['resolveSlice',['../struct_ogre_1_1_render_pass_target_base.html#af25253ac5a6aefe92b365c2468c58898',1,'Ogre::RenderPassTargetBase::resolveSlice()'],['../struct_ogre_1_1_render_target_view_entry.html#a22ece6c6b82c34306bef2a5e2875b590',1,'Ogre::RenderTargetViewEntry::resolveSlice()']]],
